"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_id-ID_send-feedback_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/id-ID/send-feedback.json":
/*!****************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/id-ID/send-feedback.json ***!
  \****************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"dialog":{"title":"Bagikan masukan Anda","fieldTitlePlaceholder":"Judul","fieldDescriptionPlaceholder":"Beritahu kami apa yang Anda pikirkan","fieldSubjectPlaceholder":"Pilih subjek masukan Anda","fieldProductPlaceholder":"Pilih produk","note":"Kami menghargai masukan Anda! Meskipun kami meninjau semua kiriman, kami tidak dapat menjamin bahwa setiap saran akan menghasilkan perubahan atau pembaruan.","subjects":{"leaveFeedback":"Berikan masukan","reportBug":"Laporkan bug","requestFeature":"Minta fitur","shareThoughts":"Bagikan pemikiran lain"},"products":{"general":"Umum","editor":"Editor","accessibility":"Aksesibilitas","imageOptimization":"Optimasi gambar","emailDeliverability":"Keterkiriman email","siteManagement":"Site Management"},"cancel":"Batal","submit":"Kirim","titleLengthError":"Judul harus kurang dari 90 karakter","descriptionLengthError":"Deskripsi harus kurang dari 1024 karakter","alert":{"title":"Butuh bantuan atau mengalami masalah?","button":"Kirim tiket dukungan"}},"tooltipSuccess":"Masukan terkirim. Terima kasih telah membantu kami.","tooltipError":"Terjadi kesalahan. Silakan coba kirim masukan Anda lagi."}');

/***/ })

}]);