"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_id-ID_common_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/id-ID/common.json":
/*!*********************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/id-ID/common.json ***!
  \*********************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"example":{"component":"Komponen Contoh"}}');

/***/ })

}]);