"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_de_common_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/de/common.json":
/*!******************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/de/common.json ***!
  \******************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"example":{"component":"Beispielkomponente"},"header":{"title":"Website-Builder","userInfo":"Mein Konto","userProfileMenu":{"connectPreText":"Haben Sie einen Elementor-One-Tarif?","connect":"Verbinden","goToMyAccount":"Zu meinem Konto","disconnect":"Trennen","elementorOneActive":"Elementor One","active":"Aktiv","urlMismatch":"URL stimmt nicht überein","fixUrlMismatch":"Jetzt beheben"},"whatsNew":"Neuigkeiten","whatsNewError":"Beim Abruf der Benachrichtigungen ist etwas schiefgelaufen. Bitte versuchen Sie es später erneut."}}');

/***/ })

}]);