"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_pl-PL_common_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/pl-PL/common.json":
/*!*********************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/pl-PL/common.json ***!
  \*********************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"example":{"component":"Przykładowy komponent"}}');

/***/ })

}]);