"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_fr_send-feedback_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/fr/send-feedback.json":
/*!*************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/fr/send-feedback.json ***!
  \*************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"dialog":{"title":"Partagez vos commentaires","fieldTitlePlaceholder":"Titre","fieldDescriptionPlaceholder":"Dites-nous ce que vous aviez en tête","fieldSubjectPlaceholder":"Sélectionnez le sujet de vos commentaires","fieldProductPlaceholder":"Sélectionner le produit","note":"Nous apprécions vos commentaires ! Bien que nous examinions toutes les soumissions, nous ne pouvons pas garantir que chaque suggestion entraînera un changement ou une mise à jour.","subjects":{"leaveFeedback":"Laisser un commentaire","reportBug":"Signaler un bug","requestFeature":"Demander une fonctionnalité","shareThoughts":"Partager d’autres réflexions"},"products":{"general":"Général","editor":"Éditeur","accessibility":"Accessibilité","imageOptimization":"Optimisation des images","emailDeliverability":"Délivrabilité des e-mails","siteManagement":"Site Management"},"cancel":"Annuler","submit":"Envoyer","titleLengthError":"Le titre doit contenir moins de 90 caractères","descriptionLengthError":"La description doit contenir moins de 1024 caractères","alert":{"title":"Besoin d\'aide ou rencontré un problème ?","button":"Envoyer un ticket d\'assistance"}},"tooltipSuccess":"Commentaires envoyés. Merci de nous avoir aidés.","tooltipError":"Une erreur s\'est produite. Veuillez réessayer d\'envoyer vos commentaires."}');

/***/ })

}]);