"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_it_common_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/it/common.json":
/*!******************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/it/common.json ***!
  \******************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"example":{"component":"Componente di esempio"},"header":{"title":"costruttore di siti web","userInfo":"Il mio conto","userProfileMenu":{"connectPreText":"Hai un piano Elementor One?","connect":"Collegare","goToMyAccount":"Vai a Il mio account","disconnect":"Disconnetti","elementorOneActive":"Elementore Uno","active":"Attivo","urlMismatch":"Rilevata mancata corrispondenza dell\'URL","fixUrlMismatch":"Risolvilo adesso"},"whatsNew":"Cosa c\'è di nuovo","whatsNewError":"Qualcosa è andato storto durante il recupero delle notifiche. Per favore riprova più tardi."}}');

/***/ })

}]);