/******/ (() => { // webpackBootstrap
/******/ 	var __webpack_modules__ = ({

/***/ "../assets/dev/js/utils/react.js":
/*!***************************************!*\
  !*** ../assets/dev/js/utils/react.js ***!
  \***************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _typeof = __webpack_require__(/*! @babel/runtime/helpers/typeof */ "../node_modules/@babel/runtime/helpers/typeof.js");
Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;
var React = _interopRequireWildcard(__webpack_require__(/*! react */ "react"));
var ReactDOM = _interopRequireWildcard(__webpack_require__(/*! react-dom */ "react-dom"));
var _client = __webpack_require__(/*! react-dom/client */ "../node_modules/react-dom/client.js");
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != _typeof(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); return f; })(e, t); }
/**
 * Support conditional rendering of a React App to the DOM, based on the React version.
 * We use `createRoot` when available, but fallback to `ReactDOM.render` for older versions.
 *
 * @param { React.ReactElement } app        The app to render.
 * @param { HTMLElement }        domElement The DOM element to render the app into.
 *
 * @return {{ unmount: () => void }} The unmount function.
 */
function render(app, domElement) {
  var unmountFunction;
  try {
    var root = (0, _client.createRoot)(domElement);
    root.render(app);
    unmountFunction = function unmountFunction() {
      root.unmount();
    };
  } catch (e) {
    // eslint-disable-next-line react/no-deprecated
    ReactDOM.render(app, domElement);
    unmountFunction = function unmountFunction() {
      // eslint-disable-next-line react/no-deprecated
      ReactDOM.unmountComponentAtNode(domElement);
    };
  }
  return {
    unmount: unmountFunction
  };
}
var _default = exports["default"] = {
  render: render
};

/***/ }),

/***/ "../modules/editor-one/assets/js/shared/is-rtl.js":
/*!********************************************************!*\
  !*** ../modules/editor-one/assets/js/shared/is-rtl.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = isRTL;
function isRTL() {
  var _elementorCommon$conf, _elementorCommon;
  return (_elementorCommon$conf = (_elementorCommon = elementorCommon) === null || _elementorCommon === void 0 || (_elementorCommon = _elementorCommon.config) === null || _elementorCommon === void 0 ? void 0 : _elementorCommon.isRTL) !== null && _elementorCommon$conf !== void 0 ? _elementorCommon$conf : false;
}

/***/ }),

/***/ "../modules/editor-one/assets/js/sidebar-navigation/components/hooks/use-admin-menu-offset.js":
/*!****************************************************************************************************!*\
  !*** ../modules/editor-one/assets/js/sidebar-navigation/components/hooks/use-admin-menu-offset.js ***!
  \****************************************************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "../node_modules/@babel/runtime/helpers/interopRequireDefault.js");
Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.useAdminMenuOffset = void 0;
var _element = __webpack_require__(/*! @wordpress/element */ "../node_modules/@wordpress/element/build-module/index.js");
var _isRtl = _interopRequireDefault(__webpack_require__(/*! ../../../shared/is-rtl */ "../modules/editor-one/assets/js/shared/is-rtl.js"));
var ADMIN_MENU_WRAP_ID = 'adminmenuwrap';
var WPCONTENT_ID = 'wpcontent';
var EDITOR_ONE_TOP_BAR_ID = 'editor-one-top-bar';
var WPADMINBAR_ID = 'wpadminbar';
var INITIALIZED_DATA_ATTR = 'data-editor-one-offset-initialized';
var WPFOOTER_ID = 'wpfooter';
var WPBODY_CONTENT_ID = 'wpbody-content';
var useAdminMenuOffset = exports.useAdminMenuOffset = function useAdminMenuOffset() {
  var cleanupRef = (0, _element.useRef)(null);
  (0, _element.useEffect)(function () {
    var adminMenuWrap = document.getElementById(ADMIN_MENU_WRAP_ID);
    var wpcontent = document.getElementById(WPCONTENT_ID);
    if (!adminMenuWrap || !wpcontent || wpcontent.hasAttribute(INITIALIZED_DATA_ATTR)) {
      return;
    }
    var wpfooter = document.getElementById(WPFOOTER_ID);
    var wpbodyContent = document.getElementById(WPBODY_CONTENT_ID);
    wpbodyContent === null || wpbodyContent === void 0 || wpbodyContent.insertBefore(wpfooter, wpbodyContent.querySelector(':scope > .clear'));
    var wpAdminBar = document.getElementById(WPADMINBAR_ID);
    var updateOffset = function updateOffset() {
      var _document$getElementB, _wpAdminBar$clientHei, _topBarHeader$clientH;
      var topBarHeader = (_document$getElementB = document.getElementById(EDITOR_ONE_TOP_BAR_ID)) === null || _document$getElementB === void 0 ? void 0 : _document$getElementB.querySelector(':scope > header');
      var isRtlLanguage = (0, _isRtl.default)();
      var rect = adminMenuWrap.getBoundingClientRect();
      var offset = isRtlLanguage ? document.documentElement.clientWidth - rect.left : rect.right;
      var adminBarHeightPx = "".concat((_wpAdminBar$clientHei = wpAdminBar === null || wpAdminBar === void 0 ? void 0 : wpAdminBar.clientHeight) !== null && _wpAdminBar$clientHei !== void 0 ? _wpAdminBar$clientHei : 0, "px");
      var topBarHeaderHeightPx = "".concat((_topBarHeader$clientH = topBarHeader === null || topBarHeader === void 0 ? void 0 : topBarHeader.clientHeight) !== null && _topBarHeader$clientH !== void 0 ? _topBarHeader$clientH : 0, "px");
      wpcontent.style.setProperty('--editor-one-sidebar-left-offset', "".concat(offset, "px"));
      wpcontent.style.setProperty('--e-admin-bar-height', adminBarHeightPx);
      wpcontent.style.setProperty('--e-top-bar-header-height', topBarHeaderHeightPx);
    };
    updateOffset();
    var resizeObserver = new ResizeObserver(updateOffset);
    resizeObserver.observe(wpcontent);
    var topBar = document.getElementById(EDITOR_ONE_TOP_BAR_ID);
    if (topBar) {
      resizeObserver.observe(topBar);
    }
    window.addEventListener('resize', updateOffset);
    wpcontent.setAttribute(INITIALIZED_DATA_ATTR, 'true');
    cleanupRef.current = function () {
      resizeObserver.disconnect();
      window.removeEventListener('resize', updateOffset);
      wpcontent.removeAttribute(INITIALIZED_DATA_ATTR);
    };
    return function () {
      if (cleanupRef.current) {
        cleanupRef.current();
        cleanupRef.current = null;
      }
    };
  }, []);
};

/***/ }),

/***/ "../node_modules/@babel/runtime/helpers/interopRequireDefault.js":
/*!***********************************************************************!*\
  !*** ../node_modules/@babel/runtime/helpers/interopRequireDefault.js ***!
  \***********************************************************************/
/***/ ((module) => {

function _interopRequireDefault(e) {
  return e && e.__esModule ? e : {
    "default": e
  };
}
module.exports = _interopRequireDefault, module.exports.__esModule = true, module.exports["default"] = module.exports;

/***/ }),

/***/ "../node_modules/@babel/runtime/helpers/typeof.js":
/*!********************************************************!*\
  !*** ../node_modules/@babel/runtime/helpers/typeof.js ***!
  \********************************************************/
/***/ ((module) => {

function _typeof(o) {
  "@babel/helpers - typeof";

  return module.exports = _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) {
    return typeof o;
  } : function (o) {
    return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o;
  }, module.exports.__esModule = true, module.exports["default"] = module.exports, _typeof(o);
}
module.exports = _typeof, module.exports.__esModule = true, module.exports["default"] = module.exports;

/***/ }),

/***/ "../node_modules/@elementor/elementor-one-assets/index.cjs.js":
/*!********************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/index.cjs.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";
Object.defineProperty(exports,Symbol.toStringTag,{value:"Module"});const e=__webpack_require__(/*! react/jsx-runtime */ "../node_modules/react/jsx-runtime.js"),t=__webpack_require__(/*! react */ "react"),r=__webpack_require__(/*! react-dom */ "react-dom");function n(e){const t=Object.create(null,{[Symbol.toStringTag]:{value:"Module"}});if(e)for(const r in e)if("default"!==r){const n=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(t,r,n.get?n:{enumerable:!0,get:()=>e[r]})}return t.default=e,Object.freeze(t)}const o=n(t),i=n(r);function s(e,t){if(null==e)return{};var r={};for(var n in e)if({}.hasOwnProperty.call(e,n)){if(-1!==t.indexOf(n))continue;r[n]=e[n]}return r}function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)({}).hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},a.apply(null,arguments)}function l(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}function c(e){if(Object.prototype.hasOwnProperty.call(e,"__esModule"))return e;var t=e.default;if("function"==typeof t){var r=function e(){var r=!1;try{r=this instanceof e}catch{}return r?Reflect.construct(t,arguments,this.constructor):t.apply(this,arguments)};r.prototype=t.prototype}else r={};return Object.defineProperty(r,"__esModule",{value:!0}),Object.keys(e).forEach(function(t){var n=Object.getOwnPropertyDescriptor(e,t);Object.defineProperty(r,t,n.get?n:{enumerable:!0,get:function(){return e[t]}})}),r}var u,p={exports:{}},d={exports:{}},f={};function h(){if(u)return f;u=1;var e="function"==typeof Symbol&&Symbol.for,t=e?Symbol.for("react.element"):60103,r=e?Symbol.for("react.portal"):60106,n=e?Symbol.for("react.fragment"):60107,o=e?Symbol.for("react.strict_mode"):60108,i=e?Symbol.for("react.profiler"):60114,s=e?Symbol.for("react.provider"):60109,a=e?Symbol.for("react.context"):60110,l=e?Symbol.for("react.async_mode"):60111,c=e?Symbol.for("react.concurrent_mode"):60111,p=e?Symbol.for("react.forward_ref"):60112,d=e?Symbol.for("react.suspense"):60113,h=e?Symbol.for("react.suspense_list"):60120,m=e?Symbol.for("react.memo"):60115,g=e?Symbol.for("react.lazy"):60116,v=e?Symbol.for("react.block"):60121,y=e?Symbol.for("react.fundamental"):60117,b=e?Symbol.for("react.responder"):60118,w=e?Symbol.for("react.scope"):60119;function x(e){if("object"==typeof e&&null!==e){var u=e.$$typeof;switch(u){case t:switch(e=e.type){case l:case c:case n:case i:case o:case d:return e;default:switch(e=e&&e.$$typeof){case a:case p:case g:case m:case s:return e;default:return u}}case r:return u}}}function _(e){return x(e)===c}return f.AsyncMode=l,f.ConcurrentMode=c,f.ContextConsumer=a,f.ContextProvider=s,f.Element=t,f.ForwardRef=p,f.Fragment=n,f.Lazy=g,f.Memo=m,f.Portal=r,f.Profiler=i,f.StrictMode=o,f.Suspense=d,f.isAsyncMode=function(e){return _(e)||x(e)===l},f.isConcurrentMode=_,f.isContextConsumer=function(e){return x(e)===a},f.isContextProvider=function(e){return x(e)===s},f.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===t},f.isForwardRef=function(e){return x(e)===p},f.isFragment=function(e){return x(e)===n},f.isLazy=function(e){return x(e)===g},f.isMemo=function(e){return x(e)===m},f.isPortal=function(e){return x(e)===r},f.isProfiler=function(e){return x(e)===i},f.isStrictMode=function(e){return x(e)===o},f.isSuspense=function(e){return x(e)===d},f.isValidElementType=function(e){return"string"==typeof e||"function"==typeof e||e===n||e===c||e===i||e===o||e===d||e===h||"object"==typeof e&&null!==e&&(e.$$typeof===g||e.$$typeof===m||e.$$typeof===s||e.$$typeof===a||e.$$typeof===p||e.$$typeof===y||e.$$typeof===b||e.$$typeof===w||e.$$typeof===v)},f.typeOf=x,f}var m,g,v,y,b,w,x,_,S,k,C,O,E,T,R,I={};function M(){return m||(m=1, true&&function(){var e="function"==typeof Symbol&&Symbol.for,t=e?Symbol.for("react.element"):60103,r=e?Symbol.for("react.portal"):60106,n=e?Symbol.for("react.fragment"):60107,o=e?Symbol.for("react.strict_mode"):60108,i=e?Symbol.for("react.profiler"):60114,s=e?Symbol.for("react.provider"):60109,a=e?Symbol.for("react.context"):60110,l=e?Symbol.for("react.async_mode"):60111,c=e?Symbol.for("react.concurrent_mode"):60111,u=e?Symbol.for("react.forward_ref"):60112,p=e?Symbol.for("react.suspense"):60113,d=e?Symbol.for("react.suspense_list"):60120,f=e?Symbol.for("react.memo"):60115,h=e?Symbol.for("react.lazy"):60116,m=e?Symbol.for("react.block"):60121,g=e?Symbol.for("react.fundamental"):60117,v=e?Symbol.for("react.responder"):60118,y=e?Symbol.for("react.scope"):60119;function b(e){if("object"==typeof e&&null!==e){var d=e.$$typeof;switch(d){case t:var m=e.type;switch(m){case l:case c:case n:case i:case o:case p:return m;default:var g=m&&m.$$typeof;switch(g){case a:case u:case h:case f:case s:return g;default:return d}}case r:return d}}}var w=l,x=c,_=a,S=s,k=t,C=u,O=n,E=h,T=f,R=r,M=i,A=o,P=p,N=!1;function j(e){return b(e)===c}I.AsyncMode=w,I.ConcurrentMode=x,I.ContextConsumer=_,I.ContextProvider=S,I.Element=k,I.ForwardRef=C,I.Fragment=O,I.Lazy=E,I.Memo=T,I.Portal=R,I.Profiler=M,I.StrictMode=A,I.Suspense=P,I.isAsyncMode=function(e){return N||(N=!0,console.warn("The ReactIs.isAsyncMode() alias has been deprecated, and will be removed in React 17+. Update your code to use ReactIs.isConcurrentMode() instead. It has the exact same API.")),j(e)||b(e)===l},I.isConcurrentMode=j,I.isContextConsumer=function(e){return b(e)===a},I.isContextProvider=function(e){return b(e)===s},I.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===t},I.isForwardRef=function(e){return b(e)===u},I.isFragment=function(e){return b(e)===n},I.isLazy=function(e){return b(e)===h},I.isMemo=function(e){return b(e)===f},I.isPortal=function(e){return b(e)===r},I.isProfiler=function(e){return b(e)===i},I.isStrictMode=function(e){return b(e)===o},I.isSuspense=function(e){return b(e)===p},I.isValidElementType=function(e){return"string"==typeof e||"function"==typeof e||e===n||e===c||e===i||e===o||e===p||e===d||"object"==typeof e&&null!==e&&(e.$$typeof===h||e.$$typeof===f||e.$$typeof===s||e.$$typeof===a||e.$$typeof===u||e.$$typeof===g||e.$$typeof===v||e.$$typeof===y||e.$$typeof===m)},I.typeOf=b}()),I}function A(){return g||(g=1, false?0:d.exports=M()),d.exports}function P(){if(y)return v;y=1;var e=Object.getOwnPropertySymbols,t=Object.prototype.hasOwnProperty,r=Object.prototype.propertyIsEnumerable;return v=function(){try{if(!Object.assign)return!1;var e=new String("abc");if(e[5]="de","5"===Object.getOwnPropertyNames(e)[0])return!1;for(var t={},r=0;r<10;r++)t["_"+String.fromCharCode(r)]=r;var n=Object.getOwnPropertyNames(t).map(function(e){return t[e]});if("0123456789"!==n.join(""))return!1;var o={};return"abcdefghijklmnopqrst".split("").forEach(function(e){o[e]=e}),"abcdefghijklmnopqrst"===Object.keys(Object.assign({},o)).join("")}catch(e){return!1}}()?Object.assign:function(n,o){for(var i,s,a=function(e){if(null==e)throw new TypeError("Object.assign cannot be called with null or undefined");return Object(e)}(n),l=1;l<arguments.length;l++){for(var c in i=Object(arguments[l]))t.call(i,c)&&(a[c]=i[c]);if(e){s=e(i);for(var u=0;u<s.length;u++)r.call(i,s[u])&&(a[s[u]]=i[s[u]])}}return a},v}function N(){return w?b:(w=1,b="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED")}function j(){return _?x:(_=1,x=Function.call.bind(Object.prototype.hasOwnProperty))}function L(){if(k)return S;k=1;var e=function(){};if(true){var t=N(),r={},n=j();e=function(e){var t="Warning: "+e;"undefined"!=typeof console&&console.error(t);try{throw new Error(t)}catch(e){}}}function o(o,i,s,a,l){if(true)for(var c in o)if(n(o,c)){var u;try{if("function"!=typeof o[c]){var p=Error((a||"React class")+": "+s+" type `"+c+"` is invalid; it must be a function, usually from the `prop-types` package, but received `"+typeof o[c]+"`.This often happens because of typos such as `PropTypes.function` instead of `PropTypes.func`.");throw p.name="Invariant Violation",p}u=o[c](i,c,a,s,null,t)}catch(e){u=e}if(!u||u instanceof Error||e((a||"React class")+": type specification of "+s+" `"+c+"` is invalid; the type checker function must return `null` or an `Error` but returned a "+typeof u+". You may have forgotten to pass an argument to the type checker creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and shape all require an argument)."),u instanceof Error&&!(u.message in r)){r[u.message]=!0;var d=l?l():"";e("Failed "+s+" type: "+u.message+(null!=d?d:""))}}}return o.resetWarningCache=function(){ true&&(r={})},S=o}function D(){if(O)return C;O=1;var e=A(),t=P(),r=N(),n=j(),o=L(),i=function(){};function s(){return null}return true&&(i=function(e){var t="Warning: "+e;"undefined"!=typeof console&&console.error(t);try{throw new Error(t)}catch(e){}}),C=function(a,l){var c="function"==typeof Symbol&&Symbol.iterator,u="<<anonymous>>",p={array:m("array"),bigint:m("bigint"),bool:m("boolean"),func:m("function"),number:m("number"),object:m("object"),string:m("string"),symbol:m("symbol"),any:h(s),arrayOf:function(e){return h(function(t,n,o,i,s){if("function"!=typeof e)return new f("Property `"+s+"` of component `"+o+"` has invalid PropType notation inside arrayOf.");var a=t[n];if(!Array.isArray(a))return new f("Invalid "+i+" `"+s+"` of type `"+y(a)+"` supplied to `"+o+"`, expected an array.");for(var l=0;l<a.length;l++){var c=e(a,l,o,i,s+"["+l+"]",r);if(c instanceof Error)return c}return null})},element:h(function(e,t,r,n,o){var i=e[t];return a(i)?null:new f("Invalid "+n+" `"+o+"` of type `"+y(i)+"` supplied to `"+r+"`, expected a single ReactElement.")}),elementType:h(function(t,r,n,o,i){var s=t[r];return e.isValidElementType(s)?null:new f("Invalid "+o+" `"+i+"` of type `"+y(s)+"` supplied to `"+n+"`, expected a single ReactElement type.")}),instanceOf:function(e){return h(function(t,r,n,o,i){if(!(t[r]instanceof e)){var s=e.name||u;return new f("Invalid "+o+" `"+i+"` of type `"+((a=t[r]).constructor&&a.constructor.name?a.constructor.name:u)+"` supplied to `"+n+"`, expected instance of `"+s+"`.")}var a;return null})},node:h(function(e,t,r,n,o){return v(e[t])?null:new f("Invalid "+n+" `"+o+"` supplied to `"+r+"`, expected a ReactNode.")}),objectOf:function(e){return h(function(t,o,i,s,a){if("function"!=typeof e)return new f("Property `"+a+"` of component `"+i+"` has invalid PropType notation inside objectOf.");var l=t[o],c=y(l);if("object"!==c)return new f("Invalid "+s+" `"+a+"` of type `"+c+"` supplied to `"+i+"`, expected an object.");for(var u in l)if(n(l,u)){var p=e(l,u,i,s,a+"."+u,r);if(p instanceof Error)return p}return null})},oneOf:function(e){return Array.isArray(e)?h(function(t,r,n,o,i){for(var s=t[r],a=0;a<e.length;a++)if(d(s,e[a]))return null;var l=JSON.stringify(e,function(e,t){return"symbol"===b(t)?String(t):t});return new f("Invalid "+o+" `"+i+"` of value `"+String(s)+"` supplied to `"+n+"`, expected one of "+l+".")}):( true&&i(arguments.length>1?"Invalid arguments supplied to oneOf, expected an array, got "+arguments.length+" arguments. A common mistake is to write oneOf(x, y, z) instead of oneOf([x, y, z]).":"Invalid argument supplied to oneOf, expected an array."),s)},oneOfType:function(e){if(!Array.isArray(e))return true&&i("Invalid argument supplied to oneOfType, expected an instance of array."),s;for(var t=0;t<e.length;t++){var o=e[t];if("function"!=typeof o)return i("Invalid argument supplied to oneOfType. Expected an array of check functions, but received "+w(o)+" at index "+t+"."),s}return h(function(t,o,i,s,a){for(var l=[],c=0;c<e.length;c++){var u=(0,e[c])(t,o,i,s,a,r);if(null==u)return null;u.data&&n(u.data,"expectedType")&&l.push(u.data.expectedType)}return new f("Invalid "+s+" `"+a+"` supplied to `"+i+"`"+(l.length>0?", expected one of type ["+l.join(", ")+"]":"")+".")})},shape:function(e){return h(function(t,n,o,i,s){var a=t[n],l=y(a);if("object"!==l)return new f("Invalid "+i+" `"+s+"` of type `"+l+"` supplied to `"+o+"`, expected `object`.");for(var c in e){var u=e[c];if("function"!=typeof u)return g(o,i,s,c,b(u));var p=u(a,c,o,i,s+"."+c,r);if(p)return p}return null})},exact:function(e){return h(function(o,i,s,a,l){var c=o[i],u=y(c);if("object"!==u)return new f("Invalid "+a+" `"+l+"` of type `"+u+"` supplied to `"+s+"`, expected `object`.");var p=t({},o[i],e);for(var d in p){var h=e[d];if(n(e,d)&&"function"!=typeof h)return g(s,a,l,d,b(h));if(!h)return new f("Invalid "+a+" `"+l+"` key `"+d+"` supplied to `"+s+"`.\nBad object: "+JSON.stringify(o[i],null,"  ")+"\nValid keys: "+JSON.stringify(Object.keys(e),null,"  "));var m=h(c,d,s,a,l+"."+d,r);if(m)return m}return null})}};function d(e,t){return e===t?0!==e||1/e==1/t:e!=e&&t!=t}function f(e,t){this.message=e,this.data=t&&"object"==typeof t?t:{},this.stack=""}function h(e){if(true)var t={},n=0;function o(o,s,a,c,p,d,h){if(c=c||u,d=d||a,h!==r){if(l){var m=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use `PropTypes.checkPropTypes()` to call them. Read more at http://fb.me/use-check-prop-types");throw m.name="Invariant Violation",m}if( true&&"undefined"!=typeof console){var g=c+":"+a;!t[g]&&n<3&&(i("You are manually calling a React.PropTypes validation function for the `"+d+"` prop on `"+c+"`. This is deprecated and will throw in the standalone `prop-types` package. You may be seeing this warning due to a third-party PropTypes library. See https://fb.me/react-warning-dont-call-proptypes for details."),t[g]=!0,n++)}}return null==s[a]?o?null===s[a]?new f("The "+p+" `"+d+"` is marked as required in `"+c+"`, but its value is `null`."):new f("The "+p+" `"+d+"` is marked as required in `"+c+"`, but its value is `undefined`."):null:e(s,a,c,p,d)}var s=o.bind(null,!1);return s.isRequired=o.bind(null,!0),s}function m(e){return h(function(t,r,n,o,i,s){var a=t[r];return y(a)!==e?new f("Invalid "+o+" `"+i+"` of type `"+b(a)+"` supplied to `"+n+"`, expected `"+e+"`.",{expectedType:e}):null})}function g(e,t,r,n,o){return new f((e||"React class")+": "+t+" type `"+r+"."+n+"` is invalid; it must be a function, usually from the `prop-types` package, but received `"+o+"`.")}function v(e){switch(typeof e){case"number":case"string":case"undefined":return!0;case"boolean":return!e;case"object":if(Array.isArray(e))return e.every(v);if(null===e||a(e))return!0;var t=function(e){var t=e&&(c&&e[c]||e["@@iterator"]);if("function"==typeof t)return t}(e);if(!t)return!1;var r,n=t.call(e);if(t!==e.entries){for(;!(r=n.next()).done;)if(!v(r.value))return!1}else for(;!(r=n.next()).done;){var o=r.value;if(o&&!v(o[1]))return!1}return!0;default:return!1}}function y(e){var t=typeof e;return Array.isArray(e)?"array":e instanceof RegExp?"object":function(e,t){return"symbol"===e||!!t&&("Symbol"===t["@@toStringTag"]||"function"==typeof Symbol&&t instanceof Symbol)}(t,e)?"symbol":t}function b(e){if(null==e)return""+e;var t=y(e);if("object"===t){if(e instanceof Date)return"date";if(e instanceof RegExp)return"regexp"}return t}function w(e){var t=b(e);switch(t){case"array":case"object":return"an "+t;case"boolean":case"date":case"regexp":return"a "+t;default:return t}}return f.prototype=Error.prototype,p.checkPropTypes=o,p.resetWarningCache=o.resetWarningCache,p.PropTypes=p,p},C}function F(){if(T)return E;T=1;var e=N();function t(){}function r(){}return r.resetWarningCache=t,E=function(){function n(t,r,n,o,i,s){if(s!==e){var a=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw a.name="Invariant Violation",a}}function o(){return n}n.isRequired=n;var i={array:n,bigint:n,bool:n,func:n,number:n,object:n,string:n,symbol:n,any:n,arrayOf:o,element:n,elementType:n,instanceOf:o,node:n,objectOf:o,oneOf:o,oneOfType:o,shape:o,exact:o,checkPropTypes:r,resetWarningCache:t};return i.PropTypes=i,i},E}function $(){if(R)return p.exports;if(R=1,"production"!=="development"){var e=A();p.exports=D()(e.isElement,!0)}else p.exports=F()();return p.exports}const B=l($());function z(e){var t,r,n="";if("string"==typeof e||"number"==typeof e)n+=e;else if("object"==typeof e)if(Array.isArray(e)){var o=e.length;for(t=0;t<o;t++)e[t]&&(r=z(e[t]))&&(n&&(n+=" "),n+=r)}else for(r in e)e[r]&&(n&&(n+=" "),n+=r);return n}function V(){for(var e,t,r=0,n="",o=arguments.length;r<o;r++)(e=arguments[r])&&(t=z(e))&&(n&&(n+=" "),n+=t);return n}function U(e,t,r=void 0){const n={};return Object.keys(e).forEach(o=>{n[o]=e[o].reduce((e,n)=>{if(n){const o=t(n);""!==o&&e.push(o),r&&r[n]&&e.push(r[n])}return e},[]).join(" ")}),n}var q,W={},H={exports:{}};function G(){return q||(q=1,(e=H).exports=function(e){return e&&e.__esModule?e:{default:e}},e.exports.__esModule=!0,e.exports.default=e.exports),H.exports;// removed by dead control flow
 var e; }var K,Y={exports:{}};function Z(){return K||(K=1,function(e){function t(){return e.exports=t=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)({}).hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},e.exports.__esModule=!0,e.exports.default=e.exports,t.apply(null,arguments)}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports}(Y)),Y.exports}var X,J={exports:{}};function Q(){return X||(X=1,(e=J).exports=function(e,t){if(null==e)return{};var r={};for(var n in e)if({}.hasOwnProperty.call(e,n)){if(-1!==t.indexOf(n))continue;r[n]=e[n]}return r},e.exports.__esModule=!0,e.exports.default=e.exports),J.exports;// removed by dead control flow
 var e; }function ee(e){var t=Object.create(null);return function(r){return void 0===t[r]&&(t[r]=e(r)),t[r]}}var te=/^((children|dangerouslySetInnerHTML|key|ref|autoFocus|defaultValue|defaultChecked|innerHTML|suppressContentEditableWarning|suppressHydrationWarning|valueLink|abbr|accept|acceptCharset|accessKey|action|allow|allowUserMedia|allowPaymentRequest|allowFullScreen|allowTransparency|alt|async|autoComplete|autoPlay|capture|cellPadding|cellSpacing|challenge|charSet|checked|cite|classID|className|cols|colSpan|content|contentEditable|contextMenu|controls|controlsList|coords|crossOrigin|data|dateTime|decoding|default|defer|dir|disabled|disablePictureInPicture|disableRemotePlayback|download|draggable|encType|enterKeyHint|fetchpriority|fetchPriority|form|formAction|formEncType|formMethod|formNoValidate|formTarget|frameBorder|headers|height|hidden|high|href|hrefLang|htmlFor|httpEquiv|id|inputMode|integrity|is|keyParams|keyType|kind|label|lang|list|loading|loop|low|marginHeight|marginWidth|max|maxLength|media|mediaGroup|method|min|minLength|multiple|muted|name|nonce|noValidate|open|optimum|pattern|placeholder|playsInline|popover|popoverTarget|popoverTargetAction|poster|preload|profile|radioGroup|readOnly|referrerPolicy|rel|required|reversed|role|rows|rowSpan|sandbox|scope|scoped|scrolling|seamless|selected|shape|size|sizes|slot|span|spellCheck|src|srcDoc|srcLang|srcSet|start|step|style|summary|tabIndex|target|title|translate|type|useMap|value|width|wmode|wrap|about|datatype|inlist|prefix|property|resource|typeof|vocab|autoCapitalize|autoCorrect|autoSave|color|incremental|fallback|inert|itemProp|itemScope|itemType|itemID|itemRef|on|option|results|security|unselectable|accentHeight|accumulate|additive|alignmentBaseline|allowReorder|alphabetic|amplitude|arabicForm|ascent|attributeName|attributeType|autoReverse|azimuth|baseFrequency|baselineShift|baseProfile|bbox|begin|bias|by|calcMode|capHeight|clip|clipPathUnits|clipPath|clipRule|colorInterpolation|colorInterpolationFilters|colorProfile|colorRendering|contentScriptType|contentStyleType|cursor|cx|cy|d|decelerate|descent|diffuseConstant|direction|display|divisor|dominantBaseline|dur|dx|dy|edgeMode|elevation|enableBackground|end|exponent|externalResourcesRequired|fill|fillOpacity|fillRule|filter|filterRes|filterUnits|floodColor|floodOpacity|focusable|fontFamily|fontSize|fontSizeAdjust|fontStretch|fontStyle|fontVariant|fontWeight|format|from|fr|fx|fy|g1|g2|glyphName|glyphOrientationHorizontal|glyphOrientationVertical|glyphRef|gradientTransform|gradientUnits|hanging|horizAdvX|horizOriginX|ideographic|imageRendering|in|in2|intercept|k|k1|k2|k3|k4|kernelMatrix|kernelUnitLength|kerning|keyPoints|keySplines|keyTimes|lengthAdjust|letterSpacing|lightingColor|limitingConeAngle|local|markerEnd|markerMid|markerStart|markerHeight|markerUnits|markerWidth|mask|maskContentUnits|maskUnits|mathematical|mode|numOctaves|offset|opacity|operator|order|orient|orientation|origin|overflow|overlinePosition|overlineThickness|panose1|paintOrder|pathLength|patternContentUnits|patternTransform|patternUnits|pointerEvents|points|pointsAtX|pointsAtY|pointsAtZ|preserveAlpha|preserveAspectRatio|primitiveUnits|r|radius|refX|refY|renderingIntent|repeatCount|repeatDur|requiredExtensions|requiredFeatures|restart|result|rotate|rx|ry|scale|seed|shapeRendering|slope|spacing|specularConstant|specularExponent|speed|spreadMethod|startOffset|stdDeviation|stemh|stemv|stitchTiles|stopColor|stopOpacity|strikethroughPosition|strikethroughThickness|string|stroke|strokeDasharray|strokeDashoffset|strokeLinecap|strokeLinejoin|strokeMiterlimit|strokeOpacity|strokeWidth|surfaceScale|systemLanguage|tableValues|targetX|targetY|textAnchor|textDecoration|textRendering|textLength|to|transform|u1|u2|underlinePosition|underlineThickness|unicode|unicodeBidi|unicodeRange|unitsPerEm|vAlphabetic|vHanging|vIdeographic|vMathematical|values|vectorEffect|version|vertAdvY|vertOriginX|vertOriginY|viewBox|viewTarget|visibility|widths|wordSpacing|writingMode|x|xHeight|x1|x2|xChannelSelector|xlinkActuate|xlinkArcrole|xlinkHref|xlinkRole|xlinkShow|xlinkTitle|xlinkType|xmlBase|xmlns|xmlnsXlink|xmlLang|xmlSpace|y|y1|y2|yChannelSelector|z|zoomAndPan|for|class|autofocus)|(([Dd][Aa][Tt][Aa]|[Aa][Rr][Ii][Aa]|x)-.*))$/,re=ee(function(e){return te.test(e)||111===e.charCodeAt(0)&&110===e.charCodeAt(1)&&e.charCodeAt(2)<91}),ne=function(){function e(e){var t=this;this._insertTag=function(e){var r;r=0===t.tags.length?t.insertionPoint?t.insertionPoint.nextSibling:t.prepend?t.container.firstChild:t.before:t.tags[t.tags.length-1].nextSibling,t.container.insertBefore(e,r),t.tags.push(e)},this.isSpeedy=void 0===e.speedy||e.speedy,this.tags=[],this.ctr=0,this.nonce=e.nonce,this.key=e.key,this.container=e.container,this.prepend=e.prepend,this.insertionPoint=e.insertionPoint,this.before=null}var t=e.prototype;return t.hydrate=function(e){e.forEach(this._insertTag)},t.insert=function(e){this.ctr%(this.isSpeedy?65e3:1)==0&&this._insertTag(function(e){var t=document.createElement("style");return t.setAttribute("data-emotion",e.key),void 0!==e.nonce&&t.setAttribute("nonce",e.nonce),t.appendChild(document.createTextNode("")),t.setAttribute("data-s",""),t}(this));var t=this.tags[this.tags.length-1];if(this.isSpeedy){var r=function(e){if(e.sheet)return e.sheet;for(var t=0;t<document.styleSheets.length;t++)if(document.styleSheets[t].ownerNode===e)return document.styleSheets[t]}(t);try{r.insertRule(e,r.cssRules.length)}catch(e){}}else t.appendChild(document.createTextNode(e));this.ctr++},t.flush=function(){this.tags.forEach(function(e){var t;return null==(t=e.parentNode)?void 0:t.removeChild(e)}),this.tags=[],this.ctr=0},e}(),oe="-ms-",ie="-moz-",se="-webkit-",ae="comm",le="rule",ce="decl",ue="@keyframes",pe=Math.abs,de=String.fromCharCode,fe=Object.assign;function he(e){return e.trim()}function me(e,t,r){return e.replace(t,r)}function ge(e,t){return e.indexOf(t)}function ve(e,t){return 0|e.charCodeAt(t)}function ye(e,t,r){return e.slice(t,r)}function be(e){return e.length}function we(e){return e.length}function xe(e,t){return t.push(e),e}var _e=1,Se=1,ke=0,Ce=0,Oe=0,Ee="";function Te(e,t,r,n,o,i,s){return{value:e,root:t,parent:r,type:n,props:o,children:i,line:_e,column:Se,length:s,return:""}}function Re(e,t){return fe(Te("",null,null,"",null,null,0),e,{length:-e.length},t)}function Ie(){return Oe=Ce>0?ve(Ee,--Ce):0,Se--,10===Oe&&(Se=1,_e--),Oe}function Me(){return Oe=Ce<ke?ve(Ee,Ce++):0,Se++,10===Oe&&(Se=1,_e++),Oe}function Ae(){return ve(Ee,Ce)}function Pe(){return Ce}function Ne(e,t){return ye(Ee,e,t)}function je(e){switch(e){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function Le(e){return _e=Se=1,ke=be(Ee=e),Ce=0,[]}function De(e){return Ee="",e}function Fe(e){return he(Ne(Ce-1,ze(91===e?e+2:40===e?e+1:e)))}function $e(e){for(;(Oe=Ae())&&Oe<33;)Me();return je(e)>2||je(Oe)>3?"":" "}function Be(e,t){for(;--t&&Me()&&!(Oe<48||Oe>102||Oe>57&&Oe<65||Oe>70&&Oe<97););return Ne(e,Pe()+(t<6&&32==Ae()&&32==Me()))}function ze(e){for(;Me();)switch(Oe){case e:return Ce;case 34:case 39:34!==e&&39!==e&&ze(Oe);break;case 40:41===e&&ze(e);break;case 92:Me()}return Ce}function Ve(e,t){for(;Me()&&e+Oe!==57&&(e+Oe!==84||47!==Ae()););return"/*"+Ne(t,Ce-1)+"*"+de(47===e?e:Me())}function Ue(e){for(;!je(Ae());)Me();return Ne(e,Ce)}function qe(e){return De(We("",null,null,null,[""],e=Le(e),0,[0],e))}function We(e,t,r,n,o,i,s,a,l){for(var c=0,u=0,p=s,d=0,f=0,h=0,m=1,g=1,v=1,y=0,b="",w=o,x=i,_=n,S=b;g;)switch(h=y,y=Me()){case 40:if(108!=h&&58==ve(S,p-1)){-1!=ge(S+=me(Fe(y),"&","&\f"),"&\f")&&(v=-1);break}case 34:case 39:case 91:S+=Fe(y);break;case 9:case 10:case 13:case 32:S+=$e(h);break;case 92:S+=Be(Pe()-1,7);continue;case 47:switch(Ae()){case 42:case 47:xe(Ge(Ve(Me(),Pe()),t,r),l);break;default:S+="/"}break;case 123*m:a[c++]=be(S)*v;case 125*m:case 59:case 0:switch(y){case 0:case 125:g=0;case 59+u:-1==v&&(S=me(S,/\f/g,"")),f>0&&be(S)-p&&xe(f>32?Ke(S+";",n,r,p-1):Ke(me(S," ","")+";",n,r,p-2),l);break;case 59:S+=";";default:if(xe(_=He(S,t,r,c,u,o,a,b,w=[],x=[],p),i),123===y)if(0===u)We(S,t,_,_,w,i,p,a,x);else switch(99===d&&110===ve(S,3)?100:d){case 100:case 108:case 109:case 115:We(e,_,_,n&&xe(He(e,_,_,0,0,o,a,b,o,w=[],p),x),o,x,p,a,n?w:x);break;default:We(S,_,_,_,[""],x,0,a,x)}}c=u=f=0,m=v=1,b=S="",p=s;break;case 58:p=1+be(S),f=h;default:if(m<1)if(123==y)--m;else if(125==y&&0==m++&&125==Ie())continue;switch(S+=de(y),y*m){case 38:v=u>0?1:(S+="\f",-1);break;case 44:a[c++]=(be(S)-1)*v,v=1;break;case 64:45===Ae()&&(S+=Fe(Me())),d=Ae(),u=p=be(b=S+=Ue(Pe())),y++;break;case 45:45===h&&2==be(S)&&(m=0)}}return i}function He(e,t,r,n,o,i,s,a,l,c,u){for(var p=o-1,d=0===o?i:[""],f=we(d),h=0,m=0,g=0;h<n;++h)for(var v=0,y=ye(e,p+1,p=pe(m=s[h])),b=e;v<f;++v)(b=he(m>0?d[v]+" "+y:me(y,/&\f/g,d[v])))&&(l[g++]=b);return Te(e,t,r,0===o?le:a,l,c,u)}function Ge(e,t,r){return Te(e,t,r,ae,de(Oe),ye(e,2,-2),0)}function Ke(e,t,r,n){return Te(e,t,r,ce,ye(e,0,n),ye(e,n+1,-1),n)}function Ye(e,t){for(var r="",n=we(e),o=0;o<n;o++)r+=t(e[o],o,e,t)||"";return r}function Ze(e,t,r,n){switch(e.type){case"@layer":if(e.children.length)break;case"@import":case ce:return e.return=e.return||e.value;case ae:return"";case ue:return e.return=e.value+"{"+Ye(e.children,n)+"}";case le:e.value=e.props.join(",")}return be(r=Ye(e.children,n))?e.return=e.value+"{"+r+"}":""}var Xe=function(e,t,r){for(var n=0,o=0;n=o,o=Ae(),38===n&&12===o&&(t[r]=1),!je(o);)Me();return Ne(e,Ce)},Je=new WeakMap,Qe=function(e){if("rule"===e.type&&e.parent&&!(e.length<1)){for(var t=e.value,r=e.parent,n=e.column===r.column&&e.line===r.line;"rule"!==r.type;)if(!(r=r.parent))return;if((1!==e.props.length||58===t.charCodeAt(0)||Je.get(r))&&!n){Je.set(e,!0);for(var o=[],i=function(e,t){return De(function(e,t){var r=-1,n=44;do{switch(je(n)){case 0:38===n&&12===Ae()&&(t[r]=1),e[r]+=Xe(Ce-1,t,r);break;case 2:e[r]+=Fe(n);break;case 4:if(44===n){e[++r]=58===Ae()?"&\f":"",t[r]=e[r].length;break}default:e[r]+=de(n)}}while(n=Me());return e}(Le(e),t))}(t,o),s=r.props,a=0,l=0;a<i.length;a++)for(var c=0;c<s.length;c++,l++)e.props[l]=o[a]?i[a].replace(/&\f/g,s[c]):s[c]+" "+i[a]}}},et=function(e){if("decl"===e.type){var t=e.value;108===t.charCodeAt(0)&&98===t.charCodeAt(2)&&(e.return="",e.value="")}};function tt(e,t){switch(function(e,t){return 45^ve(e,0)?(((t<<2^ve(e,0))<<2^ve(e,1))<<2^ve(e,2))<<2^ve(e,3):0}(e,t)){case 5103:return se+"print-"+e+e;case 5737:case 4201:case 3177:case 3433:case 1641:case 4457:case 2921:case 5572:case 6356:case 5844:case 3191:case 6645:case 3005:case 6391:case 5879:case 5623:case 6135:case 4599:case 4855:case 4215:case 6389:case 5109:case 5365:case 5621:case 3829:return se+e+e;case 5349:case 4246:case 4810:case 6968:case 2756:return se+e+ie+e+oe+e+e;case 6828:case 4268:return se+e+oe+e+e;case 6165:return se+e+oe+"flex-"+e+e;case 5187:return se+e+me(e,/(\w+).+(:[^]+)/,se+"box-$1$2"+oe+"flex-$1$2")+e;case 5443:return se+e+oe+"flex-item-"+me(e,/flex-|-self/,"")+e;case 4675:return se+e+oe+"flex-line-pack"+me(e,/align-content|flex-|-self/,"")+e;case 5548:return se+e+oe+me(e,"shrink","negative")+e;case 5292:return se+e+oe+me(e,"basis","preferred-size")+e;case 6060:return se+"box-"+me(e,"-grow","")+se+e+oe+me(e,"grow","positive")+e;case 4554:return se+me(e,/([^-])(transform)/g,"$1"+se+"$2")+e;case 6187:return me(me(me(e,/(zoom-|grab)/,se+"$1"),/(image-set)/,se+"$1"),e,"")+e;case 5495:case 3959:return me(e,/(image-set\([^]*)/,se+"$1$`$1");case 4968:return me(me(e,/(.+:)(flex-)?(.*)/,se+"box-pack:$3"+oe+"flex-pack:$3"),/s.+-b[^;]+/,"justify")+se+e+e;case 4095:case 3583:case 4068:case 2532:return me(e,/(.+)-inline(.+)/,se+"$1$2")+e;case 8116:case 7059:case 5753:case 5535:case 5445:case 5701:case 4933:case 4677:case 5533:case 5789:case 5021:case 4765:if(be(e)-1-t>6)switch(ve(e,t+1)){case 109:if(45!==ve(e,t+4))break;case 102:return me(e,/(.+:)(.+)-([^]+)/,"$1"+se+"$2-$3$1"+ie+(108==ve(e,t+3)?"$3":"$2-$3"))+e;case 115:return~ge(e,"stretch")?tt(me(e,"stretch","fill-available"),t)+e:e}break;case 4949:if(115!==ve(e,t+1))break;case 6444:switch(ve(e,be(e)-3-(~ge(e,"!important")&&10))){case 107:return me(e,":",":"+se)+e;case 101:return me(e,/(.+:)([^;!]+)(;|!.+)?/,"$1"+se+(45===ve(e,14)?"inline-":"")+"box$3$1"+se+"$2$3$1"+oe+"$2box$3")+e}break;case 5936:switch(ve(e,t+11)){case 114:return se+e+oe+me(e,/[svh]\w+-[tblr]{2}/,"tb")+e;case 108:return se+e+oe+me(e,/[svh]\w+-[tblr]{2}/,"tb-rl")+e;case 45:return se+e+oe+me(e,/[svh]\w+-[tblr]{2}/,"lr")+e}return se+e+oe+e+e}return e}var rt=[function(e,t,r,n){if(e.length>-1&&!e.return)switch(e.type){case ce:e.return=tt(e.value,e.length);break;case ue:return Ye([Re(e,{value:me(e.value,"@","@"+se)})],n);case le:if(e.length)return function(e,t){return e.map(t).join("")}(e.props,function(t){switch(function(e){return(e=/(::plac\w+|:read-\w+)/.exec(e))?e[0]:e}(t)){case":read-only":case":read-write":return Ye([Re(e,{props:[me(t,/:(read-\w+)/,":-moz-$1")]})],n);case"::placeholder":return Ye([Re(e,{props:[me(t,/:(plac\w+)/,":"+se+"input-$1")]}),Re(e,{props:[me(t,/:(plac\w+)/,":-moz-$1")]}),Re(e,{props:[me(t,/:(plac\w+)/,oe+"input-$1")]})],n)}return""})}}],nt=function(e){var t=e.key;if("css"===t){var r=document.querySelectorAll("style[data-emotion]:not([data-s])");Array.prototype.forEach.call(r,function(e){-1!==e.getAttribute("data-emotion").indexOf(" ")&&(document.head.appendChild(e),e.setAttribute("data-s",""))})}var n,o,i=e.stylisPlugins||rt,s={},a=[];n=e.container||document.head,Array.prototype.forEach.call(document.querySelectorAll('style[data-emotion^="'+t+' "]'),function(e){for(var t=e.getAttribute("data-emotion").split(" "),r=1;r<t.length;r++)s[t[r]]=!0;a.push(e)});var l,c,u=[Ze,(c=function(e){l.insert(e)},function(e){e.root||(e=e.return)&&c(e)})],p=function(e){var t=we(e);return function(r,n,o,i){for(var s="",a=0;a<t;a++)s+=e[a](r,n,o,i)||"";return s}}([Qe,et].concat(i,u));o=function(e,t,r,n){l=r,Ye(qe(e?e+"{"+t.styles+"}":t.styles),p),n&&(d.inserted[t.name]=!0)};var d={key:t,sheet:new ne({key:t,container:n,nonce:e.nonce,speedy:e.speedy,prepend:e.prepend,insertionPoint:e.insertionPoint}),nonce:e.nonce,inserted:s,registered:{},insert:o};return d.sheet.hydrate(a),d},ot=function(e,t,r){var n=e.key+"-"+t.name;!1===r&&void 0===e.registered[n]&&(e.registered[n]=t.styles)},it=function(e,t,r){ot(e,t,r);var n=e.key+"-"+t.name;if(void 0===e.inserted[t.name]){var o=t;do{e.insert(t===o?"."+n:"",o,e.sheet,!0),o=o.next}while(void 0!==o)}},st={animationIterationCount:1,aspectRatio:1,borderImageOutset:1,borderImageSlice:1,borderImageWidth:1,boxFlex:1,boxFlexGroup:1,boxOrdinalGroup:1,columnCount:1,columns:1,flex:1,flexGrow:1,flexPositive:1,flexShrink:1,flexNegative:1,flexOrder:1,gridRow:1,gridRowEnd:1,gridRowSpan:1,gridRowStart:1,gridColumn:1,gridColumnEnd:1,gridColumnSpan:1,gridColumnStart:1,msGridRow:1,msGridRowSpan:1,msGridColumn:1,msGridColumnSpan:1,fontWeight:1,lineHeight:1,opacity:1,order:1,orphans:1,scale:1,tabSize:1,widows:1,zIndex:1,zoom:1,WebkitLineClamp:1,fillOpacity:1,floodOpacity:1,stopOpacity:1,strokeDasharray:1,strokeDashoffset:1,strokeMiterlimit:1,strokeOpacity:1,strokeWidth:1},at=/[A-Z]|^ms/g,lt=/_EMO_([^_]+?)_([^]*?)_EMO_/g,ct=function(e){return 45===e.charCodeAt(1)},ut=function(e){return null!=e&&"boolean"!=typeof e},pt=ee(function(e){return ct(e)?e:e.replace(at,"-$&").toLowerCase()}),dt=function(e,t){switch(e){case"animation":case"animationName":if("string"==typeof t)return t.replace(lt,function(e,t,r){return ht={name:t,styles:r,next:ht},t})}return 1===st[e]||ct(e)||"number"!=typeof t||0===t?t:t+"px"};function ft(e,t,r){if(null==r)return"";var n=r;if(void 0!==n.__emotion_styles)return n;switch(typeof r){case"boolean":return"";case"object":var o=r;if(1===o.anim)return ht={name:o.name,styles:o.styles,next:ht},o.name;var i=r;if(void 0!==i.styles){var s=i.next;if(void 0!==s)for(;void 0!==s;)ht={name:s.name,styles:s.styles,next:ht},s=s.next;return i.styles+";"}return function(e,t,r){var n="";if(Array.isArray(r))for(var o=0;o<r.length;o++)n+=ft(e,t,r[o])+";";else for(var i in r){var s=r[i];if("object"!=typeof s){var a=s;null!=t&&void 0!==t[a]?n+=i+"{"+t[a]+"}":ut(a)&&(n+=pt(i)+":"+dt(i,a)+";")}else if(!Array.isArray(s)||"string"!=typeof s[0]||null!=t&&void 0!==t[s[0]]){var l=ft(e,t,s);switch(i){case"animation":case"animationName":n+=pt(i)+":"+l+";";break;default:n+=i+"{"+l+"}"}}else for(var c=0;c<s.length;c++)ut(s[c])&&(n+=pt(i)+":"+dt(i,s[c])+";")}return n}(e,t,r);case"function":if(void 0!==e){var a=ht,l=r(e);return ht=a,ft(e,t,l)}}var c=r;if(null==t)return c;var u=t[c];return void 0!==u?u:c}var ht,mt=/label:\s*([^\s;{]+)\s*(;|$)/g;function gt(e,t,r){if(1===e.length&&"object"==typeof e[0]&&null!==e[0]&&void 0!==e[0].styles)return e[0];var n=!0,o="";ht=void 0;var i=e[0];null==i||void 0===i.raw?(n=!1,o+=ft(r,t,i)):o+=i[0];for(var s=1;s<e.length;s++)o+=ft(r,t,e[s]),n&&(o+=i[s]);mt.lastIndex=0;for(var a,l="";null!==(a=mt.exec(o));)l+="-"+a[1];var c=function(e){for(var t,r=0,n=0,o=e.length;o>=4;++n,o-=4)t=1540483477*(65535&(t=255&e.charCodeAt(n)|(255&e.charCodeAt(++n))<<8|(255&e.charCodeAt(++n))<<16|(255&e.charCodeAt(++n))<<24))+(59797*(t>>>16)<<16),r=1540483477*(65535&(t^=t>>>24))+(59797*(t>>>16)<<16)^1540483477*(65535&r)+(59797*(r>>>16)<<16);switch(o){case 3:r^=(255&e.charCodeAt(n+2))<<16;case 2:r^=(255&e.charCodeAt(n+1))<<8;case 1:r=1540483477*(65535&(r^=255&e.charCodeAt(n)))+(59797*(r>>>16)<<16)}return(((r=1540483477*(65535&(r^=r>>>13))+(59797*(r>>>16)<<16))^r>>>15)>>>0).toString(36)}(o)+l;return{name:c,styles:o,next:ht}}var vt=!!o.useInsertionEffect&&o.useInsertionEffect,yt=vt||function(e){return e()},bt=vt||o.useLayoutEffect,wt=o.createContext("undefined"!=typeof HTMLElement?nt({key:"css"}):null),xt=wt.Provider,_t=function(e){return t.forwardRef(function(r,n){var o=t.useContext(wt);return e(r,o,n)})},St=o.createContext({}),kt=_t(function(e,t){var r=gt([e.styles],void 0,o.useContext(St)),n=o.useRef();return bt(function(){var e=t.key+"-global",o=new t.sheet.constructor({key:e,nonce:t.sheet.nonce,container:t.sheet.container,speedy:t.sheet.isSpeedy}),i=!1,s=document.querySelector('style[data-emotion="'+e+" "+r.name+'"]');return t.sheet.tags.length&&(o.before=t.sheet.tags[0]),null!==s&&(i=!0,s.setAttribute("data-emotion",e),o.hydrate([s])),n.current=[o,i],function(){o.flush()}},[t]),bt(function(){var e=n.current,o=e[0];if(e[1])e[1]=!1;else{if(void 0!==r.next&&it(t,r.next,!0),o.tags.length){var i=o.tags[o.tags.length-1].nextElementSibling;o.before=i,o.flush()}t.insert("",r,o,!1)}},[t,r.name]),null});function Ct(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];return gt(t)}var Ot=function(){var e=Ct.apply(void 0,arguments),t="animation-"+e.name;return{name:t,styles:"@keyframes "+t+"{"+e.styles+"}",anim:1,toString:function(){return"_EMO_"+this.name+"_"+this.styles+"_EMO_"}}},Et=re,Tt=function(e){return"theme"!==e},Rt=function(e){return"string"==typeof e&&e.charCodeAt(0)>96?Et:Tt},It=function(e,t,r){var n;if(t){var o=t.shouldForwardProp;n=e.__emotion_forwardProp&&o?function(t){return e.__emotion_forwardProp(t)&&o(t)}:o}return"function"!=typeof n&&r&&(n=e.__emotion_forwardProp),n},Mt=function(e){var t=e.cache,r=e.serialized,n=e.isStringTag;return ot(t,r,n),yt(function(){return it(t,r,n)}),null},At=function e(t,r){var n,i,s=t.__emotion_real===t,l=s&&t.__emotion_base||t;void 0!==r&&(n=r.label,i=r.target);var c=It(t,r,s),u=c||Rt(l),p=!u("as");return function(){var d=arguments,f=s&&void 0!==t.__emotion_styles?t.__emotion_styles.slice(0):[];if(void 0!==n&&f.push("label:"+n+";"),null==d[0]||void 0===d[0].raw)f.push.apply(f,d);else{f.push(d[0][0]);for(var h=d.length,m=1;m<h;m++)f.push(d[m],d[0][m])}var g=_t(function(e,t,r){var n=p&&e.as||l,s="",a=[],d=e;if(null==e.theme){for(var h in d={},e)d[h]=e[h];d.theme=o.useContext(St)}"string"==typeof e.className?s=function(e,t,r){var n="";return r.split(" ").forEach(function(r){void 0!==e[r]?t.push(e[r]+";"):r&&(n+=r+" ")}),n}(t.registered,a,e.className):null!=e.className&&(s=e.className+" ");var m=gt(f.concat(a),t.registered,d);s+=t.key+"-"+m.name,void 0!==i&&(s+=" "+i);var g=p&&void 0===c?Rt(n):u,v={};for(var y in e)p&&"as"===y||g(y)&&(v[y]=e[y]);return v.className=s,r&&(v.ref=r),o.createElement(o.Fragment,null,o.createElement(Mt,{cache:t,serialized:m,isStringTag:"string"==typeof n}),o.createElement(n,v))});return g.displayName=void 0!==n?n:"Styled("+("string"==typeof l?l:l.displayName||l.name||"Component")+")",g.defaultProps=t.defaultProps,g.__emotion_real=g,g.__emotion_base=l,g.__emotion_styles=f,g.__emotion_forwardProp=c,Object.defineProperty(g,"toString",{value:function(){return"."+i}}),g.withComponent=function(t,n){return e(t,a({},r,n,{shouldForwardProp:It(g,n,!0)})).apply(void 0,f)},g}}.bind();["a","abbr","address","area","article","aside","audio","b","base","bdi","bdo","big","blockquote","body","br","button","canvas","caption","cite","code","col","colgroup","data","datalist","dd","del","details","dfn","dialog","div","dl","dt","em","embed","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","head","header","hgroup","hr","html","i","iframe","img","input","ins","kbd","keygen","label","legend","li","link","main","map","mark","marquee","menu","menuitem","meta","meter","nav","noscript","object","ol","optgroup","option","output","p","param","picture","pre","progress","q","rp","rt","ruby","s","samp","script","section","select","small","source","span","strong","style","sub","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","title","tr","track","u","ul","var","video","wbr","circle","clipPath","defs","ellipse","foreignObject","g","image","line","linearGradient","mask","path","pattern","polygon","polyline","radialGradient","rect","stop","svg","text","tspan"].forEach(function(e){At[e]=At(e)});var Pt="-ms-",Nt="-moz-",jt="-webkit-",Lt="comm",Dt="rule",Ft="decl",$t="@keyframes",Bt=Math.abs,zt=String.fromCharCode,Vt=Object.assign;function Ut(e){return e.trim()}function qt(e,t,r){return e.replace(t,r)}function Wt(e,t){return e.indexOf(t)}function Ht(e,t){return 0|e.charCodeAt(t)}function Gt(e,t,r){return e.slice(t,r)}function Kt(e){return e.length}function Yt(e){return e.length}function Zt(e,t){return t.push(e),e}var Xt=1,Jt=1,Qt=0,er=0,tr=0,rr="";function nr(e,t,r,n,o,i,s){return{value:e,root:t,parent:r,type:n,props:o,children:i,line:Xt,column:Jt,length:s,return:""}}function or(e,t){return Vt(nr("",null,null,"",null,null,0),e,{length:-e.length},t)}function ir(){return tr=er>0?Ht(rr,--er):0,Jt--,10===tr&&(Jt=1,Xt--),tr}function sr(){return tr=er<Qt?Ht(rr,er++):0,Jt++,10===tr&&(Jt=1,Xt++),tr}function ar(){return Ht(rr,er)}function lr(){return er}function cr(e,t){return Gt(rr,e,t)}function ur(e){switch(e){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function pr(e){return Xt=Jt=1,Qt=Kt(rr=e),er=0,[]}function dr(e){return rr="",e}function fr(e){return Ut(cr(er-1,gr(91===e?e+2:40===e?e+1:e)))}function hr(e){for(;(tr=ar())&&tr<33;)sr();return ur(e)>2||ur(tr)>3?"":" "}function mr(e,t){for(;--t&&sr()&&!(tr<48||tr>102||tr>57&&tr<65||tr>70&&tr<97););return cr(e,lr()+(t<6&&32==ar()&&32==sr()))}function gr(e){for(;sr();)switch(tr){case e:return er;case 34:case 39:34!==e&&39!==e&&gr(tr);break;case 40:41===e&&gr(e);break;case 92:sr()}return er}function vr(e,t){for(;sr()&&e+tr!==57&&(e+tr!==84||47!==ar()););return"/*"+cr(t,er-1)+"*"+zt(47===e?e:sr())}function yr(e){for(;!ur(ar());)sr();return cr(e,er)}function br(e){return dr(wr("",null,null,null,[""],e=pr(e),0,[0],e))}function wr(e,t,r,n,o,i,s,a,l){for(var c=0,u=0,p=s,d=0,f=0,h=0,m=1,g=1,v=1,y=0,b="",w=o,x=i,_=n,S=b;g;)switch(h=y,y=sr()){case 40:if(108!=h&&58==Ht(S,p-1)){-1!=Wt(S+=qt(fr(y),"&","&\f"),"&\f")&&(v=-1);break}case 34:case 39:case 91:S+=fr(y);break;case 9:case 10:case 13:case 32:S+=hr(h);break;case 92:S+=mr(lr()-1,7);continue;case 47:switch(ar()){case 42:case 47:Zt(_r(vr(sr(),lr()),t,r),l);break;default:S+="/"}break;case 123*m:a[c++]=Kt(S)*v;case 125*m:case 59:case 0:switch(y){case 0:case 125:g=0;case 59+u:-1==v&&(S=qt(S,/\f/g,"")),f>0&&Kt(S)-p&&Zt(f>32?Sr(S+";",n,r,p-1):Sr(qt(S," ","")+";",n,r,p-2),l);break;case 59:S+=";";default:if(Zt(_=xr(S,t,r,c,u,o,a,b,w=[],x=[],p),i),123===y)if(0===u)wr(S,t,_,_,w,i,p,a,x);else switch(99===d&&110===Ht(S,3)?100:d){case 100:case 108:case 109:case 115:wr(e,_,_,n&&Zt(xr(e,_,_,0,0,o,a,b,o,w=[],p),x),o,x,p,a,n?w:x);break;default:wr(S,_,_,_,[""],x,0,a,x)}}c=u=f=0,m=v=1,b=S="",p=s;break;case 58:p=1+Kt(S),f=h;default:if(m<1)if(123==y)--m;else if(125==y&&0==m++&&125==ir())continue;switch(S+=zt(y),y*m){case 38:v=u>0?1:(S+="\f",-1);break;case 44:a[c++]=(Kt(S)-1)*v,v=1;break;case 64:45===ar()&&(S+=fr(sr())),d=ar(),u=p=Kt(b=S+=yr(lr())),y++;break;case 45:45===h&&2==Kt(S)&&(m=0)}}return i}function xr(e,t,r,n,o,i,s,a,l,c,u){for(var p=o-1,d=0===o?i:[""],f=Yt(d),h=0,m=0,g=0;h<n;++h)for(var v=0,y=Gt(e,p+1,p=Bt(m=s[h])),b=e;v<f;++v)(b=Ut(m>0?d[v]+" "+y:qt(y,/&\f/g,d[v])))&&(l[g++]=b);return nr(e,t,r,0===o?Dt:a,l,c,u)}function _r(e,t,r){return nr(e,t,r,Lt,zt(tr),Gt(e,2,-2),0)}function Sr(e,t,r,n){return nr(e,t,r,Ft,Gt(e,0,n),Gt(e,n+1,-1),n)}function kr(e,t){for(var r="",n=Yt(e),o=0;o<n;o++)r+=t(e[o],o,e,t)||"";return r}function Cr(e,t,r,n){switch(e.type){case"@layer":if(e.children.length)break;case"@import":case Ft:return e.return=e.return||e.value;case Lt:return"";case $t:return e.return=e.value+"{"+kr(e.children,n)+"}";case Dt:e.value=e.props.join(",")}return Kt(r=kr(e.children,n))?e.return=e.value+"{"+r+"}":""}var Or=function(e,t,r){for(var n=0,o=0;n=o,o=ar(),38===n&&12===o&&(t[r]=1),!ur(o);)sr();return cr(e,er)},Er=new WeakMap,Tr=function(e){if("rule"===e.type&&e.parent&&!(e.length<1)){for(var t=e.value,r=e.parent,n=e.column===r.column&&e.line===r.line;"rule"!==r.type;)if(!(r=r.parent))return;if((1!==e.props.length||58===t.charCodeAt(0)||Er.get(r))&&!n){Er.set(e,!0);for(var o=[],i=function(e,t){return dr(function(e,t){var r=-1,n=44;do{switch(ur(n)){case 0:38===n&&12===ar()&&(t[r]=1),e[r]+=Or(er-1,t,r);break;case 2:e[r]+=fr(n);break;case 4:if(44===n){e[++r]=58===ar()?"&\f":"",t[r]=e[r].length;break}default:e[r]+=zt(n)}}while(n=sr());return e}(pr(e),t))}(t,o),s=r.props,a=0,l=0;a<i.length;a++)for(var c=0;c<s.length;c++,l++)e.props[l]=o[a]?i[a].replace(/&\f/g,s[c]):s[c]+" "+i[a]}}},Rr=function(e){if("decl"===e.type){var t=e.value;108===t.charCodeAt(0)&&98===t.charCodeAt(2)&&(e.return="",e.value="")}};function Ir(e,t){switch(function(e,t){return 45^Ht(e,0)?(((t<<2^Ht(e,0))<<2^Ht(e,1))<<2^Ht(e,2))<<2^Ht(e,3):0}(e,t)){case 5103:return jt+"print-"+e+e;case 5737:case 4201:case 3177:case 3433:case 1641:case 4457:case 2921:case 5572:case 6356:case 5844:case 3191:case 6645:case 3005:case 6391:case 5879:case 5623:case 6135:case 4599:case 4855:case 4215:case 6389:case 5109:case 5365:case 5621:case 3829:return jt+e+e;case 5349:case 4246:case 4810:case 6968:case 2756:return jt+e+Nt+e+Pt+e+e;case 6828:case 4268:return jt+e+Pt+e+e;case 6165:return jt+e+Pt+"flex-"+e+e;case 5187:return jt+e+qt(e,/(\w+).+(:[^]+)/,jt+"box-$1$2"+Pt+"flex-$1$2")+e;case 5443:return jt+e+Pt+"flex-item-"+qt(e,/flex-|-self/,"")+e;case 4675:return jt+e+Pt+"flex-line-pack"+qt(e,/align-content|flex-|-self/,"")+e;case 5548:return jt+e+Pt+qt(e,"shrink","negative")+e;case 5292:return jt+e+Pt+qt(e,"basis","preferred-size")+e;case 6060:return jt+"box-"+qt(e,"-grow","")+jt+e+Pt+qt(e,"grow","positive")+e;case 4554:return jt+qt(e,/([^-])(transform)/g,"$1"+jt+"$2")+e;case 6187:return qt(qt(qt(e,/(zoom-|grab)/,jt+"$1"),/(image-set)/,jt+"$1"),e,"")+e;case 5495:case 3959:return qt(e,/(image-set\([^]*)/,jt+"$1$`$1");case 4968:return qt(qt(e,/(.+:)(flex-)?(.*)/,jt+"box-pack:$3"+Pt+"flex-pack:$3"),/s.+-b[^;]+/,"justify")+jt+e+e;case 4095:case 3583:case 4068:case 2532:return qt(e,/(.+)-inline(.+)/,jt+"$1$2")+e;case 8116:case 7059:case 5753:case 5535:case 5445:case 5701:case 4933:case 4677:case 5533:case 5789:case 5021:case 4765:if(Kt(e)-1-t>6)switch(Ht(e,t+1)){case 109:if(45!==Ht(e,t+4))break;case 102:return qt(e,/(.+:)(.+)-([^]+)/,"$1"+jt+"$2-$3$1"+Nt+(108==Ht(e,t+3)?"$3":"$2-$3"))+e;case 115:return~Wt(e,"stretch")?Ir(qt(e,"stretch","fill-available"),t)+e:e}break;case 4949:if(115!==Ht(e,t+1))break;case 6444:switch(Ht(e,Kt(e)-3-(~Wt(e,"!important")&&10))){case 107:return qt(e,":",":"+jt)+e;case 101:return qt(e,/(.+:)([^;!]+)(;|!.+)?/,"$1"+jt+(45===Ht(e,14)?"inline-":"")+"box$3$1"+jt+"$2$3$1"+Pt+"$2box$3")+e}break;case 5936:switch(Ht(e,t+11)){case 114:return jt+e+Pt+qt(e,/[svh]\w+-[tblr]{2}/,"tb")+e;case 108:return jt+e+Pt+qt(e,/[svh]\w+-[tblr]{2}/,"tb-rl")+e;case 45:return jt+e+Pt+qt(e,/[svh]\w+-[tblr]{2}/,"lr")+e}return jt+e+Pt+e+e}return e}var Mr=[function(e,t,r,n){if(e.length>-1&&!e.return)switch(e.type){case Ft:e.return=Ir(e.value,e.length);break;case $t:return kr([or(e,{value:qt(e.value,"@","@"+jt)})],n);case Dt:if(e.length)return function(e,t){return e.map(t).join("")}(e.props,function(t){switch(function(e){return(e=/(::plac\w+|:read-\w+)/.exec(e))?e[0]:e}(t)){case":read-only":case":read-write":return kr([or(e,{props:[qt(t,/:(read-\w+)/,":-moz-$1")]})],n);case"::placeholder":return kr([or(e,{props:[qt(t,/:(plac\w+)/,":"+jt+"input-$1")]}),or(e,{props:[qt(t,/:(plac\w+)/,":-moz-$1")]}),or(e,{props:[qt(t,/:(plac\w+)/,Pt+"input-$1")]})],n)}return""})}}];const Ar=new Map;function Pr(t){const{injectFirst:r,enableCssLayer:n,children:i}=t,s=o.useMemo(()=>{const e=`${r}-${n}`;if("object"==typeof document&&Ar.has(e))return Ar.get(e);const t=function(e,t){const r=function(e){var t=e.key;if("css"===t){var r=document.querySelectorAll("style[data-emotion]:not([data-s])");Array.prototype.forEach.call(r,function(e){-1!==e.getAttribute("data-emotion").indexOf(" ")&&(document.head.appendChild(e),e.setAttribute("data-s",""))})}var n,o,i=e.stylisPlugins||Mr,s={},a=[];n=e.container||document.head,Array.prototype.forEach.call(document.querySelectorAll('style[data-emotion^="'+t+' "]'),function(e){for(var t=e.getAttribute("data-emotion").split(" "),r=1;r<t.length;r++)s[t[r]]=!0;a.push(e)});var l,c,u=[Cr,(c=function(e){l.insert(e)},function(e){e.root||(e=e.return)&&c(e)})],p=function(e){var t=Yt(e);return function(r,n,o,i){for(var s="",a=0;a<t;a++)s+=e[a](r,n,o,i)||"";return s}}([Tr,Rr].concat(i,u));o=function(e,t,r,n){l=r,kr(br(e?e+"{"+t.styles+"}":t.styles),p),n&&(d.inserted[t.name]=!0)};var d={key:t,sheet:new ne({key:t,container:n,nonce:e.nonce,speedy:e.speedy,prepend:e.prepend,insertionPoint:e.insertionPoint}),nonce:e.nonce,inserted:s,registered:{},insert:o};return d.sheet.hydrate(a),d}({key:"css",prepend:e});if(t){const e=r.insert;r.insert=(...t)=>(t[1].styles.match(/^@layer\s+[^{]*$/)||(t[1].styles=`@layer mui {${t[1].styles}}`),e(...t))}return r}(r,n);return Ar.set(e,t),t},[r,n]);return r||n?e.jsx(xt,{value:s,children:i}):i}function Nr(t){const{styles:r,defaultTheme:n={}}=t,o="function"==typeof r?e=>{return r(null==(t=e)||0===Object.keys(t).length?n:e);// removed by dead control flow
 var t; }:r;return e.jsx(kt,{styles:o})}function jr(e,t){const r=At(e,t);return true?(...t)=>{const n="string"==typeof e?`"${e}"`:"component";return 0===t.length?console.error([`MUI: Seems like you called \`styled(${n})()\` without a \`style\` argument.`,'You must provide a `styles` argument: `styled("div")(styleYouForgotToPass)`.'].join("\n")):t.some(e=>void 0===e)&&console.error(`MUI: the styled(${n})(...args) API requires all its args to be defined.`),r(...t)}:0} true&&(Pr.propTypes={children:B.node,enableCssLayer:B.bool,injectFirst:B.bool}), true&&(Nr.propTypes={defaultTheme:B.object,styles:B.oneOfType([B.array,B.string,B.object,B.func])});const Lr=(e,t)=>{Array.isArray(e.__emotion_styles)&&(e.__emotion_styles=t(e.__emotion_styles))},Dr=[],Fr=c(Object.freeze(Object.defineProperty({__proto__:null,GlobalStyles:Nr,StyledEngineProvider:Pr,ThemeContext:St,css:Ct,default:jr,internal_processStyles:Lr,internal_serializeStyles:function(e){return Dr[0]=e,gt(Dr)},keyframes:Ot},Symbol.toStringTag,{value:"Module"})));function $r(e){if("object"!=typeof e||null===e)return!1;const t=Object.getPrototypeOf(e);return!(null!==t&&t!==Object.prototype&&null!==Object.getPrototypeOf(t)||Symbol.toStringTag in e||Symbol.iterator in e)}function Br(e){if(o.isValidElement(e)||!$r(e))return e;const t={};return Object.keys(e).forEach(r=>{t[r]=Br(e[r])}),t}function zr(e,t,r={clone:!0}){const n=r.clone?a({},e):e;return $r(e)&&$r(t)&&Object.keys(t).forEach(i=>{o.isValidElement(t[i])?n[i]=t[i]:$r(t[i])&&Object.prototype.hasOwnProperty.call(e,i)&&$r(e[i])?n[i]=zr(e[i],t[i],r):r.clone?n[i]=$r(t[i])?Br(t[i]):t[i]:n[i]=t[i]}),n}const Vr=c(Object.freeze(Object.defineProperty({__proto__:null,default:zr,isPlainObject:$r},Symbol.toStringTag,{value:"Module"})));function Ur(e){let t="https://mui.com/production-error/?code="+e;for(let e=1;e<arguments.length;e+=1)t+="&args[]="+encodeURIComponent(arguments[e]);return"Minified MUI error #"+e+"; visit "+t+" for the full message."}const qr=Object.freeze(Object.defineProperty({__proto__:null,default:Ur},Symbol.toStringTag,{value:"Module"}));function Wr(e){if("string"!=typeof e)throw new Error( true?"MUI: `capitalize(string)` expects a string argument.":0);return e.charAt(0).toUpperCase()+e.slice(1)}const Hr=c(Object.freeze(Object.defineProperty({__proto__:null,default:Wr},Symbol.toStringTag,{value:"Module"})));var Gr,Kr={exports:{}},Yr={};function Zr(){if(Gr)return Yr;Gr=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.portal"),r=Symbol.for("react.fragment"),n=Symbol.for("react.strict_mode"),o=Symbol.for("react.profiler"),i=Symbol.for("react.consumer"),s=Symbol.for("react.context"),a=Symbol.for("react.forward_ref"),l=Symbol.for("react.suspense"),c=Symbol.for("react.suspense_list"),u=Symbol.for("react.memo"),p=Symbol.for("react.lazy"),d=Symbol.for("react.view_transition"),f=Symbol.for("react.client.reference");function h(f){if("object"==typeof f&&null!==f){var h=f.$$typeof;switch(h){case e:switch(f=f.type){case r:case o:case n:case l:case c:case d:return f;default:switch(f=f&&f.$$typeof){case s:case a:case p:case u:case i:return f;default:return h}}case t:return h}}}return Yr.ContextConsumer=i,Yr.ContextProvider=s,Yr.Element=e,Yr.ForwardRef=a,Yr.Fragment=r,Yr.Lazy=p,Yr.Memo=u,Yr.Portal=t,Yr.Profiler=o,Yr.StrictMode=n,Yr.Suspense=l,Yr.SuspenseList=c,Yr.isContextConsumer=function(e){return h(e)===i},Yr.isContextProvider=function(e){return h(e)===s},Yr.isElement=function(t){return"object"==typeof t&&null!==t&&t.$$typeof===e},Yr.isForwardRef=function(e){return h(e)===a},Yr.isFragment=function(e){return h(e)===r},Yr.isLazy=function(e){return h(e)===p},Yr.isMemo=function(e){return h(e)===u},Yr.isPortal=function(e){return h(e)===t},Yr.isProfiler=function(e){return h(e)===o},Yr.isStrictMode=function(e){return h(e)===n},Yr.isSuspense=function(e){return h(e)===l},Yr.isSuspenseList=function(e){return h(e)===c},Yr.isValidElementType=function(e){return"string"==typeof e||"function"==typeof e||e===r||e===o||e===n||e===l||e===c||"object"==typeof e&&null!==e&&(e.$$typeof===p||e.$$typeof===u||e.$$typeof===s||e.$$typeof===i||e.$$typeof===a||e.$$typeof===f||void 0!==e.getModuleId)},Yr.typeOf=h,Yr}var Xr,Jr,Qr={};function en(){return Xr||(Xr=1, true&&function(){function e(e){if("object"==typeof e&&null!==e){var h=e.$$typeof;switch(h){case t:switch(e=e.type){case n:case i:case o:case c:case u:case f:return e;default:switch(e=e&&e.$$typeof){case a:case l:case d:case p:case s:return e;default:return h}}case r:return h}}}var t=Symbol.for("react.transitional.element"),r=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),o=Symbol.for("react.strict_mode"),i=Symbol.for("react.profiler"),s=Symbol.for("react.consumer"),a=Symbol.for("react.context"),l=Symbol.for("react.forward_ref"),c=Symbol.for("react.suspense"),u=Symbol.for("react.suspense_list"),p=Symbol.for("react.memo"),d=Symbol.for("react.lazy"),f=Symbol.for("react.view_transition"),h=Symbol.for("react.client.reference");Qr.ContextConsumer=s,Qr.ContextProvider=a,Qr.Element=t,Qr.ForwardRef=l,Qr.Fragment=n,Qr.Lazy=d,Qr.Memo=p,Qr.Portal=r,Qr.Profiler=i,Qr.StrictMode=o,Qr.Suspense=c,Qr.SuspenseList=u,Qr.isContextConsumer=function(t){return e(t)===s},Qr.isContextProvider=function(t){return e(t)===a},Qr.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===t},Qr.isForwardRef=function(t){return e(t)===l},Qr.isFragment=function(t){return e(t)===n},Qr.isLazy=function(t){return e(t)===d},Qr.isMemo=function(t){return e(t)===p},Qr.isPortal=function(t){return e(t)===r},Qr.isProfiler=function(t){return e(t)===i},Qr.isStrictMode=function(t){return e(t)===o},Qr.isSuspense=function(t){return e(t)===c},Qr.isSuspenseList=function(t){return e(t)===u},Qr.isValidElementType=function(e){return"string"==typeof e||"function"==typeof e||e===n||e===i||e===o||e===c||e===u||"object"==typeof e&&null!==e&&(e.$$typeof===d||e.$$typeof===p||e.$$typeof===a||e.$$typeof===s||e.$$typeof===l||e.$$typeof===h||void 0!==e.getModuleId)},Qr.typeOf=e}()),Qr}function tn(){return Jr||(Jr=1, false?0:Kr.exports=en()),Kr.exports}var rn=tn();const nn=/^\s*function(?:\s|\s*\/\*.*\*\/\s*)+([^(\s/]*)\s*/;function on(e){const t=`${e}`.match(nn);return t&&t[1]||""}function sn(e,t=""){return e.displayName||e.name||on(e)||t}function an(e,t,r){const n=sn(t);return e.displayName||(""!==n?`${r}(${n})`:r)}function ln(e){if(null!=e){if("string"==typeof e)return e;if("function"==typeof e)return sn(e,"Component");if("object"==typeof e)switch(e.$$typeof){case rn.ForwardRef:return an(e,e.render,"ForwardRef");case rn.Memo:return an(e,e.type,"memo");default:return}}}const cn=c(Object.freeze(Object.defineProperty({__proto__:null,default:ln,getFunctionName:on},Symbol.toStringTag,{value:"Module"}))),un=["values","unit","step"];function pn(e){const{values:t={xs:0,sm:600,md:900,lg:1200,xl:1536},unit:r="px",step:n=5}=e,o=s(e,un),i=(e=>{const t=Object.keys(e).map(t=>({key:t,val:e[t]}))||[];return t.sort((e,t)=>e.val-t.val),t.reduce((e,t)=>a({},e,{[t.key]:t.val}),{})})(t),l=Object.keys(i);function c(e){return`@media (min-width:${"number"==typeof t[e]?t[e]:e}${r})`}function u(e){return`@media (max-width:${("number"==typeof t[e]?t[e]:e)-n/100}${r})`}function p(e,o){const i=l.indexOf(o);return`@media (min-width:${"number"==typeof t[e]?t[e]:e}${r}) and (max-width:${(-1!==i&&"number"==typeof t[l[i]]?t[l[i]]:o)-n/100}${r})`}return a({keys:l,values:i,up:c,down:u,between:p,only:function(e){return l.indexOf(e)+1<l.length?p(e,l[l.indexOf(e)+1]):c(e)},not:function(e){const t=l.indexOf(e);return 0===t?c(l[1]):t===l.length-1?u(l[t]):p(e,l[l.indexOf(e)+1]).replace("@media","@media not all and")},unit:r},o)}const dn={borderRadius:4},fn= true?B.oneOfType([B.number,B.string,B.object,B.array]):0;function hn(e,t){return t?zr(e,t,{clone:!1}):e}const mn={xs:0,sm:600,md:900,lg:1200,xl:1536},gn={keys:["xs","sm","md","lg","xl"],up:e=>`@media (min-width:${mn[e]}px)`};function vn(e,t,r){const n=e.theme||{};if(Array.isArray(t)){const e=n.breakpoints||gn;return t.reduce((n,o,i)=>(n[e.up(e.keys[i])]=r(t[i]),n),{})}if("object"==typeof t){const e=n.breakpoints||gn;return Object.keys(t).reduce((n,o)=>{if(-1!==Object.keys(e.values||mn).indexOf(o))n[e.up(o)]=r(t[o],o);else{const e=o;n[e]=t[e]}return n},{})}return r(t)}function yn(e={}){var t;return(null==(t=e.keys)?void 0:t.reduce((t,r)=>(t[e.up(r)]={},t),{}))||{}}function bn(e,t){return e.reduce((e,t)=>{const r=e[t];return(!r||0===Object.keys(r).length)&&delete e[t],e},t)}function wn({values:e,breakpoints:t,base:r}){const n=r||function(e,t){if("object"!=typeof e)return{};const r={},n=Object.keys(t);return Array.isArray(e)?n.forEach((t,n)=>{n<e.length&&(r[t]=!0)}):n.forEach(t=>{null!=e[t]&&(r[t]=!0)}),r}(e,t),o=Object.keys(n);if(0===o.length)return e;let i;return o.reduce((t,r,n)=>(Array.isArray(e)?(t[r]=null!=e[n]?e[n]:e[i],i=n):"object"==typeof e?(t[r]=null!=e[r]?e[r]:e[i],i=r):t[r]=e,t),{})}function xn(e,t,r=!0){if(!t||"string"!=typeof t)return null;if(e&&e.vars&&r){const r=`vars.${t}`.split(".").reduce((e,t)=>e&&e[t]?e[t]:null,e);if(null!=r)return r}return t.split(".").reduce((e,t)=>e&&null!=e[t]?e[t]:null,e)}function _n(e,t,r,n=r){let o;return o="function"==typeof e?e(r):Array.isArray(e)?e[r]||n:xn(e,r)||n,t&&(o=t(o,n,e)),o}function Sn(e){const{prop:t,cssProperty:r=e.prop,themeKey:n,transform:o}=e,i=e=>{if(null==e[t])return null;const i=e[t],s=xn(e.theme,n)||{};return vn(e,i,e=>{let n=_n(s,o,e);return e===n&&"string"==typeof e&&(n=_n(s,o,`${t}${"default"===e?"":Wr(e)}`,e)),!1===r?n:{[r]:n}})};return i.propTypes= true?{[t]:fn}:0,i.filterProps=[t],i}const kn={m:"margin",p:"padding"},Cn={t:"Top",r:"Right",b:"Bottom",l:"Left",x:["Left","Right"],y:["Top","Bottom"]},On={marginX:"mx",marginY:"my",paddingX:"px",paddingY:"py"},En=function(){const e={};return t=>(void 0===e[t]&&(e[t]=(e=>{if(e.length>2){if(!On[e])return[e];e=On[e]}const[t,r]=e.split(""),n=kn[t],o=Cn[r]||"";return Array.isArray(o)?o.map(e=>n+e):[n+o]})(t)),e[t])}(),Tn=["m","mt","mr","mb","ml","mx","my","margin","marginTop","marginRight","marginBottom","marginLeft","marginX","marginY","marginInline","marginInlineStart","marginInlineEnd","marginBlock","marginBlockStart","marginBlockEnd"],Rn=["p","pt","pr","pb","pl","px","py","padding","paddingTop","paddingRight","paddingBottom","paddingLeft","paddingX","paddingY","paddingInline","paddingInlineStart","paddingInlineEnd","paddingBlock","paddingBlockStart","paddingBlockEnd"],In=[...Tn,...Rn];function Mn(e,t,r,n){var o;const i=null!=(o=xn(e,t,!1))?o:r;return"number"==typeof i?e=>"string"==typeof e?e:( true&&"number"!=typeof e&&console.error(`MUI: Expected ${n} argument to be a number or a string, got ${e}.`),i*e):Array.isArray(i)?e=>"string"==typeof e?e:( true&&(Number.isInteger(e)?e>i.length-1&&console.error([`MUI: The value provided (${e}) overflows.`,`The supported values are: ${JSON.stringify(i)}.`,`${e} > ${i.length-1}, you need to add the missing values.`].join("\n")):console.error([`MUI: The \`theme.${t}\` array type cannot be combined with non integer values.You should either use an integer value that can be used as index, or define the \`theme.${t}\` as a number.`].join("\n"))),i[e]):"function"==typeof i?i:( true&&console.error([`MUI: The \`theme.${t}\` value (${i}) is invalid.`,"It should be a number, an array or a function."].join("\n")),()=>{})}function An(e){return Mn(e,"spacing",8,"spacing")}function Pn(e,t){if("string"==typeof t||null==t)return t;const r=e(Math.abs(t));return t>=0?r:"number"==typeof r?-r:`-${r}`}function Nn(e,t){const r=An(e.theme);return Object.keys(e).map(n=>function(e,t,r,n){if(-1===t.indexOf(r))return null;const o=function(e,t){return r=>e.reduce((e,n)=>(e[n]=Pn(t,r),e),{})}(En(r),n);return vn(e,e[r],o)}(e,t,n,r)).reduce(hn,{})}function jn(e){return Nn(e,Tn)}function Ln(e){return Nn(e,Rn)}function Dn(...e){const t=e.reduce((e,t)=>(t.filterProps.forEach(r=>{e[r]=t}),e),{}),r=e=>Object.keys(e).reduce((r,n)=>t[n]?hn(r,t[n](e)):r,{});return r.propTypes= true?e.reduce((e,t)=>Object.assign(e,t.propTypes),{}):0,r.filterProps=e.reduce((e,t)=>e.concat(t.filterProps),[]),r}function Fn(e){return"number"!=typeof e?e:`${e}px solid`}function $n(e,t){return Sn({prop:e,themeKey:"borders",transform:t})}jn.propTypes= true?Tn.reduce((e,t)=>(e[t]=fn,e),{}):0,jn.filterProps=Tn,Ln.propTypes= true?Rn.reduce((e,t)=>(e[t]=fn,e),{}):0,Ln.filterProps=Rn, false||In.reduce((e,t)=>(e[t]=fn,e),{});const Bn=$n("border",Fn),zn=$n("borderTop",Fn),Vn=$n("borderRight",Fn),Un=$n("borderBottom",Fn),qn=$n("borderLeft",Fn),Wn=$n("borderColor"),Hn=$n("borderTopColor"),Gn=$n("borderRightColor"),Kn=$n("borderBottomColor"),Yn=$n("borderLeftColor"),Zn=$n("outline",Fn),Xn=$n("outlineColor"),Jn=e=>{if(void 0!==e.borderRadius&&null!==e.borderRadius){const t=Mn(e.theme,"shape.borderRadius",4,"borderRadius"),r=e=>({borderRadius:Pn(t,e)});return vn(e,e.borderRadius,r)}return null};Jn.propTypes= true?{borderRadius:fn}:0,Jn.filterProps=["borderRadius"],Dn(Bn,zn,Vn,Un,qn,Wn,Hn,Gn,Kn,Yn,Jn,Zn,Xn);const Qn=e=>{if(void 0!==e.gap&&null!==e.gap){const t=Mn(e.theme,"spacing",8,"gap"),r=e=>({gap:Pn(t,e)});return vn(e,e.gap,r)}return null};Qn.propTypes= true?{gap:fn}:0,Qn.filterProps=["gap"];const eo=e=>{if(void 0!==e.columnGap&&null!==e.columnGap){const t=Mn(e.theme,"spacing",8,"columnGap"),r=e=>({columnGap:Pn(t,e)});return vn(e,e.columnGap,r)}return null};eo.propTypes= true?{columnGap:fn}:0,eo.filterProps=["columnGap"];const to=e=>{if(void 0!==e.rowGap&&null!==e.rowGap){const t=Mn(e.theme,"spacing",8,"rowGap"),r=e=>({rowGap:Pn(t,e)});return vn(e,e.rowGap,r)}return null};function ro(e,t){return"grey"===t?t:e}function no(e){return e<=1&&0!==e?100*e+"%":e}to.propTypes= true?{rowGap:fn}:0,to.filterProps=["rowGap"],Dn(Qn,eo,to,Sn({prop:"gridColumn"}),Sn({prop:"gridRow"}),Sn({prop:"gridAutoFlow"}),Sn({prop:"gridAutoColumns"}),Sn({prop:"gridAutoRows"}),Sn({prop:"gridTemplateColumns"}),Sn({prop:"gridTemplateRows"}),Sn({prop:"gridTemplateAreas"}),Sn({prop:"gridArea"})),Dn(Sn({prop:"color",themeKey:"palette",transform:ro}),Sn({prop:"bgcolor",cssProperty:"backgroundColor",themeKey:"palette",transform:ro}),Sn({prop:"backgroundColor",themeKey:"palette",transform:ro}));const oo=Sn({prop:"width",transform:no}),io=e=>{if(void 0!==e.maxWidth&&null!==e.maxWidth){const t=t=>{var r,n;const o=(null==(r=e.theme)||null==(r=r.breakpoints)||null==(r=r.values)?void 0:r[t])||mn[t];return o?"px"!==(null==(n=e.theme)||null==(n=n.breakpoints)?void 0:n.unit)?{maxWidth:`${o}${e.theme.breakpoints.unit}`}:{maxWidth:o}:{maxWidth:no(t)}};return vn(e,e.maxWidth,t)}return null};io.filterProps=["maxWidth"];const so=Sn({prop:"minWidth",transform:no}),ao=Sn({prop:"height",transform:no}),lo=Sn({prop:"maxHeight",transform:no}),co=Sn({prop:"minHeight",transform:no});Sn({prop:"size",cssProperty:"width",transform:no}),Sn({prop:"size",cssProperty:"height",transform:no}),Dn(oo,io,so,ao,lo,co,Sn({prop:"boxSizing"}));const uo={border:{themeKey:"borders",transform:Fn},borderTop:{themeKey:"borders",transform:Fn},borderRight:{themeKey:"borders",transform:Fn},borderBottom:{themeKey:"borders",transform:Fn},borderLeft:{themeKey:"borders",transform:Fn},borderColor:{themeKey:"palette"},borderTopColor:{themeKey:"palette"},borderRightColor:{themeKey:"palette"},borderBottomColor:{themeKey:"palette"},borderLeftColor:{themeKey:"palette"},outline:{themeKey:"borders",transform:Fn},outlineColor:{themeKey:"palette"},borderRadius:{themeKey:"shape.borderRadius",style:Jn},color:{themeKey:"palette",transform:ro},bgcolor:{themeKey:"palette",cssProperty:"backgroundColor",transform:ro},backgroundColor:{themeKey:"palette",transform:ro},p:{style:Ln},pt:{style:Ln},pr:{style:Ln},pb:{style:Ln},pl:{style:Ln},px:{style:Ln},py:{style:Ln},padding:{style:Ln},paddingTop:{style:Ln},paddingRight:{style:Ln},paddingBottom:{style:Ln},paddingLeft:{style:Ln},paddingX:{style:Ln},paddingY:{style:Ln},paddingInline:{style:Ln},paddingInlineStart:{style:Ln},paddingInlineEnd:{style:Ln},paddingBlock:{style:Ln},paddingBlockStart:{style:Ln},paddingBlockEnd:{style:Ln},m:{style:jn},mt:{style:jn},mr:{style:jn},mb:{style:jn},ml:{style:jn},mx:{style:jn},my:{style:jn},margin:{style:jn},marginTop:{style:jn},marginRight:{style:jn},marginBottom:{style:jn},marginLeft:{style:jn},marginX:{style:jn},marginY:{style:jn},marginInline:{style:jn},marginInlineStart:{style:jn},marginInlineEnd:{style:jn},marginBlock:{style:jn},marginBlockStart:{style:jn},marginBlockEnd:{style:jn},displayPrint:{cssProperty:!1,transform:e=>({"@media print":{display:e}})},display:{},overflow:{},textOverflow:{},visibility:{},whiteSpace:{},flexBasis:{},flexDirection:{},flexWrap:{},justifyContent:{},alignItems:{},alignContent:{},order:{},flex:{},flexGrow:{},flexShrink:{},alignSelf:{},justifyItems:{},justifySelf:{},gap:{style:Qn},rowGap:{style:to},columnGap:{style:eo},gridColumn:{},gridRow:{},gridAutoFlow:{},gridAutoColumns:{},gridAutoRows:{},gridTemplateColumns:{},gridTemplateRows:{},gridTemplateAreas:{},gridArea:{},position:{},zIndex:{themeKey:"zIndex"},top:{},right:{},bottom:{},left:{},boxShadow:{themeKey:"shadows"},width:{transform:no},maxWidth:{style:io},minWidth:{transform:no},height:{transform:no},maxHeight:{transform:no},minHeight:{transform:no},boxSizing:{},fontFamily:{themeKey:"typography"},fontSize:{themeKey:"typography"},fontStyle:{themeKey:"typography"},fontWeight:{themeKey:"typography"},letterSpacing:{},textTransform:{},lineHeight:{},textAlign:{},typography:{cssProperty:!1,themeKey:"typography"}};function po(){function e(e,t,r,n){const o={[e]:t,theme:r},i=n[e];if(!i)return{[e]:t};const{cssProperty:s=e,themeKey:a,transform:l,style:c}=i;if(null==t)return null;if("typography"===a&&"inherit"===t)return{[e]:t};const u=xn(r,a)||{};return c?c(o):vn(o,t,t=>{let r=_n(u,l,t);return t===r&&"string"==typeof t&&(r=_n(u,l,`${e}${"default"===t?"":Wr(t)}`,t)),!1===s?r:{[s]:r}})}return function t(r){var n;const{sx:o,theme:i={}}=r||{};if(!o)return null;const s=null!=(n=i.unstable_sxConfig)?n:uo;function a(r){let n=r;if("function"==typeof r)n=r(i);else if("object"!=typeof r)return r;if(!n)return null;const o=yn(i.breakpoints),a=Object.keys(o);let l=o;return Object.keys(n).forEach(r=>{const o="function"==typeof(a=n[r])?a(i):a;var a;if(null!=o)if("object"==typeof o)if(s[r])l=hn(l,e(r,o,i,s));else{const e=vn({theme:i},o,e=>({[r]:e}));!function(...e){const t=e.reduce((e,t)=>e.concat(Object.keys(t)),[]),r=new Set(t);return e.every(e=>r.size===Object.keys(e).length)}(e,o)?l=hn(l,e):l[r]=t({sx:o,theme:i})}else l=hn(l,e(r,o,i,s))}),bn(a,l)}return Array.isArray(o)?o.map(a):a(o)}}const fo=po();function ho(e,t){const r=this;if(r.vars&&"function"==typeof r.getColorSchemeSelector){const n=r.getColorSchemeSelector(e).replace(/(\[[^\]]+\])/,"*:where($1)");return{[n]:t}}return r.palette.mode===e?t:{}}fo.filterProps=["sx"];const mo=["breakpoints","palette","spacing","shape"];function go(e={},...t){const{breakpoints:r={},palette:n={},spacing:o,shape:i={}}=e,l=s(e,mo),c=pn(r),u=function(e=8){if(e.mui)return e;const t=An({spacing:e}),r=(...e)=>( true&&(e.length<=4||console.error(`MUI: Too many arguments provided, expected between 0 and 4, got ${e.length}`)),(0===e.length?[1]:e).map(e=>{const r=t(e);return"number"==typeof r?`${r}px`:r}).join(" "));return r.mui=!0,r}(o);let p=zr({breakpoints:c,direction:"ltr",components:{},palette:a({mode:"light"},n),spacing:u,shape:a({},dn,i)},l);return p.applyStyles=ho,p=t.reduce((e,t)=>zr(e,t),p),p.unstable_sxConfig=a({},uo,null==l?void 0:l.unstable_sxConfig),p.unstable_sx=function(e){return fo({sx:e,theme:this})},p}const vo=c(Object.freeze(Object.defineProperty({__proto__:null,default:go,private_createBreakpoints:pn,unstable_applyStyles:ho},Symbol.toStringTag,{value:"Module"}))),yo=["sx"];function bo(e){const{sx:t}=e,r=s(e,yo),{systemProps:n,otherProps:o}=(e=>{var t,r;const n={systemProps:{},otherProps:{}},o=null!=(t=null==e||null==(r=e.theme)?void 0:r.unstable_sxConfig)?t:uo;return Object.keys(e).forEach(t=>{o[t]?n.systemProps[t]=e[t]:n.otherProps[t]=e[t]}),n})(r);let i;return i=Array.isArray(t)?[n,...t]:"function"==typeof t?(...e)=>{const r=t(...e);return $r(r)?a({},n,r):n}:a({},n,t),a({},o,{sx:i})}const wo=c(Object.freeze(Object.defineProperty({__proto__:null,default:fo,extendSxProp:bo,unstable_createStyleFunctionSx:po,unstable_defaultSxConfig:uo},Symbol.toStringTag,{value:"Module"})));var xo;function _o(){if(xo)return W;xo=1;var e=G();Object.defineProperty(W,"__esModule",{value:!0}),W.default=function(e={}){const{themeId:a,defaultTheme:c=h,rootShouldForwardProp:u=f,slotShouldForwardProp:d=f}=e,b=e=>(0,l.default)((0,t.default)({},e,{theme:g((0,t.default)({},e,{defaultTheme:c,themeId:a}))}));return b.__mui_systemSx=!0,(e,l={})=>{(0,n.internal_processStyles)(e,e=>e.filter(e=>!(null!=e&&e.__mui_systemSx)));const{name:h,slot:w,skipVariantsResolver:x,skipSx:_,overridesResolver:S=v(m(w))}=l,k=(0,r.default)(l,p),C=void 0!==x?x:w&&"Root"!==w&&"root"!==w||!1,O=_||!1;let E; true&&h&&(E=`${h}-${m(w||"Root")}`);let T=f;"Root"===w||"root"===w?T=u:w?T=d:function(e){return"string"==typeof e&&e.charCodeAt(0)>96}(e)&&(T=void 0);const R=(0,n.default)(e,(0,t.default)({shouldForwardProp:T,label:E},k)),I=e=>"function"==typeof e&&e.__emotion_real!==e||(0,o.isPlainObject)(e)?r=>y(e,(0,t.default)({},r,{theme:g({theme:r.theme,defaultTheme:c,themeId:a})})):e,M=(r,...n)=>{let o=I(r);const l=n?n.map(I):[];h&&S&&l.push(e=>{const r=g((0,t.default)({},e,{defaultTheme:c,themeId:a}));if(!r.components||!r.components[h]||!r.components[h].styleOverrides)return null;const n=r.components[h].styleOverrides,o={};return Object.entries(n).forEach(([n,i])=>{o[n]=y(i,(0,t.default)({},e,{theme:r}))}),S(e,o)}),h&&!C&&l.push(e=>{var r;const n=g((0,t.default)({},e,{defaultTheme:c,themeId:a}));return y({variants:null==n||null==(r=n.components)||null==(r=r[h])?void 0:r.variants},(0,t.default)({},e,{theme:n}))}),O||l.push(b);const u=l.length-n.length;if(Array.isArray(r)&&u>0){const e=new Array(u).fill("");o=[...r,...e],o.raw=[...r.raw,...e]}const p=R(o,...l);if(true){let t;h&&(t=`${h}${(0,i.default)(w||"")}`),void 0===t&&(t=`Styled(${(0,s.default)(e)})`),p.displayName=t}return e.muiName&&(p.muiName=e.muiName),p};return R.withConfig&&(M.withConfig=R.withConfig),M}},W.shouldForwardProp=f,W.systemDefaultTheme=void 0;var t=e(Z()),r=e(Q()),n=function(e,t){if(e&&e.__esModule)return e;if(null===e||"object"!=typeof e&&"function"!=typeof e)return{default:e};var r=d(t);if(r&&r.has(e))return r.get(e);var n={__proto__:null},o=Object.defineProperty&&Object.getOwnPropertyDescriptor;for(var i in e)if("default"!==i&&Object.prototype.hasOwnProperty.call(e,i)){var s=o?Object.getOwnPropertyDescriptor(e,i):null;s&&(s.get||s.set)?Object.defineProperty(n,i,s):n[i]=e[i]}return n.default=e,r&&r.set(e,n),n}(Fr),o=Vr,i=e(Hr),s=e(cn),a=e(vo),l=e(wo);const c=["ownerState"],u=["variants"],p=["name","slot","skipVariantsResolver","skipSx","overridesResolver"];function d(e){if("function"!=typeof WeakMap)return null;var t=new WeakMap,r=new WeakMap;return(d=function(e){return e?r:t})(e)}function f(e){return"ownerState"!==e&&"theme"!==e&&"sx"!==e&&"as"!==e}const h=W.systemDefaultTheme=(0,a.default)(),m=e=>e?e.charAt(0).toLowerCase()+e.slice(1):e;function g({defaultTheme:e,theme:t,themeId:r}){return n=t,0===Object.keys(n).length?e:t[r]||t;// removed by dead control flow
 var n; }function v(e){return e?(t,r)=>r[e]:null}function y(e,n){let{ownerState:o}=n,i=(0,r.default)(n,c);const s="function"==typeof e?e((0,t.default)({ownerState:o},i)):e;if(Array.isArray(s))return s.flatMap(e=>y(e,(0,t.default)({ownerState:o},i)));if(s&&"object"==typeof s&&Array.isArray(s.variants)){const{variants:e=[]}=s;let n=(0,r.default)(s,u);return e.forEach(e=>{let r=!0;"function"==typeof e.props?r=e.props((0,t.default)({ownerState:o},i,o)):Object.keys(e.props).forEach(t=>{(null==o?void 0:o[t])!==e.props[t]&&i[t]!==e.props[t]&&(r=!1)}),r&&(Array.isArray(n)||(n=[n]),n.push("function"==typeof e.style?e.style((0,t.default)({ownerState:o},i,o)):e.style))}),n}return s}return W}const So=l(_o());function ko(e){let t="https://mui.com/production-error/?code="+e;for(let e=1;e<arguments.length;e+=1)t+="&args[]="+encodeURIComponent(arguments[e]);return"Minified MUI error #"+e+"; visit "+t+" for the full message."}function Co(e){if("object"!=typeof e||null===e)return!1;const t=Object.getPrototypeOf(e);return!(null!==t&&t!==Object.prototype&&null!==Object.getPrototypeOf(t)||Symbol.toStringTag in e||Symbol.iterator in e)}function Oo(e){if(o.isValidElement(e)||!Co(e))return e;const t={};return Object.keys(e).forEach(r=>{t[r]=Oo(e[r])}),t}function Eo(e,t,r={clone:!0}){const n=r.clone?a({},e):e;return Co(e)&&Co(t)&&Object.keys(t).forEach(i=>{o.isValidElement(t[i])?n[i]=t[i]:Co(t[i])&&Object.prototype.hasOwnProperty.call(e,i)&&Co(e[i])?n[i]=Eo(e[i],t[i],r):r.clone?n[i]=Co(t[i])?Oo(t[i]):t[i]:n[i]=t[i]}),n}const To=e=>e,Ro=(()=>{let e=To;return{configure(t){e=t},generate:t=>e(t),reset(){e=To}}})(),Io={active:"active",checked:"checked",completed:"completed",disabled:"disabled",error:"error",expanded:"expanded",focused:"focused",focusVisible:"focusVisible",open:"open",readOnly:"readOnly",required:"required",selected:"selected"};function Mo(e,t,r="Mui"){const n=Io[t];return n?`${r}-${n}`:`${Ro.generate(e)}-${t}`}var Ao={};const Po=c(qr);function No(e,t=Number.MIN_SAFE_INTEGER,r=Number.MAX_SAFE_INTEGER){return Math.max(t,Math.min(e,r))}const jo=c(Object.freeze(Object.defineProperty({__proto__:null,default:No},Symbol.toStringTag,{value:"Module"})));var Lo;function Do(){if(Lo)return Ao;Lo=1;var e=G();Object.defineProperty(Ao,"__esModule",{value:!0}),Ao.alpha=u,Ao.blend=function(e,t,r,n=1){const o=(e,t)=>Math.round((e**(1/n)*(1-r)+t**(1/n)*r)**n),s=i(e),l=i(t);return a({type:"rgb",values:[o(s.values[0],l.values[0]),o(s.values[1],l.values[1]),o(s.values[2],l.values[2])]})},Ao.colorChannel=void 0,Ao.darken=p,Ao.decomposeColor=i,Ao.emphasize=f,Ao.getContrastRatio=function(e,t){const r=c(e),n=c(t);return(Math.max(r,n)+.05)/(Math.min(r,n)+.05)},Ao.getLuminance=c,Ao.hexToRgb=o,Ao.hslToRgb=l,Ao.lighten=d,Ao.private_safeAlpha=function(e,t,r){try{return u(e,t)}catch(t){return r&&"production"!=="development"&&console.warn(r),e}},Ao.private_safeColorChannel=void 0,Ao.private_safeDarken=function(e,t,r){try{return p(e,t)}catch(t){return r&&"production"!=="development"&&console.warn(r),e}},Ao.private_safeEmphasize=function(e,t,r){try{return f(e,t)}catch(t){return r&&"production"!=="development"&&console.warn(r),e}},Ao.private_safeLighten=function(e,t,r){try{return d(e,t)}catch(t){return r&&"production"!=="development"&&console.warn(r),e}},Ao.recomposeColor=a,Ao.rgbToHex=function(e){if(0===e.indexOf("#"))return e;const{values:t}=i(e);return`#${t.map((e,t)=>function(e){const t=e.toString(16);return 1===t.length?`0${t}`:t}(3===t?Math.round(255*e):e)).join("")}`};var t=e(Po),r=e(jo);function n(e,t=0,n=1){return true&&(e<t||e>n)&&console.error(`MUI: The value provided ${e} is out of range [${t}, ${n}].`),(0,r.default)(e,t,n)}function o(e){e=e.slice(1);const t=new RegExp(`.{1,${e.length>=6?2:1}}`,"g");let r=e.match(t);return r&&1===r[0].length&&(r=r.map(e=>e+e)),r?`rgb${4===r.length?"a":""}(${r.map((e,t)=>t<3?parseInt(e,16):Math.round(parseInt(e,16)/255*1e3)/1e3).join(", ")})`:""}function i(e){if(e.type)return e;if("#"===e.charAt(0))return i(o(e));const r=e.indexOf("("),n=e.substring(0,r);if(-1===["rgb","rgba","hsl","hsla","color"].indexOf(n))throw new Error( true?`MUI: Unsupported \`${e}\` color.\nThe following formats are supported: #nnn, #nnnnnn, rgb(), rgba(), hsl(), hsla(), color().`:0);let s,a=e.substring(r+1,e.length-1);if("color"===n){if(a=a.split(" "),s=a.shift(),4===a.length&&"/"===a[3].charAt(0)&&(a[3]=a[3].slice(1)),-1===["srgb","display-p3","a98-rgb","prophoto-rgb","rec-2020"].indexOf(s))throw new Error( true?`MUI: unsupported \`${s}\` color space.\nThe following color spaces are supported: srgb, display-p3, a98-rgb, prophoto-rgb, rec-2020.`:0)}else a=a.split(",");return a=a.map(e=>parseFloat(e)),{type:n,values:a,colorSpace:s}}const s=e=>{const t=i(e);return t.values.slice(0,3).map((e,r)=>-1!==t.type.indexOf("hsl")&&0!==r?`${e}%`:e).join(" ")};function a(e){const{type:t,colorSpace:r}=e;let{values:n}=e;return-1!==t.indexOf("rgb")?n=n.map((e,t)=>t<3?parseInt(e,10):e):-1!==t.indexOf("hsl")&&(n[1]=`${n[1]}%`,n[2]=`${n[2]}%`),n=-1!==t.indexOf("color")?`${r} ${n.join(" ")}`:`${n.join(", ")}`,`${t}(${n})`}function l(e){e=i(e);const{values:t}=e,r=t[0],n=t[1]/100,o=t[2]/100,s=n*Math.min(o,1-o),l=(e,t=(e+r/30)%12)=>o-s*Math.max(Math.min(t-3,9-t,1),-1);let c="rgb";const u=[Math.round(255*l(0)),Math.round(255*l(8)),Math.round(255*l(4))];return"hsla"===e.type&&(c+="a",u.push(t[3])),a({type:c,values:u})}function c(e){let t="hsl"===(e=i(e)).type||"hsla"===e.type?i(l(e)).values:e.values;return t=t.map(t=>("color"!==e.type&&(t/=255),t<=.03928?t/12.92:((t+.055)/1.055)**2.4)),Number((.2126*t[0]+.7152*t[1]+.0722*t[2]).toFixed(3))}function u(e,t){return e=i(e),t=n(t),"rgb"!==e.type&&"hsl"!==e.type||(e.type+="a"),"color"===e.type?e.values[3]=`/${t}`:e.values[3]=t,a(e)}function p(e,t){if(e=i(e),t=n(t),-1!==e.type.indexOf("hsl"))e.values[2]*=1-t;else if(-1!==e.type.indexOf("rgb")||-1!==e.type.indexOf("color"))for(let r=0;r<3;r+=1)e.values[r]*=1-t;return a(e)}function d(e,t){if(e=i(e),t=n(t),-1!==e.type.indexOf("hsl"))e.values[2]+=(100-e.values[2])*t;else if(-1!==e.type.indexOf("rgb"))for(let r=0;r<3;r+=1)e.values[r]+=(255-e.values[r])*t;else if(-1!==e.type.indexOf("color"))for(let r=0;r<3;r+=1)e.values[r]+=(1-e.values[r])*t;return a(e)}function f(e,t=.15){return c(e)>.5?p(e,t):d(e,t)}return Ao.colorChannel=s,Ao.private_safeColorChannel=(e,t)=>{try{return s(e)}catch(r){return t&&"production"!=="development"&&console.warn(t),e}},Ao}var Fo=Do();const $o={black:"#000",white:"#fff"},Bo={50:"#fafafa",100:"#f5f5f5",200:"#eeeeee",300:"#e0e0e0",400:"#bdbdbd",500:"#9e9e9e",600:"#757575",700:"#616161",800:"#424242",900:"#212121",A100:"#f5f5f5",A200:"#eeeeee",A400:"#bdbdbd",A700:"#616161"},zo="#f3e5f5",Vo="#ce93d8",Uo="#ba68c8",qo="#ab47bc",Wo="#9c27b0",Ho="#7b1fa2",Go="#e57373",Ko="#ef5350",Yo="#f44336",Zo="#d32f2f",Xo="#c62828",Jo="#ffb74d",Qo="#ffa726",ei="#ff9800",ti="#f57c00",ri="#e65100",ni="#e3f2fd",oi="#90caf9",ii="#42a5f5",si="#1976d2",ai="#1565c0",li="#4fc3f7",ci="#29b6f6",ui="#03a9f4",pi="#0288d1",di="#01579b",fi="#81c784",hi="#66bb6a",mi="#4caf50",gi="#388e3c",vi="#2e7d32",yi="#1b5e20",bi=["mode","contrastThreshold","tonalOffset"],wi={text:{primary:"rgba(0, 0, 0, 0.87)",secondary:"rgba(0, 0, 0, 0.6)",disabled:"rgba(0, 0, 0, 0.38)"},divider:"rgba(0, 0, 0, 0.12)",background:{paper:$o.white,default:$o.white},action:{active:"rgba(0, 0, 0, 0.54)",hover:"rgba(0, 0, 0, 0.04)",hoverOpacity:.04,selected:"rgba(0, 0, 0, 0.08)",selectedOpacity:.08,disabled:"rgba(0, 0, 0, 0.26)",disabledBackground:"rgba(0, 0, 0, 0.12)",disabledOpacity:.38,focus:"rgba(0, 0, 0, 0.12)",focusOpacity:.12,activatedOpacity:.12}},xi={text:{primary:$o.white,secondary:"rgba(255, 255, 255, 0.7)",disabled:"rgba(255, 255, 255, 0.5)",icon:"rgba(255, 255, 255, 0.5)"},divider:"rgba(255, 255, 255, 0.12)",background:{paper:"#121212",default:"#121212"},action:{active:$o.white,hover:"rgba(255, 255, 255, 0.08)",hoverOpacity:.08,selected:"rgba(255, 255, 255, 0.16)",selectedOpacity:.16,disabled:"rgba(255, 255, 255, 0.3)",disabledBackground:"rgba(255, 255, 255, 0.12)",disabledOpacity:.38,focus:"rgba(255, 255, 255, 0.12)",focusOpacity:.12,activatedOpacity:.24}};function _i(e,t,r,n){const o=n.light||n,i=n.dark||1.5*n;e[t]||(e.hasOwnProperty(r)?e[t]=e[r]:"light"===t?e.light=Fo.lighten(e.main,o):"dark"===t&&(e.dark=Fo.darken(e.main,i)))}const Si=["fontFamily","fontSize","fontWeightLight","fontWeightRegular","fontWeightMedium","fontWeightBold","htmlFontSize","allVariants","pxToRem"],ki={textTransform:"uppercase"},Ci='"Roboto", "Helvetica", "Arial", sans-serif';function Oi(e,t){const r="function"==typeof t?t(e):t,{fontFamily:n=Ci,fontSize:o=14,fontWeightLight:i=300,fontWeightRegular:l=400,fontWeightMedium:c=500,fontWeightBold:u=700,htmlFontSize:p=16,allVariants:d,pxToRem:f}=r,h=s(r,Si); true&&("number"!=typeof o&&console.error("MUI: `fontSize` is required to be a number."),"number"!=typeof p&&console.error("MUI: `htmlFontSize` is required to be a number."));const m=o/14,g=f||(e=>e/p*m+"rem"),v=(e,t,r,o,i)=>{return a({fontFamily:n,fontWeight:e,fontSize:g(t),lineHeight:r},n===Ci?{letterSpacing:(s=o/t,Math.round(1e5*s)/1e5+"em")}:{},i,d);// removed by dead control flow
 var s; },y={h1:v(i,96,1.167,-1.5),h2:v(i,60,1.2,-.5),h3:v(l,48,1.167,0),h4:v(l,34,1.235,.25),h5:v(l,24,1.334,0),h6:v(c,20,1.6,.15),subtitle1:v(l,16,1.75,.15),subtitle2:v(c,14,1.57,.1),body1:v(l,16,1.5,.15),body2:v(l,14,1.43,.15),button:v(c,14,1.75,.4,ki),caption:v(l,12,1.66,.4),overline:v(l,12,2.66,1,ki),inherit:{fontFamily:"inherit",fontWeight:"inherit",fontSize:"inherit",lineHeight:"inherit",letterSpacing:"inherit"}};return Eo(a({htmlFontSize:p,pxToRem:g,fontFamily:n,fontSize:o,fontWeightLight:i,fontWeightRegular:l,fontWeightMedium:c,fontWeightBold:u},y),h,{clone:!1})}function Ei(...e){return[`${e[0]}px ${e[1]}px ${e[2]}px ${e[3]}px rgba(0,0,0,0.2)`,`${e[4]}px ${e[5]}px ${e[6]}px ${e[7]}px rgba(0,0,0,0.14)`,`${e[8]}px ${e[9]}px ${e[10]}px ${e[11]}px rgba(0,0,0,0.12)`].join(",")}const Ti=["none",Ei(0,2,1,-1,0,1,1,0,0,1,3,0),Ei(0,3,1,-2,0,2,2,0,0,1,5,0),Ei(0,3,3,-2,0,3,4,0,0,1,8,0),Ei(0,2,4,-1,0,4,5,0,0,1,10,0),Ei(0,3,5,-1,0,5,8,0,0,1,14,0),Ei(0,3,5,-1,0,6,10,0,0,1,18,0),Ei(0,4,5,-2,0,7,10,1,0,2,16,1),Ei(0,5,5,-3,0,8,10,1,0,3,14,2),Ei(0,5,6,-3,0,9,12,1,0,3,16,2),Ei(0,6,6,-3,0,10,14,1,0,4,18,3),Ei(0,6,7,-4,0,11,15,1,0,4,20,3),Ei(0,7,8,-4,0,12,17,2,0,5,22,4),Ei(0,7,8,-4,0,13,19,2,0,5,24,4),Ei(0,7,9,-4,0,14,21,2,0,5,26,4),Ei(0,8,9,-5,0,15,22,2,0,6,28,5),Ei(0,8,10,-5,0,16,24,2,0,6,30,5),Ei(0,8,11,-5,0,17,26,2,0,6,32,5),Ei(0,9,11,-5,0,18,28,2,0,7,34,6),Ei(0,9,12,-6,0,19,29,2,0,7,36,6),Ei(0,10,13,-6,0,20,31,3,0,8,38,7),Ei(0,10,13,-6,0,21,33,3,0,8,40,7),Ei(0,10,14,-6,0,22,35,3,0,8,42,7),Ei(0,11,14,-7,0,23,36,3,0,9,44,8),Ei(0,11,15,-7,0,24,38,3,0,9,46,8)],Ri=["duration","easing","delay"],Ii={easeInOut:"cubic-bezier(0.4, 0, 0.2, 1)",easeOut:"cubic-bezier(0.0, 0, 0.2, 1)",easeIn:"cubic-bezier(0.4, 0, 1, 1)",sharp:"cubic-bezier(0.4, 0, 0.6, 1)"},Mi={shortest:150,shorter:200,short:250,standard:300,complex:375,enteringScreen:225,leavingScreen:195};function Ai(e){return`${Math.round(e)}ms`}function Pi(e){if(!e)return 0;const t=e/36;return Math.round(10*(4+15*t**.25+t/5))}function Ni(e){const t=a({},Ii,e.easing),r=a({},Mi,e.duration);return a({getAutoHeightDuration:Pi,create:(e=["all"],n={})=>{const{duration:o=r.standard,easing:i=t.easeInOut,delay:a=0}=n,l=s(n,Ri);if(true){const t=e=>"string"==typeof e,r=e=>!isNaN(parseFloat(e));t(e)||Array.isArray(e)||console.error('MUI: Argument "props" must be a string or Array.'),r(o)||t(o)||console.error(`MUI: Argument "duration" must be a number or a string but found ${o}.`),t(i)||console.error('MUI: Argument "easing" must be a string.'),r(a)||t(a)||console.error('MUI: Argument "delay" must be a number or a string.'),"object"!=typeof n&&console.error(["MUI: Secong argument of transition.create must be an object.","Arguments should be either `create('prop1', options)` or `create(['prop1', 'prop2'], options)`"].join("\n")),0!==Object.keys(l).length&&console.error(`MUI: Unrecognized argument(s) [${Object.keys(l).join(",")}].`)}return(Array.isArray(e)?e:[e]).map(e=>`${e} ${"string"==typeof o?o:Ai(o)} ${i} ${"string"==typeof a?a:Ai(a)}`).join(",")}},e,{easing:t,duration:r})}const ji={mobileStepper:1e3,fab:1050,speedDial:1050,appBar:1100,drawer:1200,modal:1300,snackbar:1400,tooltip:1500},Li=["breakpoints","mixins","spacing","palette","transitions","typography","shape"];function Di(e={},...t){const{mixins:r={},palette:n={},transitions:o={},typography:i={}}=e,l=s(e,Li);if(e.vars)throw new Error( true?"MUI: `vars` is a private field used for CSS variables support.\nPlease use another name.":0);const c=function(e){const{mode:t="light",contrastThreshold:r=3,tonalOffset:n=.2}=e,o=s(e,bi),i=e.primary||function(e="light"){return"dark"===e?{main:oi,light:ni,dark:ii}:{main:si,light:ii,dark:ai}}(t),l=e.secondary||function(e="light"){return"dark"===e?{main:Vo,light:zo,dark:qo}:{main:Wo,light:Uo,dark:Ho}}(t),c=e.error||function(e="light"){return"dark"===e?{main:Yo,light:Go,dark:Zo}:{main:Zo,light:Ko,dark:Xo}}(t),u=e.info||function(e="light"){return"dark"===e?{main:ci,light:li,dark:pi}:{main:pi,light:ui,dark:di}}(t),p=e.success||function(e="light"){return"dark"===e?{main:hi,light:fi,dark:gi}:{main:vi,light:mi,dark:yi}}(t),d=e.warning||function(e="light"){return"dark"===e?{main:Qo,light:Jo,dark:ti}:{main:"#ed6c02",light:ei,dark:ri}}(t);function f(e){const t=Fo.getContrastRatio(e,xi.text.primary)>=r?xi.text.primary:wi.text.primary;if(true){const r=Fo.getContrastRatio(e,t);r<3&&console.error([`MUI: The contrast ratio of ${r}:1 for ${t} on ${e}`,"falls below the WCAG recommended absolute minimum contrast ratio of 3:1.","https://www.w3.org/TR/2008/REC-WCAG20-20081211/#visual-audio-contrast-contrast"].join("\n"))}return t}const h=({color:e,name:t,mainShade:r=500,lightShade:o=300,darkShade:i=700})=>{if(!(e=a({},e)).main&&e[r]&&(e.main=e[r]),!e.hasOwnProperty("main"))throw new Error( true?`MUI: The color${t?` (${t})`:""} provided to augmentColor(color) is invalid.\nThe color object needs to have a \`main\` property or a \`${r}\` property.`:0);if("string"!=typeof e.main)throw new Error( true?`MUI: The color${t?` (${t})`:""} provided to augmentColor(color) is invalid.\n\`color.main\` should be a string, but \`${JSON.stringify(e.main)}\` was provided instead.\n\nDid you intend to use one of the following approaches?\n\nimport { green } from "@mui/material/colors";\n\nconst theme1 = createTheme({ palette: {\n  primary: green,\n} });\n\nconst theme2 = createTheme({ palette: {\n  primary: { main: green[500] },\n} });`:0);return _i(e,"light",o,n),_i(e,"dark",i,n),e.contrastText||(e.contrastText=f(e.main)),e},m={dark:xi,light:wi};return true&&(m[t]||console.error(`MUI: The palette mode \`${t}\` is not supported.`)),Eo(a({common:a({},$o),mode:t,primary:h({color:i,name:"primary"}),secondary:h({color:l,name:"secondary",mainShade:"A400",lightShade:"A200",darkShade:"A700"}),error:h({color:c,name:"error"}),warning:h({color:d,name:"warning"}),info:h({color:u,name:"info"}),success:h({color:p,name:"success"}),grey:Bo,contrastThreshold:r,getContrastText:f,augmentColor:h,tonalOffset:n},m[t]),o)}(n),u=go(e);let p=Eo(u,{mixins:(d=u.breakpoints,f=r,a({toolbar:{minHeight:56,[d.up("xs")]:{"@media (orientation: landscape)":{minHeight:48}},[d.up("sm")]:{minHeight:64}}},f)),palette:c,shadows:Ti.slice(),typography:Oi(c,i),transitions:Ni(o),zIndex:a({},ji)});var d,f;if(p=Eo(p,l),p=t.reduce((e,t)=>Eo(e,t),p),"production"!=="development"){const e=["active","checked","completed","disabled","error","expanded","focused","focusVisible","required","selected"],t=(t,r)=>{let n;for(n in t){const o=t[n];if(-1!==e.indexOf(n)&&Object.keys(o).length>0){if(true){const e=Mo("",n);console.error([`MUI: The \`${r}\` component increases the CSS specificity of the \`${n}\` internal state.`,"You can not override it like this: ",JSON.stringify(t,null,2),"",`Instead, you need to use the '&.${e}' syntax:`,JSON.stringify({root:{[`&.${e}`]:o}},null,2),"","https://mui.com/r/state-classes-guide"].join("\n"))}t[n]={}}}};Object.keys(p.components).forEach(e=>{const r=p.components[e].styleOverrides;r&&0===e.indexOf("Mui")&&t(r,e)})}return p.unstable_sxConfig=a({},uo,null==l?void 0:l.unstable_sxConfig),p.unstable_sx=function(e){return fo({sx:e,theme:this})},p}const Fi=Di(),$i="$$material";function Bi(e){return"ownerState"!==e&&"theme"!==e&&"sx"!==e&&"as"!==e}const zi=e=>Bi(e)&&"classes"!==e,Vi=So({themeId:$i,defaultTheme:Fi,rootShouldForwardProp:zi});function Ui(e,t){const r=a({},t);return Object.keys(e).forEach(n=>{if(n.toString().match(/^(components|slots)$/))r[n]=a({},e[n],r[n]);else if(n.toString().match(/^(componentsProps|slotProps)$/)){const o=e[n]||{},i=t[n];r[n]={},i&&Object.keys(i)?o&&Object.keys(o)?(r[n]=a({},i),Object.keys(o).forEach(e=>{r[n][e]=Ui(o[e],i[e])})):r[n]=i:r[n]=o}else void 0===r[n]&&(r[n]=e[n])}),r}function qi(e){const{theme:t,name:r,props:n}=e;return t&&t.components&&t.components[r]&&t.components[r].defaultProps?Ui(t.components[r].defaultProps,n):n}function Wi(e=null){const t=o.useContext(St);return t&&(r=t,0!==Object.keys(r).length)?t:e;// removed by dead control flow
 var r; }const Hi=go();function Gi(e=Hi){return Wi(e)}function Ki({props:e,name:t,defaultTheme:r,themeId:n}){let o=Gi(r);return n&&(o=o[n]||o),qi({theme:o,name:t,props:e})}function Yi({props:e,name:t}){return Ki({props:e,name:t,defaultTheme:Fi,themeId:$i})}function Zi(e){if("string"!=typeof e)throw new Error( true?"MUI: `capitalize(string)` expects a string argument.":0);return e.charAt(0).toUpperCase()+e.slice(1)}const Xi=Number.isInteger||function(e){return"number"==typeof e&&isFinite(e)&&Math.floor(e)===e};function Ji(e,t,r,n){const o=e[t];if(null==o||!Xi(o)){const e=function(e){const t=typeof e;switch(t){case"number":return Number.isNaN(e)?"NaN":Number.isFinite(e)?e!==Math.floor(e)?"float":"number":"Infinity";case"object":return null===e?"null":e.constructor.name;default:return t}}(o);return new RangeError(`Invalid ${n} \`${t}\` of type \`${e}\` supplied to \`${r}\`, expected \`integer\`.`)}return null}function Qi(e,t,...r){return void 0===e[t]?null:Ji(e,t,...r)}function es(){return null}Qi.isRequired=Ji,es.isRequired=es;const ts= false?0:Qi;function rs(e,t){return false?0:function(...r){return e(...r)||t(...r)}}const ns=e=>{let t;return t=e<1?5.11916*e**2:4.5*Math.log(e+1)+2,(t/100).toFixed(2)};function os({styles:t,themeId:r,defaultTheme:n={}}){const o=Gi(n),i="function"==typeof t?t(r&&o[r]||o):t;return e.jsx(Nr,{styles:i})} true&&(os.propTypes={defaultTheme:B.object,styles:B.oneOfType([B.array,B.func,B.number,B.object,B.string,B.bool]),themeId:B.string});const is=e=>e,ss=(()=>{let e=is;return{configure(t){e=t},generate:t=>e(t),reset(){e=is}}})();function as(e){var t,r,n="";if("string"==typeof e||"number"==typeof e)n+=e;else if("object"==typeof e)if(Array.isArray(e)){var o=e.length;for(t=0;t<o;t++)e[t]&&(r=as(e[t]))&&(n&&(n+=" "),n+=r)}else for(r in e)e[r]&&(n&&(n+=" "),n+=r);return n}function ls(){for(var e,t,r=0,n="",o=arguments.length;r<o;r++)(e=arguments[r])&&(t=as(e))&&(n&&(n+=" "),n+=t);return n}const cs=["className","component"],us={active:"active",checked:"checked",completed:"completed",disabled:"disabled",error:"error",expanded:"expanded",focused:"focused",focusVisible:"focusVisible",open:"open",readOnly:"readOnly",required:"required",selected:"selected"},ps=["ownerState"],ds=["variants"],fs=["name","slot","skipVariantsResolver","skipSx","overridesResolver"];function hs(e){return"ownerState"!==e&&"theme"!==e&&"sx"!==e&&"as"!==e}const ms=go(),gs=e=>e?e.charAt(0).toLowerCase()+e.slice(1):e;function vs({defaultTheme:e,theme:t,themeId:r}){return n=t,0===Object.keys(n).length?e:t[r]||t;// removed by dead control flow
 var n; }function ys(e){return e?(t,r)=>r[e]:null}function bs(e,t){let{ownerState:r}=t,n=s(t,ps);const o="function"==typeof e?e(a({ownerState:r},n)):e;if(Array.isArray(o))return o.flatMap(e=>bs(e,a({ownerState:r},n)));if(o&&"object"==typeof o&&Array.isArray(o.variants)){const{variants:e=[]}=o;let t=s(o,ds);return e.forEach(e=>{let o=!0;"function"==typeof e.props?o=e.props(a({ownerState:r},n,r)):Object.keys(e.props).forEach(t=>{(null==r?void 0:r[t])!==e.props[t]&&n[t]!==e.props[t]&&(o=!1)}),o&&(Array.isArray(t)||(t=[t]),t.push("function"==typeof e.style?e.style(a({ownerState:r},n,r)):e.style))}),t}return o}const ws=function(e={}){const{themeId:t,defaultTheme:r=ms,rootShouldForwardProp:n=hs,slotShouldForwardProp:o=hs}=e,i=e=>fo(a({},e,{theme:vs(a({},e,{defaultTheme:r,themeId:t}))}));return i.__mui_systemSx=!0,(e,l={})=>{Lr(e,e=>e.filter(e=>!(null!=e&&e.__mui_systemSx)));const{name:c,slot:u,skipVariantsResolver:p,skipSx:d,overridesResolver:f=ys(gs(u))}=l,h=s(l,fs),m=void 0!==p?p:u&&"Root"!==u&&"root"!==u||!1,g=d||!1;let v; true&&c&&(v=`${c}-${gs(u||"Root")}`);let y=hs;"Root"===u||"root"===u?y=n:u?y=o:function(e){return"string"==typeof e&&e.charCodeAt(0)>96}(e)&&(y=void 0);const b=jr(e,a({shouldForwardProp:y,label:v},h)),w=e=>"function"==typeof e&&e.__emotion_real!==e||$r(e)?n=>bs(e,a({},n,{theme:vs({theme:n.theme,defaultTheme:r,themeId:t})})):e,x=(n,...o)=>{let s=w(n);const l=o?o.map(w):[];c&&f&&l.push(e=>{const n=vs(a({},e,{defaultTheme:r,themeId:t}));if(!n.components||!n.components[c]||!n.components[c].styleOverrides)return null;const o=n.components[c].styleOverrides,i={};return Object.entries(o).forEach(([t,r])=>{i[t]=bs(r,a({},e,{theme:n}))}),f(e,i)}),c&&!m&&l.push(e=>{var n;const o=vs(a({},e,{defaultTheme:r,themeId:t}));return bs({variants:null==o||null==(n=o.components)||null==(n=n[c])?void 0:n.variants},a({},e,{theme:o}))}),g||l.push(i);const p=l.length-o.length;if(Array.isArray(n)&&p>0){const e=new Array(p).fill("");s=[...n,...e],s.raw=[...n.raw,...e]}const d=b(s,...l);if(true){let t;c&&(t=`${c}${Wr(u||"")}`),void 0===t&&(t=`Styled(${ln(e)})`),d.displayName=t}return e.muiName&&(d.muiName=e.muiName),d};return b.withConfig&&(x.withConfig=b.withConfig),x}}(),xs="undefined"!=typeof window?o.useLayoutEffect:o.useEffect;function _s(e,t,r,n,i){const[s,a]=o.useState(()=>i&&r?r(e).matches:n?n(e).matches:t);return xs(()=>{let t=!0;if(!r)return;const n=r(e),o=()=>{t&&a(n.matches)};return o(),n.addListener(o),()=>{t=!1,n.removeListener(o)}},[e,r]),s}const Ss=o.useSyncExternalStore;function ks(e,t,r,n,i){const s=o.useCallback(()=>t,[t]),a=o.useMemo(()=>{if(i&&r)return()=>r(e).matches;if(null!==n){const{matches:t}=n(e);return()=>t}return s},[s,e,n,i,r]),[l,c]=o.useMemo(()=>{if(null===r)return[s,()=>()=>{}];const t=r(e);return[()=>t.matches,e=>(t.addListener(e),()=>{t.removeListener(e)})]},[s,r,e]);return Ss(c,l,a)}function Cs(e,t={}){const r=Wi(),n="undefined"!=typeof window&&void 0!==window.matchMedia,{defaultMatches:i=!1,matchMedia:s=(n?window.matchMedia:null),ssrMatchMedia:a=null,noSsr:l=!1}=qi({name:"MuiUseMediaQuery",props:t,theme:r}); true&&"function"==typeof e&&null===r&&console.error(["MUI: The `query` argument provided is invalid.","You are providing a function without a theme in the context.","One of the parent elements needs to use a ThemeProvider."].join("\n"));let c="function"==typeof e?e(r):e;c=c.replace(/^@media( ?)/m,"");const u=(void 0!==Ss?ks:_s)(c,i,s,a,l);return true&&o.useDebugValue({query:c,match:u}),u}function Os(e,t=0,r=1){return true&&(e<t||e>r)&&console.error(`MUI: The value provided ${e} is out of range [${t}, ${r}].`),No(e,t,r)}function Es(e){if(e.type)return e;if("#"===e.charAt(0))return Es(function(e){e=e.slice(1);const t=new RegExp(`.{1,${e.length>=6?2:1}}`,"g");let r=e.match(t);return r&&1===r[0].length&&(r=r.map(e=>e+e)),r?`rgb${4===r.length?"a":""}(${r.map((e,t)=>t<3?parseInt(e,16):Math.round(parseInt(e,16)/255*1e3)/1e3).join(", ")})`:""}(e));const t=e.indexOf("("),r=e.substring(0,t);if(-1===["rgb","rgba","hsl","hsla","color"].indexOf(r))throw new Error( true?`MUI: Unsupported \`${e}\` color.\nThe following formats are supported: #nnn, #nnnnnn, rgb(), rgba(), hsl(), hsla(), color().`:0);let n,o=e.substring(t+1,e.length-1);if("color"===r){if(o=o.split(" "),n=o.shift(),4===o.length&&"/"===o[3].charAt(0)&&(o[3]=o[3].slice(1)),-1===["srgb","display-p3","a98-rgb","prophoto-rgb","rec-2020"].indexOf(n))throw new Error( true?`MUI: unsupported \`${n}\` color space.\nThe following color spaces are supported: srgb, display-p3, a98-rgb, prophoto-rgb, rec-2020.`:0)}else o=o.split(",");return o=o.map(e=>parseFloat(e)),{type:r,values:o,colorSpace:n}}function Ts(e){const{type:t,colorSpace:r}=e;let{values:n}=e;return-1!==t.indexOf("rgb")?n=n.map((e,t)=>t<3?parseInt(e,10):e):-1!==t.indexOf("hsl")&&(n[1]=`${n[1]}%`,n[2]=`${n[2]}%`),n=-1!==t.indexOf("color")?`${r} ${n.join(" ")}`:`${n.join(", ")}`,`${t}(${n})`}function Rs(e,t){return e=Es(e),t=Os(t),"rgb"!==e.type&&"hsl"!==e.type||(e.type+="a"),"color"===e.type?e.values[3]=`/${t}`:e.values[3]=t,Ts(e)}function Is(e,t){if(e=Es(e),t=Os(t),-1!==e.type.indexOf("hsl"))e.values[2]*=1-t;else if(-1!==e.type.indexOf("rgb")||-1!==e.type.indexOf("color"))for(let r=0;r<3;r+=1)e.values[r]*=1-t;return Ts(e)}function Ms(e,t){if(e=Es(e),t=Os(t),-1!==e.type.indexOf("hsl"))e.values[2]+=(100-e.values[2])*t;else if(-1!==e.type.indexOf("rgb"))for(let r=0;r<3;r+=1)e.values[r]+=(255-e.values[r])*t;else if(-1!==e.type.indexOf("color"))for(let r=0;r<3;r+=1)e.values[r]+=(1-e.values[r])*t;return Ts(e)}const As="exact-prop: ​",Ps=o.createContext(null); true&&(Ps.displayName="ThemeContext");const Ns=Ps;function js(){const e=o.useContext(Ns);return true&&o.useDebugValue(e),e}const Ls="function"==typeof Symbol&&Symbol.for?Symbol.for("mui.nested"):"__THEME_NESTED__";function Ds(t){const{children:r,theme:n}=t,i=js(); true&&null===i&&"function"==typeof n&&console.error(["MUI: You are providing a theme function prop to the ThemeProvider component:","<ThemeProvider theme={outerTheme => outerTheme} />","","However, no outer theme is present.","Make sure a theme is already injected higher in the React tree or provide a theme object."].join("\n"));const s=o.useMemo(()=>{const e=null===i?n:function(e,t){if("function"==typeof t){const r=t(e);return true&&(r||console.error(["MUI: You should return an object from your theme function, i.e.","<ThemeProvider theme={() => ({})} />"].join("\n"))),r}return a({},e,t)}(i,n);return null!=e&&(e[Ls]=null!==i),e},[n,i]);return e.jsx(Ns.Provider,{value:s,children:r})} true&&(Ds.propTypes={children:B.node,theme:B.oneOfType([B.object,B.func]).isRequired}), true&&(Ds.propTypes=function(e){return false?0:a({},e,{[As]:t=>{const r=Object.keys(t).filter(t=>!e.hasOwnProperty(t));return r.length>0?new Error(`The following props are not supported: ${r.map(e=>`\`${e}\``).join(", ")}. Please remove them.`):null}})}(Ds.propTypes));const Fs="exact-prop: ​",$s=["value"],Bs=o.createContext();function zs(t){let{value:r}=t,n=s(t,$s);return e.jsx(Bs.Provider,a({value:null==r||r},n))} true&&(zs.propTypes={children:B.node,value:B.bool});const Vs=()=>{const e=o.useContext(Bs);return null!=e&&e},Us=o.createContext(void 0);function qs({value:t,children:r}){return e.jsx(Us.Provider,{value:t,children:r})} true&&(qs.propTypes={children:B.node,value:B.object});const Ws={};function Hs(e,t,r,n=!1){return o.useMemo(()=>{const o=e&&t[e]||t;if("function"==typeof r){const i=r(o),s=e?a({},t,{[e]:i}):i;return n?()=>s:s}return a({},t,e?{[e]:r}:r)},[e,t,r,n])}function Gs(t){const{children:r,theme:n,themeId:o}=t,i=Wi(Ws),s=js()||Ws; true&&(null===i&&"function"==typeof n||o&&i&&!i[o]&&"function"==typeof n)&&console.error(["MUI: You are providing a theme function prop to the ThemeProvider component:","<ThemeProvider theme={outerTheme => outerTheme} />","","However, no outer theme is present.","Make sure a theme is already injected higher in the React tree or provide a theme object."].join("\n"));const a=Hs(o,i,n),l=Hs(o,s,n,!0),c="rtl"===a.direction;return e.jsx(Ds,{theme:l,children:e.jsx(St.Provider,{value:a,children:e.jsx(zs,{value:c,children:e.jsx(qs,{value:null==a?void 0:a.components,children:r})})})})} true&&(Gs.propTypes={children:B.node,theme:B.oneOfType([B.func,B.object]).isRequired,themeId:B.string}), true&&(Gs.propTypes=function(e){return false?0:a({},e,{[Fs]:t=>{const r=Object.keys(t).filter(t=>!e.hasOwnProperty(t));return r.length>0?new Error(`The following props are not supported: ${r.map(e=>`\`${e}\``).join(", ")}. Please remove them.`):null}})}(Gs.propTypes));const Ks=["component","direction","spacing","divider","children","className","useFlexGap"],Ys=go(),Zs=ws("div",{name:"MuiStack",slot:"Root",overridesResolver:(e,t)=>t.root});function Xs(e){return Ki({props:e,name:"MuiStack",defaultTheme:Ys})}function Js(e,t){const r=o.Children.toArray(e).filter(Boolean);return r.reduce((e,n,i)=>(e.push(n),i<r.length-1&&e.push(o.cloneElement(t,{key:`separator-${i}`})),e),[])}const Qs=({ownerState:e,theme:t})=>{let r=a({display:"flex",flexDirection:"column"},vn({theme:t},wn({values:e.direction,breakpoints:t.breakpoints.values}),e=>({flexDirection:e})));if(e.spacing){const n=An(t),o=Object.keys(t.breakpoints.values).reduce((t,r)=>(("object"==typeof e.spacing&&null!=e.spacing[r]||"object"==typeof e.direction&&null!=e.direction[r])&&(t[r]=!0),t),{}),i=wn({values:e.direction,base:o}),s=wn({values:e.spacing,base:o});"object"==typeof i&&Object.keys(i).forEach((e,t,r)=>{if(!i[e]){const n=t>0?i[r[t-1]]:"column";i[e]=n}}),r=zr(r,vn({theme:t},s,(t,r)=>{return e.useFlexGap?{gap:Pn(n,t)}:{"& > :not(style):not(style)":{margin:0},"& > :not(style) ~ :not(style)":{[`margin${o=r?i[r]:e.direction,{row:"Left","row-reverse":"Right",column:"Top","column-reverse":"Bottom"}[o]}`]:Pn(n,t)}};// removed by dead control flow
 var o; }))}return r=function(e,...t){const r=yn(e),n=[r,...t].reduce((e,t)=>zr(e,t),{});return bn(Object.keys(r),n)}(t.breakpoints,r),r};function ea(){const e=Gi(Fi);return true&&o.useDebugValue(e),e[$i]||e}function ta(e,t,r="Mui"){const n={};return t.forEach(t=>{n[t]=Mo(e,t,r)}),n}function ra(e){return Mo("MuiPaper",e)}ta("MuiPaper",["root","rounded","outlined","elevation","elevation0","elevation1","elevation2","elevation3","elevation4","elevation5","elevation6","elevation7","elevation8","elevation9","elevation10","elevation11","elevation12","elevation13","elevation14","elevation15","elevation16","elevation17","elevation18","elevation19","elevation20","elevation21","elevation22","elevation23","elevation24"]);const na=["className","component","elevation","square","variant"],oa=Vi("div",{name:"MuiPaper",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,t[r.variant],!r.square&&t.rounded,"elevation"===r.variant&&t[`elevation${r.elevation}`]]}})(({theme:e,ownerState:t})=>{var r;return a({backgroundColor:(e.vars||e).palette.background.paper,color:(e.vars||e).palette.text.primary,transition:e.transitions.create("box-shadow")},!t.square&&{borderRadius:e.shape.borderRadius},"outlined"===t.variant&&{border:`1px solid ${(e.vars||e).palette.divider}`},"elevation"===t.variant&&a({boxShadow:(e.vars||e).shadows[t.elevation]},!e.vars&&"dark"===e.palette.mode&&{backgroundImage:`linear-gradient(${Fo.alpha("#fff",ns(t.elevation))}, ${Fo.alpha("#fff",ns(t.elevation))})`},e.vars&&{backgroundImage:null==(r=e.vars.overlays)?void 0:r[t.elevation]}))}),ia=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiPaper"}),{className:o,component:i="div",elevation:l=1,square:c=!1,variant:u="elevation"}=n,p=s(n,na),d=a({},n,{component:i,elevation:l,square:c,variant:u}),f=(e=>{const{square:t,elevation:r,variant:n,classes:o}=e;return U({root:["root",n,!t&&"rounded","elevation"===n&&`elevation${r}`]},ra,o)})(d);return true&&void 0===ea().shadows[l]&&console.error([`MUI: The elevation provided <Paper elevation={${l}}> is not available in the theme.`,`Please make sure that \`theme.shadows[${l}]\` is defined.`].join("\n")),e.jsx(oa,a({as:i,ownerState:d,className:V(f.root,o),ref:r},p))}); true&&(ia.propTypes={children:B.node,classes:B.object,className:B.string,component:B.elementType,elevation:rs(ts,e=>{const{elevation:t,variant:r}=e;return t>0&&"outlined"===r?new Error(`MUI: Combining \`elevation={${t}}\` with \`variant="${r}"\` has no effect. Either use \`elevation={0}\` or use a different \`variant\`.`):null}),square:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),variant:B.oneOfType([B.oneOf(["elevation","outlined"]),B.string])});const sa=ia;function aa(e){return Mo("MuiAppBar",e)}ta("MuiAppBar",["root","positionFixed","positionAbsolute","positionSticky","positionStatic","positionRelative","colorDefault","colorPrimary","colorSecondary","colorInherit","colorTransparent","colorError","colorInfo","colorSuccess","colorWarning"]);const la=["className","color","enableColorOnDark","position"],ca=(e,t)=>e?`${null==e?void 0:e.replace(")","")}, ${t})`:t,ua=Vi(sa,{name:"MuiAppBar",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,t[`position${Zi(r.position)}`],t[`color${Zi(r.color)}`]]}})(({theme:e,ownerState:t})=>{const r="light"===e.palette.mode?e.palette.grey[100]:e.palette.grey[900];return a({display:"flex",flexDirection:"column",width:"100%",boxSizing:"border-box",flexShrink:0},"fixed"===t.position&&{position:"fixed",zIndex:(e.vars||e).zIndex.appBar,top:0,left:"auto",right:0,"@media print":{position:"absolute"}},"absolute"===t.position&&{position:"absolute",zIndex:(e.vars||e).zIndex.appBar,top:0,left:"auto",right:0},"sticky"===t.position&&{position:"sticky",zIndex:(e.vars||e).zIndex.appBar,top:0,left:"auto",right:0},"static"===t.position&&{position:"static"},"relative"===t.position&&{position:"relative"},!e.vars&&a({},"default"===t.color&&{backgroundColor:r,color:e.palette.getContrastText(r)},t.color&&"default"!==t.color&&"inherit"!==t.color&&"transparent"!==t.color&&{backgroundColor:e.palette[t.color].main,color:e.palette[t.color].contrastText},"inherit"===t.color&&{color:"inherit"},"dark"===e.palette.mode&&!t.enableColorOnDark&&{backgroundColor:null,color:null},"transparent"===t.color&&a({backgroundColor:"transparent",color:"inherit"},"dark"===e.palette.mode&&{backgroundImage:"none"})),e.vars&&a({},"default"===t.color&&{"--AppBar-background":t.enableColorOnDark?e.vars.palette.AppBar.defaultBg:ca(e.vars.palette.AppBar.darkBg,e.vars.palette.AppBar.defaultBg),"--AppBar-color":t.enableColorOnDark?e.vars.palette.text.primary:ca(e.vars.palette.AppBar.darkColor,e.vars.palette.text.primary)},t.color&&!t.color.match(/^(default|inherit|transparent)$/)&&{"--AppBar-background":t.enableColorOnDark?e.vars.palette[t.color].main:ca(e.vars.palette.AppBar.darkBg,e.vars.palette[t.color].main),"--AppBar-color":t.enableColorOnDark?e.vars.palette[t.color].contrastText:ca(e.vars.palette.AppBar.darkColor,e.vars.palette[t.color].contrastText)},{backgroundColor:"var(--AppBar-background)",color:"inherit"===t.color?"inherit":"var(--AppBar-color)"},"transparent"===t.color&&{backgroundImage:"none",backgroundColor:"transparent",color:"inherit"}))}),pa=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiAppBar"}),{className:o,color:i="primary",enableColorOnDark:l=!1,position:c="fixed"}=n,u=s(n,la),p=a({},n,{color:i,position:c,enableColorOnDark:l}),d=(e=>{const{color:t,position:r,classes:n}=e;return U({root:["root",`color${Zi(t)}`,`position${Zi(r)}`]},aa,n)})(p);return e.jsx(ua,a({square:!0,component:"header",ownerState:p,elevation:4,className:V(d.root,o,"fixed"===c&&"mui-fixed"),ref:r},u))}); true&&(pa.propTypes={children:B.node,classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["default","inherit","primary","secondary","transparent","error","info","success","warning"]),B.string]),enableColorOnDark:B.bool,position:B.oneOf(["absolute","fixed","relative","static","sticky"]),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const da=pa,fa={elevation:0,color:"default"},ha=t.forwardRef((e,r)=>t.createElement(da,{...fa,...e,ref:r}));ha.defaultProps=fa;var ma=ha;const ga=function(t={}){const{createStyledComponent:r=Zs,useThemeProps:n=Xs,componentName:i="MuiStack"}=t,l=()=>function(e,t,r){const n={};return Object.keys(e).forEach(t=>{n[t]=e[t].reduce((e,t)=>{if(t){const n=(e=>function(e,t,r="Mui"){const n=us[t];return n?`${r}-${n}`:`${ss.generate(e)}-${t}`}(i,e))(t);""!==n&&e.push(n),r&&r[t]&&e.push(r[t])}return e},[]).join(" ")}),n}({root:["root"]},0,{}),c=r(Qs),u=o.forwardRef(function(t,r){const o=bo(n(t)),{component:i="div",direction:u="column",spacing:p=0,divider:d,children:f,className:h,useFlexGap:m=!1}=o,g=s(o,Ks),v={direction:u,spacing:p,useFlexGap:m},y=l();return e.jsx(c,a({as:i,ownerState:v,ref:r,className:ls(y.root,h)},g,{children:d?Js(f,d):f}))});return true&&(u.propTypes={children:B.node,direction:B.oneOfType([B.oneOf(["column-reverse","column","row-reverse","row"]),B.arrayOf(B.oneOf(["column-reverse","column","row-reverse","row"])),B.object]),divider:B.node,spacing:B.oneOfType([B.arrayOf(B.oneOfType([B.number,B.string])),B.number,B.object,B.string]),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])}),u}({createStyledComponent:Vi("div",{name:"MuiStack",slot:"Root",overridesResolver:(e,t)=>t.root}),useThemeProps:e=>Yi({props:e,name:"MuiStack"})}); true&&(ga.propTypes={children:B.node,component:B.elementType,direction:B.oneOfType([B.oneOf(["column-reverse","column","row-reverse","row"]),B.arrayOf(B.oneOf(["column-reverse","column","row-reverse","row"])),B.object]),divider:B.node,spacing:B.oneOfType([B.arrayOf(B.oneOfType([B.number,B.string])),B.number,B.object,B.string]),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),useFlexGap:B.bool});const va=ga;var ya=t.forwardRef((e,r)=>t.createElement(va,{...e,ref:r}));function ba(e){return Mo("MuiToolbar",e)}ta("MuiToolbar",["root","gutters","regular","dense"]);const wa=["className","component","disableGutters","variant"],xa=Vi("div",{name:"MuiToolbar",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,!r.disableGutters&&t.gutters,t[r.variant]]}})(({theme:e,ownerState:t})=>a({position:"relative",display:"flex",alignItems:"center"},!t.disableGutters&&{paddingLeft:e.spacing(2),paddingRight:e.spacing(2),[e.breakpoints.up("sm")]:{paddingLeft:e.spacing(3),paddingRight:e.spacing(3)}},"dense"===t.variant&&{minHeight:48}),({theme:e,ownerState:t})=>"regular"===t.variant&&e.mixins.toolbar),_a=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiToolbar"}),{className:o,component:i="div",disableGutters:l=!1,variant:c="regular"}=n,u=s(n,wa),p=a({},n,{component:i,disableGutters:l,variant:c}),d=(e=>{const{classes:t,disableGutters:r,variant:n}=e;return U({root:["root",!r&&"gutters",n]},ba,t)})(p);return e.jsx(xa,a({as:i,className:V(d.root,o),ref:r,ownerState:p},u))}); true&&(_a.propTypes={children:B.node,classes:B.object,className:B.string,component:B.elementType,disableGutters:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),variant:B.oneOfType([B.oneOf(["dense","regular"]),B.string])});const Sa=_a;var ka=t.forwardRef((e,r)=>t.createElement(Sa,{...e,ref:r}));function Ca(e){return Mo("MuiTypography",e)}ta("MuiTypography",["root","h1","h2","h3","h4","h5","h6","subtitle1","subtitle2","body1","body2","inherit","button","caption","overline","alignLeft","alignRight","alignCenter","alignJustify","noWrap","gutterBottom","paragraph"]);const Oa=["align","className","component","gutterBottom","noWrap","paragraph","variant","variantMapping"],Ea=Vi("span",{name:"MuiTypography",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,r.variant&&t[r.variant],"inherit"!==r.align&&t[`align${Zi(r.align)}`],r.noWrap&&t.noWrap,r.gutterBottom&&t.gutterBottom,r.paragraph&&t.paragraph]}})(({theme:e,ownerState:t})=>a({margin:0},"inherit"===t.variant&&{font:"inherit"},"inherit"!==t.variant&&e.typography[t.variant],"inherit"!==t.align&&{textAlign:t.align},t.noWrap&&{overflow:"hidden",textOverflow:"ellipsis",whiteSpace:"nowrap"},t.gutterBottom&&{marginBottom:"0.35em"},t.paragraph&&{marginBottom:16})),Ta={h1:"h1",h2:"h2",h3:"h3",h4:"h4",h5:"h5",h6:"h6",subtitle1:"h6",subtitle2:"h6",body1:"p",body2:"p",inherit:"p"},Ra={primary:"primary.main",textPrimary:"text.primary",secondary:"secondary.main",textSecondary:"text.secondary",error:"error.main"},Ia=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiTypography"}),o=(e=>Ra[e]||e)(n.color),i=bo(a({},n,{color:o})),{align:l="inherit",className:c,component:u,gutterBottom:p=!1,noWrap:d=!1,paragraph:f=!1,variant:h="body1",variantMapping:m=Ta}=i,g=s(i,Oa),v=a({},i,{align:l,color:o,className:c,component:u,gutterBottom:p,noWrap:d,paragraph:f,variant:h,variantMapping:m}),y=u||(f?"p":m[h]||Ta[h])||"span",b=(e=>{const{align:t,gutterBottom:r,noWrap:n,paragraph:o,variant:i,classes:s}=e;return U({root:["root",i,"inherit"!==e.align&&`align${Zi(t)}`,r&&"gutterBottom",n&&"noWrap",o&&"paragraph"]},Ca,s)})(v);return e.jsx(Ea,a({as:y,ref:r,ownerState:v,className:V(b.root,c)},g))}); true&&(Ia.propTypes={align:B.oneOf(["center","inherit","justify","left","right"]),children:B.node,classes:B.object,className:B.string,component:B.elementType,gutterBottom:B.bool,noWrap:B.bool,paragraph:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),variant:B.oneOfType([B.oneOf(["body1","body2","button","caption","h1","h2","h3","h4","h5","h6","inherit","overline","subtitle1","subtitle2"]),B.string]),variantMapping:B.object});const Ma=Ia,Aa={variantMapping:{display1:"h1",display2:"h2",display3:"h3",display4:"h4",display5:"h5",display6:"h6"}},Pa=t.forwardRef((e,r)=>{const n={...Aa,...e,variantMapping:{...Aa.variantMapping,...e.variantMapping}};return t.createElement(Ma,{...n,ref:r})});Pa.defaultProps=Aa;var Na=Pa;const ja=B.oneOfType([B.func,B.object]),La=rs(B.elementType,function(e,t,r,n,o){const i=e[t],s=o||t;if(null==i||"undefined"==typeof window)return null;let a;return"function"!=typeof i||function(e){const{prototype:t={}}=e;return Boolean(t.isReactComponent)}(i)||(a="Did you accidentally provide a plain function component instead?"),void 0!==a?new Error(`Invalid ${n} \`${s}\` supplied to \`${r}\`. Expected an element type that can hold a ref. ${a} For more information see https://mui.com/r/caveat-with-refs-guide`):null});function Da(e,t){"function"==typeof e?e(t):e&&(e.current=t)}function Fa(...e){return o.useMemo(()=>e.every(e=>null==e)?null:t=>{e.forEach(e=>{Da(e,t)})},e)}const $a="undefined"!=typeof window?o.useLayoutEffect:o.useEffect;function Ba(e){const t=o.useRef(e);return $a(()=>{t.current=e}),o.useRef((...e)=>(0,t.current)(...e)).current}const za={},Va=[];class Ua{static create(){return new Ua}start(e,t){this.clear(),this.currentId=setTimeout(()=>{this.currentId=null,t()},e)}constructor(){this.currentId=null,this.clear=()=>{null!==this.currentId&&(clearTimeout(this.currentId),this.currentId=null)},this.disposeEffect=()=>this.clear}}function qa(){const e=function(e){const t=o.useRef(za);return t.current===za&&(t.current=e(void 0)),t}(Ua.create).current;var t;return t=e.disposeEffect,o.useEffect(t,Va),e}let Wa=!0,Ha=!1;const Ga=new Ua,Ka={text:!0,search:!0,url:!0,tel:!0,email:!0,password:!0,number:!0,date:!0,month:!0,week:!0,time:!0,datetime:!0,"datetime-local":!0};function Ya(e){e.metaKey||e.altKey||e.ctrlKey||(Wa=!0)}function Za(){Wa=!1}function Xa(){"hidden"===this.visibilityState&&Ha&&(Wa=!0)}function Ja(){const e=o.useCallback(e=>{var t;null!=e&&((t=e.ownerDocument).addEventListener("keydown",Ya,!0),t.addEventListener("mousedown",Za,!0),t.addEventListener("pointerdown",Za,!0),t.addEventListener("touchstart",Za,!0),t.addEventListener("visibilitychange",Xa,!0))},[]),t=o.useRef(!1);return{isFocusVisibleRef:t,onFocus:function(e){return!!function(e){const{target:t}=e;try{return t.matches(":focus-visible")}catch(e){}return Wa||function(e){const{type:t,tagName:r}=e;return!("INPUT"!==r||!Ka[t]||e.readOnly)||"TEXTAREA"===r&&!e.readOnly||!!e.isContentEditable}(t)}(e)&&(t.current=!0,!0)},onBlur:function(){return!!t.current&&(Ha=!0,Ga.start(100,()=>{Ha=!1}),t.current=!1,!0)},ref:e}}function Qa(e,t){return Qa=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(e,t){return e.__proto__=t,e},Qa(e,t)}function el(e,t){e.prototype=Object.create(t.prototype),e.prototype.constructor=e,Qa(e,t)}var tl= true?B.oneOfType([B.number,B.shape({enter:B.number,exit:B.number,appear:B.number}).isRequired]):0; true&&B.oneOfType([B.string,B.shape({enter:B.string,exit:B.string,active:B.string}),B.shape({enter:B.string,enterDone:B.string,enterActive:B.string,exit:B.string,exitDone:B.string,exitActive:B.string})]);const rl=t.createContext(null);var nl="unmounted",ol="exited",il="entering",sl="entered",al="exiting",ll=function(e){function n(t,r){var n;n=e.call(this,t,r)||this;var o,i=r&&!r.isMounting?t.enter:t.appear;return n.appearStatus=null,t.in?i?(o=ol,n.appearStatus=il):o=sl:o=t.unmountOnExit||t.mountOnEnter?nl:ol,n.state={status:o},n.nextCallback=null,n}el(n,e),n.getDerivedStateFromProps=function(e,t){return e.in&&t.status===nl?{status:ol}:null};var o=n.prototype;return o.componentDidMount=function(){this.updateStatus(!0,this.appearStatus)},o.componentDidUpdate=function(e){var t=null;if(e!==this.props){var r=this.state.status;this.props.in?r!==il&&r!==sl&&(t=il):r!==il&&r!==sl||(t=al)}this.updateStatus(!1,t)},o.componentWillUnmount=function(){this.cancelNextCallback()},o.getTimeouts=function(){var e,t,r,n=this.props.timeout;return e=t=r=n,null!=n&&"number"!=typeof n&&(e=n.exit,t=n.enter,r=void 0!==n.appear?n.appear:t),{exit:e,enter:t,appear:r}},o.updateStatus=function(e,t){void 0===e&&(e=!1),null!==t?(this.cancelNextCallback(),t===il?((this.props.unmountOnExit||this.props.mountOnEnter)&&(this.props.nodeRef?this.props.nodeRef.current:r.findDOMNode(this)),this.performEnter(e)):this.performExit()):this.props.unmountOnExit&&this.state.status===ol&&this.setState({status:nl})},o.performEnter=function(e){var t=this,n=this.props.enter,o=this.context?this.context.isMounting:e,i=this.props.nodeRef?[o]:[r.findDOMNode(this),o],s=i[0],a=i[1],l=this.getTimeouts(),c=o?l.appear:l.enter;e||n?(this.props.onEnter(s,a),this.safeSetState({status:il},function(){t.props.onEntering(s,a),t.onTransitionEnd(c,function(){t.safeSetState({status:sl},function(){t.props.onEntered(s,a)})})})):this.safeSetState({status:sl},function(){t.props.onEntered(s)})},o.performExit=function(){var e=this,t=this.props.exit,n=this.getTimeouts(),o=this.props.nodeRef?void 0:r.findDOMNode(this);t?(this.props.onExit(o),this.safeSetState({status:al},function(){e.props.onExiting(o),e.onTransitionEnd(n.exit,function(){e.safeSetState({status:ol},function(){e.props.onExited(o)})})})):this.safeSetState({status:ol},function(){e.props.onExited(o)})},o.cancelNextCallback=function(){null!==this.nextCallback&&(this.nextCallback.cancel(),this.nextCallback=null)},o.safeSetState=function(e,t){t=this.setNextCallback(t),this.setState(e,t)},o.setNextCallback=function(e){var t=this,r=!0;return this.nextCallback=function(n){r&&(r=!1,t.nextCallback=null,e(n))},this.nextCallback.cancel=function(){r=!1},this.nextCallback},o.onTransitionEnd=function(e,t){this.setNextCallback(t);var n=this.props.nodeRef?this.props.nodeRef.current:r.findDOMNode(this),o=null==e&&!this.props.addEndListener;if(n&&!o){if(this.props.addEndListener){var i=this.props.nodeRef?[this.nextCallback]:[n,this.nextCallback],s=i[0],a=i[1];this.props.addEndListener(s,a)}null!=e&&setTimeout(this.nextCallback,e)}else setTimeout(this.nextCallback,0)},o.render=function(){var e=this.state.status;if(e===nl)return null;var r=this.props,n=r.children,o=s(r,["children","in","mountOnEnter","unmountOnExit","appear","enter","exit","timeout","addEndListener","onEnter","onEntering","onEntered","onExit","onExiting","onExited","nodeRef"]);return t.createElement(rl.Provider,{value:null},"function"==typeof n?n(e,o):t.cloneElement(t.Children.only(n),o))},n}(t.Component);function cl(){}ll.contextType=rl,ll.propTypes= true?{nodeRef:B.shape({current:"undefined"==typeof Element?B.any:function(e,t,r,n,o,i){var s=e[t];return B.instanceOf(s&&"ownerDocument"in s?s.ownerDocument.defaultView.Element:Element)(e,t,r,n,o,i)}}),children:B.oneOfType([B.func.isRequired,B.element.isRequired]).isRequired,in:B.bool,mountOnEnter:B.bool,unmountOnExit:B.bool,appear:B.bool,enter:B.bool,exit:B.bool,timeout:function(e){var t=tl;e.addEndListener||(t=t.isRequired);for(var r=arguments.length,n=new Array(r>1?r-1:0),o=1;o<r;o++)n[o-1]=arguments[o];return t.apply(void 0,[e].concat(n))},addEndListener:B.func,onEnter:B.func,onEntering:B.func,onEntered:B.func,onExit:B.func,onExiting:B.func,onExited:B.func}:0,ll.defaultProps={in:!1,mountOnEnter:!1,unmountOnExit:!1,appear:!1,enter:!0,exit:!0,onEnter:cl,onEntering:cl,onEntered:cl,onExit:cl,onExiting:cl,onExited:cl},ll.UNMOUNTED=nl,ll.EXITED=ol,ll.ENTERING=il,ll.ENTERED=sl,ll.EXITING=al;const ul=ll;function pl(e,r){var n=Object.create(null);return e&&t.Children.map(e,function(e){return e}).forEach(function(e){n[e.key]=function(e){return r&&t.isValidElement(e)?r(e):e}(e)}),n}function dl(e,t,r){return null!=r[t]?r[t]:e.props[t]}function fl(e,r,n){var o=pl(e.children),i=function(e,t){function r(r){return r in t?t[r]:e[r]}e=e||{},t=t||{};var n,o=Object.create(null),i=[];for(var s in e)s in t?i.length&&(o[s]=i,i=[]):i.push(s);var a={};for(var l in t){if(o[l])for(n=0;n<o[l].length;n++){var c=o[l][n];a[o[l][n]]=r(c)}a[l]=r(l)}for(n=0;n<i.length;n++)a[i[n]]=r(i[n]);return a}(r,o);return Object.keys(i).forEach(function(s){var a=i[s];if(t.isValidElement(a)){var l=s in r,c=s in o,u=r[s],p=t.isValidElement(u)&&!u.props.in;!c||l&&!p?c||!l||p?c&&l&&t.isValidElement(u)&&(i[s]=t.cloneElement(a,{onExited:n.bind(null,a),in:u.props.in,exit:dl(a,"exit",e),enter:dl(a,"enter",e)})):i[s]=t.cloneElement(a,{in:!1}):i[s]=t.cloneElement(a,{onExited:n.bind(null,a),in:!0,exit:dl(a,"exit",e),enter:dl(a,"enter",e)})}}),i}var hl=Object.values||function(e){return Object.keys(e).map(function(t){return e[t]})},ml=function(e){function r(t,r){var n,o=(n=e.call(this,t,r)||this).handleExited.bind(function(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}(n));return n.state={contextValue:{isMounting:!0},handleExited:o,firstRender:!0},n}el(r,e);var n=r.prototype;return n.componentDidMount=function(){this.mounted=!0,this.setState({contextValue:{isMounting:!1}})},n.componentWillUnmount=function(){this.mounted=!1},r.getDerivedStateFromProps=function(e,r){var n,o,i=r.children,s=r.handleExited;return{children:r.firstRender?(n=e,o=s,pl(n.children,function(e){return t.cloneElement(e,{onExited:o.bind(null,e),in:!0,appear:dl(e,"appear",n),enter:dl(e,"enter",n),exit:dl(e,"exit",n)})})):fl(e,i,s),firstRender:!1}},n.handleExited=function(e,t){var r=pl(this.props.children);e.key in r||(e.props.onExited&&e.props.onExited(t),this.mounted&&this.setState(function(t){var r=a({},t.children);return delete r[e.key],{children:r}}))},n.render=function(){var e=this.props,r=e.component,n=e.childFactory,o=s(e,["component","childFactory"]),i=this.state.contextValue,a=hl(this.state.children).map(n);return delete o.appear,delete o.enter,delete o.exit,null===r?t.createElement(rl.Provider,{value:i},a):t.createElement(rl.Provider,{value:i},t.createElement(r,o,a))},r}(t.Component);ml.propTypes= true?{component:B.any,children:B.node,appear:B.bool,enter:B.bool,exit:B.bool,childFactory:B.func}:0,ml.defaultProps={component:"div",childFactory:function(e){return e}};const gl=ml;function vl(t){const{className:r,classes:n,pulsate:i=!1,rippleX:s,rippleY:a,rippleSize:l,in:c,onExited:u,timeout:p}=t,[d,f]=o.useState(!1),h=V(r,n.ripple,n.rippleVisible,i&&n.ripplePulsate),m={width:l,height:l,top:-l/2+a,left:-l/2+s},g=V(n.child,d&&n.childLeaving,i&&n.childPulsate);return c||d||f(!0),o.useEffect(()=>{if(!c&&null!=u){const e=setTimeout(u,p);return()=>{clearTimeout(e)}}},[u,c,p]),e.jsx("span",{className:h,style:m,children:e.jsx("span",{className:g})})} true&&(vl.propTypes={classes:B.object.isRequired,className:B.string,in:B.bool,onExited:B.func,pulsate:B.bool,rippleSize:B.number,rippleX:B.number,rippleY:B.number,timeout:B.number.isRequired});const yl=ta("MuiTouchRipple",["root","ripple","rippleVisible","ripplePulsate","child","childLeaving","childPulsate"]),bl=["center","classes","className"];let wl,xl,_l,Sl,kl=e=>e;const Cl=Ot(wl||(wl=kl`
  0% {
    transform: scale(0);
    opacity: 0.1;
  }

  100% {
    transform: scale(1);
    opacity: 0.3;
  }
`)),Ol=Ot(xl||(xl=kl`
  0% {
    opacity: 1;
  }

  100% {
    opacity: 0;
  }
`)),El=Ot(_l||(_l=kl`
  0% {
    transform: scale(1);
  }

  50% {
    transform: scale(0.92);
  }

  100% {
    transform: scale(1);
  }
`)),Tl=Vi("span",{name:"MuiTouchRipple",slot:"Root"})({overflow:"hidden",pointerEvents:"none",position:"absolute",zIndex:0,top:0,right:0,bottom:0,left:0,borderRadius:"inherit"}),Rl=Vi(vl,{name:"MuiTouchRipple",slot:"Ripple"})(Sl||(Sl=kl`
  opacity: 0;
  position: absolute;

  &.${0} {
    opacity: 0.3;
    transform: scale(1);
    animation-name: ${0};
    animation-duration: ${0}ms;
    animation-timing-function: ${0};
  }

  &.${0} {
    animation-duration: ${0}ms;
  }

  & .${0} {
    opacity: 1;
    display: block;
    width: 100%;
    height: 100%;
    border-radius: 50%;
    background-color: currentColor;
  }

  & .${0} {
    opacity: 0;
    animation-name: ${0};
    animation-duration: ${0}ms;
    animation-timing-function: ${0};
  }

  & .${0} {
    position: absolute;
    /* @noflip */
    left: 0px;
    top: 0;
    animation-name: ${0};
    animation-duration: 2500ms;
    animation-timing-function: ${0};
    animation-iteration-count: infinite;
    animation-delay: 200ms;
  }
`),yl.rippleVisible,Cl,550,({theme:e})=>e.transitions.easing.easeInOut,yl.ripplePulsate,({theme:e})=>e.transitions.duration.shorter,yl.child,yl.childLeaving,Ol,550,({theme:e})=>e.transitions.easing.easeInOut,yl.childPulsate,El,({theme:e})=>e.transitions.easing.easeInOut),Il=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiTouchRipple"}),{center:i=!1,classes:l={},className:c}=n,u=s(n,bl),[p,d]=o.useState([]),f=o.useRef(0),h=o.useRef(null);o.useEffect(()=>{h.current&&(h.current(),h.current=null)},[p]);const m=o.useRef(!1),g=qa(),v=o.useRef(null),y=o.useRef(null),b=o.useCallback(t=>{const{pulsate:r,rippleX:n,rippleY:o,rippleSize:i,cb:s}=t;d(t=>[...t,e.jsx(Rl,{classes:{ripple:V(l.ripple,yl.ripple),rippleVisible:V(l.rippleVisible,yl.rippleVisible),ripplePulsate:V(l.ripplePulsate,yl.ripplePulsate),child:V(l.child,yl.child),childLeaving:V(l.childLeaving,yl.childLeaving),childPulsate:V(l.childPulsate,yl.childPulsate)},timeout:550,pulsate:r,rippleX:n,rippleY:o,rippleSize:i},f.current)]),f.current+=1,h.current=s},[l]),w=o.useCallback((e={},t={},r=()=>{})=>{const{pulsate:n=!1,center:o=i||t.pulsate,fakeElement:s=!1}=t;if("mousedown"===(null==e?void 0:e.type)&&m.current)return void(m.current=!1);"touchstart"===(null==e?void 0:e.type)&&(m.current=!0);const a=s?null:y.current,l=a?a.getBoundingClientRect():{width:0,height:0,left:0,top:0};let c,u,p;if(o||void 0===e||0===e.clientX&&0===e.clientY||!e.clientX&&!e.touches)c=Math.round(l.width/2),u=Math.round(l.height/2);else{const{clientX:t,clientY:r}=e.touches&&e.touches.length>0?e.touches[0]:e;c=Math.round(t-l.left),u=Math.round(r-l.top)}if(o)p=Math.sqrt((2*l.width**2+l.height**2)/3),p%2==0&&(p+=1);else{const e=2*Math.max(Math.abs((a?a.clientWidth:0)-c),c)+2,t=2*Math.max(Math.abs((a?a.clientHeight:0)-u),u)+2;p=Math.sqrt(e**2+t**2)}null!=e&&e.touches?null===v.current&&(v.current=()=>{b({pulsate:n,rippleX:c,rippleY:u,rippleSize:p,cb:r})},g.start(80,()=>{v.current&&(v.current(),v.current=null)})):b({pulsate:n,rippleX:c,rippleY:u,rippleSize:p,cb:r})},[i,b,g]),x=o.useCallback(()=>{w({},{pulsate:!0})},[w]),_=o.useCallback((e,t)=>{if(g.clear(),"touchend"===(null==e?void 0:e.type)&&v.current)return v.current(),v.current=null,void g.start(0,()=>{_(e,t)});v.current=null,d(e=>e.length>0?e.slice(1):e),h.current=t},[g]);return o.useImperativeHandle(r,()=>({pulsate:x,start:w,stop:_}),[x,w,_]),e.jsx(Tl,a({className:V(yl.root,l.root,c),ref:y},u,{children:e.jsx(gl,{component:null,exit:!0,children:p})}))}); true&&(Il.propTypes={center:B.bool,classes:B.object,className:B.string});const Ml=Il;function Al(e){return Mo("MuiButtonBase",e)}const Pl=ta("MuiButtonBase",["root","disabled","focusVisible"]),Nl=["action","centerRipple","children","className","component","disabled","disableRipple","disableTouchRipple","focusRipple","focusVisibleClassName","LinkComponent","onBlur","onClick","onContextMenu","onDragLeave","onFocus","onFocusVisible","onKeyDown","onKeyUp","onMouseDown","onMouseLeave","onMouseUp","onTouchEnd","onTouchMove","onTouchStart","tabIndex","TouchRippleProps","touchRippleRef","type"],jl=Vi("button",{name:"MuiButtonBase",slot:"Root",overridesResolver:(e,t)=>t.root})({display:"inline-flex",alignItems:"center",justifyContent:"center",position:"relative",boxSizing:"border-box",WebkitTapHighlightColor:"transparent",backgroundColor:"transparent",outline:0,border:0,margin:0,borderRadius:0,padding:0,cursor:"pointer",userSelect:"none",verticalAlign:"middle",MozAppearance:"none",WebkitAppearance:"none",textDecoration:"none",color:"inherit","&::-moz-focus-inner":{borderStyle:"none"},[`&.${Pl.disabled}`]:{pointerEvents:"none",cursor:"default"},"@media print":{colorAdjust:"exact"}}),Ll=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiButtonBase"}),{action:i,centerRipple:l=!1,children:c,className:u,component:p="button",disabled:d=!1,disableRipple:f=!1,disableTouchRipple:h=!1,focusRipple:m=!1,LinkComponent:g="a",onBlur:v,onClick:y,onContextMenu:b,onDragLeave:w,onFocus:x,onFocusVisible:_,onKeyDown:S,onKeyUp:k,onMouseDown:C,onMouseLeave:O,onMouseUp:E,onTouchEnd:T,onTouchMove:R,onTouchStart:I,tabIndex:M=0,TouchRippleProps:A,touchRippleRef:P,type:N}=n,j=s(n,Nl),L=o.useRef(null),D=o.useRef(null),F=Fa(D,P),{isFocusVisibleRef:$,onFocus:B,onBlur:z,ref:q}=Ja(),[W,H]=o.useState(!1);d&&W&&H(!1),o.useImperativeHandle(i,()=>({focusVisible:()=>{H(!0),L.current.focus()}}),[]);const[G,K]=o.useState(!1);o.useEffect(()=>{K(!0)},[]);const Y=G&&!f&&!d;function Z(e,t,r=h){return Ba(n=>(t&&t(n),!r&&D.current&&D.current[e](n),!0))}o.useEffect(()=>{W&&m&&!f&&G&&D.current.pulsate()},[f,m,W,G]);const X=Z("start",C),J=Z("stop",b),Q=Z("stop",w),ee=Z("stop",E),te=Z("stop",e=>{W&&e.preventDefault(),O&&O(e)}),re=Z("start",I),ne=Z("stop",T),oe=Z("stop",R),ie=Z("stop",e=>{z(e),!1===$.current&&H(!1),v&&v(e)},!1),se=Ba(e=>{L.current||(L.current=e.currentTarget),B(e),!0===$.current&&(H(!0),_&&_(e)),x&&x(e)}),ae=()=>{const e=L.current;return p&&"button"!==p&&!("A"===e.tagName&&e.href)},le=o.useRef(!1),ce=Ba(e=>{m&&!le.current&&W&&D.current&&" "===e.key&&(le.current=!0,D.current.stop(e,()=>{D.current.start(e)})),e.target===e.currentTarget&&ae()&&" "===e.key&&e.preventDefault(),S&&S(e),e.target===e.currentTarget&&ae()&&"Enter"===e.key&&!d&&(e.preventDefault(),y&&y(e))}),ue=Ba(e=>{m&&" "===e.key&&D.current&&W&&!e.defaultPrevented&&(le.current=!1,D.current.stop(e,()=>{D.current.pulsate(e)})),k&&k(e),y&&e.target===e.currentTarget&&ae()&&" "===e.key&&!e.defaultPrevented&&y(e)});let pe=p;"button"===pe&&(j.href||j.to)&&(pe=g);const de={};"button"===pe?(de.type=void 0===N?"button":N,de.disabled=d):(j.href||j.to||(de.role="button"),d&&(de["aria-disabled"]=d));const fe=Fa(r,q,L); true&&o.useEffect(()=>{Y&&!D.current&&console.error(["MUI: The `component` prop provided to ButtonBase is invalid.","Please make sure the children prop is rendered in this custom component."].join("\n"))},[Y]);const he=a({},n,{centerRipple:l,component:p,disabled:d,disableRipple:f,disableTouchRipple:h,focusRipple:m,tabIndex:M,focusVisible:W}),me=(e=>{const{disabled:t,focusVisible:r,focusVisibleClassName:n,classes:o}=e,i=U({root:["root",t&&"disabled",r&&"focusVisible"]},Al,o);return r&&n&&(i.root+=` ${n}`),i})(he);return e.jsxs(jl,a({as:pe,className:V(me.root,u),ownerState:he,onBlur:ie,onClick:y,onContextMenu:J,onFocus:se,onKeyDown:ce,onKeyUp:ue,onMouseDown:X,onMouseLeave:te,onMouseUp:ee,onDragLeave:Q,onTouchEnd:ne,onTouchMove:oe,onTouchStart:re,ref:fe,tabIndex:d?-1:M,type:N},de,j,{children:[c,Y?e.jsx(Ml,a({ref:F,center:l},A)):null]}))}); true&&(Ll.propTypes={action:ja,centerRipple:B.bool,children:B.node,classes:B.object,className:B.string,component:La,disabled:B.bool,disableRipple:B.bool,disableTouchRipple:B.bool,focusRipple:B.bool,focusVisibleClassName:B.string,href:B.any,LinkComponent:B.elementType,onBlur:B.func,onClick:B.func,onContextMenu:B.func,onDragLeave:B.func,onFocus:B.func,onFocusVisible:B.func,onKeyDown:B.func,onKeyUp:B.func,onMouseDown:B.func,onMouseLeave:B.func,onMouseUp:B.func,onTouchEnd:B.func,onTouchMove:B.func,onTouchStart:B.func,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),tabIndex:B.number,TouchRippleProps:B.object,touchRippleRef:B.oneOfType([B.func,B.shape({current:B.shape({pulsate:B.func.isRequired,start:B.func.isRequired,stop:B.func.isRequired})})]),type:B.oneOfType([B.oneOf(["button","reset","submit"]),B.string])});const Dl=Ll;function Fl(e){return Mo("MuiIconButton",e)}const $l=ta("MuiIconButton",["root","disabled","colorInherit","colorPrimary","colorSecondary","colorError","colorInfo","colorSuccess","colorWarning","edgeStart","edgeEnd","sizeSmall","sizeMedium","sizeLarge"]),Bl=["edge","children","className","color","disabled","disableFocusRipple","size"],zl=Vi(Dl,{name:"MuiIconButton",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,"default"!==r.color&&t[`color${Zi(r.color)}`],r.edge&&t[`edge${Zi(r.edge)}`],t[`size${Zi(r.size)}`]]}})(({theme:e,ownerState:t})=>a({textAlign:"center",flex:"0 0 auto",fontSize:e.typography.pxToRem(24),padding:8,borderRadius:"50%",overflow:"visible",color:(e.vars||e).palette.action.active,transition:e.transitions.create("background-color",{duration:e.transitions.duration.shortest})},!t.disableRipple&&{"&:hover":{backgroundColor:e.vars?`rgba(${e.vars.palette.action.activeChannel} / ${e.vars.palette.action.hoverOpacity})`:Fo.alpha(e.palette.action.active,e.palette.action.hoverOpacity),"@media (hover: none)":{backgroundColor:"transparent"}}},"start"===t.edge&&{marginLeft:"small"===t.size?-3:-12},"end"===t.edge&&{marginRight:"small"===t.size?-3:-12}),({theme:e,ownerState:t})=>{var r;const n=null==(r=(e.vars||e).palette)?void 0:r[t.color];return a({},"inherit"===t.color&&{color:"inherit"},"inherit"!==t.color&&"default"!==t.color&&a({color:null==n?void 0:n.main},!t.disableRipple&&{"&:hover":a({},n&&{backgroundColor:e.vars?`rgba(${n.mainChannel} / ${e.vars.palette.action.hoverOpacity})`:Fo.alpha(n.main,e.palette.action.hoverOpacity)},{"@media (hover: none)":{backgroundColor:"transparent"}})}),"small"===t.size&&{padding:5,fontSize:e.typography.pxToRem(18)},"large"===t.size&&{padding:12,fontSize:e.typography.pxToRem(28)},{[`&.${$l.disabled}`]:{backgroundColor:"transparent",color:(e.vars||e).palette.action.disabled}})}),Vl=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiIconButton"}),{edge:o=!1,children:i,className:l,color:c="default",disabled:u=!1,disableFocusRipple:p=!1,size:d="medium"}=n,f=s(n,Bl),h=a({},n,{edge:o,color:c,disabled:u,disableFocusRipple:p,size:d}),m=(e=>{const{classes:t,disabled:r,color:n,edge:o,size:i}=e;return U({root:["root",r&&"disabled","default"!==n&&`color${Zi(n)}`,o&&`edge${Zi(o)}`,`size${Zi(i)}`]},Fl,t)})(h);return e.jsx(zl,a({className:V(m.root,l),centerRipple:!0,focusRipple:!p,disabled:u,ref:r},f,{ownerState:h,children:i}))}); true&&(Vl.propTypes={children:rs(B.node,e=>o.Children.toArray(e.children).some(e=>o.isValidElement(e)&&e.props.onClick)?new Error(["MUI: You are providing an onClick event listener to a child of a button element.","Prefer applying it to the IconButton directly.","This guarantees that the whole <button> will be responsive to click events."].join("\n")):null),classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["inherit","default","primary","secondary","error","info","success","warning"]),B.string]),disabled:B.bool,disableFocusRipple:B.bool,disableRipple:B.bool,edge:B.oneOf(["end","start",!1]),size:B.oneOfType([B.oneOf(["small","medium","large"]),B.string]),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const Ul=Vl,ql="&:hover,&:focus,&:active,&:visited",Wl="__unstableAccessibleMain",Hl="__unstableAccessibleLight",Gl="0.75rem",Kl="1.25em",Yl="1.25em",Zl="1.25em",Xl="eui-rtl",Jl=[0,1,1,1,1],Ql=["theme"];function ec(t){let{theme:r}=t,n=s(t,Ql);const o=r[$i];return e.jsx(Gs,a({},n,{themeId:o?$i:void 0,theme:o||r}))} true&&(ec.propTypes={children:B.node,theme:B.oneOfType([B.object,B.func]).isRequired});const tc=(e,t)=>{const r={},n={};return t.forEach(t=>{n[t]=`Mui${e}-${t}`,r[t]={slot:t,name:`Mui${e}`}}),{slots:r,classNames:n}},rc=(e,...t)=>{const r={...e};return r.shape={borderRadius:4,__unstableBorderRadiusMultipliers:Jl,...r.shape},Di(r,...t)},nc=e=>function(e){return"ownerState"!==e&&"theme"!==e&&"sx"!==e&&"as"!==e}(e)&&"classes"!==e,oc=rc({}),ic=So({themeId:$i,defaultTheme:oc,rootShouldForwardProp:nc}),sc=(e,t)=>{if(!t?.shouldForwardProp)return ic(e,t);const r=t.shouldForwardProp,n={...t};return n.shouldForwardProp=e=>nc(e)&&r(e),ic(e,n)},ac="#FFFFFF",lc="#f1f3f3",cc="#d5d8dc",uc="#babfc5",pc="#9da5ae",dc="#818a96",fc="#69727d",hc="#515962",mc="#3f444b",gc="#1f2124",vc="#0c0d0e",yc="#f3bafd",bc="#f0abfc",wc="#eb8efb",xc="#ef4444",_c="#dc2626",Sc="#b91c1c",kc="#b15211",Cc="#3b82f6",Oc="#2563eb",Ec="#1d4ed8",Tc="#10b981",Rc="#0a875a",Ic="#047857",Mc="#99f6e4",Ac="#5eead4",Pc="#2adfcd",Nc="#b51243",jc="#93003f",Lc="#7e013b",Dc={styleOverrides:{listbox:({theme:e})=>({"&.MuiAutocomplete-listboxSizeTiny":{fontSize:"0.875rem"},'&.MuiAutocomplete-listbox .MuiAutocomplete-option[aria-selected="true"]':{"&,&.Mui-Mui-focused":{backgroundColor:e.palette.action.selected}}})},variants:[{props:{size:"tiny"},style:()=>({"& .MuiOutlinedInput-root":{padding:"2.5px 0","& .MuiAutocomplete-input":{lineHeight:Yl,height:Yl,padding:"4px 2px 4px 8px"}},"& .MuiFilledInput-root":{padding:0,"& .MuiAutocomplete-input":{padding:"15px 8px 6px"}},"& .MuiInput-root":{paddingBottom:0,"& .MuiAutocomplete-input":{padding:"2px 0"}},"& .MuiAutocomplete-popupIndicator":{fontSize:"1.5em"},"& .MuiAutocomplete-clearIndicator":{fontSize:"1.2em"},"& .MuiAutocomplete-popupIndicator .MuiSvgIcon-root, & .MuiAutocomplete-clearIndicator .MuiSvgIcon-root":{fontSize:"1em"},"& .MuiInputAdornment-root .MuiIconButton-root":{padding:"2px"},"& .MuiAutocomplete-tagSizeTiny":{fontSize:Gl},"&.MuiAutocomplete-hasPopupIcon.MuiAutocomplete-hasClearIcon .MuiOutlinedInput-root .MuiAutocomplete-input":{paddingRight:"48px"}})},{props:{size:"tiny",multiple:!0},style:()=>({"& .MuiAutocomplete-tag":{margin:"1.5px 3px"}})}]},Fc=["primary","secondary","error","warning","info","success","accent","global","promotion","decorative","neutral"],$c=["primary","global"],Bc=Fc.filter(e=>!$c.includes(e)),zc={styleOverrides:{root:()=>({boxShadow:"none","&:hover":{boxShadow:"none"}})},variants:Fc.map(e=>({props:{variant:"contained",color:e},style:({theme:t})=>({"& .MuiButtonGroup-grouped:not(:last-of-type), & .MuiButtonGroup-grouped:not(:last-of-type).Mui-disabled":{borderRight:0},"& .MuiButtonGroup-grouped:not(:last-child), & > *:not(:last-child) .MuiButtonGroup-grouped":{borderRight:`1px solid ${t.palette[e].dark}`},"& .MuiButtonGroup-grouped:not(:last-child).Mui-disabled, & > *:not(:last-child) .MuiButtonGroup-grouped.Mui-disabled":{borderRight:`1px solid ${t.palette.action.disabled}`}})}))},Vc={variants:[{props:{color:"primary",variant:"outlined"},style:({theme:e})=>({color:e.palette.primary.__unstableAccessibleMain,borderColor:e.palette.primary.__unstableAccessibleMain,"& .MuiChip-deleteIcon":{color:e.palette.primary.__unstableAccessibleLight,"&:hover":{color:e.palette.primary.__unstableAccessibleMain}}})},{props:{color:"global",variant:"outlined"},style:({theme:e})=>({color:e.palette.global.__unstableAccessibleMain,borderColor:e.palette.global.__unstableAccessibleMain,"& .MuiChip-deleteIcon":{color:e.palette.global.__unstableAccessibleLight,"&:hover":{color:e.palette.global.__unstableAccessibleMain}}})},{props:{color:"default",variant:"filled"},style:({theme:e})=>({backgroundColor:"light"===e.palette.mode?"#EBEBEB":"#434547","&.Mui-focusVisible, &.MuiChip-clickable:hover":{backgroundColor:e.palette.action.focus},"& .MuiChip-icon":{color:"inherit"}})},...Uc(["default"],function(e){return{backgroundColor:{light:"#EBEBEB",dark:"#434547"},backgroundColorHover:{light:e.palette.action.focus,dark:e.palette.action.focus},color:{light:e.palette.text.primary,dark:e.palette.text.primary},deleteIconOpacity:.26,deleteIconOpacityHover:.7}}),...Uc(["primary","global"],function(e,t){const r=e.palette[t];return{backgroundColor:{light:Ms(r.light,.8),dark:Is(r.__unstableAccessibleMain,.8)},backgroundColorHover:{light:Ms(r.light,.6),dark:Is(r.__unstableAccessibleMain,.9)},color:{light:Is(r.__unstableAccessibleMain,.3),dark:Ms(r.light,.3)},deleteIconOpacity:.7,deleteIconOpacityHover:1}}),...Uc(Bc,function(e,t){return{backgroundColor:{light:Ms(e.palette[t].light,.9),dark:Is(e.palette[t].light,.8)},backgroundColorHover:{light:Ms(e.palette[t].light,.8),dark:Is(e.palette[t].light,.9)},color:{light:Is(e.palette[t].main,.3),dark:Ms(e.palette[t].main,.5)},deleteIconOpacity:.7,deleteIconOpacityHover:1}}),{props:{size:"tiny"},style:()=>({fontSize:Gl,height:"20px",paddingInline:"5px","& .MuiChip-avatar":{width:"1rem",height:"1rem",fontSize:"9px",marginLeft:0,marginRight:"1px"},"& .MuiChip-icon":{fontSize:"1rem",marginLeft:0,marginRight:0},"& .MuiChip-label":{paddingRight:"3px",paddingLeft:"3px"},"& .MuiChip-deleteIcon":{fontSize:"0.875rem",marginLeft:0,marginRight:0}})},{props:{size:"small"},style:()=>({height:"24px",paddingInline:"5px","& .MuiChip-avatar":{width:"1.125rem",height:"1.125rem",fontSize:"9px",marginLeft:0,marginRight:"2px"},"& .MuiChip-icon":{fontSize:"1.125rem",marginLeft:0,marginRight:0},"& .MuiChip-label":{paddingRight:"3px",paddingLeft:"3px"},"& .MuiChip-deleteIcon":{fontSize:"1rem",marginLeft:0,marginRight:0}})},{props:{size:"medium"},style:()=>({height:"32px",paddingInline:"6px","& .MuiChip-avatar":{width:"1.25rem",height:"1.25rem",fontSize:"0.75rem",marginLeft:0,marginRight:"2px"},"& .MuiChip-icon":{fontSize:"1.25rem",marginLeft:0,marginRight:0},"& .MuiChip-label":{paddingRight:"4px",paddingLeft:"4px"},"& .MuiChip-deleteIcon":{fontSize:"1.125rem",marginLeft:0,marginRight:0}})}]};function Uc(e,t){return e.map(e=>({props:{color:e,variant:"standard"},style:({theme:r})=>{const n=t(r,e),{mode:o}=r.palette;return{backgroundColor:n.backgroundColor[o],color:n.color[o],"&.Mui-focusVisible, &.MuiChip-clickable:hover":{backgroundColor:n.backgroundColorHover[o]},"& .MuiChip-icon":{color:"inherit"},"& .MuiChip-deleteIcon":{color:n.color[o],opacity:n.deleteIconOpacity,"&:hover,&:focus":{color:n.color[o],opacity:n.deleteIconOpacityHover}}}}}))}const qc="1rem",Wc="0.75rem";var Hc={MuiAccordion:{styleOverrides:{root:({theme:e})=>({backgroundColor:e.palette.background.default,"&:before":{content:"none"},"&.Mui-expanded":{margin:0},"&.MuiAccordion-gutters + .MuiAccordion-root.MuiAccordion-gutters":{marginTop:e.spacing(1),marginBottom:e.spacing(0)},"&:not(.MuiAccordion-gutters) + .MuiAccordion-root:not(.MuiAccordion-gutters)":{borderTop:0},"&.Mui-disabled":{backgroundColor:e.palette.background.default}})},variants:[{props:{square:!1},style:({theme:e})=>{const t=e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[3];return{"&:first-of-type":{borderTopLeftRadius:t,borderTopRightRadius:t},"&:last-of-type":{borderBottomLeftRadius:t,borderBottomRightRadius:t}}}}]},MuiAccordionActions:{styleOverrides:{root:({theme:e})=>({padding:e.spacing(2)})}},MuiAccordionSummary:{styleOverrides:{root:()=>({minHeight:"64px"}),content:({theme:e})=>({margin:e.spacing(1,0),"&.MuiAccordionSummary-content.Mui-expanded":{margin:e.spacing(1,0)}})}},MuiAccordionSummaryIcon:{styleOverrides:{root:({theme:e})=>({padding:e.spacing(1,0)})}},MuiAccordionSummaryText:{styleOverrides:{root:({theme:e})=>({marginTop:0,marginBottom:0,padding:e.spacing(1,0)})}},MuiAutocomplete:Dc,MuiAvatar:{variants:[{props:{variant:"rounded"},style:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[1]})}]},MuiButton:{styleOverrides:{root:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[2],boxShadow:"none",whiteSpace:"nowrap","&:hover":{boxShadow:"none"},"& .MuiSvgIcon-root":{fill:"currentColor"}})},variants:[{props:{color:"primary",variant:"outlined"},style:({theme:e})=>({color:e.palette.primary.__unstableAccessibleMain,borderColor:e.palette.primary.__unstableAccessibleMain,"&:hover":{borderColor:e.palette.primary.__unstableAccessibleMain}})},{props:{color:"primary",variant:"text"},style:({theme:e})=>({color:e.palette.primary.__unstableAccessibleMain})},{props:{color:"global",variant:"outlined"},style:({theme:e})=>({color:e.palette.global.__unstableAccessibleMain,borderColor:e.palette.global.__unstableAccessibleMain,"&:hover":{borderColor:e.palette.global.__unstableAccessibleMain}})},{props:{color:"global",variant:"text"},style:({theme:e})=>({color:e.palette.global.__unstableAccessibleMain})}]},MuiButtonBase:{styleOverrides:{root:()=>({"&.MuiButtonBase-root.Mui-focusVisible":{boxShadow:"0 0 0 1px inset"},".MuiCircularProgress-root":{fontSize:"inherit"}})}},MuiButtonGroup:zc,MuiCard:{defaultProps:{},styleOverrides:{root:()=>({position:"relative"})}},MuiCardActions:{styleOverrides:{root:({theme:e})=>({justifyContent:"flex-end",padding:e.spacing(1.5,2)})}},MuiCardGroup:{styleOverrides:{root:()=>({"& .MuiCard-root.MuiPaper-outlined:not(:last-child)":{borderBottom:0},"& .MuiCard-root.MuiPaper-rounded":{"&:first-child:not(:last-child)":{borderBottomRightRadius:0,borderBottomLeftRadius:0},"&:not(:first-child):not(:last-child)":{borderRadius:0},"&:last-child:not(:first-child)":{borderTopRightRadius:0,borderTopLeftRadius:0}}})}},MuiCardHeader:{styleOverrides:{action:()=>({alignSelf:"center"})}},MuiChip:Vc,MuiCircularProgress:{styleOverrides:{root:({theme:e})=>({fontSize:e.spacing(5)})}},MuiDialog:{styleOverrides:{paper:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[4]})}},MuiDialogActions:{styleOverrides:{root:({theme:e})=>({padding:e.spacing(2,3)})}},MuiDialogContent:{styleOverrides:{dividers:()=>({"&:last-child":{borderBottom:"none"}})}},MuiFilledInput:{styleOverrides:{root:({theme:e})=>({borderTopLeftRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[2],borderTopRightRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[2]})},variants:[{props:{size:"tiny"},style:({theme:e})=>({fontSize:Gl,lineHeight:Zl,"& .MuiInputBase-input":{fontSize:Gl,lineHeight:Zl,height:Zl,padding:"15px 8px 6px"},"&.MuiInputBase-adornedStart":{paddingLeft:e.spacing(1)},"&.MuiInputBase-adornedEnd":{paddingRight:e.spacing(1)},"& .MuiInputAdornment-root.MuiInputAdornment-positionStart:not(.MuiInputAdornment-hiddenLabel)":{marginTop:e.spacing(1)},"& .MuiInputAdornment-root:not(.MuiInputAdornment-positionEnd)":{marginRight:0},"& .MuiInputAdornment-root.MuiInputAdornment-positionEnd":{marginLeft:0}})},{props:{size:"tiny",multiline:!0},style:()=>({padding:0})}]},MuiFormHelperText:{styleOverrides:{root:({theme:e})=>({color:e.palette.text.tertiary,margin:e.spacing(.5,0,0)})}},MuiFormLabel:{variants:[{props:{size:"tiny"},style:()=>({fontSize:"0.75rem",lineHeight:"1.6",fontWeight:"400",letterSpacing:"0.19px"})},{props:{size:"small"},style:({theme:e})=>({...e.typography.body2})}]},MuiIconButton:{variants:[{props:{color:"primary"},style:({theme:e})=>({color:e.palette.primary.__unstableAccessibleMain})},{props:{color:"global"},style:({theme:e})=>({color:e.palette.global.__unstableAccessibleMain})},{props:{edge:"start",size:"small"},style:({theme:e})=>({marginLeft:e.spacing(-1.5)})},{props:{edge:"end",size:"small"},style:({theme:e})=>({marginRight:e.spacing(-1.5)})},{props:{edge:"start",size:"large"},style:({theme:e})=>({marginLeft:e.spacing(-2)})},{props:{edge:"end",size:"large"},style:({theme:e})=>({marginRight:e.spacing(-2)})},{props:{size:"tiny"},style:({theme:e})=>({padding:e.spacing(.75)})},{props:{size:"tiny",edge:"start"},style:({theme:e})=>({marginLeft:e.spacing(-1)})},{props:{size:"tiny",edge:"end"},style:({theme:e})=>({marginRight:e.spacing(-1)})}]},MuiInput:{variants:[{props:{size:"tiny"},style:({theme:e})=>({fontSize:Gl,lineHeight:Kl,"&.MuiInput-root":{marginTop:e.spacing(1.5)},"& .MuiInputBase-input":{fontSize:Gl,lineHeight:Kl,height:Kl,padding:"6.5px 0"}})}]},MuiInputAdornment:{styleOverrides:{root:({theme:e})=>({"&.MuiInputAdornment-sizeTiny":{"&.MuiInputAdornment-positionStart":{marginRight:e.spacing(.5)},"&.MuiInputAdornment-positionEnd":{marginLeft:e.spacing(.5)}}})}},MuiInputBase:{styleOverrides:{input:()=>({".MuiInputBase-root.Mui-disabled &":{backgroundColor:"initial"}})}},MuiInputLabel:{variants:[{props:{size:"tiny",shrink:!1},style:()=>({"&.MuiInputLabel-outlined":{transform:"translate(7.5px, 5.5px) scale(1)"},"&.MuiInputLabel-standard":{transform:"translate(0px, 18px) scale(1)"},"&.MuiInputLabel-filled":{transform:"translate(8px, 11px) scale(1)"}})},{props:{size:"tiny",shrink:!0},style:()=>({"&.MuiInputLabel-filled":{transform:"translate(8px, 2px) scale(0.75)"}})}]},MuiListItem:{styleOverrides:{root:({theme:e})=>({color:e.palette.text.primary,"a&":{[ql]:{color:e.palette.text.primary}}})}},MuiListItemButton:{styleOverrides:{root:({theme:e})=>({color:e.palette.text.primary,"&.Mui-selected":{backgroundColor:e.palette.action.selected,"&:hover":{backgroundColor:e.palette.action.selected},"&:focus":{backgroundColor:e.palette.action.focus}},"a&":{[ql]:{color:e.palette.text.primary}}})}},MuiListItemIcon:{styleOverrides:{root:({theme:e})=>({minWidth:"initial","&:not(:last-child)":{marginRight:e.spacing(1)}})}},MuiListItemText:{styleOverrides:{root:({theme:e})=>({color:e.palette.text.primary})}},MuiListSubheader:{styleOverrides:{root:({theme:e})=>({backgroundImage:"linear-gradient(rgba(255, 255, 255, 0.12), rgba(255, 255, 255, 0.12))",lineHeight:"36px",color:e.palette.text.secondary})}},MuiMenuItem:{styleOverrides:{root:({theme:e})=>({"&.Mui-selected":{backgroundColor:e.palette.action.selected,"&:hover":{backgroundColor:e.palette.action.selected},"&:focus":{backgroundColor:e.palette.action.focus}},"a&":{[ql]:{color:e.palette.text.primary}},"& .MuiListItemIcon-root":{minWidth:"initial"}})}},MuiOutlinedInput:{styleOverrides:{root:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[2],"&.Mui-focused .MuiInputAdornment-root .MuiOutlinedInput-notchedOutline":{borderColor:"dark"===e.palette.mode?"rgba(255, 255, 255, 0.23)":"rgba(0, 0, 0, 0.23)",borderWidth:"1px"}})},variants:[{props:{size:"tiny"},style:({theme:e})=>({fontSize:Gl,lineHeight:Yl,"&.MuiInputBase-adornedStart":{paddingLeft:e.spacing(1)},"&.MuiInputBase-adornedEnd":{paddingRight:e.spacing(1)},"& .MuiInputBase-input":{fontSize:Gl,lineHeight:Yl,height:Yl,padding:"6.5px 8px"},"& .MuiInputAdornment-root + .MuiInputBase-input":{paddingLeft:0},"&:has(.MuiInputBase-input + .MuiInputAdornment-root) .MuiInputBase-input":{paddingRight:0}})},{props:{size:"tiny",multiline:!0},style:()=>({padding:0})},{props:e=>!!e.endAdornment&&"tiny"===e.size,style:()=>({"& .MuiInputAdornment-root .MuiInputBase-root .MuiSelect-select":{"&.MuiSelect-standard":{paddingTop:0,paddingBottom:0},"&.MuiSelect-outlined,&.MuiSelect-filled":{paddingTop:"4px",paddingBottom:"4px"}}})},{props:e=>!!e.endAdornment&&"small"===e.size,style:()=>({"& .MuiInputAdornment-root .MuiInputBase-root .MuiSelect-select":{paddingTop:"2.5px",paddingBottom:"2.5px"}})},{props:e=>!(!e.endAdornment||"medium"!==e.size&&e.size),style:()=>({"& .MuiInputAdornment-root .MuiInputBase-root .MuiSelect-select":{paddingTop:"8.5px",paddingBottom:"8.5px"}})}]},MuiPagination:{variants:[{props:{shape:"rounded"},style:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[1]})}]},MuiPaper:{variants:[{props:{square:!1},style:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[3]})}]},MuiSelect:{styleOverrides:{nativeInput:()=>({".MuiInputBase-root.Mui-disabled &":{backgroundColor:"initial",opacity:0}})},variants:[{props:{size:"tiny"},style:()=>({"& .MuiSelect-icon":{fontSize:qc,right:"9px"},"& .MuiSelect-select.MuiSelect-outlined, & .MuiSelect-select.MuiSelect-filled":{minHeight:Yl},"& .MuiSelect-select.MuiSelect-standard":{lineHeight:Kl,minHeight:Kl}})}]},MuiSkeleton:{variants:[{props:{variant:"rounded"},style:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[1]})}]},MuiSnackbarContent:{defaultProps:{},styleOverrides:{root:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[2]})}},MuiStepConnector:{styleOverrides:{root:({theme:e})=>({"& .MuiStepConnector-line":{borderColor:e.palette.divider}})}},MuiStepIcon:{styleOverrides:{root:({theme:e})=>({"&:not(.Mui-active) .MuiStepIcon-text":{fill:e.palette.common.white}})}},MuiStepLabel:{styleOverrides:{root:()=>({alignItems:"flex-start"})}},MuiStepper:{styleOverrides:{root:()=>({"& .MuiStepLabel-root":{alignItems:"center"}})}},MuiSvgIcon:{variants:[{props:{fontSize:"tiny"},style:()=>({fontSize:"1rem"})}]},MuiTab:{styleOverrides:{root:{"&:not(.Mui-selected)":{fontWeight:400},"&.Mui-selected":{fontWeight:700}}},variants:[{props:{size:"small"},style:({theme:e})=>({fontSize:Wc,lineHeight:1.6,padding:e.spacing(.75,1),minWidth:72,"&:not(.MuiTab-labelIcon)":{minHeight:32},"&.MuiTab-labelIcon":{minHeight:32}})}]},MuiTableRow:{styleOverrides:{root:({theme:e})=>({"&.Mui-selected":{backgroundColor:e.palette.action.selected,"&:hover":{backgroundColor:e.palette.action.selected}}})},variants:[{props:e=>"onClick"in e,style:()=>({cursor:"pointer"})}]},MuiTabPanel:{styleOverrides:{root:({theme:e})=>({color:e.palette.text.primary})}},MuiTabs:{styleOverrides:{indicator:{height:"3px"}},variants:[{props:{size:"small"},style:({theme:e})=>({minHeight:32,"& .MuiTab-root":{fontSize:Wc,lineHeight:1.6,padding:e.spacing(.75,1),minWidth:72,"&:not(.MuiTab-labelIcon)":{minHeight:32},"&.MuiTab-labelIcon":{minHeight:32}}})}]},MuiTextField:{styleOverrides:{root:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[2],"& legend":{transition:"unset"}})},variants:[{props:{size:"tiny",select:!0},style:()=>({"& .MuiSelect-icon":{fontSize:qc,right:"9px"},"& .MuiInputBase-root .MuiSelect-select":{minHeight:"auto"}})}]},MuiToggleButton:{styleOverrides:{root:({theme:e})=>({borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[2]})},variants:[{props:{color:"primary"},style:({theme:e})=>({"&.MuiToggleButton-root.Mui-selected":{color:e.palette.primary.__unstableAccessibleMain}})},{props:{color:"global"},style:({theme:e})=>({"&.MuiToggleButton-root.Mui-selected":{color:e.palette.global.__unstableAccessibleMain}})},{props:{size:"tiny"},style:({theme:e})=>({fontSize:Gl,lineHeight:1.3334,padding:e.spacing(.625)})}]},MuiTooltip:{styleOverrides:{arrow:({theme:e})=>({color:e.palette.grey[700]}),tooltip:({theme:e})=>({backgroundColor:e.palette.grey[700],borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[1]})}}};const Gc={components:Hc,shape:{borderRadius:4,__unstableBorderRadiusMultipliers:Jl},typography:{display1:{fontSize:"0rem"},display2:{fontSize:"0rem"},display3:{fontSize:"0rem"},display4:{fontSize:"0rem"},display5:{fontSize:"0rem"},display6:{fontSize:"0rem"},button:{textTransform:"none"},h1:{fontWeight:700},h2:{fontWeight:700},h3:{fontSize:"2.75rem",fontWeight:700},h4:{fontSize:"2rem",fontWeight:700},h5:{fontWeight:700},subtitle1:{fontWeight:500,lineHeight:1.3},subtitle2:{lineHeight:1.3}},zIndex:{mobileStepper:1e3,fab:1050,speedDial:1050,appBar:1100,drawer:1200,modal:1300,snackbar:1400,tooltip:1500}},Kc={...Gc,palette:{mode:"light",primary:{main:bc,light:yc,dark:wc,contrastText:vc,[Wl]:"#C00BB9",[Hl]:"#D355CE"},secondary:{main:hc,light:fc,dark:mc,contrastText:ac},grey:{50:lc,100:cc,200:uc,300:pc,400:dc,500:fc,600:hc,700:mc,800:gc,900:vc},text:{primary:vc,secondary:mc,tertiary:fc,disabled:pc},background:{paper:ac,default:ac},success:{main:Rc,light:Tc,dark:Ic,contrastText:ac},error:{main:_c,light:xc,dark:Sc,contrastText:ac},warning:{main:"#bb5b1d",light:"#d97706",dark:kc,contrastText:ac},info:{main:Oc,light:Cc,dark:Ec,contrastText:ac},global:{main:Ac,light:Mc,dark:Pc,contrastText:vc,[Wl]:"#17929B",[Hl]:"#5DB3B9"},accent:{main:jc,light:Nc,dark:Lc,contrastText:ac},promotion:{main:jc,light:Nc,dark:Lc,contrastText:ac},decorative:{main:Ac,light:Mc,dark:Pc,contrastText:vc},neutral:{main:"#ffffff",light:"#ffffff",dark:"#ffffff",contrastText:"#ffffff"}}},Yc={...Gc,palette:{mode:"dark",primary:{main:bc,light:yc,dark:wc,contrastText:vc,[Wl]:"#C00BB9",[Hl]:"#D355CE"},secondary:{main:pc,light:uc,dark:dc,contrastText:vc},grey:{50:lc,100:cc,200:uc,300:pc,400:dc,500:fc,600:hc,700:mc,800:gc,900:vc},text:{primary:ac,secondary:uc,tertiary:pc,disabled:hc},background:{paper:vc,default:gc},success:{main:Rc,light:Tc,dark:Ic,contrastText:ac},error:{main:_c,light:xc,dark:Sc,contrastText:ac},warning:{main:"#f59e0b",light:"#fbbf24",dark:kc,contrastText:"#000000"},info:{main:Oc,light:Cc,dark:Ec,contrastText:ac},global:{main:Ac,light:Mc,dark:Pc,contrastText:vc,[Wl]:"#17929B",[Hl]:"#5DB3B9"},accent:{main:jc,light:Nc,dark:Lc,contrastText:ac},promotion:{main:jc,light:Nc,dark:Lc,contrastText:ac},decorative:{main:Ac,light:Mc,dark:Pc,contrastText:vc},neutral:{main:"#ffffff",light:"#ffffff",dark:"#ffffff",contrastText:"#ffffff"}}},Zc="#524CFF";var Xc={primary:{main:Zc,light:"#6B65FF",dark:"#4C43E5",contrastText:"#FFFFFF",[Wl]:"#524CFF",[Hl]:"#6B65FF"},action:{selected:Rs(Zc,.08)}};const Jc=gc,Qc=mc;var eu={primary:{main:Jc,light:Qc,dark:vc,contrastText:"#FFFFFF",[Wl]:Jc,[Hl]:Qc},accent:{main:bc,light:yc,dark:wc,contrastText:vc}};const tu=lc,ru="#FFFFFF";var nu={primary:{main:tu,light:ru,dark:cc,contrastText:vc,[Wl]:tu,[Hl]:ru},accent:{main:bc,light:yc,dark:wc,contrastText:vc}};const ou=gc,iu=mc;var su={primary:{main:ou,light:iu,dark:vc,contrastText:"#FFFFFF",[Wl]:ou,[Hl]:iu},accent:{main:"#f00",light:"#f00",dark:"#f00",contrastText:"#f00"},decorative:{main:"#f00",light:"#f00",dark:"#f00",contrastText:"#f00"},neutral:{main:"#f00",light:"#f00",dark:"#f00",contrastText:"#f00"}};const au=lc,lu="#FFFFFF";var cu={primary:{main:au,light:lu,dark:cc,contrastText:vc,[Wl]:au,[Hl]:lu},accent:{main:"#f00",light:"#f00",dark:"#f00",contrastText:"#f00"},decorative:{main:"#f00",light:"#f00",dark:"#f00",contrastText:"#f00"},neutral:{main:"#f00",light:"#f00",dark:"#f00",contrastText:"#f00"}};const uu=t.createContext(null),pu=({value:e,children:t})=>o.createElement(uu.Provider,{value:e},t),du={zIndex:Gc.zIndex};const fu=!0;function hu(e){return e?mu(e,{primary:["main","light","dark","contrastText","whisper","delicate","soft","__unstableAccessibleMain","__unstableAccessibleLight","__unstableTonalMain","__unstableTonalDark","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],secondary:["main","light","dark","contrastText","whisper","delicate","soft","__unstableAccessibleMain","__unstableAccessibleLight","__unstableTonalMain","__unstableTonalDark","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],success:["main","light","dark","contrastText","whisper","delicate","soft","__unstableAccessibleMain","__unstableAccessibleLight","__unstableTonalMain","__unstableTonalDark","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],info:["main","light","dark","contrastText","whisper","delicate","soft","__unstableAccessibleMain","__unstableAccessibleLight","__unstableTonalMain","__unstableTonalDark","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],warning:["main","light","dark","contrastText","whisper","delicate","soft","__unstableAccessibleMain","__unstableAccessibleLight","__unstableTonalMain","__unstableTonalDark","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],error:["main","light","dark","contrastText","whisper","delicate","soft","__unstableAccessibleMain","__unstableAccessibleLight","__unstableTonalMain","__unstableTonalDark","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],background:["default","paper","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],decorative:["main","light","dark","contrastText","whisper","delicate","soft","__unstableAccessibleMain","__unstableAccessibleLight","__unstableTonalMain","__unstableTonalDark","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],accent:["main","light","dark","contrastText","whisper","delicate","soft","__unstableAccessibleMain","__unstableAccessibleLight","__unstableTonalMain","__unstableTonalDark","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],neutral:["main","light","dark","contrastText","whisper","delicate","soft","__unstableAccessibleMain","__unstableAccessibleLight","__unstableTonalMain","__unstableTonalDark","__unstableSurface","__unstableSurfaceMain","__unstableSurfaceLight","__unstableSurfaceDark","__unstableSurfaceTranslucent"],text:["primary","secondary","tertiary","disabled"],action:["active","focus","hover","disabled","disabledBackground","selected","__unstableGradientAngle"],divider:fu}):{}}function mu(e,t){if(!e||!t)return{};const r={};return Object.entries(t).forEach(([t,n])=>{if(e[t])if("boolean"!=typeof n){if(Array.isArray(n)){const o=e[t];n.forEach(e=>{void 0!==o?.[e]&&(r[t]={...r[t],[e]:o[e]})})}}else r[t]=e[t]}),r}const gu=new Map,vu=_t(({colorScheme:e,palette:r,children:n,overrides:o,unstableThemeV0:i},s)=>{const a=t.useContext(uu),l=s.key===Xl,c=e||a?.colorScheme||"auto",u=Cs("(prefers-color-scheme: dark)"),p="auto"===c&&u||"dark"===c,d=function(e,t){if(!e)return t;if("function"!=typeof e)return console.error("overrides must be a function"),t;const r=e(structuredClone(t||du));return r&&"object"==typeof r?r:(console.error("overrides function must return an object"),t)}(o,a?.overrides),f=i?.name||r||a?.themeName,h=i||a?.customTheme;let m=h?((e,t=!1,r=!1)=>{if(!e.name)throw new Error("Custom theme must have a name");const n=`${e.name}-${t}-${r}`;if(gu.has(n))return gu.get(n);const o={typography:{subtitle1:{fontWeight:500,lineHeight:1.3},subtitle2:{lineHeight:1.3}}};r&&(o.direction="rtl");const i=function(e,t){const r={components:Hc};return t&&e.palette?.dark?r.palette={...Yc.palette,...hu(e.palette.dark),mode:"dark"}:e.palette?.light&&(r.palette={...Kc.palette,...hu(e.palette.light)}),e.shadows&&(r.shadows=e.shadows),e.shape&&(r.shape=e.shape),e.typography&&(r.typography=function(e={}){return e?mu(e,{fontFamily:fu,display1:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],display2:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],display3:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],display4:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],display5:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],display6:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],h1:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],h2:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],h3:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],h4:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],h5:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],h6:["fontFamily","fontSize","fontWeight","lineHeight","letterSpacing"],subtitle1:["fontFamily"],subtitle2:["fontFamily"],body1:["fontFamily"],body2:["fontFamily"],caption:["fontFamily"],overline:["fontFamily"],button:["fontFamily","textTransform"]}):{}}(e.typography)),e.zIndex&&(r.zIndex=e.zIndex),r}(e,t),s=rc(i,o);return gu.set(n,s),s})(h,p,l):(({palette:e="default",rtl:t=!1,isDarkMode:r=!1}={})=>{const n=`${e}-${r}-${t}`;if(gu.has(n))return gu.get(n);const o=r?Yc:Kc,i={};"marketing-suite"===e&&(i.palette=Xc),"unstable"===e&&(i.palette=r?nu:eu,i.shape={borderRadius:8,__unstableBorderRadiusMultipliers:[0,.5,1,1.5,2.5]}),"argon-beta"===e&&(i.palette=r?cu:su,i.shape={borderRadius:8,__unstableBorderRadiusMultipliers:[0,.5,1,1.5,2.5]}),t&&(i.direction="rtl");const s=rc(o,i);return gu.set(n,s),s})({rtl:l,isDarkMode:p,palette:r||a?.themeName});return d&&(m=((e,t)=>{if(!t)return e;const r={};return["zIndex"].forEach(e=>{e in t&&(r[e]=t[e])}),Eo(e,r,{clone:!0})})(m,d)),t.createElement(pu,{value:{colorScheme:e,themeName:f,overrides:d,customTheme:h}},t.createElement(ec,{theme:m},n))}),yu=(e="default")=>"inherit"===e?"inherit":"default"===e?"action.active":$c.includes(e)?`${e}.${Wl}`:`${e}.main`;var bu=t.forwardRef((e,r)=>{const{sx:n={},color:o}=e,i=e.href?ql:"&:hover,&:focus,&:active",s={[i]:{color:yu(o)}};return t.createElement(Ul,{...e,sx:{...s,...n},ref:r})});function wu(e){return Mo("MuiSvgIcon",e)}ta("MuiSvgIcon",["root","colorPrimary","colorSecondary","colorAction","colorError","colorDisabled","fontSizeInherit","fontSizeSmall","fontSizeMedium","fontSizeLarge"]);const xu=["children","className","color","component","fontSize","htmlColor","inheritViewBox","titleAccess","viewBox"],_u=Vi("svg",{name:"MuiSvgIcon",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,"inherit"!==r.color&&t[`color${Zi(r.color)}`],t[`fontSize${Zi(r.fontSize)}`]]}})(({theme:e,ownerState:t})=>{var r,n,o,i,s,a,l,c,u,p,d,f,h;return{userSelect:"none",width:"1em",height:"1em",display:"inline-block",fill:t.hasSvgAsChild?void 0:"currentColor",flexShrink:0,transition:null==(r=e.transitions)||null==(n=r.create)?void 0:n.call(r,"fill",{duration:null==(o=e.transitions)||null==(o=o.duration)?void 0:o.shorter}),fontSize:{inherit:"inherit",small:(null==(i=e.typography)||null==(s=i.pxToRem)?void 0:s.call(i,20))||"1.25rem",medium:(null==(a=e.typography)||null==(l=a.pxToRem)?void 0:l.call(a,24))||"1.5rem",large:(null==(c=e.typography)||null==(u=c.pxToRem)?void 0:u.call(c,35))||"2.1875rem"}[t.fontSize],color:null!=(p=null==(d=(e.vars||e).palette)||null==(d=d[t.color])?void 0:d.main)?p:{action:null==(f=(e.vars||e).palette)||null==(f=f.action)?void 0:f.active,disabled:null==(h=(e.vars||e).palette)||null==(h=h.action)?void 0:h.disabled,inherit:void 0}[t.color]}}),Su=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiSvgIcon"}),{children:i,className:l,color:c="inherit",component:u="svg",fontSize:p="medium",htmlColor:d,inheritViewBox:f=!1,titleAccess:h,viewBox:m="0 0 24 24"}=n,g=s(n,xu),v=o.isValidElement(i)&&"svg"===i.type,y=a({},n,{color:c,component:u,fontSize:p,instanceFontSize:t.fontSize,inheritViewBox:f,viewBox:m,hasSvgAsChild:v}),b={};f||(b.viewBox=m);const w=(e=>{const{color:t,fontSize:r,classes:n}=e;return U({root:["root","inherit"!==t&&`color${Zi(t)}`,`fontSize${Zi(r)}`]},wu,n)})(y);return e.jsxs(_u,a({as:u,className:V(w.root,l),focusable:"false",color:d,"aria-hidden":!h||void 0,role:h?"img":void 0,ref:r},b,g,v&&i.props,{ownerState:y,children:[v?i.props.children:i,h?e.jsx("title",{children:h}):null]}))}); true&&(Su.propTypes={children:B.node,classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["inherit","action","disabled","primary","secondary","error","info","success","warning"]),B.string]),component:B.elementType,fontSize:B.oneOfType([B.oneOf(["inherit","large","medium","small"]),B.string]),htmlColor:B.string,inheritViewBox:B.bool,shapeRendering:B.string,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),titleAccess:B.string,viewBox:B.string}),Su.muiName="SvgIcon";const ku=Su;var Cu=t.forwardRef((e,r)=>t.createElement(ku,{...e,ref:r})),Ou=o.forwardRef((e,t)=>o.createElement(Cu,{viewBox:"0 0 24 24",...e,ref:t},o.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M12 2.25C12.4142 2.25 12.75 2.58579 12.75 3V4C12.75 4.41421 12.4142 4.75 12 4.75C11.5858 4.75 11.25 4.41421 11.25 4V3C11.25 2.58579 11.5858 2.25 12 2.25ZM5.06967 5.06967C5.36256 4.77678 5.83744 4.77678 6.13033 5.06967L6.83033 5.76967C7.12322 6.06256 7.12322 6.53744 6.83033 6.83033C6.53744 7.12322 6.06256 7.12322 5.76967 6.83033L5.06967 6.13033C4.77678 5.83744 4.77678 5.36256 5.06967 5.06967ZM18.9303 5.06967C19.2232 5.36256 19.2232 5.83744 18.9303 6.13033L18.2303 6.83033C17.9374 7.12322 17.4626 7.12322 17.1697 6.83033C16.8768 6.53744 16.8768 6.06256 17.1697 5.76967L17.8697 5.06967C18.1626 4.77678 18.6374 4.77678 18.9303 5.06967ZM12 7.75C11.108 7.75 10.2386 8.03066 9.51498 8.55222C8.79135 9.07378 8.25017 9.80981 7.9681 10.656C7.68602 11.5023 7.67735 12.4158 7.94332 13.2672C8.20928 14.1186 8.7364 14.8648 9.45 15.4C9.47737 15.4205 9.50331 15.4429 9.52763 15.467C9.76639 15.7033 9.97545 15.9663 10.1511 16.25H13.8489C14.0246 15.9663 14.2336 15.7033 14.4724 15.467C14.4967 15.4429 14.5226 15.4205 14.55 15.4C15.2636 14.8648 15.7907 14.1186 16.0567 13.2672C16.3226 12.4158 16.314 11.5023 16.0319 10.656C15.7498 9.80981 15.2086 9.07378 14.485 8.55222C13.7614 8.03066 12.892 7.75 12 7.75ZM14.9408 17.3899C14.9685 17.3444 14.9916 17.2956 15.0092 17.2444C15.1354 16.9955 15.2989 16.7666 15.4949 16.566C16.4376 15.8445 17.1342 14.8485 17.4885 13.7145C17.8483 12.5625 17.8366 11.3266 17.4549 10.1817C17.0733 9.0368 16.3411 8.041 15.3621 7.33536C14.3831 6.62971 13.2068 6.25 12 6.25C10.7932 6.25 9.61694 6.62971 8.63792 7.33536C7.65889 8.041 6.9267 9.0368 6.54507 10.1817C6.16344 11.3266 6.15171 12.5625 6.51155 13.7145C6.86579 14.8485 7.56245 15.8445 8.50515 16.566C8.7009 16.7665 8.86438 16.9951 8.99046 17.2438C9.00821 17.2954 9.03145 17.3446 9.05947 17.3905C9.0918 17.4648 9.12088 17.5406 9.14662 17.6178C9.28311 18.0273 9.3213 18.4632 9.25809 18.8902C9.2527 18.9265 9.25 18.9632 9.25 19C9.25 19.7293 9.53973 20.4288 10.0555 20.9445C10.5712 21.4603 11.2707 21.75 12 21.75C12.7293 21.75 13.4288 21.4603 13.9445 20.9445C14.4603 20.4288 14.75 19.7293 14.75 19C14.75 18.9632 14.7473 18.9265 14.7419 18.8902C14.6787 18.4632 14.7169 18.0273 14.8534 17.6178C14.8792 17.5404 14.9083 17.4644 14.9408 17.3899ZM13.2767 17.75H10.7233C10.7985 18.177 10.8081 18.6141 10.7509 19.0461C10.7625 19.3609 10.8926 19.6604 11.1161 19.8839C11.3505 20.1183 11.6685 20.25 12 20.25C12.3315 20.25 12.6495 20.1183 12.8839 19.8839C13.1074 19.6604 13.2375 19.3609 13.2491 19.0461C13.1919 18.6141 13.2015 18.177 13.2767 17.75ZM2.25 12C2.25 11.5858 2.58579 11.25 3 11.25H4C4.41421 11.25 4.75 11.5858 4.75 12C4.75 12.4142 4.41421 12.75 4 12.75H3C2.58579 12.75 2.25 12.4142 2.25 12ZM19.25 12C19.25 11.5858 19.5858 11.25 20 11.25H21C21.4142 11.25 21.75 11.5858 21.75 12C21.75 12.4142 21.4142 12.75 21 12.75H20C19.5858 12.75 19.25 12.4142 19.25 12Z"}))),Eu=o.forwardRef((e,t)=>o.createElement(Cu,{viewBox:"0 0 24 24",...e,ref:t},o.createElement("path",{d:"M11.75 15.75C12.3023 15.75 12.75 16.1977 12.75 16.75V16.7598C12.75 17.3121 12.3023 17.7598 11.75 17.7598C11.1977 17.7598 10.75 17.3121 10.75 16.7598V16.75C10.75 16.1977 11.1977 15.75 11.75 15.75Z"}),o.createElement("path",{d:"M11.1846 5.80957C11.8554 5.67269 12.5519 5.7716 13.1592 6.08887L13.1611 6.09082C13.7668 6.41042 14.2478 6.92595 14.5283 7.55273C14.8087 8.17938 14.8742 8.88338 14.7158 9.55176C14.5574 10.2202 14.1831 10.8182 13.6494 11.248C13.3136 11.5185 12.9265 11.7121 12.5156 11.8193V13.5C12.5156 13.9142 12.1798 14.25 11.7656 14.25C11.3516 14.2498 11.0156 13.9141 11.0156 13.5V11.167C11.0156 10.7537 11.3504 10.4183 11.7637 10.417C12.1047 10.4159 12.4371 10.2973 12.708 10.0791C12.9791 9.86074 13.1733 9.55417 13.2559 9.20605C13.3384 8.85764 13.3036 8.49103 13.1582 8.16602C13.0131 7.84167 12.7675 7.57909 12.4629 7.41797C12.1603 7.26033 11.8157 7.21168 11.4844 7.2793C11.1523 7.34706 10.8495 7.52873 10.627 7.79688C10.3624 8.11534 9.88993 8.15896 9.57129 7.89453C9.25265 7.63007 9.20839 7.1576 9.47266 6.83887C9.91082 6.31093 10.5138 5.94644 11.1846 5.80957Z"}),o.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M11.75 2C17.1348 2 21.5 6.36522 21.5 11.75C21.5 17.1348 17.1348 21.5 11.75 21.5C6.36522 21.5 2 17.1348 2 11.75C2 6.36522 6.36522 2 11.75 2ZM11.75 3.5C7.19365 3.5 3.5 7.19365 3.5 11.75C3.5 16.3063 7.19365 20 11.75 20C16.3063 20 20 16.3063 20 11.75C20 7.19365 16.3063 3.5 11.75 3.5Z"})));function Tu(e){return Mo("MuiDivider",e)}const Ru=ta("MuiDivider",["root","absolute","fullWidth","inset","middle","flexItem","light","vertical","withChildren","withChildrenVertical","textAlignRight","textAlignLeft","wrapper","wrapperVertical"]),Iu=["absolute","children","className","component","flexItem","light","orientation","role","textAlign","variant"],Mu=Vi("div",{name:"MuiDivider",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,r.absolute&&t.absolute,t[r.variant],r.light&&t.light,"vertical"===r.orientation&&t.vertical,r.flexItem&&t.flexItem,r.children&&t.withChildren,r.children&&"vertical"===r.orientation&&t.withChildrenVertical,"right"===r.textAlign&&"vertical"!==r.orientation&&t.textAlignRight,"left"===r.textAlign&&"vertical"!==r.orientation&&t.textAlignLeft]}})(({theme:e,ownerState:t})=>a({margin:0,flexShrink:0,borderWidth:0,borderStyle:"solid",borderColor:(e.vars||e).palette.divider,borderBottomWidth:"thin"},t.absolute&&{position:"absolute",bottom:0,left:0,width:"100%"},t.light&&{borderColor:e.vars?`rgba(${e.vars.palette.dividerChannel} / 0.08)`:Fo.alpha(e.palette.divider,.08)},"inset"===t.variant&&{marginLeft:72},"middle"===t.variant&&"horizontal"===t.orientation&&{marginLeft:e.spacing(2),marginRight:e.spacing(2)},"middle"===t.variant&&"vertical"===t.orientation&&{marginTop:e.spacing(1),marginBottom:e.spacing(1)},"vertical"===t.orientation&&{height:"100%",borderBottomWidth:0,borderRightWidth:"thin"},t.flexItem&&{alignSelf:"stretch",height:"auto"}),({ownerState:e})=>a({},e.children&&{display:"flex",whiteSpace:"nowrap",textAlign:"center",border:0,"&::before, &::after":{content:'""',alignSelf:"center"}}),({theme:e,ownerState:t})=>a({},t.children&&"vertical"!==t.orientation&&{"&::before, &::after":{width:"100%",borderTop:`thin solid ${(e.vars||e).palette.divider}`}}),({theme:e,ownerState:t})=>a({},t.children&&"vertical"===t.orientation&&{flexDirection:"column","&::before, &::after":{height:"100%",borderLeft:`thin solid ${(e.vars||e).palette.divider}`}}),({ownerState:e})=>a({},"right"===e.textAlign&&"vertical"!==e.orientation&&{"&::before":{width:"90%"},"&::after":{width:"10%"}},"left"===e.textAlign&&"vertical"!==e.orientation&&{"&::before":{width:"10%"},"&::after":{width:"90%"}})),Au=Vi("span",{name:"MuiDivider",slot:"Wrapper",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.wrapper,"vertical"===r.orientation&&t.wrapperVertical]}})(({theme:e,ownerState:t})=>a({display:"inline-block",paddingLeft:`calc(${e.spacing(1)} * 1.2)`,paddingRight:`calc(${e.spacing(1)} * 1.2)`},"vertical"===t.orientation&&{paddingTop:`calc(${e.spacing(1)} * 1.2)`,paddingBottom:`calc(${e.spacing(1)} * 1.2)`})),Pu=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiDivider"}),{absolute:o=!1,children:i,className:l,component:c=(i?"div":"hr"),flexItem:u=!1,light:p=!1,orientation:d="horizontal",role:f=("hr"!==c?"separator":void 0),textAlign:h="center",variant:m="fullWidth"}=n,g=s(n,Iu),v=a({},n,{absolute:o,component:c,flexItem:u,light:p,orientation:d,role:f,textAlign:h,variant:m}),y=(e=>{const{absolute:t,children:r,classes:n,flexItem:o,light:i,orientation:s,textAlign:a,variant:l}=e;return U({root:["root",t&&"absolute",l,i&&"light","vertical"===s&&"vertical",o&&"flexItem",r&&"withChildren",r&&"vertical"===s&&"withChildrenVertical","right"===a&&"vertical"!==s&&"textAlignRight","left"===a&&"vertical"!==s&&"textAlignLeft"],wrapper:["wrapper","vertical"===s&&"wrapperVertical"]},Tu,n)})(v);return e.jsx(Mu,a({as:c,className:V(y.root,l),role:f,ref:r,ownerState:v},g,{children:i?e.jsx(Au,{className:y.wrapper,ownerState:v,children:i}):null}))});Pu.muiSkipListHighlight=!0, true&&(Pu.propTypes={absolute:B.bool,children:B.node,classes:B.object,className:B.string,component:B.elementType,flexItem:B.bool,light:B.bool,orientation:B.oneOf(["horizontal","vertical"]),role:B.string,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),textAlign:B.oneOf(["center","left","right"]),variant:B.oneOfType([B.oneOf(["fullWidth","inset","middle"]),B.string])});const Nu=Pu;var ju=t.forwardRef((e,r)=>t.createElement(Nu,{...e,ref:r})),Lu=o.forwardRef((e,t)=>o.createElement(Cu,{viewBox:"0 0 24 24",...e,ref:t},o.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M12 3.75C10.2051 3.75 8.75 5.20507 8.75 7C8.75 8.79493 10.2051 10.25 12 10.25C13.7949 10.25 15.25 8.79493 15.25 7C15.25 5.20507 13.7949 3.75 12 3.75ZM7.25 7C7.25 4.37665 9.37665 2.25 12 2.25C14.6234 2.25 16.75 4.37665 16.75 7C16.75 9.62335 14.6234 11.75 12 11.75C9.37665 11.75 7.25 9.62335 7.25 7ZM10 15.75C9.13805 15.75 8.3114 16.0924 7.7019 16.7019C7.09241 17.3114 6.75 18.138 6.75 19V21C6.75 21.4142 6.41421 21.75 6 21.75C5.58579 21.75 5.25 21.4142 5.25 21V19C5.25 17.7402 5.75044 16.532 6.64124 15.6412C7.53204 14.7504 8.74022 14.25 10 14.25H14C15.2598 14.25 16.468 14.7504 17.3588 15.6412C18.2496 16.532 18.75 17.7402 18.75 19V21C18.75 21.4142 18.4142 21.75 18 21.75C17.5858 21.75 17.25 21.4142 17.25 21V19C17.25 18.138 16.9076 17.3114 16.2981 16.7019C15.6886 16.0924 14.862 15.75 14 15.75H10Z"})));function Du(e,t){const r=a({},t);return Object.keys(e).forEach(n=>{if(n.toString().match(/^(components|slots)$/))r[n]=a({},e[n],r[n]);else if(n.toString().match(/^(componentsProps|slotProps)$/)){const o=e[n]||{},i=t[n];r[n]={},i&&Object.keys(i)?o&&Object.keys(o)?(r[n]=a({},i),Object.keys(o).forEach(e=>{r[n][e]=Du(o[e],i[e])})):r[n]=i:r[n]=o}else void 0===r[n]&&(r[n]=e[n])}),r}function Fu(e){return Mo("MuiButton",e)}const $u=ta("MuiButton",["root","text","textInherit","textPrimary","textSecondary","textSuccess","textError","textInfo","textWarning","outlined","outlinedInherit","outlinedPrimary","outlinedSecondary","outlinedSuccess","outlinedError","outlinedInfo","outlinedWarning","contained","containedInherit","containedPrimary","containedSecondary","containedSuccess","containedError","containedInfo","containedWarning","disableElevation","focusVisible","disabled","colorInherit","colorPrimary","colorSecondary","colorSuccess","colorError","colorInfo","colorWarning","textSizeSmall","textSizeMedium","textSizeLarge","outlinedSizeSmall","outlinedSizeMedium","outlinedSizeLarge","containedSizeSmall","containedSizeMedium","containedSizeLarge","sizeMedium","sizeSmall","sizeLarge","fullWidth","startIcon","endIcon","icon","iconSizeSmall","iconSizeMedium","iconSizeLarge"]),Bu=o.createContext({}); true&&(Bu.displayName="ButtonGroupContext");const zu=Bu,Vu=o.createContext(void 0); true&&(Vu.displayName="ButtonGroupButtonContext");const Uu=Vu,qu=["children","color","component","className","disabled","disableElevation","disableFocusRipple","endIcon","focusVisibleClassName","fullWidth","size","startIcon","type","variant"],Wu=e=>a({},"small"===e.size&&{"& > *:nth-of-type(1)":{fontSize:18}},"medium"===e.size&&{"& > *:nth-of-type(1)":{fontSize:20}},"large"===e.size&&{"& > *:nth-of-type(1)":{fontSize:22}}),Hu=Vi(Dl,{shouldForwardProp:e=>zi(e)||"classes"===e,name:"MuiButton",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,t[r.variant],t[`${r.variant}${Zi(r.color)}`],t[`size${Zi(r.size)}`],t[`${r.variant}Size${Zi(r.size)}`],"inherit"===r.color&&t.colorInherit,r.disableElevation&&t.disableElevation,r.fullWidth&&t.fullWidth]}})(({theme:e,ownerState:t})=>{var r,n;const o="light"===e.palette.mode?e.palette.grey[300]:e.palette.grey[800],i="light"===e.palette.mode?e.palette.grey.A100:e.palette.grey[700];return a({},e.typography.button,{minWidth:64,padding:"6px 16px",borderRadius:(e.vars||e).shape.borderRadius,transition:e.transitions.create(["background-color","box-shadow","border-color","color"],{duration:e.transitions.duration.short}),"&:hover":a({textDecoration:"none",backgroundColor:e.vars?`rgba(${e.vars.palette.text.primaryChannel} / ${e.vars.palette.action.hoverOpacity})`:Fo.alpha(e.palette.text.primary,e.palette.action.hoverOpacity),"@media (hover: none)":{backgroundColor:"transparent"}},"text"===t.variant&&"inherit"!==t.color&&{backgroundColor:e.vars?`rgba(${e.vars.palette[t.color].mainChannel} / ${e.vars.palette.action.hoverOpacity})`:Fo.alpha(e.palette[t.color].main,e.palette.action.hoverOpacity),"@media (hover: none)":{backgroundColor:"transparent"}},"outlined"===t.variant&&"inherit"!==t.color&&{border:`1px solid ${(e.vars||e).palette[t.color].main}`,backgroundColor:e.vars?`rgba(${e.vars.palette[t.color].mainChannel} / ${e.vars.palette.action.hoverOpacity})`:Fo.alpha(e.palette[t.color].main,e.palette.action.hoverOpacity),"@media (hover: none)":{backgroundColor:"transparent"}},"contained"===t.variant&&{backgroundColor:e.vars?e.vars.palette.Button.inheritContainedHoverBg:i,boxShadow:(e.vars||e).shadows[4],"@media (hover: none)":{boxShadow:(e.vars||e).shadows[2],backgroundColor:(e.vars||e).palette.grey[300]}},"contained"===t.variant&&"inherit"!==t.color&&{backgroundColor:(e.vars||e).palette[t.color].dark,"@media (hover: none)":{backgroundColor:(e.vars||e).palette[t.color].main}}),"&:active":a({},"contained"===t.variant&&{boxShadow:(e.vars||e).shadows[8]}),[`&.${$u.focusVisible}`]:a({},"contained"===t.variant&&{boxShadow:(e.vars||e).shadows[6]}),[`&.${$u.disabled}`]:a({color:(e.vars||e).palette.action.disabled},"outlined"===t.variant&&{border:`1px solid ${(e.vars||e).palette.action.disabledBackground}`},"contained"===t.variant&&{color:(e.vars||e).palette.action.disabled,boxShadow:(e.vars||e).shadows[0],backgroundColor:(e.vars||e).palette.action.disabledBackground})},"text"===t.variant&&{padding:"6px 8px"},"text"===t.variant&&"inherit"!==t.color&&{color:(e.vars||e).palette[t.color].main},"outlined"===t.variant&&{padding:"5px 15px",border:"1px solid currentColor"},"outlined"===t.variant&&"inherit"!==t.color&&{color:(e.vars||e).palette[t.color].main,border:e.vars?`1px solid rgba(${e.vars.palette[t.color].mainChannel} / 0.5)`:`1px solid ${Fo.alpha(e.palette[t.color].main,.5)}`},"contained"===t.variant&&{color:e.vars?e.vars.palette.text.primary:null==(r=(n=e.palette).getContrastText)?void 0:r.call(n,e.palette.grey[300]),backgroundColor:e.vars?e.vars.palette.Button.inheritContainedBg:o,boxShadow:(e.vars||e).shadows[2]},"contained"===t.variant&&"inherit"!==t.color&&{color:(e.vars||e).palette[t.color].contrastText,backgroundColor:(e.vars||e).palette[t.color].main},"inherit"===t.color&&{color:"inherit",borderColor:"currentColor"},"small"===t.size&&"text"===t.variant&&{padding:"4px 5px",fontSize:e.typography.pxToRem(13)},"large"===t.size&&"text"===t.variant&&{padding:"8px 11px",fontSize:e.typography.pxToRem(15)},"small"===t.size&&"outlined"===t.variant&&{padding:"3px 9px",fontSize:e.typography.pxToRem(13)},"large"===t.size&&"outlined"===t.variant&&{padding:"7px 21px",fontSize:e.typography.pxToRem(15)},"small"===t.size&&"contained"===t.variant&&{padding:"4px 10px",fontSize:e.typography.pxToRem(13)},"large"===t.size&&"contained"===t.variant&&{padding:"8px 22px",fontSize:e.typography.pxToRem(15)},t.fullWidth&&{width:"100%"})},({ownerState:e})=>e.disableElevation&&{boxShadow:"none","&:hover":{boxShadow:"none"},[`&.${$u.focusVisible}`]:{boxShadow:"none"},"&:active":{boxShadow:"none"},[`&.${$u.disabled}`]:{boxShadow:"none"}}),Gu=Vi("span",{name:"MuiButton",slot:"StartIcon",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.startIcon,t[`iconSize${Zi(r.size)}`]]}})(({ownerState:e})=>a({display:"inherit",marginRight:8,marginLeft:-4},"small"===e.size&&{marginLeft:-2},Wu(e))),Ku=Vi("span",{name:"MuiButton",slot:"EndIcon",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.endIcon,t[`iconSize${Zi(r.size)}`]]}})(({ownerState:e})=>a({display:"inherit",marginRight:-4,marginLeft:8},"small"===e.size&&{marginRight:-2},Wu(e))),Yu=o.forwardRef(function(t,r){const n=o.useContext(zu),i=o.useContext(Uu),l=Yi({props:Du(n,t),name:"MuiButton"}),{children:c,color:u="primary",component:p="button",className:d,disabled:f=!1,disableElevation:h=!1,disableFocusRipple:m=!1,endIcon:g,focusVisibleClassName:v,fullWidth:y=!1,size:b="medium",startIcon:w,type:x,variant:_="text"}=l,S=s(l,qu),k=a({},l,{color:u,component:p,disabled:f,disableElevation:h,disableFocusRipple:m,fullWidth:y,size:b,type:x,variant:_}),C=(e=>{const{color:t,disableElevation:r,fullWidth:n,size:o,variant:i,classes:s}=e;return a({},s,U({root:["root",i,`${i}${Zi(t)}`,`size${Zi(o)}`,`${i}Size${Zi(o)}`,`color${Zi(t)}`,r&&"disableElevation",n&&"fullWidth"],label:["label"],startIcon:["icon","startIcon",`iconSize${Zi(o)}`],endIcon:["icon","endIcon",`iconSize${Zi(o)}`]},Fu,s))})(k),O=w&&e.jsx(Gu,{className:C.startIcon,ownerState:k,children:w}),E=g&&e.jsx(Ku,{className:C.endIcon,ownerState:k,children:g}),T=i||"";return e.jsxs(Hu,a({ownerState:k,className:V(n.className,C.root,d,T),component:p,disabled:f,focusRipple:!m,focusVisibleClassName:V(C.focusVisible,v),ref:r,type:x},S,{classes:C,children:[O,c,E]}))}); true&&(Yu.propTypes={children:B.node,classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["inherit","primary","secondary","success","error","info","warning"]),B.string]),component:B.elementType,disabled:B.bool,disableElevation:B.bool,disableFocusRipple:B.bool,disableRipple:B.bool,endIcon:B.node,focusVisibleClassName:B.string,fullWidth:B.bool,href:B.string,size:B.oneOfType([B.oneOf(["small","medium","large"]),B.string]),startIcon:B.node,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),type:B.oneOfType([B.oneOf(["button","reset","submit"]),B.string]),variant:B.oneOfType([B.oneOf(["contained","outlined","text"]),B.string])});const Zu=Yu;function Xu(e){return Mo("MuiCircularProgress",e)}ta("MuiCircularProgress",["root","determinate","indeterminate","colorPrimary","colorSecondary","svg","circle","circleDeterminate","circleIndeterminate","circleDisableShrink"]);const Ju=["className","color","disableShrink","size","style","thickness","value","variant"];let Qu,ep,tp,rp,np=e=>e;const op=Ot(Qu||(Qu=np`
  0% {
    transform: rotate(0deg);
  }

  100% {
    transform: rotate(360deg);
  }
`)),ip=Ot(ep||(ep=np`
  0% {
    stroke-dasharray: 1px, 200px;
    stroke-dashoffset: 0;
  }

  50% {
    stroke-dasharray: 100px, 200px;
    stroke-dashoffset: -15px;
  }

  100% {
    stroke-dasharray: 100px, 200px;
    stroke-dashoffset: -125px;
  }
`)),sp=Vi("span",{name:"MuiCircularProgress",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,t[r.variant],t[`color${Zi(r.color)}`]]}})(({ownerState:e,theme:t})=>a({display:"inline-block"},"determinate"===e.variant&&{transition:t.transitions.create("transform")},"inherit"!==e.color&&{color:(t.vars||t).palette[e.color].main}),({ownerState:e})=>"indeterminate"===e.variant&&Ct(tp||(tp=np`
      animation: ${0} 1.4s linear infinite;
    `),op)),ap=Vi("svg",{name:"MuiCircularProgress",slot:"Svg",overridesResolver:(e,t)=>t.svg})({display:"block"}),lp=Vi("circle",{name:"MuiCircularProgress",slot:"Circle",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.circle,t[`circle${Zi(r.variant)}`],r.disableShrink&&t.circleDisableShrink]}})(({ownerState:e,theme:t})=>a({stroke:"currentColor"},"determinate"===e.variant&&{transition:t.transitions.create("stroke-dashoffset")},"indeterminate"===e.variant&&{strokeDasharray:"80px, 200px",strokeDashoffset:0}),({ownerState:e})=>"indeterminate"===e.variant&&!e.disableShrink&&Ct(rp||(rp=np`
      animation: ${0} 1.4s ease-in-out infinite;
    `),ip)),cp=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiCircularProgress"}),{className:o,color:i="primary",disableShrink:l=!1,size:c=40,style:u,thickness:p=3.6,value:d=0,variant:f="indeterminate"}=n,h=s(n,Ju),m=a({},n,{color:i,disableShrink:l,size:c,thickness:p,value:d,variant:f}),g=(e=>{const{classes:t,variant:r,color:n,disableShrink:o}=e;return U({root:["root",r,`color${Zi(n)}`],svg:["svg"],circle:["circle",`circle${Zi(r)}`,o&&"circleDisableShrink"]},Xu,t)})(m),v={},y={},b={};if("determinate"===f){const e=2*Math.PI*((44-p)/2);v.strokeDasharray=e.toFixed(3),b["aria-valuenow"]=Math.round(d),v.strokeDashoffset=`${((100-d)/100*e).toFixed(3)}px`,y.transform="rotate(-90deg)"}return e.jsx(sp,a({className:V(g.root,o),style:a({width:c,height:c},y,u),ownerState:m,ref:r,role:"progressbar"},b,h,{children:e.jsx(ap,{className:g.svg,ownerState:m,viewBox:"22 22 44 44",children:e.jsx(lp,{className:g.circle,style:v,ownerState:m,cx:44,cy:44,r:(44-p)/2,fill:"none",strokeWidth:p})})}))}); true&&(cp.propTypes={classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["inherit","primary","secondary","error","info","success","warning"]),B.string]),disableShrink:rs(B.bool,e=>e.disableShrink&&e.variant&&"indeterminate"!==e.variant?new Error("MUI: You have provided the `disableShrink` prop with a variant other than `indeterminate`. This will have no effect."):null),size:B.oneOfType([B.number,B.string]),style:B.object,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),thickness:B.number,value:B.number,variant:B.oneOf(["determinate","indeterminate"])});const up=cp,pp={color:"inherit",size:"1em"},dp=t.forwardRef((e,r)=>t.createElement(up,{...pp,...e,ref:r}));dp.defaultProps=pp;var fp=dp;const hp="rgba(0, 0, 0, 0.04)",mp="rgba(0, 0, 0, 0.08)",gp=sc(Zu)(({theme:e,ownerState:t})=>{const{color:r,unstableToColor:n,unstableGradientAngle:o}=t,i=r&&"inherit"!==r?r:"primary",s=!!e.palette[i]?.__unstableTonalMain,a=({variant:e})=>"unstableTonal"===e&&s,l=({variant:e})=>!!e&&!["contained","outlined","text"].includes(e);return{variants:[{props:()=>t.loading&&"center"===t.loadingPosition,style:{"&.MuiButtonBase-root":{"&, &:hover, &:focus, &:active":{color:"transparent"}},"& .MuiButton-loadingWrapper":{display:"contents","& .MuiButton-loadingIndicator":{display:"flex",position:"absolute",left:"50%",transform:"translateX(-50%)",color:e.palette.action.disabled}}}},{props:e=>a(e)&&"inherit"!==e.color&&!e.disabled,style:{background:e.palette[i]?.__unstableTonalMain,color:e.palette[i].main,"&:hover":{backgroundColor:e.palette[i]?.__unstableTonalDark}}},{props:e=>e.disabled&&l(e),style:{background:e.palette.action.disabledBackground,color:e.palette.action.disabled}},{props:e=>a(e)&&"inherit"===e.color,style:{background:hp,color:"inherit","&:hover":{backgroundColor:mp}}},{props:e=>"unstableTonal"===e.variant&&!s,style:{background:"#ff0000",color:"#ff0000"}},{props:e=>"small"===e.size&&l(e),style:{padding:"4px 10px",fontSize:e.typography.pxToRem(13)}},{props:e=>"large"===e.size&&l(e),style:{padding:"8px 22px",fontSize:e.typography.pxToRem(15)}},{props:e=>(({variant:e})=>"unstableGradient"===e&&s)(e)&&!e.disabled,style:_p(e,o,r,n)},{props:e=>"unstableGradient"===e.variant&&!s,style:{background:"#ff0000",color:"#ff0000"}}]}}),vp=(e="primary",t="text",r)=>{if(e)return"inherit"===e?"inherit":"contained"===t?`${e}.contrastText`:"unstableTonal"===t?`${e}.main`:r.palette.primary.__unstableAccessibleMain&&$c.includes(e)?`${e}.${Wl}`:`${e}.main`},yp={loading:!1,loadingIndicator:t.createElement(fp,{color:"inherit",size:16}),loadingPosition:"center"},bp=t.forwardRef((e,r)=>{const n={...yp,...e},o=t.useContext(zu),i=ea(),{sx:s={},unstableToColor:a,unstableGradientAngle:l,...c}=function(e){const{loading:r,loadingPosition:n,loadingIndicator:o,...i}=e;if(!r)return i;switch(n){case"start":i.startIcon=o;break;case"end":i.endIcon=o;break;case"center":i.children=t.createElement(xp,{loadingIndicator:o},e.children)}return{...i,disabled:!0}}(n),u={...c,loading:n.loading,loadingPosition:n.loadingPosition,loadingIndicator:n.loadingIndicator,unstableToColor:a,unstableGradientAngle:l};let p={};const d=c.href?ql:"&:hover,&:focus,&:active",f=c.color||o?.color,h=c.variant||o?.variant;return p={[d]:{color:vp(f,h,i)}},t.createElement(gp,{...c,color:f,variant:h,sx:{...p,...s},ref:r,ownerState:u})});var wp=bp;function xp({loadingIndicator:e,children:r}){return t.createElement(t.Fragment,null,t.createElement("div",{className:"MuiButton-loadingWrapper"},t.createElement("div",{className:"MuiButton-loadingIndicator"},e)),r)}function _p(e,t,r,n){if(!r)return;const o=r,i=function(e,t){if(void 0!==t)return t;const{__unstableGradientAngle:r}=e.palette.action;return void 0!==r?r:125}(e,t);let{main:s,__unstableTonalMain:a,__unstableTonalDark:l}=e.palette[o]||{};"inherit"===r&&(s="inherit",a=hp,l=mp);const c=[a],u=[l];if(n){const t=n,{__unstableTonalMain:r,__unstableTonalDark:o}=e.palette[t];c.push(r),u.push(o)}return{color:s,backgroundImage:`linear-gradient( ${i}deg, ${c.join(", ")} )`,"&:hover":{backgroundImage:`linear-gradient( ${i}deg, ${u.join(",")} )`}}}bp.defaultProps=yp;const Sp=e=>"string"==typeof e,kp=()=>{let e,t;const r=new Promise((r,n)=>{e=r,t=n});return r.resolve=e,r.reject=t,r},Cp=e=>null==e?"":""+e,Op=/###/g,Ep=e=>e&&e.indexOf("###")>-1?e.replace(Op,"."):e,Tp=e=>!e||Sp(e),Rp=(e,t,r)=>{const n=Sp(t)?t.split("."):t;let o=0;for(;o<n.length-1;){if(Tp(e))return{};const t=Ep(n[o]);!e[t]&&r&&(e[t]=new r),e=Object.prototype.hasOwnProperty.call(e,t)?e[t]:{},++o}return Tp(e)?{}:{obj:e,k:Ep(n[o])}},Ip=(e,t,r)=>{const{obj:n,k:o}=Rp(e,t,Object);if(void 0!==n||1===t.length)return void(n[o]=r);let i=t[t.length-1],s=t.slice(0,t.length-1),a=Rp(e,s,Object);for(;void 0===a.obj&&s.length;)i=`${s[s.length-1]}.${i}`,s=s.slice(0,s.length-1),a=Rp(e,s,Object),a?.obj&&void 0!==a.obj[`${a.k}.${i}`]&&(a.obj=void 0);a.obj[`${a.k}.${i}`]=r},Mp=(e,t)=>{const{obj:r,k:n}=Rp(e,t);if(r&&Object.prototype.hasOwnProperty.call(r,n))return r[n]},Ap=(e,t,r)=>{for(const n in t)"__proto__"!==n&&"constructor"!==n&&(n in e?Sp(e[n])||e[n]instanceof String||Sp(t[n])||t[n]instanceof String?r&&(e[n]=t[n]):Ap(e[n],t[n],r):e[n]=t[n]);return e},Pp=e=>e.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g,"\\$&");var Np={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","/":"&#x2F;"};const jp=e=>Sp(e)?e.replace(/[&<>"'\/]/g,e=>Np[e]):e,Lp=[" ",",","?","!",";"],Dp=new class{getRegExp(e){const t=this.regExpMap.get(e);if(void 0!==t)return t;const r=new RegExp(e);return this.regExpQueue.length===this.capacity&&this.regExpMap.delete(this.regExpQueue.shift()),this.regExpMap.set(e,r),this.regExpQueue.push(e),r}constructor(e){this.capacity=e,this.regExpMap=new Map,this.regExpQueue=[]}}(20),Fp=(e,t,r=".")=>{if(!e)return;if(e[t]){if(!Object.prototype.hasOwnProperty.call(e,t))return;return e[t]}const n=t.split(r);let o=e;for(let e=0;e<n.length;){if(!o||"object"!=typeof o)return;let t,i="";for(let s=e;s<n.length;++s)if(s!==e&&(i+=r),i+=n[s],t=o[i],void 0!==t){if(["string","number","boolean"].indexOf(typeof t)>-1&&s<n.length-1)continue;e+=s-e+1;break}o=t}return o},$p=e=>e?.replace(/_/g,"-"),Bp={type:"logger",log(e){this.output("log",e)},warn(e){this.output("warn",e)},error(e){this.output("error",e)},output(e,t){console?.[e]?.apply?.(console,t)}};class zp{init(e,t={}){this.prefix=t.prefix||"i18next:",this.logger=e||Bp,this.options=t,this.debug=t.debug}log(...e){return this.forward(e,"log","",!0)}warn(...e){return this.forward(e,"warn","",!0)}error(...e){return this.forward(e,"error","")}deprecate(...e){return this.forward(e,"warn","WARNING DEPRECATED: ",!0)}forward(e,t,r,n){return n&&!this.debug?null:(Sp(e[0])&&(e[0]=`${r}${this.prefix} ${e[0]}`),this.logger[t](e))}create(e){return new zp(this.logger,{prefix:`${this.prefix}:${e}:`,...this.options})}clone(e){return(e=e||this.options).prefix=e.prefix||this.prefix,new zp(this.logger,e)}constructor(e,t={}){this.init(e,t)}}var Vp=new zp;class Up{on(e,t){return e.split(" ").forEach(e=>{this.observers[e]||(this.observers[e]=new Map);const r=this.observers[e].get(t)||0;this.observers[e].set(t,r+1)}),this}off(e,t){this.observers[e]&&(t?this.observers[e].delete(t):delete this.observers[e])}emit(e,...t){this.observers[e]&&Array.from(this.observers[e].entries()).forEach(([e,r])=>{for(let n=0;n<r;n++)e(...t)}),this.observers["*"]&&Array.from(this.observers["*"].entries()).forEach(([r,n])=>{for(let o=0;o<n;o++)r.apply(r,[e,...t])})}constructor(){this.observers={}}}class qp extends Up{addNamespaces(e){this.options.ns.indexOf(e)<0&&this.options.ns.push(e)}removeNamespaces(e){const t=this.options.ns.indexOf(e);t>-1&&this.options.ns.splice(t,1)}getResource(e,t,r,n={}){const o=void 0!==n.keySeparator?n.keySeparator:this.options.keySeparator,i=void 0!==n.ignoreJSONStructure?n.ignoreJSONStructure:this.options.ignoreJSONStructure;let s;e.indexOf(".")>-1?s=e.split("."):(s=[e,t],r&&(Array.isArray(r)?s.push(...r):Sp(r)&&o?s.push(...r.split(o)):s.push(r)));const a=Mp(this.data,s);return!a&&!t&&!r&&e.indexOf(".")>-1&&(e=s[0],t=s[1],r=s.slice(2).join(".")),!a&&i&&Sp(r)?Fp(this.data?.[e]?.[t],r,o):a}addResource(e,t,r,n,o={silent:!1}){const i=void 0!==o.keySeparator?o.keySeparator:this.options.keySeparator;let s=[e,t];r&&(s=s.concat(i?r.split(i):r)),e.indexOf(".")>-1&&(s=e.split("."),n=t,t=s[1]),this.addNamespaces(t),Ip(this.data,s,n),o.silent||this.emit("added",e,t,r,n)}addResources(e,t,r,n={silent:!1}){for(const n in r)(Sp(r[n])||Array.isArray(r[n]))&&this.addResource(e,t,n,r[n],{silent:!0});n.silent||this.emit("added",e,t,r)}addResourceBundle(e,t,r,n,o,i={silent:!1,skipCopy:!1}){let s=[e,t];e.indexOf(".")>-1&&(s=e.split("."),n=r,r=t,t=s[1]),this.addNamespaces(t);let a=Mp(this.data,s)||{};i.skipCopy||(r=JSON.parse(JSON.stringify(r))),n?Ap(a,r,o):a={...a,...r},Ip(this.data,s,a),i.silent||this.emit("added",e,t,r)}removeResourceBundle(e,t){this.hasResourceBundle(e,t)&&delete this.data[e][t],this.removeNamespaces(t),this.emit("removed",e,t)}hasResourceBundle(e,t){return void 0!==this.getResource(e,t)}getResourceBundle(e,t){return t||(t=this.options.defaultNS),this.getResource(e,t)}getDataByLanguage(e){return this.data[e]}hasLanguageSomeTranslations(e){const t=this.getDataByLanguage(e);return!!(t&&Object.keys(t)||[]).find(e=>t[e]&&Object.keys(t[e]).length>0)}toJSON(){return this.data}constructor(e,t={ns:["translation"],defaultNS:"translation"}){super(),this.data=e||{},this.options=t,void 0===this.options.keySeparator&&(this.options.keySeparator="."),void 0===this.options.ignoreJSONStructure&&(this.options.ignoreJSONStructure=!0)}}var Wp={processors:{},addPostProcessor(e){this.processors[e.name]=e},handle(e,t,r,n,o){return e.forEach(e=>{t=this.processors[e]?.process(t,r,n,o)??t}),t}};const Hp=Symbol("i18next/PATH_KEY");function Gp(e,t){const{[Hp]:r}=e(function(){const e=[],t=Object.create(null);let r;return t.get=(n,o)=>(r?.revoke?.(),o===Hp?e:(e.push(o),r=Proxy.revocable(n,t),r.proxy)),Proxy.revocable(Object.create(null),t).proxy}()),n=t?.keySeparator??".",o=t?.nsSeparator??":";if(r.length>1&&o){const e=t?.ns;if((e?Array.isArray(e)?e:[e]:[]).includes(r[0]))return`${r[0]}${o}${r.slice(1).join(n)}`}return r.join(n)}const Kp={},Yp=e=>!Sp(e)&&"boolean"!=typeof e&&"number"!=typeof e;class Zp extends Up{changeLanguage(e){e&&(this.language=e)}exists(e,t={interpolation:{}}){const r={...t};if(null==e)return!1;const n=this.resolve(e,r);if(void 0===n?.res)return!1;const o=Yp(n.res);return!1!==r.returnObjects||!o}extractFromKey(e,t){let r=void 0!==t.nsSeparator?t.nsSeparator:this.options.nsSeparator;void 0===r&&(r=":");const n=void 0!==t.keySeparator?t.keySeparator:this.options.keySeparator;let o=t.ns||this.options.defaultNS||[];const i=r&&e.indexOf(r)>-1,s=!(this.options.userDefinedKeySeparator||t.keySeparator||this.options.userDefinedNsSeparator||t.nsSeparator||((e,t,r)=>{t=t||"",r=r||"";const n=Lp.filter(e=>t.indexOf(e)<0&&r.indexOf(e)<0);if(0===n.length)return!0;const o=Dp.getRegExp(`(${n.map(e=>"?"===e?"\\?":e).join("|")})`);let i=!o.test(e);if(!i){const t=e.indexOf(r);t>0&&!o.test(e.substring(0,t))&&(i=!0)}return i})(e,r,n));if(i&&!s){const t=e.match(this.interpolator.nestingRegexp);if(t&&t.length>0)return{key:e,namespaces:Sp(o)?[o]:o};const i=e.split(r);(r!==n||r===n&&this.options.ns.indexOf(i[0])>-1)&&(o=i.shift()),e=i.join(n)}return{key:e,namespaces:Sp(o)?[o]:o}}translate(e,t,r){let n="object"==typeof t?{...t}:t;if("object"!=typeof n&&this.options.overloadTranslationOptionHandler&&(n=this.options.overloadTranslationOptionHandler(arguments)),"object"==typeof n&&(n={...n}),n||(n={}),null==e)return"";"function"==typeof e&&(e=Gp(e,{...this.options,...n})),Array.isArray(e)||(e=[String(e)]);const o=void 0!==n.returnDetails?n.returnDetails:this.options.returnDetails,i=void 0!==n.keySeparator?n.keySeparator:this.options.keySeparator,{key:s,namespaces:a}=this.extractFromKey(e[e.length-1],n),l=a[a.length-1];let c=void 0!==n.nsSeparator?n.nsSeparator:this.options.nsSeparator;void 0===c&&(c=":");const u=n.lng||this.language,p=n.appendNamespaceToCIMode||this.options.appendNamespaceToCIMode;if("cimode"===u?.toLowerCase())return p?o?{res:`${l}${c}${s}`,usedKey:s,exactUsedKey:s,usedLng:u,usedNS:l,usedParams:this.getUsedParamsDetails(n)}:`${l}${c}${s}`:o?{res:s,usedKey:s,exactUsedKey:s,usedLng:u,usedNS:l,usedParams:this.getUsedParamsDetails(n)}:s;const d=this.resolve(e,n);let f=d?.res;const h=d?.usedKey||s,m=d?.exactUsedKey||s,g=void 0!==n.joinArrays?n.joinArrays:this.options.joinArrays,v=!this.i18nFormat||this.i18nFormat.handleAsObject,y=void 0!==n.count&&!Sp(n.count),b=Zp.hasDefaultValue(n),w=y?this.pluralResolver.getSuffix(u,n.count,n):"",x=n.ordinal&&y?this.pluralResolver.getSuffix(u,n.count,{ordinal:!1}):"",_=y&&!n.ordinal&&0===n.count,S=_&&n[`defaultValue${this.options.pluralSeparator}zero`]||n[`defaultValue${w}`]||n[`defaultValue${x}`]||n.defaultValue;let k=f;v&&!f&&b&&(k=S);const C=Yp(k),O=Object.prototype.toString.apply(k);if(!(v&&k&&C&&["[object Number]","[object Function]","[object RegExp]"].indexOf(O)<0)||Sp(g)&&Array.isArray(k))if(v&&Sp(g)&&Array.isArray(f))f=f.join(g),f&&(f=this.extendTranslation(f,e,n,r));else{let t=!1,o=!1;!this.isValidLookup(f)&&b&&(t=!0,f=S),this.isValidLookup(f)||(o=!0,f=s);const a=(n.missingKeyNoValueFallbackToKey||this.options.missingKeyNoValueFallbackToKey)&&o?void 0:f,p=b&&S!==f&&this.options.updateMissing;if(o||t||p){if(this.logger.log(p?"updateKey":"missingKey",u,l,s,p?S:f),i){const e=this.resolve(s,{...n,keySeparator:!1});e&&e.res&&this.logger.warn("Seems the loaded translations were in flat JSON format instead of nested. Either set keySeparator: false on init or make sure your translations are published in nested format.")}let e=[];const t=this.languageUtils.getFallbackCodes(this.options.fallbackLng,n.lng||this.language);if("fallback"===this.options.saveMissingTo&&t&&t[0])for(let r=0;r<t.length;r++)e.push(t[r]);else"all"===this.options.saveMissingTo?e=this.languageUtils.toResolveHierarchy(n.lng||this.language):e.push(n.lng||this.language);const r=(e,t,r)=>{const o=b&&r!==f?r:a;this.options.missingKeyHandler?this.options.missingKeyHandler(e,l,t,o,p,n):this.backendConnector?.saveMissing&&this.backendConnector.saveMissing(e,l,t,o,p,n),this.emit("missingKey",e,l,t,f)};this.options.saveMissing&&(this.options.saveMissingPlurals&&y?e.forEach(e=>{const t=this.pluralResolver.getSuffixes(e,n);_&&n[`defaultValue${this.options.pluralSeparator}zero`]&&t.indexOf(`${this.options.pluralSeparator}zero`)<0&&t.push(`${this.options.pluralSeparator}zero`),t.forEach(t=>{r([e],s+t,n[`defaultValue${t}`]||S)})}):r(e,s,S))}f=this.extendTranslation(f,e,n,d,r),o&&f===s&&this.options.appendNamespaceToMissingKey&&(f=`${l}${c}${s}`),(o||t)&&this.options.parseMissingKeyHandler&&(f=this.options.parseMissingKeyHandler(this.options.appendNamespaceToMissingKey?`${l}${c}${s}`:s,t?f:void 0,n))}else{if(!n.returnObjects&&!this.options.returnObjects){this.options.returnedObjectHandler||this.logger.warn("accessing an object - but returnObjects options is not enabled!");const e=this.options.returnedObjectHandler?this.options.returnedObjectHandler(h,k,{...n,ns:a}):`key '${s} (${this.language})' returned an object instead of string.`;return o?(d.res=e,d.usedParams=this.getUsedParamsDetails(n),d):e}if(i){const e=Array.isArray(k),t=e?[]:{},r=e?m:h;for(const e in k)if(Object.prototype.hasOwnProperty.call(k,e)){const o=`${r}${i}${e}`;t[e]=b&&!f?this.translate(o,{...n,defaultValue:Yp(S)?S[e]:void 0,joinArrays:!1,ns:a}):this.translate(o,{...n,joinArrays:!1,ns:a}),t[e]===o&&(t[e]=k[e])}f=t}}return o?(d.res=f,d.usedParams=this.getUsedParamsDetails(n),d):f}extendTranslation(e,t,r,n,o){if(this.i18nFormat?.parse)e=this.i18nFormat.parse(e,{...this.options.interpolation.defaultVariables,...r},r.lng||this.language||n.usedLng,n.usedNS,n.usedKey,{resolved:n});else if(!r.skipInterpolation){r.interpolation&&this.interpolator.init({...r,interpolation:{...this.options.interpolation,...r.interpolation}});const i=Sp(e)&&(void 0!==r?.interpolation?.skipOnVariables?r.interpolation.skipOnVariables:this.options.interpolation.skipOnVariables);let s;if(i){const t=e.match(this.interpolator.nestingRegexp);s=t&&t.length}let a=r.replace&&!Sp(r.replace)?r.replace:r;if(this.options.interpolation.defaultVariables&&(a={...this.options.interpolation.defaultVariables,...a}),e=this.interpolator.interpolate(e,a,r.lng||this.language||n.usedLng,r),i){const t=e.match(this.interpolator.nestingRegexp);s<(t&&t.length)&&(r.nest=!1)}!r.lng&&n&&n.res&&(r.lng=this.language||n.usedLng),!1!==r.nest&&(e=this.interpolator.nest(e,(...e)=>o?.[0]!==e[0]||r.context?this.translate(...e,t):(this.logger.warn(`It seems you are nesting recursively key: ${e[0]} in key: ${t[0]}`),null),r)),r.interpolation&&this.interpolator.reset()}const i=r.postProcess||this.options.postProcess,s=Sp(i)?[i]:i;return null!=e&&s?.length&&!1!==r.applyPostProcessor&&(e=Wp.handle(s,e,t,this.options&&this.options.postProcessPassResolved?{i18nResolved:{...n,usedParams:this.getUsedParamsDetails(r)},...r}:r,this)),e}resolve(e,t={}){let r,n,o,i,s;return Sp(e)&&(e=[e]),e.forEach(e=>{if(this.isValidLookup(r))return;const a=this.extractFromKey(e,t),l=a.key;n=l;let c=a.namespaces;this.options.fallbackNS&&(c=c.concat(this.options.fallbackNS));const u=void 0!==t.count&&!Sp(t.count),p=u&&!t.ordinal&&0===t.count,d=void 0!==t.context&&(Sp(t.context)||"number"==typeof t.context)&&""!==t.context,f=t.lngs?t.lngs:this.languageUtils.toResolveHierarchy(t.lng||this.language,t.fallbackLng);c.forEach(e=>{this.isValidLookup(r)||(s=e,Kp[`${f[0]}-${e}`]||!this.utils?.hasLoadedNamespace||this.utils?.hasLoadedNamespace(s)||(Kp[`${f[0]}-${e}`]=!0,this.logger.warn(`key "${n}" for languages "${f.join(", ")}" won't get resolved as namespace "${s}" was not yet loaded`,"This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!")),f.forEach(n=>{if(this.isValidLookup(r))return;i=n;const s=[l];if(this.i18nFormat?.addLookupKeys)this.i18nFormat.addLookupKeys(s,l,n,e,t);else{let e;u&&(e=this.pluralResolver.getSuffix(n,t.count,t));const r=`${this.options.pluralSeparator}zero`,o=`${this.options.pluralSeparator}ordinal${this.options.pluralSeparator}`;if(u&&(t.ordinal&&0===e.indexOf(o)&&s.push(l+e.replace(o,this.options.pluralSeparator)),s.push(l+e),p&&s.push(l+r)),d){const n=`${l}${this.options.contextSeparator||"_"}${t.context}`;s.push(n),u&&(t.ordinal&&0===e.indexOf(o)&&s.push(n+e.replace(o,this.options.pluralSeparator)),s.push(n+e),p&&s.push(n+r))}}let a;for(;a=s.pop();)this.isValidLookup(r)||(o=a,r=this.getResource(n,e,a,t))}))})}),{res:r,usedKey:n,exactUsedKey:o,usedLng:i,usedNS:s}}isValidLookup(e){return!(void 0===e||!this.options.returnNull&&null===e||!this.options.returnEmptyString&&""===e)}getResource(e,t,r,n={}){return this.i18nFormat?.getResource?this.i18nFormat.getResource(e,t,r,n):this.resourceStore.getResource(e,t,r,n)}getUsedParamsDetails(e={}){const t=["defaultValue","ordinal","context","replace","lng","lngs","fallbackLng","ns","keySeparator","nsSeparator","returnObjects","returnDetails","joinArrays","postProcess","interpolation"],r=e.replace&&!Sp(e.replace);let n=r?e.replace:e;if(r&&void 0!==e.count&&(n.count=e.count),this.options.interpolation.defaultVariables&&(n={...this.options.interpolation.defaultVariables,...n}),!r){n={...n};for(const e of t)delete n[e]}return n}static hasDefaultValue(e){for(const t in e)if(Object.prototype.hasOwnProperty.call(e,t)&&"defaultValue"===t.substring(0,12)&&void 0!==e[t])return!0;return!1}constructor(e,t={}){var r,n;super(),r=e,n=this,["resourceStore","languageUtils","pluralResolver","interpolator","backendConnector","i18nFormat","utils"].forEach(e=>{r[e]&&(n[e]=r[e])}),this.options=t,void 0===this.options.keySeparator&&(this.options.keySeparator="."),this.logger=Vp.create("translator")}}class Xp{getScriptPartFromCode(e){if(!(e=$p(e))||e.indexOf("-")<0)return null;const t=e.split("-");return 2===t.length?null:(t.pop(),"x"===t[t.length-1].toLowerCase()?null:this.formatLanguageCode(t.join("-")))}getLanguagePartFromCode(e){if(!(e=$p(e))||e.indexOf("-")<0)return e;const t=e.split("-");return this.formatLanguageCode(t[0])}formatLanguageCode(e){if(Sp(e)&&e.indexOf("-")>-1){let t;try{t=Intl.getCanonicalLocales(e)[0]}catch(e){}return t&&this.options.lowerCaseLng&&(t=t.toLowerCase()),t||(this.options.lowerCaseLng?e.toLowerCase():e)}return this.options.cleanCode||this.options.lowerCaseLng?e.toLowerCase():e}isSupportedCode(e){return("languageOnly"===this.options.load||this.options.nonExplicitSupportedLngs)&&(e=this.getLanguagePartFromCode(e)),!this.supportedLngs||!this.supportedLngs.length||this.supportedLngs.indexOf(e)>-1}getBestMatchFromCodes(e){if(!e)return null;let t;return e.forEach(e=>{if(t)return;const r=this.formatLanguageCode(e);this.options.supportedLngs&&!this.isSupportedCode(r)||(t=r)}),!t&&this.options.supportedLngs&&e.forEach(e=>{if(t)return;const r=this.getScriptPartFromCode(e);if(this.isSupportedCode(r))return t=r;const n=this.getLanguagePartFromCode(e);if(this.isSupportedCode(n))return t=n;t=this.options.supportedLngs.find(e=>e===n?e:e.indexOf("-")<0&&n.indexOf("-")<0?void 0:e.indexOf("-")>0&&n.indexOf("-")<0&&e.substring(0,e.indexOf("-"))===n||0===e.indexOf(n)&&n.length>1?e:void 0)}),t||(t=this.getFallbackCodes(this.options.fallbackLng)[0]),t}getFallbackCodes(e,t){if(!e)return[];if("function"==typeof e&&(e=e(t)),Sp(e)&&(e=[e]),Array.isArray(e))return e;if(!t)return e.default||[];let r=e[t];return r||(r=e[this.getScriptPartFromCode(t)]),r||(r=e[this.formatLanguageCode(t)]),r||(r=e[this.getLanguagePartFromCode(t)]),r||(r=e.default),r||[]}toResolveHierarchy(e,t){const r=this.getFallbackCodes((!1===t?[]:t)||this.options.fallbackLng||[],e),n=[],o=e=>{e&&(this.isSupportedCode(e)?n.push(e):this.logger.warn(`rejecting language code not found in supportedLngs: ${e}`))};return Sp(e)&&(e.indexOf("-")>-1||e.indexOf("_")>-1)?("languageOnly"!==this.options.load&&o(this.formatLanguageCode(e)),"languageOnly"!==this.options.load&&"currentOnly"!==this.options.load&&o(this.getScriptPartFromCode(e)),"currentOnly"!==this.options.load&&o(this.getLanguagePartFromCode(e))):Sp(e)&&o(this.formatLanguageCode(e)),r.forEach(e=>{n.indexOf(e)<0&&o(this.formatLanguageCode(e))}),n}constructor(e){this.options=e,this.supportedLngs=this.options.supportedLngs||!1,this.logger=Vp.create("languageUtils")}}const Jp={zero:0,one:1,two:2,few:3,many:4,other:5},Qp={select:e=>1===e?"one":"other",resolvedOptions:()=>({pluralCategories:["one","other"]})};class ed{clearCache(){this.pluralRulesCache={}}getRule(e,t={}){const r=$p("dev"===e?"en":e),n=t.ordinal?"ordinal":"cardinal",o=JSON.stringify({cleanedCode:r,type:n});if(o in this.pluralRulesCache)return this.pluralRulesCache[o];let i;try{i=new Intl.PluralRules(r,{type:n})}catch(r){if("undefined"==typeof Intl)return this.logger.error("No Intl support, please use an Intl polyfill!"),Qp;if(!e.match(/-|_/))return Qp;const n=this.languageUtils.getLanguagePartFromCode(e);i=this.getRule(n,t)}return this.pluralRulesCache[o]=i,i}needsPlural(e,t={}){let r=this.getRule(e,t);return r||(r=this.getRule("dev",t)),r?.resolvedOptions().pluralCategories.length>1}getPluralFormsOfKey(e,t,r={}){return this.getSuffixes(e,r).map(e=>`${t}${e}`)}getSuffixes(e,t={}){let r=this.getRule(e,t);return r||(r=this.getRule("dev",t)),r?r.resolvedOptions().pluralCategories.sort((e,t)=>Jp[e]-Jp[t]).map(e=>`${this.options.prepend}${t.ordinal?`ordinal${this.options.prepend}`:""}${e}`):[]}getSuffix(e,t,r={}){const n=this.getRule(e,r);return n?`${this.options.prepend}${r.ordinal?`ordinal${this.options.prepend}`:""}${n.select(t)}`:(this.logger.warn(`no plural rule found for: ${e}`),this.getSuffix("dev",t,r))}constructor(e,t={}){this.languageUtils=e,this.options=t,this.logger=Vp.create("pluralResolver"),this.pluralRulesCache={}}}const td=(e,t,r,n=".",o=!0)=>{let i=((e,t,r)=>{const n=Mp(e,r);return void 0!==n?n:Mp(t,r)})(e,t,r);return!i&&o&&Sp(r)&&(i=Fp(e,r,n),void 0===i&&(i=Fp(t,r,n))),i},rd=e=>e.replace(/\$/g,"$$$$");class nd{init(e={}){e.interpolation||(e.interpolation={escapeValue:!0});const{escape:t,escapeValue:r,useRawValueToEscape:n,prefix:o,prefixEscaped:i,suffix:s,suffixEscaped:a,formatSeparator:l,unescapeSuffix:c,unescapePrefix:u,nestingPrefix:p,nestingPrefixEscaped:d,nestingSuffix:f,nestingSuffixEscaped:h,nestingOptionsSeparator:m,maxReplaces:g,alwaysFormat:v}=e.interpolation;this.escape=void 0!==t?t:jp,this.escapeValue=void 0===r||r,this.useRawValueToEscape=void 0!==n&&n,this.prefix=o?Pp(o):i||"{{",this.suffix=s?Pp(s):a||"}}",this.formatSeparator=l||",",this.unescapePrefix=c?"":u||"-",this.unescapeSuffix=this.unescapePrefix?"":c||"",this.nestingPrefix=p?Pp(p):d||Pp("$t("),this.nestingSuffix=f?Pp(f):h||Pp(")"),this.nestingOptionsSeparator=m||",",this.maxReplaces=g||1e3,this.alwaysFormat=void 0!==v&&v,this.resetRegExp()}reset(){this.options&&this.init(this.options)}resetRegExp(){const e=(e,t)=>e?.source===t?(e.lastIndex=0,e):new RegExp(t,"g");this.regexp=e(this.regexp,`${this.prefix}(.+?)${this.suffix}`),this.regexpUnescape=e(this.regexpUnescape,`${this.prefix}${this.unescapePrefix}(.+?)${this.unescapeSuffix}${this.suffix}`),this.nestingRegexp=e(this.nestingRegexp,`${this.nestingPrefix}((?:[^()"']+|"[^"]*"|'[^']*'|\\((?:[^()]|"[^"]*"|'[^']*')*\\))*?)${this.nestingSuffix}`)}interpolate(e,t,r,n){let o,i,s;const a=this.options&&this.options.interpolation&&this.options.interpolation.defaultVariables||{},l=e=>{if(e.indexOf(this.formatSeparator)<0){const o=td(t,a,e,this.options.keySeparator,this.options.ignoreJSONStructure);return this.alwaysFormat?this.format(o,void 0,r,{...n,...t,interpolationkey:e}):o}const o=e.split(this.formatSeparator),i=o.shift().trim(),s=o.join(this.formatSeparator).trim();return this.format(td(t,a,i,this.options.keySeparator,this.options.ignoreJSONStructure),s,r,{...n,...t,interpolationkey:i})};this.resetRegExp();const c=n?.missingInterpolationHandler||this.options.missingInterpolationHandler,u=void 0!==n?.interpolation?.skipOnVariables?n.interpolation.skipOnVariables:this.options.interpolation.skipOnVariables;return[{regex:this.regexpUnescape,safeValue:e=>rd(e)},{regex:this.regexp,safeValue:e=>this.escapeValue?rd(this.escape(e)):rd(e)}].forEach(t=>{for(s=0;o=t.regex.exec(e);){const r=o[1].trim();if(i=l(r),void 0===i)if("function"==typeof c){const t=c(e,o,n);i=Sp(t)?t:""}else if(n&&Object.prototype.hasOwnProperty.call(n,r))i="";else{if(u){i=o[0];continue}this.logger.warn(`missed to pass in variable ${r} for interpolating ${e}`),i=""}else Sp(i)||this.useRawValueToEscape||(i=Cp(i));const a=t.safeValue(i);if(e=e.replace(o[0],a),u?(t.regex.lastIndex+=i.length,t.regex.lastIndex-=o[0].length):t.regex.lastIndex=0,s++,s>=this.maxReplaces)break}}),e}nest(e,t,r={}){let n,o,i;const s=(e,t)=>{const r=this.nestingOptionsSeparator;if(e.indexOf(r)<0)return e;const n=e.split(new RegExp(`${Pp(r)}[ ]*{`));let o=`{${n[1]}`;e=n[0],o=this.interpolate(o,i);const s=o.match(/'/g),a=o.match(/"/g);((s?.length??0)%2==0&&!a||(a?.length??0)%2!=0)&&(o=o.replace(/'/g,'"'));try{i=JSON.parse(o),t&&(i={...t,...i})}catch(t){return this.logger.warn(`failed parsing options string in nesting for key ${e}`,t),`${e}${r}${o}`}return i.defaultValue&&i.defaultValue.indexOf(this.prefix)>-1&&delete i.defaultValue,e};for(;n=this.nestingRegexp.exec(e);){let a=[];i={...r},i=i.replace&&!Sp(i.replace)?i.replace:i,i.applyPostProcessor=!1,delete i.defaultValue;const l=/{.*}/.test(n[1])?n[1].lastIndexOf("}")+1:n[1].indexOf(this.formatSeparator);if(-1!==l&&(a=n[1].slice(l).split(this.formatSeparator).map(e=>e.trim()).filter(Boolean),n[1]=n[1].slice(0,l)),o=t(s.call(this,n[1].trim(),i),i),o&&n[0]===e&&!Sp(o))return o;Sp(o)||(o=Cp(o)),o||(this.logger.warn(`missed to resolve ${n[1]} for nesting ${e}`),o=""),a.length&&(o=a.reduce((e,t)=>this.format(e,t,r.lng,{...r,interpolationkey:n[1].trim()}),o.trim())),e=e.replace(n[0],o),this.regexp.lastIndex=0}return e}constructor(e={}){this.logger=Vp.create("interpolator"),this.options=e,this.format=e?.interpolation?.format||(e=>e),this.init(e)}}const od=e=>{const t={};return(r,n,o)=>{let i=o;o&&o.interpolationkey&&o.formatParams&&o.formatParams[o.interpolationkey]&&o[o.interpolationkey]&&(i={...i,[o.interpolationkey]:void 0});const s=n+JSON.stringify(i);let a=t[s];return a||(a=e($p(n),o),t[s]=a),a(r)}},id=e=>(t,r,n)=>e($p(r),n)(t);class sd{init(e,t={interpolation:{}}){this.formatSeparator=t.interpolation.formatSeparator||",";const r=t.cacheInBuiltFormats?od:id;this.formats={number:r((e,t)=>{const r=new Intl.NumberFormat(e,{...t});return e=>r.format(e)}),currency:r((e,t)=>{const r=new Intl.NumberFormat(e,{...t,style:"currency"});return e=>r.format(e)}),datetime:r((e,t)=>{const r=new Intl.DateTimeFormat(e,{...t});return e=>r.format(e)}),relativetime:r((e,t)=>{const r=new Intl.RelativeTimeFormat(e,{...t});return e=>r.format(e,t.range||"day")}),list:r((e,t)=>{const r=new Intl.ListFormat(e,{...t});return e=>r.format(e)})}}add(e,t){this.formats[e.toLowerCase().trim()]=t}addCached(e,t){this.formats[e.toLowerCase().trim()]=od(t)}format(e,t,r,n={}){const o=t.split(this.formatSeparator);if(o.length>1&&o[0].indexOf("(")>1&&o[0].indexOf(")")<0&&o.find(e=>e.indexOf(")")>-1)){const e=o.findIndex(e=>e.indexOf(")")>-1);o[0]=[o[0],...o.splice(1,e)].join(this.formatSeparator)}return o.reduce((e,t)=>{const{formatName:o,formatOptions:i}=(e=>{let t=e.toLowerCase().trim();const r={};if(e.indexOf("(")>-1){const n=e.split("(");t=n[0].toLowerCase().trim();const o=n[1].substring(0,n[1].length-1);"currency"===t&&o.indexOf(":")<0?r.currency||(r.currency=o.trim()):"relativetime"===t&&o.indexOf(":")<0?r.range||(r.range=o.trim()):o.split(";").forEach(e=>{if(e){const[t,...n]=e.split(":"),o=n.join(":").trim().replace(/^'+|'+$/g,""),i=t.trim();r[i]||(r[i]=o),"false"===o&&(r[i]=!1),"true"===o&&(r[i]=!0),isNaN(o)||(r[i]=parseInt(o,10))}})}return{formatName:t,formatOptions:r}})(t);if(this.formats[o]){let t=e;try{const s=n?.formatParams?.[n.interpolationkey]||{},a=s.locale||s.lng||n.locale||n.lng||r;t=this.formats[o](e,a,{...i,...n,...s})}catch(e){this.logger.warn(e)}return t}return this.logger.warn(`there was no format function for ${o}`),e},e)}constructor(e={}){this.logger=Vp.create("formatter"),this.options=e,this.init(e)}}class ad extends Up{queueLoad(e,t,r,n){const o={},i={},s={},a={};return e.forEach(e=>{let n=!0;t.forEach(t=>{const s=`${e}|${t}`;!r.reload&&this.store.hasResourceBundle(e,t)?this.state[s]=2:this.state[s]<0||(1===this.state[s]?void 0===i[s]&&(i[s]=!0):(this.state[s]=1,n=!1,void 0===i[s]&&(i[s]=!0),void 0===o[s]&&(o[s]=!0),void 0===a[t]&&(a[t]=!0)))}),n||(s[e]=!0)}),(Object.keys(o).length||Object.keys(i).length)&&this.queue.push({pending:i,pendingCount:Object.keys(i).length,loaded:{},errors:[],callback:n}),{toLoad:Object.keys(o),pending:Object.keys(i),toLoadLanguages:Object.keys(s),toLoadNamespaces:Object.keys(a)}}loaded(e,t,r){const n=e.split("|"),o=n[0],i=n[1];t&&this.emit("failedLoading",o,i,t),!t&&r&&this.store.addResourceBundle(o,i,r,void 0,void 0,{skipCopy:!0}),this.state[e]=t?-1:2,t&&r&&(this.state[e]=0);const s={};this.queue.forEach(r=>{((e,t,r)=>{const{obj:n,k:o}=Rp(e,t,Object);n[o]=n[o]||[],n[o].push(r)})(r.loaded,[o],i),((e,t)=>{void 0!==e.pending[t]&&(delete e.pending[t],e.pendingCount--)})(r,e),t&&r.errors.push(t),0!==r.pendingCount||r.done||(Object.keys(r.loaded).forEach(e=>{s[e]||(s[e]={});const t=r.loaded[e];t.length&&t.forEach(t=>{void 0===s[e][t]&&(s[e][t]=!0)})}),r.done=!0,r.errors.length?r.callback(r.errors):r.callback())}),this.emit("loaded",s),this.queue=this.queue.filter(e=>!e.done)}read(e,t,r,n=0,o=this.retryTimeout,i){if(!e.length)return i(null,{});if(this.readingCalls>=this.maxParallelReads)return void this.waitingReads.push({lng:e,ns:t,fcName:r,tried:n,wait:o,callback:i});this.readingCalls++;const s=(s,a)=>{if(this.readingCalls--,this.waitingReads.length>0){const e=this.waitingReads.shift();this.read(e.lng,e.ns,e.fcName,e.tried,e.wait,e.callback)}s&&a&&n<this.maxRetries?setTimeout(()=>{this.read.call(this,e,t,r,n+1,2*o,i)},o):i(s,a)},a=this.backend[r].bind(this.backend);if(2!==a.length)return a(e,t,s);try{const r=a(e,t);r&&"function"==typeof r.then?r.then(e=>s(null,e)).catch(s):s(null,r)}catch(e){s(e)}}prepareLoading(e,t,r={},n){if(!this.backend)return this.logger.warn("No backend was added via i18next.use. Will not load resources."),n&&n();Sp(e)&&(e=this.languageUtils.toResolveHierarchy(e)),Sp(t)&&(t=[t]);const o=this.queueLoad(e,t,r,n);if(!o.toLoad.length)return o.pending.length||n(),null;o.toLoad.forEach(e=>{this.loadOne(e)})}load(e,t,r){this.prepareLoading(e,t,{},r)}reload(e,t,r){this.prepareLoading(e,t,{reload:!0},r)}loadOne(e,t=""){const r=e.split("|"),n=r[0],o=r[1];this.read(n,o,"read",void 0,void 0,(r,i)=>{r&&this.logger.warn(`${t}loading namespace ${o} for language ${n} failed`,r),!r&&i&&this.logger.log(`${t}loaded namespace ${o} for language ${n}`,i),this.loaded(e,r,i)})}saveMissing(e,t,r,n,o,i={},s=()=>{}){if(!this.services?.utils?.hasLoadedNamespace||this.services?.utils?.hasLoadedNamespace(t)){if(null!=r&&""!==r){if(this.backend?.create){const a={...i,isUpdate:o},l=this.backend.create.bind(this.backend);if(l.length<6)try{let o;o=5===l.length?l(e,t,r,n,a):l(e,t,r,n),o&&"function"==typeof o.then?o.then(e=>s(null,e)).catch(s):s(null,o)}catch(e){s(e)}else l(e,t,r,n,s,a)}e&&e[0]&&this.store.addResource(e[0],t,r,n)}}else this.logger.warn(`did not save key "${r}" as the namespace "${t}" was not yet loaded`,"This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!")}constructor(e,t,r,n={}){super(),this.backend=e,this.store=t,this.services=r,this.languageUtils=r.languageUtils,this.options=n,this.logger=Vp.create("backendConnector"),this.waitingReads=[],this.maxParallelReads=n.maxParallelReads||10,this.readingCalls=0,this.maxRetries=n.maxRetries>=0?n.maxRetries:5,this.retryTimeout=n.retryTimeout>=1?n.retryTimeout:350,this.state={},this.queue=[],this.backend?.init?.(r,n.backend,n)}}const ld=()=>({debug:!1,initAsync:!0,ns:["translation"],defaultNS:["translation"],fallbackLng:["dev"],fallbackNS:!1,supportedLngs:!1,nonExplicitSupportedLngs:!1,load:"all",preload:!1,simplifyPluralSuffix:!0,keySeparator:".",nsSeparator:":",pluralSeparator:"_",contextSeparator:"_",partialBundledLanguages:!1,saveMissing:!1,updateMissing:!1,saveMissingTo:"fallback",saveMissingPlurals:!0,missingKeyHandler:!1,missingInterpolationHandler:!1,postProcess:!1,postProcessPassResolved:!1,returnNull:!1,returnEmptyString:!0,returnObjects:!1,joinArrays:!1,returnedObjectHandler:!1,parseMissingKeyHandler:!1,appendNamespaceToMissingKey:!1,appendNamespaceToCIMode:!1,overloadTranslationOptionHandler:e=>{let t={};if("object"==typeof e[1]&&(t=e[1]),Sp(e[1])&&(t.defaultValue=e[1]),Sp(e[2])&&(t.tDescription=e[2]),"object"==typeof e[2]||"object"==typeof e[3]){const r=e[3]||e[2];Object.keys(r).forEach(e=>{t[e]=r[e]})}return t},interpolation:{escapeValue:!0,format:e=>e,prefix:"{{",suffix:"}}",formatSeparator:",",unescapePrefix:"-",nestingPrefix:"$t(",nestingSuffix:")",nestingOptionsSeparator:",",maxReplaces:1e3,skipOnVariables:!0},cacheInBuiltFormats:!0}),cd=e=>(Sp(e.ns)&&(e.ns=[e.ns]),Sp(e.fallbackLng)&&(e.fallbackLng=[e.fallbackLng]),Sp(e.fallbackNS)&&(e.fallbackNS=[e.fallbackNS]),e.supportedLngs?.indexOf?.("cimode")<0&&(e.supportedLngs=e.supportedLngs.concat(["cimode"])),"boolean"==typeof e.initImmediate&&(e.initAsync=e.initImmediate),e),ud=()=>{},pd="__i18next_supportNoticeShown";class dd extends Up{init(e={},t){this.isInitializing=!0,"function"==typeof e&&(t=e,e={}),null==e.defaultNS&&e.ns&&(Sp(e.ns)?e.defaultNS=e.ns:e.ns.indexOf("translation")<0&&(e.defaultNS=e.ns[0]));const r=ld();var n;this.options={...r,...this.options,...cd(e)},this.options.interpolation={...r.interpolation,...this.options.interpolation},void 0!==e.keySeparator&&(this.options.userDefinedKeySeparator=e.keySeparator),void 0!==e.nsSeparator&&(this.options.userDefinedNsSeparator=e.nsSeparator),"function"!=typeof this.options.overloadTranslationOptionHandler&&(this.options.overloadTranslationOptionHandler=r.overloadTranslationOptionHandler),!1===this.options.showSupportNotice||(n=this,n?.modules?.backend?.name?.indexOf("Locize")>0||n?.modules?.backend?.constructor?.name?.indexOf("Locize")>0||n?.options?.backend?.backends&&n.options.backend.backends.some(e=>e?.name?.indexOf("Locize")>0||e?.constructor?.name?.indexOf("Locize")>0)||n?.options?.backend?.projectId||n?.options?.backend?.backendOptions&&n.options.backend.backendOptions.some(e=>e?.projectId))||"undefined"!=typeof globalThis&&globalThis[pd]||("undefined"!=typeof console&&void 0!==console.info&&console.info("🌐 i18next is maintained with support from Locize — consider powering your project with managed localization (AI, CDN, integrations): https://locize.com 💙"),"undefined"!=typeof globalThis&&(globalThis[pd]=!0));const o=e=>e?"function"==typeof e?new e:e:null;if(!this.options.isClone){let e;this.modules.logger?Vp.init(o(this.modules.logger),this.options):Vp.init(null,this.options),e=this.modules.formatter?this.modules.formatter:sd;const t=new Xp(this.options);this.store=new qp(this.options.resources,this.options);const n=this.services;n.logger=Vp,n.resourceStore=this.store,n.languageUtils=t,n.pluralResolver=new ed(t,{prepend:this.options.pluralSeparator,simplifyPluralSuffix:this.options.simplifyPluralSuffix}),this.options.interpolation.format&&this.options.interpolation.format!==r.interpolation.format&&this.logger.deprecate("init: you are still using the legacy format function, please use the new approach: https://www.i18next.com/translation-function/formatting"),!e||this.options.interpolation.format&&this.options.interpolation.format!==r.interpolation.format||(n.formatter=o(e),n.formatter.init&&n.formatter.init(n,this.options),this.options.interpolation.format=n.formatter.format.bind(n.formatter)),n.interpolator=new nd(this.options),n.utils={hasLoadedNamespace:this.hasLoadedNamespace.bind(this)},n.backendConnector=new ad(o(this.modules.backend),n.resourceStore,n,this.options),n.backendConnector.on("*",(e,...t)=>{this.emit(e,...t)}),this.modules.languageDetector&&(n.languageDetector=o(this.modules.languageDetector),n.languageDetector.init&&n.languageDetector.init(n,this.options.detection,this.options)),this.modules.i18nFormat&&(n.i18nFormat=o(this.modules.i18nFormat),n.i18nFormat.init&&n.i18nFormat.init(this)),this.translator=new Zp(this.services,this.options),this.translator.on("*",(e,...t)=>{this.emit(e,...t)}),this.modules.external.forEach(e=>{e.init&&e.init(this)})}if(this.format=this.options.interpolation.format,t||(t=ud),this.options.fallbackLng&&!this.services.languageDetector&&!this.options.lng){const e=this.services.languageUtils.getFallbackCodes(this.options.fallbackLng);e.length>0&&"dev"!==e[0]&&(this.options.lng=e[0])}this.services.languageDetector||this.options.lng||this.logger.warn("init: no languageDetector is used and no lng is defined"),["getResource","hasResourceBundle","getResourceBundle","getDataByLanguage"].forEach(e=>{this[e]=(...t)=>this.store[e](...t)}),["addResource","addResources","addResourceBundle","removeResourceBundle"].forEach(e=>{this[e]=(...t)=>(this.store[e](...t),this)});const i=kp(),s=()=>{const e=(e,r)=>{this.isInitializing=!1,this.isInitialized&&!this.initializedStoreOnce&&this.logger.warn("init: i18next is already initialized. You should call init just once!"),this.isInitialized=!0,this.options.isClone||this.logger.log("initialized",this.options),this.emit("initialized",this.options),i.resolve(r),t(e,r)};if(this.languages&&!this.isInitialized)return e(null,this.t.bind(this));this.changeLanguage(this.options.lng,e)};return this.options.resources||!this.options.initAsync?s():setTimeout(s,0),i}loadResources(e,t=ud){let r=t;const n=Sp(e)?e:this.language;if("function"==typeof e&&(r=e),!this.options.resources||this.options.partialBundledLanguages){if("cimode"===n?.toLowerCase()&&(!this.options.preload||0===this.options.preload.length))return r();const e=[],t=t=>{t&&"cimode"!==t&&this.services.languageUtils.toResolveHierarchy(t).forEach(t=>{"cimode"!==t&&e.indexOf(t)<0&&e.push(t)})};n?t(n):this.services.languageUtils.getFallbackCodes(this.options.fallbackLng).forEach(e=>t(e)),this.options.preload?.forEach?.(e=>t(e)),this.services.backendConnector.load(e,this.options.ns,e=>{e||this.resolvedLanguage||!this.language||this.setResolvedLanguage(this.language),r(e)})}else r(null)}reloadResources(e,t,r){const n=kp();return"function"==typeof e&&(r=e,e=void 0),"function"==typeof t&&(r=t,t=void 0),e||(e=this.languages),t||(t=this.options.ns),r||(r=ud),this.services.backendConnector.reload(e,t,e=>{n.resolve(),r(e)}),n}use(e){if(!e)throw new Error("You are passing an undefined module! Please check the object you are passing to i18next.use()");if(!e.type)throw new Error("You are passing a wrong module! Please check the object you are passing to i18next.use()");return"backend"===e.type&&(this.modules.backend=e),("logger"===e.type||e.log&&e.warn&&e.error)&&(this.modules.logger=e),"languageDetector"===e.type&&(this.modules.languageDetector=e),"i18nFormat"===e.type&&(this.modules.i18nFormat=e),"postProcessor"===e.type&&Wp.addPostProcessor(e),"formatter"===e.type&&(this.modules.formatter=e),"3rdParty"===e.type&&this.modules.external.push(e),this}setResolvedLanguage(e){if(e&&this.languages&&!(["cimode","dev"].indexOf(e)>-1)){for(let e=0;e<this.languages.length;e++){const t=this.languages[e];if(!(["cimode","dev"].indexOf(t)>-1)&&this.store.hasLanguageSomeTranslations(t)){this.resolvedLanguage=t;break}}!this.resolvedLanguage&&this.languages.indexOf(e)<0&&this.store.hasLanguageSomeTranslations(e)&&(this.resolvedLanguage=e,this.languages.unshift(e))}}changeLanguage(e,t){this.isLanguageChangingTo=e;const r=kp();this.emit("languageChanging",e);const n=e=>{this.language=e,this.languages=this.services.languageUtils.toResolveHierarchy(e),this.resolvedLanguage=void 0,this.setResolvedLanguage(e)},o=(o,i)=>{i?this.isLanguageChangingTo===e&&(n(i),this.translator.changeLanguage(i),this.isLanguageChangingTo=void 0,this.emit("languageChanged",i),this.logger.log("languageChanged",i)):this.isLanguageChangingTo=void 0,r.resolve((...e)=>this.t(...e)),t&&t(o,(...e)=>this.t(...e))},i=t=>{e||t||!this.services.languageDetector||(t=[]);const r=Sp(t)?t:t&&t[0],i=this.store.hasLanguageSomeTranslations(r)?r:this.services.languageUtils.getBestMatchFromCodes(Sp(t)?[t]:t);i&&(this.language||n(i),this.translator.language||this.translator.changeLanguage(i),this.services.languageDetector?.cacheUserLanguage?.(i)),this.loadResources(i,e=>{o(e,i)})};return e||!this.services.languageDetector||this.services.languageDetector.async?!e&&this.services.languageDetector&&this.services.languageDetector.async?0===this.services.languageDetector.detect.length?this.services.languageDetector.detect().then(i):this.services.languageDetector.detect(i):i(e):i(this.services.languageDetector.detect()),r}getFixedT(e,t,r){const n=(e,t,...o)=>{let i;i="object"!=typeof t?this.options.overloadTranslationOptionHandler([e,t].concat(o)):{...t},i.lng=i.lng||n.lng,i.lngs=i.lngs||n.lngs,i.ns=i.ns||n.ns,""!==i.keyPrefix&&(i.keyPrefix=i.keyPrefix||r||n.keyPrefix);const s=this.options.keySeparator||".";let a;return i.keyPrefix&&Array.isArray(e)?a=e.map(e=>("function"==typeof e&&(e=Gp(e,{...this.options,...t})),`${i.keyPrefix}${s}${e}`)):("function"==typeof e&&(e=Gp(e,{...this.options,...t})),a=i.keyPrefix?`${i.keyPrefix}${s}${e}`:e),this.t(a,i)};return Sp(e)?n.lng=e:n.lngs=e,n.ns=t,n.keyPrefix=r,n}t(...e){return this.translator?.translate(...e)}exists(...e){return this.translator?.exists(...e)}setDefaultNamespace(e){this.options.defaultNS=e}hasLoadedNamespace(e,t={}){if(!this.isInitialized)return this.logger.warn("hasLoadedNamespace: i18next was not initialized",this.languages),!1;if(!this.languages||!this.languages.length)return this.logger.warn("hasLoadedNamespace: i18n.languages were undefined or empty",this.languages),!1;const r=t.lng||this.resolvedLanguage||this.languages[0],n=!!this.options&&this.options.fallbackLng,o=this.languages[this.languages.length-1];if("cimode"===r.toLowerCase())return!0;const i=(e,t)=>{const r=this.services.backendConnector.state[`${e}|${t}`];return-1===r||0===r||2===r};if(t.precheck){const e=t.precheck(this,i);if(void 0!==e)return e}return!(!this.hasResourceBundle(r,e)&&this.services.backendConnector.backend&&(!this.options.resources||this.options.partialBundledLanguages)&&(!i(r,e)||n&&!i(o,e)))}loadNamespaces(e,t){const r=kp();return this.options.ns?(Sp(e)&&(e=[e]),e.forEach(e=>{this.options.ns.indexOf(e)<0&&this.options.ns.push(e)}),this.loadResources(e=>{r.resolve(),t&&t(e)}),r):(t&&t(),Promise.resolve())}loadLanguages(e,t){const r=kp();Sp(e)&&(e=[e]);const n=this.options.preload||[],o=e.filter(e=>n.indexOf(e)<0&&this.services.languageUtils.isSupportedCode(e));return o.length?(this.options.preload=n.concat(o),this.loadResources(e=>{r.resolve(),t&&t(e)}),r):(t&&t(),Promise.resolve())}dir(e){if(e||(e=this.resolvedLanguage||(this.languages?.length>0?this.languages[0]:this.language)),!e)return"rtl";try{const t=new Intl.Locale(e);if(t&&t.getTextInfo){const e=t.getTextInfo();if(e&&e.direction)return e.direction}}catch(e){}const t=this.services?.languageUtils||new Xp(ld());return e.toLowerCase().indexOf("-latn")>1?"ltr":["ar","shu","sqr","ssh","xaa","yhd","yud","aao","abh","abv","acm","acq","acw","acx","acy","adf","ads","aeb","aec","afb","ajp","apc","apd","arb","arq","ars","ary","arz","auz","avl","ayh","ayl","ayn","ayp","bbz","pga","he","iw","ps","pbt","pbu","pst","prp","prd","ug","ur","ydd","yds","yih","ji","yi","hbo","men","xmn","fa","jpr","peo","pes","prs","dv","sam","ckb"].indexOf(t.getLanguagePartFromCode(e))>-1||e.toLowerCase().indexOf("-arab")>1?"rtl":"ltr"}static createInstance(e={},t){const r=new dd(e,t);return r.createInstance=dd.createInstance,r}cloneInstance(e={},t=ud){const r=e.forkResourceStore;r&&delete e.forkResourceStore;const n={...this.options,...e,isClone:!0},o=new dd(n);if(void 0===e.debug&&void 0===e.prefix||(o.logger=o.logger.clone(e)),["store","services","language"].forEach(e=>{o[e]=this[e]}),o.services={...this.services},o.services.utils={hasLoadedNamespace:o.hasLoadedNamespace.bind(o)},r){const e=Object.keys(this.store.data).reduce((e,t)=>(e[t]={...this.store.data[t]},e[t]=Object.keys(e[t]).reduce((r,n)=>(r[n]={...e[t][n]},r),e[t]),e),{});o.store=new qp(e,n),o.services.resourceStore=o.store}if(e.interpolation){const t={...ld().interpolation,...this.options.interpolation,...e.interpolation},r={...n,interpolation:t};o.services.interpolator=new nd(r)}return o.translator=new Zp(o.services,n),o.translator.on("*",(e,...t)=>{o.emit(e,...t)}),o.init(n,t),o.translator.options=n,o.translator.backendConnector.services.utils={hasLoadedNamespace:o.hasLoadedNamespace.bind(o)},o}toJSON(){return{options:this.options,store:this.store,language:this.language,languages:this.languages,resolvedLanguage:this.resolvedLanguage}}constructor(e={},t){var r;if(super(),this.options=cd(e),this.services={},this.logger=Vp,this.modules={external:[]},r=this,Object.getOwnPropertyNames(Object.getPrototypeOf(r)).forEach(e=>{"function"==typeof r[e]&&(r[e]=r[e].bind(r))}),t&&!this.isInitialized&&!e.isClone){if(!this.options.initAsync)return this.init(e,t),this;setTimeout(()=>{this.init(e,t)},0)}}}const fd=dd.createInstance(),hd={},md=(e,t,r,n)=>{bd(r)&&hd[r]||(bd(r)&&(hd[r]=new Date),((e,t,r,n)=>{const o=[r,{code:t,...n||{}}];if(e?.services?.logger?.forward)return e.services.logger.forward(o,"warn","react-i18next::",!0);bd(o[0])&&(o[0]=`react-i18next:: ${o[0]}`),e?.services?.logger?.warn?e.services.logger.warn(...o):console?.warn&&console.warn(...o)})(e,t,r,n))},gd=(e,t)=>()=>{if(e.isInitialized)t();else{const r=()=>{setTimeout(()=>{e.off("initialized",r)},0),t()};e.on("initialized",r)}},vd=(e,t,r)=>{e.loadNamespaces(t,gd(e,r))},yd=(e,t,r,n)=>{if(bd(r)&&(r=[r]),e.options.preload&&e.options.preload.indexOf(t)>-1)return vd(e,r,n);r.forEach(t=>{e.options.ns.indexOf(t)<0&&e.options.ns.push(t)}),e.loadLanguages(t,gd(e,n))},bd=e=>"string"==typeof e,wd=/&(?:amp|#38|lt|#60|gt|#62|apos|#39|quot|#34|nbsp|#160|copy|#169|reg|#174|hellip|#8230|#x2F|#47);/g,xd={"&amp;":"&","&#38;":"&","&lt;":"<","&#60;":"<","&gt;":">","&#62;":">","&apos;":"'","&#39;":"'","&quot;":'"',"&#34;":'"',"&nbsp;":" ","&#160;":" ","&copy;":"©","&#169;":"©","&reg;":"®","&#174;":"®","&hellip;":"…","&#8230;":"…","&#x2F;":"/","&#47;":"/"},_d=e=>xd[e];let Sd,kd={bindI18n:"languageChanged",bindI18nStore:"",transEmptyNodeValue:"",transSupportBasicHtmlNodes:!0,transWrapTextNodes:"",transKeepBasicHtmlNodesFor:["br","strong","i","p"],useSuspense:!0,unescape:e=>e.replace(wd,_d),transDefaultProps:void 0};const Cd={type:"3rdParty",init(e){((e={})=>{kd={...kd,...e}})(e.options.react),(e=>{Sd=e})(e)}},Od=t.createContext();class Ed{addUsedNamespaces(e){e.forEach(e=>{this.usedNamespaces[e]||(this.usedNamespaces[e]=!0)})}getUsedNamespaces(){return Object.keys(this.usedNamespaces)}constructor(){this.usedNamespaces={}}}var Td,Rd={exports:{}},Id={};function Md(){if(Td)return Id;Td=1;var e=t,r="function"==typeof Object.is?Object.is:function(e,t){return e===t&&(0!==e||1/e==1/t)||e!=e&&t!=t},n=e.useState,o=e.useEffect,i=e.useLayoutEffect,s=e.useDebugValue;function a(e){var t=e.getSnapshot;e=e.value;try{var n=t();return!r(e,n)}catch(e){return!0}}var l="undefined"==typeof window||void 0===window.document||void 0===window.document.createElement?function(e,t){return t()}:function(e,t){var r=t(),l=n({inst:{value:r,getSnapshot:t}}),c=l[0].inst,u=l[1];return i(function(){c.value=r,c.getSnapshot=t,a(c)&&u({inst:c})},[e,r,t]),o(function(){return a(c)&&u({inst:c}),e(function(){a(c)&&u({inst:c})})},[e]),s(r),r};return Id.useSyncExternalStore=void 0!==e.useSyncExternalStore?e.useSyncExternalStore:l,Id}var Ad,Pd,Nd={};function jd(){return Ad||(Ad=1, true&&function(){function e(e){var t=e.getSnapshot;e=e.value;try{var r=t();return!n(e,r)}catch(e){return!0}}"undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStart&&__REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStart(Error());var r=t,n="function"==typeof Object.is?Object.is:function(e,t){return e===t&&(0!==e||1/e==1/t)||e!=e&&t!=t},o=r.useState,i=r.useEffect,s=r.useLayoutEffect,a=r.useDebugValue,l=!1,c=!1,u="undefined"==typeof window||void 0===window.document||void 0===window.document.createElement?function(e,t){return t()}:function(t,u){l||void 0===r.startTransition||(l=!0,console.error("You are using an outdated, pre-release alpha of React 18 that does not support useSyncExternalStore. The use-sync-external-store shim will not work correctly. Upgrade to a newer pre-release."));var p=u();if(!c){var d=u();n(p,d)||(console.error("The result of getSnapshot should be cached to avoid an infinite loop"),c=!0)}var f=(d=o({inst:{value:p,getSnapshot:u}}))[0].inst,h=d[1];return s(function(){f.value=p,f.getSnapshot=u,e(f)&&h({inst:f})},[t,p,u]),i(function(){return e(f)&&h({inst:f}),t(function(){e(f)&&h({inst:f})})},[t]),a(p),p};Nd.useSyncExternalStore=void 0!==r.useSyncExternalStore?r.useSyncExternalStore:u,"undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStop&&__REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStop(Error())}()),Nd}function Ld(){return Pd||(Pd=1, false?0:Rd.exports=jd()),Rd.exports}var Dd=Ld();const Fd={t:(e,t)=>{return bd(t)?t:"object"==typeof(r=t)&&null!==r&&bd(t.defaultValue)?t.defaultValue:Array.isArray(e)?e[e.length-1]:e;// removed by dead control flow
 var r; },ready:!1},$d=()=>()=>{},Bd=(e,r={})=>{const{i18n:n}=r,{i18n:o,defaultNS:i}=t.useContext(Od)||{},s=n||o||Sd;s&&!s.reportNamespaces&&(s.reportNamespaces=new Ed),s||md(s,"NO_I18NEXT_INSTANCE","useTranslation: You will need to pass in an i18next instance by using initReactI18next");const a=t.useMemo(()=>({...kd,...s?.options?.react,...r}),[s,r]),{useSuspense:l,keyPrefix:c}=a,u=e||i||s?.options?.defaultNS,p=bd(u)?[u]:u||["translation"],d=t.useMemo(()=>p,p);s?.reportNamespaces?.addUsedNamespaces?.(d);const f=t.useRef(0),h=t.useCallback(e=>{if(!s)return $d;const{bindI18n:t,bindI18nStore:r}=a,n=()=>{f.current+=1,e()};return t&&s.on(t,n),r&&s.store.on(r,n),()=>{t&&t.split(" ").forEach(e=>s.off(e,n)),r&&r.split(" ").forEach(e=>s.store.off(e,n))}},[s,a]),m=t.useRef(),g=t.useCallback(()=>{if(!s)return Fd;const e=!(!s.isInitialized&&!s.initializedStoreOnce)&&d.every(e=>((e,t,r={})=>t.languages&&t.languages.length?t.hasLoadedNamespace(e,{lng:r.lng,precheck:(t,n)=>{if(r.bindI18n&&r.bindI18n.indexOf("languageChanging")>-1&&t.services.backendConnector.backend&&t.isLanguageChangingTo&&!n(t.isLanguageChangingTo,e))return!1}}):(md(t,"NO_LANGUAGES","i18n.languages were undefined or empty",{languages:t.languages}),!0))(e,s,a)),t=r.lng||s.language,n=f.current,o=m.current;if(o&&o.ready===e&&o.lng===t&&o.keyPrefix===c&&o.revision===n)return o;const i={t:s.getFixedT(t,"fallback"===a.nsMode?d:d[0],c),ready:e,lng:t,keyPrefix:c,revision:n};return m.current=i,i},[s,d,c,a,r.lng]),[v,y]=t.useState(0),{t:b,ready:w}=Dd.useSyncExternalStore(h,g,g);t.useEffect(()=>{if(s&&!w&&!l){const e=()=>y(e=>e+1);r.lng?yd(s,r.lng,d,e):vd(s,d,e)}},[s,r.lng,d,w,l,v]);const x=s||{},_=t.useRef(null),S=t.useRef(),k=e=>{const t=Object.getOwnPropertyDescriptors(e);t.__original&&delete t.__original;const r=Object.create(Object.getPrototypeOf(e),t);if(!Object.prototype.hasOwnProperty.call(r,"__original"))try{Object.defineProperty(r,"__original",{value:e,writable:!1,enumerable:!1,configurable:!1})}catch(e){}return r},C=t.useMemo(()=>{const e=x,t=e?.language;let r=e;e&&(_.current&&_.current.__original===e?S.current!==t?(r=k(e),_.current=r,S.current=t):r=_.current:(r=k(e),_.current=r,S.current=t));const n=[b,r,w];return n.t=b,n.i18n=r,n.ready=w,n},[b,x,w,x.resolvedLanguage,x.language,x.languages]);if(s&&l&&!w)throw new Promise(e=>{const t=()=>e();r.lng?yd(s,r.lng,d,t):vd(s,d,t)});return C};function zd(e){if("undefined"==typeof window)return e;const t=o.useRef(null);return o.useLayoutEffect(()=>{t.current=e}),o.useCallback((...e)=>{var r;null===(r=t.current)||void 0===r||r.call(t,...e)},[])}const Vd={},Ud={isOpen:!1,setAnchorElUsed:!1,anchorEl:void 0,anchorPosition:void 0,hovered:!1,focused:!1,_openEventType:null,_childPopupState:null,_deferNextOpen:!1,_deferNextClose:!1};function qd({isOpen:e,anchorEl:t,anchorPosition:r,close:n,popupId:o,onMouseLeave:i,disableAutoFocus:s,_openEventType:a}){return{id:o,anchorEl:t,anchorPosition:r,anchorReference:"contextmenu"===a?"anchorPosition":"anchorEl",open:e,onClose:n,onMouseLeave:i,...s&&{autoFocus:!1,disableAutoFocusItem:!0,disableAutoFocus:!0,disableEnforceFocus:!0,disableRestoreFocus:!0}}}function Wd(e,t){const{anchorEl:r,_childPopupState:n}=t;return Hd(r,e)||Hd(function(e,{popupId:t}){if(!t)return null;const r="function"==typeof e.getRootNode?e.getRootNode():document;return"function"==typeof r.getElementById?r.getElementById(t):null}(e,t),e)||null!=n&&Wd(e,n)}function Hd(e,t){if(!e)return!1;for(;t;){if(t===e)return!0;t=t.parentElement}return!1}let Gd=0;var Kd,Yd=({popupId:e,...r})=>function({parentPopupState:e,popupId:r,variant:n,disableAutoFocus:o}){const i=t.useRef(!0);t.useEffect(()=>(i.current=!0,()=>{i.current=!1}),[]);const[s,a]=t.useState(Ud),l=t.useCallback(e=>{i.current&&a(e)},[]),c=t.useCallback(e=>l(t=>({...t,setAnchorElUsed:!0,anchorEl:e??void 0})),[]),u=zd(e=>(s.isOpen?f(e):p(e),s)),p=zd(t=>{const r=t instanceof Element?void 0:t,o=t instanceof Element?t:(null==t?void 0:t.currentTarget)instanceof Element?t.currentTarget:void 0;if("touchstart"===(null==r?void 0:r.type))return void l(e=>({...e,_deferNextOpen:!0}));const i=null==r?void 0:r.clientX,s=null==r?void 0:r.clientY,a="number"==typeof i&&"number"==typeof s?{left:i,top:s}:void 0,c=i=>{if(t||i.setAnchorElUsed||"dialog"===n||Vd.missingEventOrAnchorEl||(Vd.missingEventOrAnchorEl=!0,console.error("[material-ui-popup-state] WARNING","eventOrAnchorEl should be defined if setAnchorEl is not used")),e){if(!e.isOpen)return i;setTimeout(()=>e._setChildPopupState(y))}const s={...i,isOpen:!0,anchorPosition:a,hovered:"mouseover"===(null==r?void 0:r.type)||i.hovered,focused:"focus"===(null==r?void 0:r.type)||i.focused,_openEventType:null==r?void 0:r.type};return null!=r&&r.currentTarget?i.setAnchorElUsed||(s.anchorEl=null==r?void 0:r.currentTarget):o&&(s.anchorEl=o),s};l(e=>e._deferNextOpen?(setTimeout(()=>l(c),0),{...e,_deferNextOpen:!1}):c(e))}),d=t=>{const{_childPopupState:r}=t;return setTimeout(()=>{null==r||r.close(),null==e||e._setChildPopupState(null)}),{...t,isOpen:!1,hovered:!1,focused:!1}},f=zd(e=>{const t=e instanceof Element?void 0:e;"touchstart"!==(null==t?void 0:t.type)?l(e=>e._deferNextClose?(setTimeout(()=>l(d),0),{...e,_deferNextClose:!1}):d(e)):l(e=>({...e,_deferNextClose:!0}))}),h=t.useCallback((e,t)=>{e?p(t):f(t)},[]),m=zd(e=>{const{relatedTarget:t}=e;l(e=>!e.hovered||t instanceof Element&&Wd(t,y)?e:e.focused?{...e,hovered:!1}:d(e))}),g=zd(e=>{if(!e)return;const{relatedTarget:t}=e;l(e=>!e.focused||t instanceof Element&&Wd(t,y)?e:e.hovered?{...e,focused:!1}:d(e))}),v=t.useCallback(e=>l(t=>({...t,_childPopupState:e})),[]),y={...s,setAnchorEl:c,popupId:r,variant:n,open:p,close:f,toggle:u,setOpen:h,onBlur:g,onMouseLeave:m,disableAutoFocus:o??Boolean(s.hovered||s.focused),_setChildPopupState:v};return y}({...r,popupId:t.useRef(e||"eui-popup-"+Gd++).current}),Zd={exports:{}},Xd={};function Jd(){if(Kd)return Xd;Kd=1;var e,t=Symbol.for("react.element"),r=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),o=Symbol.for("react.strict_mode"),i=Symbol.for("react.profiler"),s=Symbol.for("react.provider"),a=Symbol.for("react.context"),l=Symbol.for("react.server_context"),c=Symbol.for("react.forward_ref"),u=Symbol.for("react.suspense"),p=Symbol.for("react.suspense_list"),d=Symbol.for("react.memo"),f=Symbol.for("react.lazy"),h=Symbol.for("react.offscreen");function m(e){if("object"==typeof e&&null!==e){var h=e.$$typeof;switch(h){case t:switch(e=e.type){case n:case i:case o:case u:case p:return e;default:switch(e=e&&e.$$typeof){case l:case a:case c:case f:case d:case s:return e;default:return h}}case r:return h}}}return e=Symbol.for("react.module.reference"),Xd.ContextConsumer=a,Xd.ContextProvider=s,Xd.Element=t,Xd.ForwardRef=c,Xd.Fragment=n,Xd.Lazy=f,Xd.Memo=d,Xd.Portal=r,Xd.Profiler=i,Xd.StrictMode=o,Xd.Suspense=u,Xd.SuspenseList=p,Xd.isAsyncMode=function(){return!1},Xd.isConcurrentMode=function(){return!1},Xd.isContextConsumer=function(e){return m(e)===a},Xd.isContextProvider=function(e){return m(e)===s},Xd.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===t},Xd.isForwardRef=function(e){return m(e)===c},Xd.isFragment=function(e){return m(e)===n},Xd.isLazy=function(e){return m(e)===f},Xd.isMemo=function(e){return m(e)===d},Xd.isPortal=function(e){return m(e)===r},Xd.isProfiler=function(e){return m(e)===i},Xd.isStrictMode=function(e){return m(e)===o},Xd.isSuspense=function(e){return m(e)===u},Xd.isSuspenseList=function(e){return m(e)===p},Xd.isValidElementType=function(t){return"string"==typeof t||"function"==typeof t||t===n||t===i||t===o||t===u||t===p||t===h||"object"==typeof t&&null!==t&&(t.$$typeof===f||t.$$typeof===d||t.$$typeof===s||t.$$typeof===a||t.$$typeof===c||t.$$typeof===e||void 0!==t.getModuleId)},Xd.typeOf=m,Xd}var Qd,ef,tf={};function rf(){return Qd||(Qd=1, true&&function(){var e,t=Symbol.for("react.element"),r=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),o=Symbol.for("react.strict_mode"),i=Symbol.for("react.profiler"),s=Symbol.for("react.provider"),a=Symbol.for("react.context"),l=Symbol.for("react.server_context"),c=Symbol.for("react.forward_ref"),u=Symbol.for("react.suspense"),p=Symbol.for("react.suspense_list"),d=Symbol.for("react.memo"),f=Symbol.for("react.lazy"),h=Symbol.for("react.offscreen");function m(e){if("object"==typeof e&&null!==e){var h=e.$$typeof;switch(h){case t:var m=e.type;switch(m){case n:case i:case o:case u:case p:return m;default:var g=m&&m.$$typeof;switch(g){case l:case a:case c:case f:case d:case s:return g;default:return h}}case r:return h}}}e=Symbol.for("react.module.reference");var g=a,v=s,y=t,b=c,w=n,x=f,_=d,S=r,k=i,C=o,O=u,E=p,T=!1,R=!1;tf.ContextConsumer=g,tf.ContextProvider=v,tf.Element=y,tf.ForwardRef=b,tf.Fragment=w,tf.Lazy=x,tf.Memo=_,tf.Portal=S,tf.Profiler=k,tf.StrictMode=C,tf.Suspense=O,tf.SuspenseList=E,tf.isAsyncMode=function(e){return T||(T=!0,console.warn("The ReactIs.isAsyncMode() alias has been deprecated, and will be removed in React 18+.")),!1},tf.isConcurrentMode=function(e){return R||(R=!0,console.warn("The ReactIs.isConcurrentMode() alias has been deprecated, and will be removed in React 18+.")),!1},tf.isContextConsumer=function(e){return m(e)===a},tf.isContextProvider=function(e){return m(e)===s},tf.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===t},tf.isForwardRef=function(e){return m(e)===c},tf.isFragment=function(e){return m(e)===n},tf.isLazy=function(e){return m(e)===f},tf.isMemo=function(e){return m(e)===d},tf.isPortal=function(e){return m(e)===r},tf.isProfiler=function(e){return m(e)===i},tf.isStrictMode=function(e){return m(e)===o},tf.isSuspense=function(e){return m(e)===u},tf.isSuspenseList=function(e){return m(e)===p},tf.isValidElementType=function(t){return"string"==typeof t||"function"==typeof t||t===n||t===i||t===o||t===u||t===p||t===h||"object"==typeof t&&null!==t&&(t.$$typeof===f||t.$$typeof===d||t.$$typeof===s||t.$$typeof===a||t.$$typeof===c||t.$$typeof===e||void 0!==t.getModuleId)},tf.typeOf=m}()),tf}function nf(){return ef||(ef=1, false?0:Zd.exports=rf()),Zd.exports}var of=nf();function sf(e){return"string"==typeof e}function af(e,t,r){return void 0===e||sf(e)?t:a({},t,{ownerState:a({},t.ownerState,r)})}const lf={disableDefaultClasses:!1},cf=o.createContext(lf);function uf(e,t=[]){if(void 0===e)return{};const r={};return Object.keys(e).filter(r=>r.match(/^on[A-Z]/)&&"function"==typeof e[r]&&!t.includes(r)).forEach(t=>{r[t]=e[t]}),r}function pf(e,t,r){return"function"==typeof e?e(t,r):e}function df(e,t,r,n,o){const i=e[t],s=o||t;if(null==i||"undefined"==typeof window)return null;let a;const l=i.type;return"function"!=typeof l||function(e){const{prototype:t={}}=e;return Boolean(t.isReactComponent)}(l)||(a="Did you accidentally use a plain function component for an element instead?"),void 0!==a?new Error(`Invalid ${n} \`${s}\` supplied to \`${r}\`. Expected an element that can hold a ref. ${a} For more information see https://mui.com/r/caveat-with-refs-guide`):null} true&&(cf.displayName="ClassNameConfiguratorContext");const ff=rs(B.element,df);ff.isRequired=rs(B.element.isRequired,df);const hf=ff,mf="exact-prop: ​";function gf(e){return false?0:a({},e,{[mf]:t=>{const r=Object.keys(t).filter(t=>!e.hasOwnProperty(t));return r.length>0?new Error(`The following props are not supported: ${r.map(e=>`\`${e}\``).join(", ")}. Please remove them.`):null}})}function vf(e,t,r,n,o){if(false)// removed by dead control flow
{}const i=e[t],s=o||t;return null==i?null:i&&1!==i.nodeType?new Error(`Invalid ${n} \`${s}\` supplied to \`${r}\`. Expected an HTMLElement.`):null}function yf(...e){return e.reduce((e,t)=>null==t?e:function(...r){e.apply(this,r),t.apply(this,r)},()=>{})}function bf(e,t=166){let r;function n(...n){clearTimeout(r),r=setTimeout(()=>{e.apply(this,n)},t)}return n.clear=()=>{clearTimeout(r)},n}function wf(e,t){var r,n;return o.isValidElement(e)&&-1!==t.indexOf(null!=(r=e.type.muiName)?r:null==(n=e.type)||null==(n=n._payload)||null==(n=n.value)?void 0:n.muiName)}function xf(e){return e&&e.ownerDocument||document}function _f(e){return xf(e).defaultView||window}let Sf=0;const kf=o["useId".toString()];function Cf(e){if(void 0!==kf){const t=kf();return null!=e?e:t}return function(e){const[t,r]=o.useState(e),n=e||t;return o.useEffect(()=>{null==t&&(Sf+=1,r(`mui-${Sf}`))},[t]),n}(e)}function Of({controlled:e,default:t,name:r,state:n="value"}){const{current:i}=o.useRef(void 0!==e),[s,a]=o.useState(t),l=i?e:s;if(true){o.useEffect(()=>{i!==(void 0!==e)&&console.error([`MUI: A component is changing the ${i?"":"un"}controlled ${n} state of ${r} to be ${i?"un":""}controlled.`,"Elements should not switch from uncontrolled to controlled (or vice versa).",`Decide between using a controlled or uncontrolled ${r} element for the lifetime of the component.`,"The nature of the state is determined during the first render. It's considered controlled if the value is not `undefined`.","More info: https://fb.me/react-controlled-components"].join("\n"))},[n,r,e]);const{current:s}=o.useRef(t);o.useEffect(()=>{i||Object.is(s,t)||console.error([`MUI: A component is changing the default ${n} state of an uncontrolled ${r} after being initialized. To suppress this warning opt to use a controlled ${r}.`].join("\n"))},[JSON.stringify(t)])}return[l,o.useCallback(e=>{i||a(e)},[])]}function Ef(e){const t=e.documentElement.clientWidth;return Math.abs(window.innerWidth-t)}const Tf=e=>{const t=o.useRef({});return o.useEffect(()=>{t.current=e}),t.current};function Rf(e){if(void 0===e)return{};const t={};return Object.keys(e).filter(t=>!(t.match(/^on[A-Z]/)&&"function"==typeof e[t])).forEach(r=>{t[r]=e[r]}),t}function If(e){const{getSlotProps:t,additionalProps:r,externalSlotProps:n,externalForwardedProps:o,className:i}=e;if(!t){const e=V(null==r?void 0:r.className,i,null==o?void 0:o.className,null==n?void 0:n.className),t=a({},null==r?void 0:r.style,null==o?void 0:o.style,null==n?void 0:n.style),s=a({},r,o,n);return e.length>0&&(s.className=e),Object.keys(t).length>0&&(s.style=t),{props:s,internalRef:void 0}}const s=uf(a({},o,n)),l=Rf(n),c=Rf(o),u=t(s),p=V(null==u?void 0:u.className,null==r?void 0:r.className,i,null==o?void 0:o.className,null==n?void 0:n.className),d=a({},null==u?void 0:u.style,null==r?void 0:r.style,null==o?void 0:o.style,null==n?void 0:n.style),f=a({},u,r,c,l);return p.length>0&&(f.className=p),Object.keys(d).length>0&&(f.style=d),{props:f,internalRef:u.ref}}const Mf=["elementType","externalSlotProps","ownerState","skipResolvingSlotProps"];function Af(e){var t;const{elementType:r,externalSlotProps:n,ownerState:o,skipResolvingSlotProps:i=!1}=e,l=s(e,Mf),c=i?{}:pf(n,o),{props:u,internalRef:p}=If(a({},l,{externalSlotProps:c}));return af(r,a({},u,{ref:Fa(p,null==c?void 0:c.ref,null==(t=e.additionalProps)?void 0:t.ref)}),o)}const Pf=o.createContext({}); true&&(Pf.displayName="ListContext");const Nf=Pf;function jf(e){return Mo("MuiList",e)}ta("MuiList",["root","padding","dense","subheader"]);const Lf=["children","className","component","dense","disablePadding","subheader"],Df=Vi("ul",{name:"MuiList",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,!r.disablePadding&&t.padding,r.dense&&t.dense,r.subheader&&t.subheader]}})(({ownerState:e})=>a({listStyle:"none",margin:0,padding:0,position:"relative"},!e.disablePadding&&{paddingTop:8,paddingBottom:8},e.subheader&&{paddingTop:0})),Ff=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiList"}),{children:i,className:l,component:c="ul",dense:u=!1,disablePadding:p=!1,subheader:d}=n,f=s(n,Lf),h=o.useMemo(()=>({dense:u}),[u]),m=a({},n,{component:c,dense:u,disablePadding:p}),g=(e=>{const{classes:t,disablePadding:r,dense:n,subheader:o}=e;return U({root:["root",!r&&"padding",n&&"dense",o&&"subheader"]},jf,t)})(m);return e.jsx(Nf.Provider,{value:h,children:e.jsxs(Df,a({as:c,className:V(g.root,l),ref:r,ownerState:m},f,{children:[d,i]}))})}); true&&(Ff.propTypes={children:B.node,classes:B.object,className:B.string,component:B.elementType,dense:B.bool,disablePadding:B.bool,subheader:B.node,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const $f=Ff,Bf=["actions","autoFocus","autoFocusItem","children","className","disabledItemsFocusable","disableListWrap","onKeyDown","variant"];function zf(e,t,r){return e===t?e.firstChild:t&&t.nextElementSibling?t.nextElementSibling:r?null:e.firstChild}function Vf(e,t,r){return e===t?r?e.firstChild:e.lastChild:t&&t.previousElementSibling?t.previousElementSibling:r?null:e.lastChild}function Uf(e,t){if(void 0===t)return!0;let r=e.innerText;return void 0===r&&(r=e.textContent),r=r.trim().toLowerCase(),0!==r.length&&(t.repeating?r[0]===t.keys[0]:0===r.indexOf(t.keys.join("")))}function qf(e,t,r,n,o,i){let s=!1,a=o(e,t,!!t&&r);for(;a;){if(a===e.firstChild){if(s)return!1;s=!0}const t=!n&&(a.disabled||"true"===a.getAttribute("aria-disabled"));if(a.hasAttribute("tabindex")&&Uf(a,i)&&!t)return a.focus(),!0;a=o(e,a,r)}return!1}const Wf=o.forwardRef(function(t,r){const{actions:n,autoFocus:i=!1,autoFocusItem:l=!1,children:c,className:u,disabledItemsFocusable:p=!1,disableListWrap:d=!1,onKeyDown:f,variant:h="selectedMenu"}=t,m=s(t,Bf),g=o.useRef(null),v=o.useRef({keys:[],repeating:!0,previousKeyMatched:!0,lastTime:null});$a(()=>{i&&g.current.focus()},[i]),o.useImperativeHandle(n,()=>({adjustStyleForScrollbar:(e,{direction:t})=>{const r=!g.current.style.width;if(e.clientHeight<g.current.clientHeight&&r){const r=`${Ef(xf(e))}px`;g.current.style["rtl"===t?"paddingLeft":"paddingRight"]=r,g.current.style.width=`calc(100% + ${r})`}return g.current}}),[]);const y=Fa(g,r);let b=-1;o.Children.forEach(c,(e,t)=>{o.isValidElement(e)?( true&&of.isFragment(e)&&console.error(["MUI: The Menu component doesn't accept a Fragment as a child.","Consider providing an array instead."].join("\n")),e.props.disabled||("selectedMenu"===h&&e.props.selected||-1===b)&&(b=t),b===t&&(e.props.disabled||e.props.muiSkipListHighlight||e.type.muiSkipListHighlight)&&(b+=1,b>=c.length&&(b=-1))):b===t&&(b+=1,b>=c.length&&(b=-1))});const w=o.Children.map(c,(e,t)=>{if(t===b){const t={};return l&&(t.autoFocus=!0),void 0===e.props.tabIndex&&"selectedMenu"===h&&(t.tabIndex=0),o.cloneElement(e,t)}return e});return e.jsx($f,a({role:"menu",ref:y,className:u,onKeyDown:e=>{const t=g.current,r=e.key,n=xf(t).activeElement;if("ArrowDown"===r)e.preventDefault(),qf(t,n,d,p,zf);else if("ArrowUp"===r)e.preventDefault(),qf(t,n,d,p,Vf);else if("Home"===r)e.preventDefault(),qf(t,null,d,p,zf);else if("End"===r)e.preventDefault(),qf(t,null,d,p,Vf);else if(1===r.length){const o=v.current,i=r.toLowerCase(),s=performance.now();o.keys.length>0&&(s-o.lastTime>500?(o.keys=[],o.repeating=!0,o.previousKeyMatched=!0):o.repeating&&i!==o.keys[0]&&(o.repeating=!1)),o.lastTime=s,o.keys.push(i);const a=n&&!o.repeating&&Uf(n,o);o.previousKeyMatched&&(a||qf(t,n,!1,p,zf,o))?e.preventDefault():o.previousKeyMatched=!1}f&&f(e)},tabIndex:i?0:-1},m,{children:w}))}); true&&(Wf.propTypes={autoFocus:B.bool,autoFocusItem:B.bool,children:B.node,className:B.string,disabledItemsFocusable:B.bool,disableListWrap:B.bool,onKeyDown:B.func,variant:B.oneOf(["menu","selectedMenu"])});const Hf=Wf;function Gf(e,t){var r,n;const{timeout:o,easing:i,style:s={}}=e;return{duration:null!=(r=s.transitionDuration)?r:"number"==typeof o?o:o[t.mode]||0,easing:null!=(n=s.transitionTimingFunction)?n:"object"==typeof i?i[t.mode]:i,delay:s.transitionDelay}}const Kf=["addEndListener","appear","children","easing","in","onEnter","onEntered","onEntering","onExit","onExited","onExiting","style","timeout","TransitionComponent"];function Yf(e){return`scale(${e}, ${e**2})`}const Zf={entering:{opacity:1,transform:Yf(1)},entered:{opacity:1,transform:"none"}},Xf="undefined"!=typeof navigator&&/^((?!chrome|android).)*(safari|mobile)/i.test(navigator.userAgent)&&/(os |version\/)15(.|_)4/i.test(navigator.userAgent),Jf=o.forwardRef(function(t,r){const{addEndListener:n,appear:i=!0,children:l,easing:c,in:u,onEnter:p,onEntered:d,onEntering:f,onExit:h,onExited:m,onExiting:g,style:v,timeout:y="auto",TransitionComponent:b=ul}=t,w=s(t,Kf),x=qa(),_=o.useRef(),S=ea(),k=o.useRef(null),C=Fa(k,l.ref,r),O=e=>t=>{if(e){const r=k.current;void 0===t?e(r):e(r,t)}},E=O(f),T=O((e,t)=>{const{duration:r,delay:n,easing:o}=Gf({style:v,timeout:y,easing:c},{mode:"enter"});let i;"auto"===y?(i=S.transitions.getAutoHeightDuration(e.clientHeight),_.current=i):i=r,e.style.transition=[S.transitions.create("opacity",{duration:i,delay:n}),S.transitions.create("transform",{duration:Xf?i:.666*i,delay:n,easing:o})].join(","),p&&p(e,t)}),R=O(d),I=O(g),M=O(e=>{const{duration:t,delay:r,easing:n}=Gf({style:v,timeout:y,easing:c},{mode:"exit"});let o;"auto"===y?(o=S.transitions.getAutoHeightDuration(e.clientHeight),_.current=o):o=t,e.style.transition=[S.transitions.create("opacity",{duration:o,delay:r}),S.transitions.create("transform",{duration:Xf?o:.666*o,delay:Xf?r:r||.333*o,easing:n})].join(","),e.style.opacity=0,e.style.transform=Yf(.75),h&&h(e)}),A=O(m);return e.jsx(b,a({appear:i,in:u,nodeRef:k,onEnter:T,onEntered:R,onEntering:E,onExit:M,onExited:A,onExiting:I,addEndListener:e=>{"auto"===y&&x.start(_.current||0,e),n&&n(k.current,e)},timeout:"auto"===y?null:y},w,{children:(e,t)=>o.cloneElement(l,a({style:a({opacity:0,transform:Yf(.75),visibility:"exited"!==e||u?void 0:"hidden"},Zf[e],v,l.props.style),ref:C},t))}))}); true&&(Jf.propTypes={addEndListener:B.func,appear:B.bool,children:hf.isRequired,easing:B.oneOfType([B.shape({enter:B.string,exit:B.string}),B.string]),in:B.bool,onEnter:B.func,onEntered:B.func,onEntering:B.func,onExit:B.func,onExited:B.func,onExiting:B.func,style:B.object,timeout:B.oneOfType([B.oneOf(["auto"]),B.number,B.shape({appear:B.number,enter:B.number,exit:B.number})])}),Jf.muiSupportAuto=!0;const Qf=Jf;function eh(e,t){t?e.setAttribute("aria-hidden","true"):e.removeAttribute("aria-hidden")}function th(e){return parseInt(_f(e).getComputedStyle(e).paddingRight,10)||0}function rh(e,t,r,n,o){const i=[t,r,...n];[].forEach.call(e.children,e=>{const t=-1===i.indexOf(e),r=!function(e){const t=-1!==["TEMPLATE","SCRIPT","STYLE","LINK","MAP","META","NOSCRIPT","PICTURE","COL","COLGROUP","PARAM","SLOT","SOURCE","TRACK"].indexOf(e.tagName),r="INPUT"===e.tagName&&"hidden"===e.getAttribute("type");return t||r}(e);t&&r&&eh(e,o)})}function nh(e,t){let r=-1;return e.some((e,n)=>!!t(e)&&(r=n,!0)),r}const oh=new class{add(e,t){let r=this.modals.indexOf(e);if(-1!==r)return r;r=this.modals.length,this.modals.push(e),e.modalRef&&eh(e.modalRef,!1);const n=function(e){const t=[];return[].forEach.call(e.children,e=>{"true"===e.getAttribute("aria-hidden")&&t.push(e)}),t}(t);rh(t,e.mount,e.modalRef,n,!0);const o=nh(this.containers,e=>e.container===t);return-1!==o?(this.containers[o].modals.push(e),r):(this.containers.push({modals:[e],container:t,restore:null,hiddenSiblings:n}),r)}mount(e,t){const r=nh(this.containers,t=>-1!==t.modals.indexOf(e)),n=this.containers[r];n.restore||(n.restore=function(e,t){const r=[],n=e.container;if(!t.disableScrollLock){if(function(e){const t=xf(e);return t.body===e?_f(e).innerWidth>t.documentElement.clientWidth:e.scrollHeight>e.clientHeight}(n)){const e=Ef(xf(n));r.push({value:n.style.paddingRight,property:"padding-right",el:n}),n.style.paddingRight=`${th(n)+e}px`;const t=xf(n).querySelectorAll(".mui-fixed");[].forEach.call(t,t=>{r.push({value:t.style.paddingRight,property:"padding-right",el:t}),t.style.paddingRight=`${th(t)+e}px`})}let e;if(n.parentNode instanceof DocumentFragment)e=xf(n).body;else{const t=n.parentElement,r=_f(n);e="HTML"===(null==t?void 0:t.nodeName)&&"scroll"===r.getComputedStyle(t).overflowY?t:n}r.push({value:e.style.overflow,property:"overflow",el:e},{value:e.style.overflowX,property:"overflow-x",el:e},{value:e.style.overflowY,property:"overflow-y",el:e}),e.style.overflow="hidden"}return()=>{r.forEach(({value:e,el:t,property:r})=>{e?t.style.setProperty(r,e):t.style.removeProperty(r)})}}(n,t))}remove(e,t=!0){const r=this.modals.indexOf(e);if(-1===r)return r;const n=nh(this.containers,t=>-1!==t.modals.indexOf(e)),o=this.containers[n];if(o.modals.splice(o.modals.indexOf(e),1),this.modals.splice(r,1),0===o.modals.length)o.restore&&o.restore(),e.modalRef&&eh(e.modalRef,t),rh(o.container,e.mount,e.modalRef,o.hiddenSiblings,!1),this.containers.splice(n,1);else{const e=o.modals[o.modals.length-1];e.modalRef&&eh(e.modalRef,!1)}return r}isTopModal(e){return this.modals.length>0&&this.modals[this.modals.length-1]===e}constructor(){this.containers=void 0,this.modals=void 0,this.modals=[],this.containers=[]}};const ih=["input","select","textarea","a[href]","button","[tabindex]","audio[controls]","video[controls]",'[contenteditable]:not([contenteditable="false"])'].join(",");function sh(e){const t=[],r=[];return Array.from(e.querySelectorAll(ih)).forEach((e,n)=>{const o=function(e){const t=parseInt(e.getAttribute("tabindex")||"",10);return Number.isNaN(t)?"true"===e.contentEditable||("AUDIO"===e.nodeName||"VIDEO"===e.nodeName||"DETAILS"===e.nodeName)&&null===e.getAttribute("tabindex")?0:e.tabIndex:t}(e);-1!==o&&function(e){return!(e.disabled||"INPUT"===e.tagName&&"hidden"===e.type||function(e){if("INPUT"!==e.tagName||"radio"!==e.type)return!1;if(!e.name)return!1;const t=t=>e.ownerDocument.querySelector(`input[type="radio"]${t}`);let r=t(`[name="${e.name}"]:checked`);return r||(r=t(`[name="${e.name}"]`)),r!==e}(e))}(e)&&(0===o?t.push(e):r.push({documentOrder:n,tabIndex:o,node:e}))}),r.sort((e,t)=>e.tabIndex===t.tabIndex?e.documentOrder-t.documentOrder:e.tabIndex-t.tabIndex).map(e=>e.node).concat(t)}function ah(){return!0}function lh(t){const{children:r,disableAutoFocus:n=!1,disableEnforceFocus:i=!1,disableRestoreFocus:s=!1,getTabbable:a=sh,isEnabled:l=ah,open:c}=t,u=o.useRef(!1),p=o.useRef(null),d=o.useRef(null),f=o.useRef(null),h=o.useRef(null),m=o.useRef(!1),g=o.useRef(null),v=Fa(r.ref,g),y=o.useRef(null);o.useEffect(()=>{c&&g.current&&(m.current=!n)},[n,c]),o.useEffect(()=>{if(!c||!g.current)return;const e=xf(g.current);return g.current.contains(e.activeElement)||(g.current.hasAttribute("tabIndex")||( true&&console.error(["MUI: The modal content node does not accept focus.",'For the benefit of assistive technologies, the tabIndex of the node is being set to "-1".'].join("\n")),g.current.setAttribute("tabIndex","-1")),m.current&&g.current.focus()),()=>{s||(f.current&&f.current.focus&&(u.current=!0,f.current.focus()),f.current=null)}},[c]),o.useEffect(()=>{if(!c||!g.current)return;const e=xf(g.current),t=t=>{y.current=t,!i&&l()&&"Tab"===t.key&&e.activeElement===g.current&&t.shiftKey&&(u.current=!0,d.current&&d.current.focus())},r=()=>{const t=g.current;if(null===t)return;if(!e.hasFocus()||!l()||u.current)return void(u.current=!1);if(t.contains(e.activeElement))return;if(i&&e.activeElement!==p.current&&e.activeElement!==d.current)return;if(e.activeElement!==h.current)h.current=null;else if(null!==h.current)return;if(!m.current)return;let r=[];if(e.activeElement!==p.current&&e.activeElement!==d.current||(r=a(g.current)),r.length>0){var n,o;const e=Boolean((null==(n=y.current)?void 0:n.shiftKey)&&"Tab"===(null==(o=y.current)?void 0:o.key)),t=r[0],i=r[r.length-1];"string"!=typeof t&&"string"!=typeof i&&(e?i.focus():t.focus())}else t.focus()};e.addEventListener("focusin",r),e.addEventListener("keydown",t,!0);const n=setInterval(()=>{e.activeElement&&"BODY"===e.activeElement.tagName&&r()},50);return()=>{clearInterval(n),e.removeEventListener("focusin",r),e.removeEventListener("keydown",t,!0)}},[n,i,s,l,c,a]);const b=e=>{null===f.current&&(f.current=e.relatedTarget),m.current=!0};return e.jsxs(o.Fragment,{children:[e.jsx("div",{tabIndex:c?0:-1,onFocus:b,ref:p,"data-testid":"sentinelStart"}),o.cloneElement(r,{ref:v,onFocus:e=>{null===f.current&&(f.current=e.relatedTarget),m.current=!0,h.current=e.target;const t=r.props.onFocus;t&&t(e)}}),e.jsx("div",{tabIndex:c?0:-1,onFocus:b,ref:d,"data-testid":"sentinelEnd"})]})} true&&(lh.propTypes={children:hf,disableAutoFocus:B.bool,disableEnforceFocus:B.bool,disableRestoreFocus:B.bool,getTabbable:B.func,isEnabled:B.func,open:B.bool.isRequired}), true&&(lh.propTypes=gf(lh.propTypes));const ch=o.forwardRef(function(t,r){const{children:n,container:s,disablePortal:a=!1}=t,[l,c]=o.useState(null),u=Fa(o.isValidElement(n)?n.ref:null,r);if($a(()=>{a||c(function(e){return"function"==typeof e?e():e}(s)||document.body)},[s,a]),$a(()=>{if(l&&!a)return Da(r,l),()=>{Da(r,null)}},[r,l,a]),a){if(o.isValidElement(n)){const e={ref:u};return o.cloneElement(n,e)}return e.jsx(o.Fragment,{children:n})}return e.jsx(o.Fragment,{children:l?i.createPortal(n,l):l})}); true&&(ch.propTypes={children:B.node,container:B.oneOfType([vf,B.func]),disablePortal:B.bool}), true&&(ch.propTypes=gf(ch.propTypes));const uh=["addEndListener","appear","children","easing","in","onEnter","onEntered","onEntering","onExit","onExited","onExiting","style","timeout","TransitionComponent"],ph={entering:{opacity:1},entered:{opacity:1}},dh=o.forwardRef(function(t,r){const n=ea(),i={enter:n.transitions.duration.enteringScreen,exit:n.transitions.duration.leavingScreen},{addEndListener:l,appear:c=!0,children:u,easing:p,in:d,onEnter:f,onEntered:h,onEntering:m,onExit:g,onExited:v,onExiting:y,style:b,timeout:w=i,TransitionComponent:x=ul}=t,_=s(t,uh),S=o.useRef(null),k=Fa(S,u.ref,r),C=e=>t=>{if(e){const r=S.current;void 0===t?e(r):e(r,t)}},O=C(m),E=C((e,t)=>{const r=Gf({style:b,timeout:w,easing:p},{mode:"enter"});e.style.webkitTransition=n.transitions.create("opacity",r),e.style.transition=n.transitions.create("opacity",r),f&&f(e,t)}),T=C(h),R=C(y),I=C(e=>{const t=Gf({style:b,timeout:w,easing:p},{mode:"exit"});e.style.webkitTransition=n.transitions.create("opacity",t),e.style.transition=n.transitions.create("opacity",t),g&&g(e)}),M=C(v);return e.jsx(x,a({appear:c,in:d,nodeRef:S,onEnter:E,onEntered:T,onEntering:O,onExit:I,onExited:M,onExiting:R,addEndListener:e=>{l&&l(S.current,e)},timeout:w},_,{children:(e,t)=>o.cloneElement(u,a({style:a({opacity:0,visibility:"exited"!==e||d?void 0:"hidden"},ph[e],b,u.props.style),ref:k},t))}))}); true&&(dh.propTypes={addEndListener:B.func,appear:B.bool,children:hf.isRequired,easing:B.oneOfType([B.shape({enter:B.string,exit:B.string}),B.string]),in:B.bool,onEnter:B.func,onEntered:B.func,onEntering:B.func,onExit:B.func,onExited:B.func,onExiting:B.func,style:B.object,timeout:B.oneOfType([B.number,B.shape({appear:B.number,enter:B.number,exit:B.number})])});const fh=dh;function hh(e){return Mo("MuiBackdrop",e)}ta("MuiBackdrop",["root","invisible"]);const mh=["children","className","component","components","componentsProps","invisible","open","slotProps","slots","TransitionComponent","transitionDuration"],gh=Vi("div",{name:"MuiBackdrop",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,r.invisible&&t.invisible]}})(({ownerState:e})=>a({position:"fixed",display:"flex",alignItems:"center",justifyContent:"center",right:0,bottom:0,top:0,left:0,backgroundColor:"rgba(0, 0, 0, 0.5)",WebkitTapHighlightColor:"transparent"},e.invisible&&{backgroundColor:"transparent"})),vh=o.forwardRef(function(t,r){var n,o,i;const l=Yi({props:t,name:"MuiBackdrop"}),{children:c,className:u,component:p="div",components:d={},componentsProps:f={},invisible:h=!1,open:m,slotProps:g={},slots:v={},TransitionComponent:y=fh,transitionDuration:b}=l,w=s(l,mh),x=a({},l,{component:p,invisible:h}),_=(e=>{const{classes:t,invisible:r}=e;return U({root:["root",r&&"invisible"]},hh,t)})(x),S=null!=(n=g.root)?n:f.root;return e.jsx(y,a({in:m,timeout:b},w,{children:e.jsx(gh,a({"aria-hidden":!0},S,{as:null!=(o=null!=(i=v.root)?i:d.Root)?o:p,className:V(_.root,u,null==S?void 0:S.className),ownerState:a({},x,null==S?void 0:S.ownerState),classes:_,ref:r,children:c}))}))}); true&&(vh.propTypes={children:B.node,classes:B.object,className:B.string,component:B.elementType,components:B.shape({Root:B.elementType}),componentsProps:B.shape({root:B.object}),invisible:B.bool,open:B.bool.isRequired,slotProps:B.shape({root:B.object}),slots:B.shape({root:B.elementType}),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),TransitionComponent:B.elementType,transitionDuration:B.oneOfType([B.number,B.shape({appear:B.number,enter:B.number,exit:B.number})])});const yh=vh;function bh(e){return Mo("MuiModal",e)}ta("MuiModal",["root","hidden","backdrop"]);const wh=["BackdropComponent","BackdropProps","classes","className","closeAfterTransition","children","container","component","components","componentsProps","disableAutoFocus","disableEnforceFocus","disableEscapeKeyDown","disablePortal","disableRestoreFocus","disableScrollLock","hideBackdrop","keepMounted","onBackdropClick","onClose","onTransitionEnter","onTransitionExited","open","slotProps","slots","theme"],xh=Vi("div",{name:"MuiModal",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,!r.open&&r.exited&&t.hidden]}})(({theme:e,ownerState:t})=>a({position:"fixed",zIndex:(e.vars||e).zIndex.modal,right:0,bottom:0,top:0,left:0},!t.open&&t.exited&&{visibility:"hidden"})),_h=Vi(yh,{name:"MuiModal",slot:"Backdrop",overridesResolver:(e,t)=>t.backdrop})({zIndex:-1}),Sh=o.forwardRef(function(t,r){var n,i,l,c,u,p;const d=Yi({name:"MuiModal",props:t}),{BackdropComponent:f=_h,BackdropProps:h,className:m,closeAfterTransition:g=!1,children:v,container:y,component:b,components:w={},componentsProps:x={},disableAutoFocus:_=!1,disableEnforceFocus:S=!1,disableEscapeKeyDown:k=!1,disablePortal:C=!1,disableRestoreFocus:O=!1,disableScrollLock:E=!1,hideBackdrop:T=!1,keepMounted:R=!1,onBackdropClick:I,open:M,slotProps:A,slots:P}=d,N=s(d,wh),j=a({},d,{closeAfterTransition:g,disableAutoFocus:_,disableEnforceFocus:S,disableEscapeKeyDown:k,disablePortal:C,disableRestoreFocus:O,disableScrollLock:E,hideBackdrop:T,keepMounted:R}),{getRootProps:L,getBackdropProps:D,getTransitionProps:F,portalRef:$,isTopModal:B,exited:z,hasTransition:q}=function(e){const{container:t,disableEscapeKeyDown:r=!1,disableScrollLock:n=!1,manager:i=oh,closeAfterTransition:s=!1,onTransitionEnter:l,onTransitionExited:c,children:u,onClose:p,open:d,rootRef:f}=e,h=o.useRef({}),m=o.useRef(null),g=o.useRef(null),v=Fa(g,f),[y,b]=o.useState(!d),w=function(e){return!!e&&e.props.hasOwnProperty("in")}(u);let x=!0;"false"!==e["aria-hidden"]&&!1!==e["aria-hidden"]||(x=!1);const _=()=>(h.current.modalRef=g.current,h.current.mount=m.current,h.current),S=()=>{i.mount(_(),{disableScrollLock:n}),g.current&&(g.current.scrollTop=0)},k=Ba(()=>{const e=function(e){return"function"==typeof e?e():e}(t)||xf(m.current).body;i.add(_(),e),g.current&&S()}),C=o.useCallback(()=>i.isTopModal(_()),[i]),O=Ba(e=>{m.current=e,e&&(d&&C()?S():g.current&&eh(g.current,x))}),E=o.useCallback(()=>{i.remove(_(),x)},[x,i]);o.useEffect(()=>()=>{E()},[E]),o.useEffect(()=>{d?k():w&&s||E()},[d,E,w,s,k]);const T=e=>t=>{var n;null==(n=e.onKeyDown)||n.call(e,t),"Escape"===t.key&&229!==t.which&&C()&&(r||(t.stopPropagation(),p&&p(t,"escapeKeyDown")))},R=e=>t=>{var r;null==(r=e.onClick)||r.call(e,t),t.target===t.currentTarget&&p&&p(t,"backdropClick")};return{getRootProps:(t={})=>{const r=uf(e);delete r.onTransitionEnter,delete r.onTransitionExited;const n=a({},r,t);return a({role:"presentation"},n,{onKeyDown:T(n),ref:v})},getBackdropProps:(e={})=>a({"aria-hidden":!0},e,{onClick:R(e),open:d}),getTransitionProps:()=>({onEnter:yf(()=>{b(!1),l&&l()},null==u?void 0:u.props.onEnter),onExited:yf(()=>{b(!0),c&&c(),s&&E()},null==u?void 0:u.props.onExited)}),rootRef:v,portalRef:O,isTopModal:C,exited:y,hasTransition:w}}(a({},j,{rootRef:r})),W=a({},j,{exited:z}),H=(e=>{const{open:t,exited:r,classes:n}=e;return U({root:["root",!t&&r&&"hidden"],backdrop:["backdrop"]},bh,n)})(W),G={};if(void 0===v.props.tabIndex&&(G.tabIndex="-1"),q){const{onEnter:e,onExited:t}=F();G.onEnter=e,G.onExited=t}const K=null!=(n=null!=(i=null==P?void 0:P.root)?i:w.Root)?n:xh,Y=null!=(l=null!=(c=null==P?void 0:P.backdrop)?c:w.Backdrop)?l:f,Z=null!=(u=null==A?void 0:A.root)?u:x.root,X=null!=(p=null==A?void 0:A.backdrop)?p:x.backdrop,J=Af({elementType:K,externalSlotProps:Z,externalForwardedProps:N,getSlotProps:L,additionalProps:{ref:r,as:b},ownerState:W,className:V(m,null==Z?void 0:Z.className,null==H?void 0:H.root,!W.open&&W.exited&&(null==H?void 0:H.hidden))}),Q=Af({elementType:Y,externalSlotProps:X,additionalProps:h,getSlotProps:e=>D(a({},e,{onClick:t=>{I&&I(t),null!=e&&e.onClick&&e.onClick(t)}})),className:V(null==X?void 0:X.className,null==h?void 0:h.className,null==H?void 0:H.backdrop),ownerState:W});return R||M||q&&!z?e.jsx(ch,{ref:$,container:y,disablePortal:C,children:e.jsxs(K,a({},J,{children:[!T&&f?e.jsx(Y,a({},Q)):null,e.jsx(lh,{disableEnforceFocus:S,disableAutoFocus:_,disableRestoreFocus:O,isEnabled:B,open:M,children:o.cloneElement(v,G)})]}))}):null}); true&&(Sh.propTypes={BackdropComponent:B.elementType,BackdropProps:B.object,children:hf.isRequired,classes:B.object,className:B.string,closeAfterTransition:B.bool,component:B.elementType,components:B.shape({Backdrop:B.elementType,Root:B.elementType}),componentsProps:B.shape({backdrop:B.oneOfType([B.func,B.object]),root:B.oneOfType([B.func,B.object])}),container:B.oneOfType([vf,B.func]),disableAutoFocus:B.bool,disableEnforceFocus:B.bool,disableEscapeKeyDown:B.bool,disablePortal:B.bool,disableRestoreFocus:B.bool,disableScrollLock:B.bool,hideBackdrop:B.bool,keepMounted:B.bool,onBackdropClick:B.func,onClose:B.func,onTransitionEnter:B.func,onTransitionExited:B.func,open:B.bool.isRequired,slotProps:B.shape({backdrop:B.oneOfType([B.func,B.object]),root:B.oneOfType([B.func,B.object])}),slots:B.shape({backdrop:B.elementType,root:B.elementType}),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const kh=Sh;function Ch(e){return Mo("MuiPopover",e)}ta("MuiPopover",["root","paper"]);const Oh=["onEntering"],Eh=["action","anchorEl","anchorOrigin","anchorPosition","anchorReference","children","className","container","elevation","marginThreshold","open","PaperProps","slots","slotProps","transformOrigin","TransitionComponent","transitionDuration","TransitionProps","disableScrollLock"],Th=["slotProps"];function Rh(e,t){let r=0;return"number"==typeof t?r=t:"center"===t?r=e.height/2:"bottom"===t&&(r=e.height),r}function Ih(e,t){let r=0;return"number"==typeof t?r=t:"center"===t?r=e.width/2:"right"===t&&(r=e.width),r}function Mh(e){return[e.horizontal,e.vertical].map(e=>"number"==typeof e?`${e}px`:e).join(" ")}function Ah(e){return"function"==typeof e?e():e}const Ph=Vi(kh,{name:"MuiPopover",slot:"Root",overridesResolver:(e,t)=>t.root})({}),Nh=Vi(sa,{name:"MuiPopover",slot:"Paper",overridesResolver:(e,t)=>t.paper})({position:"absolute",overflowY:"auto",overflowX:"hidden",minWidth:16,minHeight:16,maxWidth:"calc(100% - 32px)",maxHeight:"calc(100% - 32px)",outline:0}),jh=o.forwardRef(function(t,r){var n,i,l;const c=Yi({props:t,name:"MuiPopover"}),{action:u,anchorEl:p,anchorOrigin:d={vertical:"top",horizontal:"left"},anchorPosition:f,anchorReference:h="anchorEl",children:m,className:g,container:v,elevation:y=8,marginThreshold:b=16,open:w,PaperProps:x={},slots:_,slotProps:S,transformOrigin:k={vertical:"top",horizontal:"left"},TransitionComponent:C=Qf,transitionDuration:O="auto",TransitionProps:{onEntering:E}={},disableScrollLock:T=!1}=c,R=s(c.TransitionProps,Oh),I=s(c,Eh),M=null!=(n=null==S?void 0:S.paper)?n:x,A=o.useRef(),P=Fa(A,M.ref),N=a({},c,{anchorOrigin:d,anchorReference:h,elevation:y,marginThreshold:b,externalPaperSlotProps:M,transformOrigin:k,TransitionComponent:C,transitionDuration:O,TransitionProps:R}),j=(e=>{const{classes:t}=e;return U({root:["root"],paper:["paper"]},Ch,t)})(N),L=o.useCallback(()=>{if("anchorPosition"===h)return true&&(f||console.error('MUI: You need to provide a `anchorPosition` prop when using <Popover anchorReference="anchorPosition" />.')),f;const e=Ah(p),t=e&&1===e.nodeType?e:xf(A.current).body,r=t.getBoundingClientRect();if(true){const e=t.getBoundingClientRect(); true&&0===e.top&&0===e.left&&0===e.right&&0===e.bottom&&console.warn(["MUI: The `anchorEl` prop provided to the component is invalid.","The anchor element should be part of the document layout.","Make sure the element is present in the document or that it's not display none."].join("\n"))}return{top:r.top+Rh(r,d.vertical),left:r.left+Ih(r,d.horizontal)}},[p,d.horizontal,d.vertical,f,h]),D=o.useCallback(e=>({vertical:Rh(e,k.vertical),horizontal:Ih(e,k.horizontal)}),[k.horizontal,k.vertical]),F=o.useCallback(e=>{const t={width:e.offsetWidth,height:e.offsetHeight},r=D(t);if("none"===h)return{top:null,left:null,transformOrigin:Mh(r)};const n=L();let o=n.top-r.vertical,i=n.left-r.horizontal;const s=o+t.height,a=i+t.width,l=_f(Ah(p)),c=l.innerHeight-b,u=l.innerWidth-b;if(null!==b&&o<b){const e=o-b;o-=e,r.vertical+=e}else if(null!==b&&s>c){const e=s-c;o-=e,r.vertical+=e}if( true&&t.height>c&&t.height&&c&&console.error(["MUI: The popover component is too tall.",`Some part of it can not be seen on the screen (${t.height-c}px).`,"Please consider adding a `max-height` to improve the user-experience."].join("\n")),null!==b&&i<b){const e=i-b;i-=e,r.horizontal+=e}else if(a>u){const e=a-u;i-=e,r.horizontal+=e}return{top:`${Math.round(o)}px`,left:`${Math.round(i)}px`,transformOrigin:Mh(r)}},[p,h,L,D,b]),[$,B]=o.useState(w),z=o.useCallback(()=>{const e=A.current;if(!e)return;const t=F(e);null!==t.top&&(e.style.top=t.top),null!==t.left&&(e.style.left=t.left),e.style.transformOrigin=t.transformOrigin,B(!0)},[F]);o.useEffect(()=>(T&&window.addEventListener("scroll",z),()=>window.removeEventListener("scroll",z)),[p,T,z]),o.useEffect(()=>{w&&z()}),o.useImperativeHandle(u,()=>w?{updatePosition:()=>{z()}}:null,[w,z]),o.useEffect(()=>{if(!w)return;const e=bf(()=>{z()}),t=_f(p);return t.addEventListener("resize",e),()=>{e.clear(),t.removeEventListener("resize",e)}},[p,w,z]);let q=O;"auto"!==O||C.muiSupportAuto||(q=void 0);const W=v||(p?xf(Ah(p)).body:void 0),H=null!=(i=null==_?void 0:_.root)?i:Ph,G=null!=(l=null==_?void 0:_.paper)?l:Nh,K=Af({elementType:G,externalSlotProps:a({},M,{style:$?M.style:a({},M.style,{opacity:0})}),additionalProps:{elevation:y,ref:P},ownerState:N,className:V(j.paper,null==M?void 0:M.className)}),Y=Af({elementType:H,externalSlotProps:(null==S?void 0:S.root)||{},externalForwardedProps:I,additionalProps:{ref:r,slotProps:{backdrop:{invisible:!0}},container:W,open:w},ownerState:N,className:V(j.root,g)}),{slotProps:Z}=Y,X=s(Y,Th);return e.jsx(H,a({},X,!sf(H)&&{slotProps:Z,disableScrollLock:T},{children:e.jsx(C,a({appear:!0,in:w,onEntering:(e,t)=>{E&&E(e,t),z()},onExited:()=>{B(!1)},timeout:q},R,{children:e.jsx(G,a({},K,{children:m}))}))}))}); true&&(jh.propTypes={action:ja,anchorEl:rs(B.oneOfType([vf,B.func]),e=>{if(e.open&&(!e.anchorReference||"anchorEl"===e.anchorReference)){const t=Ah(e.anchorEl);if(!t||1!==t.nodeType)return new Error(["MUI: The `anchorEl` prop provided to the component is invalid.",`It should be an Element or PopoverVirtualElement instance but it's \`${t}\` instead.`].join("\n"));{const e=t.getBoundingClientRect();if( true&&0===e.top&&0===e.left&&0===e.right&&0===e.bottom)return new Error(["MUI: The `anchorEl` prop provided to the component is invalid.","The anchor element should be part of the document layout.","Make sure the element is present in the document or that it's not display none."].join("\n"))}}return null}),anchorOrigin:B.shape({horizontal:B.oneOfType([B.oneOf(["center","left","right"]),B.number]).isRequired,vertical:B.oneOfType([B.oneOf(["bottom","center","top"]),B.number]).isRequired}),anchorPosition:B.shape({left:B.number.isRequired,top:B.number.isRequired}),anchorReference:B.oneOf(["anchorEl","anchorPosition","none"]),children:B.node,classes:B.object,className:B.string,container:B.oneOfType([vf,B.func]),disableScrollLock:B.bool,elevation:ts,marginThreshold:B.number,onClose:B.func,open:B.bool.isRequired,PaperProps:B.shape({component:La}),slotProps:B.shape({paper:B.oneOfType([B.func,B.object]),root:B.oneOfType([B.func,B.object])}),slots:B.shape({paper:B.elementType,root:B.elementType}),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),transformOrigin:B.shape({horizontal:B.oneOfType([B.oneOf(["center","left","right"]),B.number]).isRequired,vertical:B.oneOfType([B.oneOf(["bottom","center","top"]),B.number]).isRequired}),TransitionComponent:B.elementType,transitionDuration:B.oneOfType([B.oneOf(["auto"]),B.number,B.shape({appear:B.number,enter:B.number,exit:B.number})]),TransitionProps:B.object});const Lh=jh;function Dh(e){return Mo("MuiMenu",e)}ta("MuiMenu",["root","paper","list"]);const Fh=["onEntering"],$h=["autoFocus","children","className","disableAutoFocusItem","MenuListProps","onClose","open","PaperProps","PopoverClasses","transitionDuration","TransitionProps","variant","slots","slotProps"],Bh={vertical:"top",horizontal:"right"},zh={vertical:"top",horizontal:"left"},Vh=Vi(Lh,{shouldForwardProp:e=>zi(e)||"classes"===e,name:"MuiMenu",slot:"Root",overridesResolver:(e,t)=>t.root})({}),Uh=Vi(Nh,{name:"MuiMenu",slot:"Paper",overridesResolver:(e,t)=>t.paper})({maxHeight:"calc(100% - 96px)",WebkitOverflowScrolling:"touch"}),qh=Vi(Hf,{name:"MuiMenu",slot:"List",overridesResolver:(e,t)=>t.list})({outline:0}),Wh=o.forwardRef(function(t,r){var n,i;const l=Yi({props:t,name:"MuiMenu"}),{autoFocus:c=!0,children:u,className:p,disableAutoFocusItem:d=!1,MenuListProps:f={},onClose:h,open:m,PaperProps:g={},PopoverClasses:v,transitionDuration:y="auto",TransitionProps:{onEntering:b}={},variant:w="selectedMenu",slots:x={},slotProps:_={}}=l,S=s(l.TransitionProps,Fh),k=s(l,$h),C=Vs(),O=a({},l,{autoFocus:c,disableAutoFocusItem:d,MenuListProps:f,onEntering:b,PaperProps:g,transitionDuration:y,TransitionProps:S,variant:w}),E=(e=>{const{classes:t}=e;return U({root:["root"],paper:["paper"],list:["list"]},Dh,t)})(O),T=c&&!d&&m,R=o.useRef(null);let I=-1;o.Children.map(u,(e,t)=>{o.isValidElement(e)&&( true&&of.isFragment(e)&&console.error(["MUI: The Menu component doesn't accept a Fragment as a child.","Consider providing an array instead."].join("\n")),e.props.disabled||("selectedMenu"===w&&e.props.selected||-1===I)&&(I=t))});const M=null!=(n=x.paper)?n:Uh,A=null!=(i=_.paper)?i:g,P=Af({elementType:x.root,externalSlotProps:_.root,ownerState:O,className:[E.root,p]}),N=Af({elementType:M,externalSlotProps:A,ownerState:O,className:E.paper});return e.jsx(Vh,a({onClose:h,anchorOrigin:{vertical:"bottom",horizontal:C?"right":"left"},transformOrigin:C?Bh:zh,slots:{paper:M,root:x.root},slotProps:{root:P,paper:N},open:m,ref:r,transitionDuration:y,TransitionProps:a({onEntering:(e,t)=>{R.current&&R.current.adjustStyleForScrollbar(e,{direction:C?"rtl":"ltr"}),b&&b(e,t)}},S),ownerState:O},k,{classes:v,children:e.jsx(qh,a({onKeyDown:e=>{"Tab"===e.key&&(e.preventDefault(),h&&h(e,"tabKeyDown"))},actions:R,autoFocus:c&&(-1===I||d),autoFocusItem:T,variant:w},f,{className:V(E.list,f.className),children:u}))}))}); true&&(Wh.propTypes={anchorEl:B.oneOfType([vf,B.func]),autoFocus:B.bool,children:B.node,classes:B.object,className:B.string,disableAutoFocusItem:B.bool,MenuListProps:B.object,onClose:B.func,open:B.bool.isRequired,PaperProps:B.object,PopoverClasses:B.object,slotProps:B.shape({paper:B.oneOfType([B.func,B.object]),root:B.oneOfType([B.func,B.object])}),slots:B.shape({paper:B.elementType,root:B.elementType}),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),transitionDuration:B.oneOfType([B.oneOf(["auto"]),B.number,B.shape({appear:B.number,enter:B.number,exit:B.number})]),TransitionProps:B.object,variant:B.oneOf(["menu","selectedMenu"])});const Hh=Wh;var Gh=t.forwardRef((e,r)=>{const{direction:n}=ea(),o={...e};return"rtl"===n&&(o.anchorOrigin?.horizontal&&(o.anchorOrigin={...o.anchorOrigin,horizontal:"left"===o.anchorOrigin.horizontal?"right":"left"}),o.transformOrigin?.horizontal&&(o.transformOrigin={...o.transformOrigin,horizontal:"left"===o.transformOrigin.horizontal?"right":"left"})),t.createElement(Lh,{...o,ref:r})});const Kh={elevation:6},Yh=t.forwardRef((e,r)=>t.createElement(Hh,{as:Gh,...Kh,...e,ref:r}));Yh.defaultProps=Kh;var Zh=Yh;function Xh(e){return Mo("MuiListItemIcon",e)}const Jh=ta("MuiListItemIcon",["root","alignItemsFlexStart"]),Qh=["className"],em=Vi("div",{name:"MuiListItemIcon",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,"flex-start"===r.alignItems&&t.alignItemsFlexStart]}})(({theme:e,ownerState:t})=>a({minWidth:56,color:(e.vars||e).palette.action.active,flexShrink:0,display:"inline-flex"},"flex-start"===t.alignItems&&{marginTop:8})),tm=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiListItemIcon"}),{className:i}=n,l=s(n,Qh),c=a({},n,{alignItems:o.useContext(Nf).alignItems}),u=(e=>{const{alignItems:t,classes:r}=e;return U({root:["root","flex-start"===t&&"alignItemsFlexStart"]},Xh,r)})(c);return e.jsx(em,a({className:V(u.root,i),ownerState:c,ref:r},l))}); true&&(tm.propTypes={children:B.node,classes:B.object,className:B.string,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const rm=tm;function nm(e){return Mo("MuiListItemText",e)}const om=ta("MuiListItemText",["root","multiline","dense","inset","primary","secondary"]),im=["children","className","disableTypography","inset","primary","primaryTypographyProps","secondary","secondaryTypographyProps"],sm=Vi("div",{name:"MuiListItemText",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[{[`& .${om.primary}`]:t.primary},{[`& .${om.secondary}`]:t.secondary},t.root,r.inset&&t.inset,r.primary&&r.secondary&&t.multiline,r.dense&&t.dense]}})(({ownerState:e})=>a({flex:"1 1 auto",minWidth:0,marginTop:4,marginBottom:4},e.primary&&e.secondary&&{marginTop:6,marginBottom:6},e.inset&&{paddingLeft:56})),am=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiListItemText"}),{children:i,className:l,disableTypography:c=!1,inset:u=!1,primary:p,primaryTypographyProps:d,secondary:f,secondaryTypographyProps:h}=n,m=s(n,im),{dense:g}=o.useContext(Nf);let v=null!=p?p:i,y=f;const b=a({},n,{disableTypography:c,inset:u,primary:!!v,secondary:!!y,dense:g}),w=(e=>{const{classes:t,inset:r,primary:n,secondary:o,dense:i}=e;return U({root:["root",r&&"inset",i&&"dense",n&&o&&"multiline"],primary:["primary"],secondary:["secondary"]},nm,t)})(b);return null==v||v.type===Ma||c||(v=e.jsx(Ma,a({variant:g?"body2":"body1",className:w.primary,component:null!=d&&d.variant?void 0:"span",display:"block"},d,{children:v}))),null==y||y.type===Ma||c||(y=e.jsx(Ma,a({variant:"body2",className:w.secondary,color:"text.secondary",display:"block"},h,{children:y}))),e.jsxs(sm,a({className:V(w.root,l),ownerState:b,ref:r},m,{children:[v,y]}))}); true&&(am.propTypes={children:B.node,classes:B.object,className:B.string,disableTypography:B.bool,inset:B.bool,primary:B.node,primaryTypographyProps:B.object,secondary:B.node,secondaryTypographyProps:B.object,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const lm=am;function cm(e){return Mo("MuiMenuItem",e)}const um=ta("MuiMenuItem",["root","focusVisible","dense","disabled","divider","gutters","selected"]),pm=["autoFocus","component","dense","divider","disableGutters","focusVisibleClassName","role","tabIndex","className"],dm=Vi(Dl,{shouldForwardProp:e=>zi(e)||"classes"===e,name:"MuiMenuItem",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,r.dense&&t.dense,r.divider&&t.divider,!r.disableGutters&&t.gutters]}})(({theme:e,ownerState:t})=>a({},e.typography.body1,{display:"flex",justifyContent:"flex-start",alignItems:"center",position:"relative",textDecoration:"none",minHeight:48,paddingTop:6,paddingBottom:6,boxSizing:"border-box",whiteSpace:"nowrap"},!t.disableGutters&&{paddingLeft:16,paddingRight:16},t.divider&&{borderBottom:`1px solid ${(e.vars||e).palette.divider}`,backgroundClip:"padding-box"},{"&:hover":{textDecoration:"none",backgroundColor:(e.vars||e).palette.action.hover,"@media (hover: none)":{backgroundColor:"transparent"}},[`&.${um.selected}`]:{backgroundColor:e.vars?`rgba(${e.vars.palette.primary.mainChannel} / ${e.vars.palette.action.selectedOpacity})`:Fo.alpha(e.palette.primary.main,e.palette.action.selectedOpacity),[`&.${um.focusVisible}`]:{backgroundColor:e.vars?`rgba(${e.vars.palette.primary.mainChannel} / calc(${e.vars.palette.action.selectedOpacity} + ${e.vars.palette.action.focusOpacity}))`:Fo.alpha(e.palette.primary.main,e.palette.action.selectedOpacity+e.palette.action.focusOpacity)}},[`&.${um.selected}:hover`]:{backgroundColor:e.vars?`rgba(${e.vars.palette.primary.mainChannel} / calc(${e.vars.palette.action.selectedOpacity} + ${e.vars.palette.action.hoverOpacity}))`:Fo.alpha(e.palette.primary.main,e.palette.action.selectedOpacity+e.palette.action.hoverOpacity),"@media (hover: none)":{backgroundColor:e.vars?`rgba(${e.vars.palette.primary.mainChannel} / ${e.vars.palette.action.selectedOpacity})`:Fo.alpha(e.palette.primary.main,e.palette.action.selectedOpacity)}},[`&.${um.focusVisible}`]:{backgroundColor:(e.vars||e).palette.action.focus},[`&.${um.disabled}`]:{opacity:(e.vars||e).palette.action.disabledOpacity},[`& + .${Ru.root}`]:{marginTop:e.spacing(1),marginBottom:e.spacing(1)},[`& + .${Ru.inset}`]:{marginLeft:52},[`& .${om.root}`]:{marginTop:0,marginBottom:0},[`& .${om.inset}`]:{paddingLeft:36},[`& .${Jh.root}`]:{minWidth:36}},!t.dense&&{[e.breakpoints.up("sm")]:{minHeight:"auto"}},t.dense&&a({minHeight:32,paddingTop:4,paddingBottom:4},e.typography.body2,{[`& .${Jh.root} svg`]:{fontSize:"1.25rem"}}))),fm=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiMenuItem"}),{autoFocus:i=!1,component:l="li",dense:c=!1,divider:u=!1,disableGutters:p=!1,focusVisibleClassName:d,role:f="menuitem",tabIndex:h,className:m}=n,g=s(n,pm),v=o.useContext(Nf),y=o.useMemo(()=>({dense:c||v.dense||!1,disableGutters:p}),[v.dense,c,p]),b=o.useRef(null);$a(()=>{i&&(b.current?b.current.focus(): true&&console.error("MUI: Unable to set focus to a MenuItem whose component has not been rendered."))},[i]);const w=a({},n,{dense:y.dense,divider:u,disableGutters:p}),x=(e=>{const{disabled:t,dense:r,divider:n,disableGutters:o,selected:i,classes:s}=e;return a({},s,U({root:["root",r&&"dense",t&&"disabled",!o&&"gutters",n&&"divider",i&&"selected"]},cm,s))})(n),_=Fa(b,r);let S;return n.disabled||(S=void 0!==h?h:-1),e.jsx(Nf.Provider,{value:y,children:e.jsx(dm,a({ref:_,role:f,tabIndex:S,component:l,focusVisibleClassName:V(x.focusVisible,d),className:V(x.root,m)},g,{ownerState:w,classes:x}))})}); true&&(fm.propTypes={autoFocus:B.bool,children:B.node,classes:B.object,className:B.string,component:B.elementType,dense:B.bool,disabled:B.bool,disableGutters:B.bool,divider:B.bool,focusVisibleClassName:B.string,role:B.string,selected:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),tabIndex:B.number});const hm=fm;var mm=t.forwardRef((e,r)=>t.createElement(hm,{...e,ref:r})),gm=t.forwardRef((e,r)=>t.createElement(rm,{...e,ref:r})),vm=t.forwardRef((e,r)=>t.createElement(lm,{...e,ref:r})),ym=o.forwardRef((e,t)=>o.createElement(Cu,{viewBox:"0 0 24 24",...e,ref:t},o.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M14 4C14 3.58579 14.3358 3.25 14.75 3.25H19.75C20.1642 3.25 20.5 3.58579 20.5 4V9C20.5 9.41421 20.1642 9.75 19.75 9.75C19.3358 9.75 19 9.41421 19 9V5.81066L10.2803 14.5303C9.98744 14.8232 9.51256 14.8232 9.21967 14.5303C8.92678 14.2374 8.92678 13.7626 9.21967 13.4697L17.9393 4.75H14.75C14.3358 4.75 14 4.41421 14 4ZM3.80546 7.05546C4.32118 6.53973 5.02065 6.25 5.75 6.25H10.75C11.1642 6.25 11.5 6.58579 11.5 7C11.5 7.41421 11.1642 7.75 10.75 7.75H5.75C5.41848 7.75 5.10054 7.8817 4.86612 8.11612C4.6317 8.35054 4.5 8.66848 4.5 9V18C4.5 18.3315 4.6317 18.6495 4.86612 18.8839C5.10054 19.1183 5.41848 19.25 5.75 19.25H14.75C15.0815 19.25 15.3995 19.1183 15.6339 18.8839C15.8683 18.6495 16 18.3315 16 18V13C16 12.5858 16.3358 12.25 16.75 12.25C17.1642 12.25 17.5 12.5858 17.5 13V18C17.5 18.7293 17.2103 19.4288 16.6945 19.9445C16.1788 20.4603 15.4793 20.75 14.75 20.75H5.75C5.02065 20.75 4.32118 20.4603 3.80546 19.9445C3.28973 19.4288 3 18.7293 3 18V9C3 8.27065 3.28973 7.57118 3.80546 7.05546Z"})));const bm=fd.createInstance();var wm;bm.use((wm=(e,t)=>__webpack_require__("../node_modules/@elementor/elementor-one-assets/locales lazy recursive ^\\.\\/.*\\/.*\\.json$")(`./${e}/${t}.json`),{type:"backend",init:function(e,t,r){},read:function(e,t,r){if(wm.length<3)try{var n=wm(e,t);n&&"function"==typeof n.then?n.then(function(e){return r(null,e&&e.default||e)}).catch(r):r(null,n)}catch(e){r(e)}else wm(e,t)}})).use(Cd).init({lng:"en",fallbackLng:"en",ns:"common",defaultNS:"common",interpolation:{escapeValue:!1},react:{useSuspense:!0}});var xm=class{subscribe(e){return this.listeners.add(e),this.onSubscribe(),()=>{this.listeners.delete(e),this.onUnsubscribe()}}hasListeners(){return this.listeners.size>0}onSubscribe(){}onUnsubscribe(){}constructor(){this.listeners=new Set,this.subscribe=this.subscribe.bind(this)}};function _m(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var Sm,km,Cm=0;function Om(e){return"__private_"+Cm+++"_"+e}var Em={setTimeout:(e,t)=>setTimeout(e,t),clearTimeout:e=>clearTimeout(e),setInterval:(e,t)=>setInterval(e,t),clearInterval:e=>clearInterval(e)},Tm=new(Sm=Om("_provider"),km=Om("_providerCalled"),class{setTimeoutProvider(e){ true&&_m(this,km)[km]&&e!==_m(this,Sm)[Sm]&&console.error("[timeoutManager]: Switching provider after calls to previous provider might result in unexpected behavior.",{previous:_m(this,Sm)[Sm],provider:e}),_m(this,Sm)[Sm]=e, true&&(_m(this,km)[km]=!1)}setTimeout(e,t){return true&&(_m(this,km)[km]=!0),_m(this,Sm)[Sm].setTimeout(e,t)}clearTimeout(e){_m(this,Sm)[Sm].clearTimeout(e)}setInterval(e,t){return true&&(_m(this,km)[km]=!0),_m(this,Sm)[Sm].setInterval(e,t)}clearInterval(e){_m(this,Sm)[Sm].clearInterval(e)}constructor(){Object.defineProperty(this,Sm,{writable:!0,value:void 0}),Object.defineProperty(this,km,{writable:!0,value:void 0}),_m(this,Sm)[Sm]=Em,_m(this,km)[km]=!1}}),Rm="undefined"==typeof window||"Deno"in globalThis;function Im(){}function Mm(e){return"number"==typeof e&&e>=0&&e!==1/0}function Am(e,t){return Math.max(e+(t||0)-Date.now(),0)}function Pm(e,t){return"function"==typeof e?e(t):e}function Nm(e,t){return"function"==typeof e?e(t):e}function jm(e,t){const{type:r="all",exact:n,fetchStatus:o,predicate:i,queryKey:s,stale:a}=e;if(s)if(n){if(t.queryHash!==Dm(s,t.options))return!1}else if(!$m(t.queryKey,s))return!1;if("all"!==r){const e=t.isActive();if("active"===r&&!e)return!1;if("inactive"===r&&e)return!1}return!("boolean"==typeof a&&t.isStale()!==a||o&&o!==t.state.fetchStatus||i&&!i(t))}function Lm(e,t){const{exact:r,status:n,predicate:o,mutationKey:i}=e;if(i){if(!t.options.mutationKey)return!1;if(r){if(Fm(t.options.mutationKey)!==Fm(i))return!1}else if(!$m(t.options.mutationKey,i))return!1}return!(n&&t.state.status!==n||o&&!o(t))}function Dm(e,t){return(t?.queryKeyHashFn||Fm)(e)}function Fm(e){return JSON.stringify(e,(e,t)=>qm(t)?Object.keys(t).sort().reduce((e,r)=>(e[r]=t[r],e),{}):t)}function $m(e,t){return e===t||typeof e==typeof t&&!(!e||!t||"object"!=typeof e||"object"!=typeof t)&&Object.keys(t).every(r=>$m(e[r],t[r]))}var Bm=Object.prototype.hasOwnProperty;function zm(e,t,r=0){if(e===t)return e;if(r>500)return t;const n=Um(e)&&Um(t);if(!(n||qm(e)&&qm(t)))return t;const o=(n?e:Object.keys(e)).length,i=n?t:Object.keys(t),s=i.length,a=n?new Array(s):{};let l=0;for(let c=0;c<s;c++){const s=n?c:i[c],u=e[s],p=t[s];if(u===p){a[s]=u,(n?c<o:Bm.call(e,s))&&l++;continue}if(null===u||null===p||"object"!=typeof u||"object"!=typeof p){a[s]=p;continue}const d=zm(u,p,r+1);a[s]=d,d===u&&l++}return o===s&&l===o?e:a}function Vm(e,t){if(!t||Object.keys(e).length!==Object.keys(t).length)return!1;for(const r in e)if(e[r]!==t[r])return!1;return!0}function Um(e){return Array.isArray(e)&&e.length===Object.keys(e).length}function qm(e){if(!Wm(e))return!1;const t=e.constructor;if(void 0===t)return!0;const r=t.prototype;return!!Wm(r)&&!!r.hasOwnProperty("isPrototypeOf")&&Object.getPrototypeOf(e)===Object.prototype}function Wm(e){return"[object Object]"===Object.prototype.toString.call(e)}function Hm(e,t,r){if("function"==typeof r.structuralSharing)return r.structuralSharing(e,t);if(!1!==r.structuralSharing){if(true)try{return zm(e,t)}catch(e){throw console.error(`Structural sharing requires data to be JSON serializable. To fix this, turn off structuralSharing or return JSON-serializable data from your queryFn. [${r.queryHash}]: ${e}`),e}// removed by dead control flow
}return t}function Gm(e,t,r=0){const n=[...e,t];return r&&n.length>r?n.slice(1):n}function Km(e,t,r=0){const n=[t,...e];return r&&n.length>r?n.slice(0,-1):n}var Ym=Symbol();function Zm(e,t){return true&&e.queryFn===Ym&&console.error(`Attempted to invoke queryFn when set to skipToken. This is likely a configuration error. Query hash: '${e.queryHash}'`),!e.queryFn&&t?.initialPromise?()=>t.initialPromise:e.queryFn&&e.queryFn!==Ym?e.queryFn:()=>Promise.reject(new Error(`Missing queryFn: '${e.queryHash}'`))}function Xm(e,t){return"function"==typeof e?e(...t):!!e}function Jm(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var Qm,eg,tg,rg=0;function ng(e){return"__private_"+rg+++"_"+e}var og=new(Qm=ng("_focused"),eg=ng("_cleanup"),tg=ng("_setup"),class extends xm{onSubscribe(){Jm(this,eg)[eg]||this.setEventListener(Jm(this,tg)[tg])}onUnsubscribe(){this.hasListeners()||(null==Jm(this,eg)[eg]||Jm(this,eg)[eg].call(this),Jm(this,eg)[eg]=void 0)}setEventListener(e){Jm(this,tg)[tg]=e,null==Jm(this,eg)[eg]||Jm(this,eg)[eg].call(this),Jm(this,eg)[eg]=e(e=>{"boolean"==typeof e?this.setFocused(e):this.onFocus()})}setFocused(e){Jm(this,Qm)[Qm]!==e&&(Jm(this,Qm)[Qm]=e,this.onFocus())}onFocus(){const e=this.isFocused();this.listeners.forEach(t=>{t(e)})}isFocused(){return"boolean"==typeof Jm(this,Qm)[Qm]?Jm(this,Qm)[Qm]:"hidden"!==globalThis.document?.visibilityState}constructor(){super(),Object.defineProperty(this,Qm,{writable:!0,value:void 0}),Object.defineProperty(this,eg,{writable:!0,value:void 0}),Object.defineProperty(this,tg,{writable:!0,value:void 0}),Jm(this,tg)[tg]=e=>{if(!Rm&&window.addEventListener){const t=()=>e();return window.addEventListener("visibilitychange",t,!1),()=>{window.removeEventListener("visibilitychange",t)}}}}});function ig(){let e,t;const r=new Promise((r,n)=>{e=r,t=n});function n(e){Object.assign(r,e),delete r.resolve,delete r.reject}return r.status="pending",r.catch(()=>{}),r.resolve=t=>{n({status:"fulfilled",value:t}),e(t)},r.reject=e=>{n({status:"rejected",reason:e}),t(e)},r}var sg=function(e){setTimeout(e,0)},ag=function(){let e=[],t=0,r=e=>{e()},n=e=>{e()},o=sg;const i=n=>{t?e.push(n):o(()=>{r(n)})};return{batch:i=>{let s;t++;try{s=i()}finally{t--,t||(()=>{const t=e;e=[],t.length&&o(()=>{n(()=>{t.forEach(e=>{r(e)})})})})()}return s},batchCalls:e=>(...t)=>{i(()=>{e(...t)})},schedule:i,setNotifyFunction:e=>{r=e},setBatchNotifyFunction:e=>{n=e},setScheduler:e=>{o=e}}}();function lg(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var cg,ug,pg,dg=0;function fg(e){return"__private_"+dg+++"_"+e}var hg=new(cg=fg("_online"),ug=fg("_cleanup"),pg=fg("_setup"),class extends xm{onSubscribe(){lg(this,ug)[ug]||this.setEventListener(lg(this,pg)[pg])}onUnsubscribe(){this.hasListeners()||(null==lg(this,ug)[ug]||lg(this,ug)[ug].call(this),lg(this,ug)[ug]=void 0)}setEventListener(e){lg(this,pg)[pg]=e,null==lg(this,ug)[ug]||lg(this,ug)[ug].call(this),lg(this,ug)[ug]=e(this.setOnline.bind(this))}setOnline(e){lg(this,cg)[cg]!==e&&(lg(this,cg)[cg]=e,this.listeners.forEach(t=>{t(e)}))}isOnline(){return lg(this,cg)[cg]}constructor(){super(),Object.defineProperty(this,cg,{writable:!0,value:void 0}),Object.defineProperty(this,ug,{writable:!0,value:void 0}),Object.defineProperty(this,pg,{writable:!0,value:void 0}),lg(this,cg)[cg]=!0,lg(this,pg)[pg]=e=>{if(!Rm&&window.addEventListener){const t=()=>e(!0),r=()=>e(!1);return window.addEventListener("online",t,!1),window.addEventListener("offline",r,!1),()=>{window.removeEventListener("online",t),window.removeEventListener("offline",r)}}}}});function mg(e){return Math.min(1e3*2**e,3e4)}function gg(e){return"online"!==(e??"online")||hg.isOnline()}var vg=class extends Error{constructor(e){super("CancelledError"),this.revert=e?.revert,this.silent=e?.silent}};function yg(e){let t,r=!1,n=0;const o=ig(),i=()=>"pending"!==o.status,s=()=>og.isFocused()&&("always"===e.networkMode||hg.isOnline())&&e.canRun(),a=()=>gg(e.networkMode)&&e.canRun(),l=e=>{i()||(t?.(),o.resolve(e))},c=e=>{i()||(t?.(),o.reject(e))},u=()=>new Promise(r=>{t=e=>{(i()||s())&&r(e)},e.onPause?.()}).then(()=>{t=void 0,i()||e.onContinue?.()}),p=()=>{if(i())return;let t;const o=0===n?e.initialPromise:void 0;try{t=o??e.fn()}catch(e){t=Promise.reject(e)}Promise.resolve(t).then(l).catch(t=>{if(i())return;const o=e.retry??(Rm?0:3),a=e.retryDelay??mg,l="function"==typeof a?a(n,t):a,d=!0===o||"number"==typeof o&&n<o||"function"==typeof o&&o(n,t);var f;!r&&d?(n++,e.onFail?.(n,t),(f=l,new Promise(e=>{Tm.setTimeout(e,f)})).then(()=>s()?void 0:u()).then(()=>{r?c(t):p()})):c(t)})};return{promise:o,status:()=>o.status,cancel:t=>{if(!i()){const r=new vg(t);c(r),e.onCancel?.(r)}},continue:()=>(t?.(),o),cancelRetry:()=>{r=!0},continueRetry:()=>{r=!1},canStart:a,start:()=>(a()?p():u().then(p),o)}}function bg(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var wg,xg=0;function _g(e){return"__private_"+xg+++"_"+e}var Sg=(wg=_g("_gcTimeout"),class{destroy(){this.clearGcTimeout()}scheduleGc(){this.clearGcTimeout(),Mm(this.gcTime)&&(bg(this,wg)[wg]=Tm.setTimeout(()=>{this.optionalRemove()},this.gcTime))}updateGcTime(e){this.gcTime=Math.max(this.gcTime||0,e??(Rm?1/0:3e5))}clearGcTimeout(){bg(this,wg)[wg]&&(Tm.clearTimeout(bg(this,wg)[wg]),bg(this,wg)[wg]=void 0)}constructor(){Object.defineProperty(this,wg,{writable:!0,value:void 0})}});function kg(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var Cg,Og,Eg,Tg,Rg,Ig,Mg,Ag,Pg,Ng=0;function jg(e){return"__private_"+Ng+++"_"+e}var Lg=(Cg=jg("_initialState"),Og=jg("_revertState"),Eg=jg("_cache"),Tg=jg("_client"),Rg=jg("_retryer"),Ig=jg("_defaultOptions"),Mg=jg("_abortSignalConsumed"),Ag=jg("_dispatch"),Pg=class extends Sg{get meta(){return this.options.meta}get promise(){return kg(this,Rg)[Rg]?.promise}setOptions(e){if(this.options={...kg(this,Ig)[Ig],...e},this.updateGcTime(this.options.gcTime),this.state&&void 0===this.state.data){const e=$g(this.options);void 0!==e.data&&(this.setState(Fg(e.data,e.dataUpdatedAt)),kg(this,Cg)[Cg]=e)}}optionalRemove(){this.observers.length||"idle"!==this.state.fetchStatus||kg(this,Eg)[Eg].remove(this)}setData(e,t){const r=Hm(this.state.data,e,this.options);return kg(this,Ag)[Ag]({data:r,type:"success",dataUpdatedAt:t?.updatedAt,manual:t?.manual}),r}setState(e,t){kg(this,Ag)[Ag]({type:"setState",state:e,setStateOptions:t})}cancel(e){const t=kg(this,Rg)[Rg]?.promise;return kg(this,Rg)[Rg]?.cancel(e),t?t.then(Im).catch(Im):Promise.resolve()}destroy(){super.destroy(),this.cancel({silent:!0})}reset(){this.destroy(),this.setState(kg(this,Cg)[Cg])}isActive(){return this.observers.some(e=>!1!==Nm(e.options.enabled,this))}isDisabled(){return this.getObserversCount()>0?!this.isActive():this.options.queryFn===Ym||this.state.dataUpdateCount+this.state.errorUpdateCount===0}isStatic(){return this.getObserversCount()>0&&this.observers.some(e=>"static"===Pm(e.options.staleTime,this))}isStale(){return this.getObserversCount()>0?this.observers.some(e=>e.getCurrentResult().isStale):void 0===this.state.data||this.state.isInvalidated}isStaleByTime(e=0){return void 0===this.state.data||"static"!==e&&(!!this.state.isInvalidated||!Am(this.state.dataUpdatedAt,e))}onFocus(){const e=this.observers.find(e=>e.shouldFetchOnWindowFocus());e?.refetch({cancelRefetch:!1}),kg(this,Rg)[Rg]?.continue()}onOnline(){const e=this.observers.find(e=>e.shouldFetchOnReconnect());e?.refetch({cancelRefetch:!1}),kg(this,Rg)[Rg]?.continue()}addObserver(e){this.observers.includes(e)||(this.observers.push(e),this.clearGcTimeout(),kg(this,Eg)[Eg].notify({type:"observerAdded",query:this,observer:e}))}removeObserver(e){this.observers.includes(e)&&(this.observers=this.observers.filter(t=>t!==e),this.observers.length||(kg(this,Rg)[Rg]&&(kg(this,Mg)[Mg]?kg(this,Rg)[Rg].cancel({revert:!0}):kg(this,Rg)[Rg].cancelRetry()),this.scheduleGc()),kg(this,Eg)[Eg].notify({type:"observerRemoved",query:this,observer:e}))}getObserversCount(){return this.observers.length}invalidate(){this.state.isInvalidated||kg(this,Ag)[Ag]({type:"invalidate"})}async fetch(e,t){if("idle"!==this.state.fetchStatus&&"rejected"!==kg(this,Rg)[Rg]?.status())if(void 0!==this.state.data&&t?.cancelRefetch)this.cancel({silent:!0});else if(kg(this,Rg)[Rg])return kg(this,Rg)[Rg].continueRetry(),kg(this,Rg)[Rg].promise;if(e&&this.setOptions(e),!this.options.queryFn){const e=this.observers.find(e=>e.options.queryFn);e&&this.setOptions(e.options)} true&&(Array.isArray(this.options.queryKey)||console.error("As of v4, queryKey needs to be an Array. If you are using a string like 'repoData', please change it to an Array, e.g. ['repoData']"));const r=new AbortController,n=e=>{Object.defineProperty(e,"signal",{enumerable:!0,get:()=>(kg(this,Mg)[Mg]=!0,r.signal)})},o=()=>{const e=Zm(this.options,t),r=(()=>{const e={client:kg(this,Tg)[Tg],queryKey:this.queryKey,meta:this.meta};return n(e),e})();return kg(this,Mg)[Mg]=!1,this.options.persister?this.options.persister(e,r,this):e(r)},i=(()=>{const e={fetchOptions:t,options:this.options,queryKey:this.queryKey,client:kg(this,Tg)[Tg],state:this.state,fetchFn:o};return n(e),e})();this.options.behavior?.onFetch(i,this),kg(this,Og)[Og]=this.state,"idle"!==this.state.fetchStatus&&this.state.fetchMeta===i.fetchOptions?.meta||kg(this,Ag)[Ag]({type:"fetch",meta:i.fetchOptions?.meta}),kg(this,Rg)[Rg]=yg({initialPromise:t?.initialPromise,fn:i.fetchFn,onCancel:e=>{e instanceof vg&&e.revert&&this.setState({...kg(this,Og)[Og],fetchStatus:"idle"}),r.abort()},onFail:(e,t)=>{kg(this,Ag)[Ag]({type:"failed",failureCount:e,error:t})},onPause:()=>{kg(this,Ag)[Ag]({type:"pause"})},onContinue:()=>{kg(this,Ag)[Ag]({type:"continue"})},retry:i.options.retry,retryDelay:i.options.retryDelay,networkMode:i.options.networkMode,canRun:()=>!0});try{const e=await kg(this,Rg)[Rg].start();if(void 0===e)throw true&&console.error(`Query data cannot be undefined. Please make sure to return a value other than undefined from your query function. Affected query key: ${this.queryHash}`),new Error(`${this.queryHash} data is undefined`);return this.setData(e),kg(this,Eg)[Eg].config.onSuccess?.(e,this),kg(this,Eg)[Eg].config.onSettled?.(e,this.state.error,this),e}catch(e){if(e instanceof vg){if(e.silent)return kg(this,Rg)[Rg].promise;if(e.revert){if(void 0===this.state.data)throw e;return this.state.data}}throw kg(this,Ag)[Ag]({type:"error",error:e}),kg(this,Eg)[Eg].config.onError?.(e,this),kg(this,Eg)[Eg].config.onSettled?.(this.state.data,e,this),e}finally{this.scheduleGc()}}constructor(e){super(),Object.defineProperty(this,Ag,{value:Bg}),Object.defineProperty(this,Cg,{writable:!0,value:void 0}),Object.defineProperty(this,Og,{writable:!0,value:void 0}),Object.defineProperty(this,Eg,{writable:!0,value:void 0}),Object.defineProperty(this,Tg,{writable:!0,value:void 0}),Object.defineProperty(this,Rg,{writable:!0,value:void 0}),Object.defineProperty(this,Ig,{writable:!0,value:void 0}),Object.defineProperty(this,Mg,{writable:!0,value:void 0}),kg(this,Mg)[Mg]=!1,kg(this,Ig)[Ig]=e.defaultOptions,this.setOptions(e.options),this.observers=[],kg(this,Tg)[Tg]=e.client,kg(this,Eg)[Eg]=kg(this,Tg)[Tg].getQueryCache(),this.queryKey=e.queryKey,this.queryHash=e.queryHash,kg(this,Cg)[Cg]=$g(this.options),this.state=e.state??kg(this,Cg)[Cg],this.scheduleGc()}},Pg);function Dg(e,t){return{fetchFailureCount:0,fetchFailureReason:null,fetchStatus:gg(t.networkMode)?"fetching":"paused",...void 0===e&&{error:null,status:"pending"}}}function Fg(e,t){return{data:e,dataUpdatedAt:t??Date.now(),error:null,isInvalidated:!1,status:"success"}}function $g(e){const t="function"==typeof e.initialData?e.initialData():e.initialData,r=void 0!==t,n=r?"function"==typeof e.initialDataUpdatedAt?e.initialDataUpdatedAt():e.initialDataUpdatedAt:0;return{data:t,dataUpdateCount:0,dataUpdatedAt:r?n??Date.now():0,error:null,errorUpdateCount:0,errorUpdatedAt:0,fetchFailureCount:0,fetchFailureReason:null,fetchMeta:null,isInvalidated:!1,status:r?"success":"pending",fetchStatus:"idle"}}function Bg(e){this.state=(t=>{switch(e.type){case"failed":return{...t,fetchFailureCount:e.failureCount,fetchFailureReason:e.error};case"pause":return{...t,fetchStatus:"paused"};case"continue":return{...t,fetchStatus:"fetching"};case"fetch":return{...t,...Dg(t.data,this.options),fetchMeta:e.meta??null};case"success":const r={...t,...Fg(e.data,e.dataUpdatedAt),dataUpdateCount:t.dataUpdateCount+1,...!e.manual&&{fetchStatus:"idle",fetchFailureCount:0,fetchFailureReason:null}};return kg(this,Og)[Og]=e.manual?r:void 0,r;case"error":const n=e.error;return{...t,error:n,errorUpdateCount:t.errorUpdateCount+1,errorUpdatedAt:Date.now(),fetchFailureCount:t.fetchFailureCount+1,fetchFailureReason:n,fetchStatus:"idle",status:"error",isInvalidated:!0};case"invalidate":return{...t,isInvalidated:!0};case"setState":return{...t,...e.state}}})(this.state),ag.batch(()=>{this.observers.forEach(e=>{e.onQueryUpdate()}),kg(this,Eg)[Eg].notify({query:this,type:"updated",action:e})})}function zg(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var Vg,Ug,qg,Wg,Hg,Gg,Kg,Yg,Zg,Xg,Jg,Qg,ev,tv,rv,nv,ov,iv,sv,av,lv,cv,uv,pv,dv,fv=0;function hv(e){return"__private_"+fv+++"_"+e}var mv=(Vg=hv("_client"),Ug=hv("_currentQuery"),qg=hv("_currentQueryInitialState"),Wg=hv("_currentResult"),Hg=hv("_currentResultState"),Gg=hv("_currentResultOptions"),Kg=hv("_currentThenable"),Yg=hv("_selectError"),Zg=hv("_selectFn"),Xg=hv("_selectResult"),Jg=hv("_lastQueryWithDefinedData"),Qg=hv("_staleTimeoutId"),ev=hv("_refetchIntervalId"),tv=hv("_currentRefetchInterval"),rv=hv("_trackedProps"),nv=hv("_executeFetch"),ov=hv("_updateStaleTimeout"),iv=hv("_computeRefetchInterval"),sv=hv("_updateRefetchInterval"),av=hv("_updateTimers"),lv=hv("_clearStaleTimeout"),cv=hv("_clearRefetchInterval"),uv=hv("_updateQuery"),pv=hv("_notify"),dv=class extends xm{bindMethods(){this.refetch=this.refetch.bind(this)}onSubscribe(){1===this.listeners.size&&(zg(this,Ug)[Ug].addObserver(this),gv(zg(this,Ug)[Ug],this.options)?zg(this,nv)[nv]():this.updateResult(),zg(this,av)[av]())}onUnsubscribe(){this.hasListeners()||this.destroy()}shouldFetchOnReconnect(){return vv(zg(this,Ug)[Ug],this.options,this.options.refetchOnReconnect)}shouldFetchOnWindowFocus(){return vv(zg(this,Ug)[Ug],this.options,this.options.refetchOnWindowFocus)}destroy(){this.listeners=new Set,zg(this,lv)[lv](),zg(this,cv)[cv](),zg(this,Ug)[Ug].removeObserver(this)}setOptions(e){const t=this.options,r=zg(this,Ug)[Ug];if(this.options=zg(this,Vg)[Vg].defaultQueryOptions(e),void 0!==this.options.enabled&&"boolean"!=typeof this.options.enabled&&"function"!=typeof this.options.enabled&&"boolean"!=typeof Nm(this.options.enabled,zg(this,Ug)[Ug]))throw new Error("Expected enabled to be a boolean or a callback that returns a boolean");zg(this,uv)[uv](),zg(this,Ug)[Ug].setOptions(this.options),t._defaulted&&!Vm(this.options,t)&&zg(this,Vg)[Vg].getQueryCache().notify({type:"observerOptionsUpdated",query:zg(this,Ug)[Ug],observer:this});const n=this.hasListeners();n&&yv(zg(this,Ug)[Ug],r,this.options,t)&&zg(this,nv)[nv](),this.updateResult(),!n||zg(this,Ug)[Ug]===r&&Nm(this.options.enabled,zg(this,Ug)[Ug])===Nm(t.enabled,zg(this,Ug)[Ug])&&Pm(this.options.staleTime,zg(this,Ug)[Ug])===Pm(t.staleTime,zg(this,Ug)[Ug])||zg(this,ov)[ov]();const o=zg(this,iv)[iv]();!n||zg(this,Ug)[Ug]===r&&Nm(this.options.enabled,zg(this,Ug)[Ug])===Nm(t.enabled,zg(this,Ug)[Ug])&&o===zg(this,tv)[tv]||zg(this,sv)[sv](o)}getOptimisticResult(e){const t=zg(this,Vg)[Vg].getQueryCache().build(zg(this,Vg)[Vg],e),r=this.createResult(t,e);return n=r,!Vm(this.getCurrentResult(),n)&&(zg(this,Wg)[Wg]=r,zg(this,Gg)[Gg]=this.options,zg(this,Hg)[Hg]=zg(this,Ug)[Ug].state),r;// removed by dead control flow
 var n; }getCurrentResult(){return zg(this,Wg)[Wg]}trackResult(e,t){return new Proxy(e,{get:(e,r)=>(this.trackProp(r),t?.(r),"promise"===r&&(this.trackProp("data"),this.options.experimental_prefetchInRender||"pending"!==zg(this,Kg)[Kg].status||zg(this,Kg)[Kg].reject(new Error("experimental_prefetchInRender feature flag is not enabled"))),Reflect.get(e,r))})}trackProp(e){zg(this,rv)[rv].add(e)}getCurrentQuery(){return zg(this,Ug)[Ug]}refetch({...e}={}){return this.fetch({...e})}fetchOptimistic(e){const t=zg(this,Vg)[Vg].defaultQueryOptions(e),r=zg(this,Vg)[Vg].getQueryCache().build(zg(this,Vg)[Vg],t);return r.fetch().then(()=>this.createResult(r,t))}fetch(e){return zg(this,nv)[nv]({...e,cancelRefetch:e.cancelRefetch??!0}).then(()=>(this.updateResult(),zg(this,Wg)[Wg]))}createResult(e,t){const r=zg(this,Ug)[Ug],n=this.options,o=zg(this,Wg)[Wg],i=zg(this,Hg)[Hg],s=zg(this,Gg)[Gg],a=e!==r?e.state:zg(this,qg)[qg],{state:l}=e;let c,u={...l},p=!1;if(t._optimisticResults){const o=this.hasListeners(),i=!o&&gv(e,t),s=o&&yv(e,r,t,n);(i||s)&&(u={...u,...Dg(l.data,e.options)}),"isRestoring"===t._optimisticResults&&(u.fetchStatus="idle")}let{error:d,errorUpdatedAt:f,status:h}=u;c=u.data;let m=!1;if(void 0!==t.placeholderData&&void 0===c&&"pending"===h){let e;o?.isPlaceholderData&&t.placeholderData===s?.placeholderData?(e=o.data,m=!0):e="function"==typeof t.placeholderData?t.placeholderData(zg(this,Jg)[Jg]?.state.data,zg(this,Jg)[Jg]):t.placeholderData,void 0!==e&&(h="success",c=Hm(o?.data,e,t),p=!0)}if(t.select&&void 0!==c&&!m)if(o&&c===i?.data&&t.select===zg(this,Zg)[Zg])c=zg(this,Xg)[Xg];else try{zg(this,Zg)[Zg]=t.select,c=t.select(c),c=Hm(o?.data,c,t),zg(this,Xg)[Xg]=c,zg(this,Yg)[Yg]=null}catch(e){zg(this,Yg)[Yg]=e}zg(this,Yg)[Yg]&&(d=zg(this,Yg)[Yg],c=zg(this,Xg)[Xg],f=Date.now(),h="error");const g="fetching"===u.fetchStatus,v="pending"===h,y="error"===h,b=v&&g,w=void 0!==c,x={status:h,fetchStatus:u.fetchStatus,isPending:v,isSuccess:"success"===h,isError:y,isInitialLoading:b,isLoading:b,data:c,dataUpdatedAt:u.dataUpdatedAt,error:d,errorUpdatedAt:f,failureCount:u.fetchFailureCount,failureReason:u.fetchFailureReason,errorUpdateCount:u.errorUpdateCount,isFetched:u.dataUpdateCount>0||u.errorUpdateCount>0,isFetchedAfterMount:u.dataUpdateCount>a.dataUpdateCount||u.errorUpdateCount>a.errorUpdateCount,isFetching:g,isRefetching:g&&!v,isLoadingError:y&&!w,isPaused:"paused"===u.fetchStatus,isPlaceholderData:p,isRefetchError:y&&w,isStale:bv(e,t),refetch:this.refetch,promise:zg(this,Kg)[Kg],isEnabled:!1!==Nm(t.enabled,e)};if(this.options.experimental_prefetchInRender){const t=void 0!==x.data,n="error"===x.status&&!t,o=e=>{n?e.reject(x.error):t&&e.resolve(x.data)},i=()=>{const e=zg(this,Kg)[Kg]=x.promise=ig();o(e)},s=zg(this,Kg)[Kg];switch(s.status){case"pending":e.queryHash===r.queryHash&&o(s);break;case"fulfilled":(n||x.data!==s.value)&&i();break;case"rejected":n&&x.error===s.reason||i()}}return x}updateResult(){const e=zg(this,Wg)[Wg],t=this.createResult(zg(this,Ug)[Ug],this.options);zg(this,Hg)[Hg]=zg(this,Ug)[Ug].state,zg(this,Gg)[Gg]=this.options,void 0!==zg(this,Hg)[Hg].data&&(zg(this,Jg)[Jg]=zg(this,Ug)[Ug]),Vm(t,e)||(zg(this,Wg)[Wg]=t,zg(this,pv)[pv]({listeners:(()=>{if(!e)return!0;const{notifyOnChangeProps:t}=this.options,r="function"==typeof t?t():t;if("all"===r||!r&&!zg(this,rv)[rv].size)return!0;const n=new Set(r??zg(this,rv)[rv]);return this.options.throwOnError&&n.add("error"),Object.keys(zg(this,Wg)[Wg]).some(t=>{const r=t;return zg(this,Wg)[Wg][r]!==e[r]&&n.has(r)})})()}))}onQueryUpdate(){this.updateResult(),this.hasListeners()&&zg(this,av)[av]()}constructor(e,t){super(),Object.defineProperty(this,nv,{value:wv}),Object.defineProperty(this,ov,{value:xv}),Object.defineProperty(this,iv,{value:_v}),Object.defineProperty(this,sv,{value:Sv}),Object.defineProperty(this,av,{value:kv}),Object.defineProperty(this,lv,{value:Cv}),Object.defineProperty(this,cv,{value:Ov}),Object.defineProperty(this,uv,{value:Ev}),Object.defineProperty(this,pv,{value:Tv}),Object.defineProperty(this,Vg,{writable:!0,value:void 0}),Object.defineProperty(this,Ug,{writable:!0,value:void 0}),Object.defineProperty(this,qg,{writable:!0,value:void 0}),Object.defineProperty(this,Wg,{writable:!0,value:void 0}),Object.defineProperty(this,Hg,{writable:!0,value:void 0}),Object.defineProperty(this,Gg,{writable:!0,value:void 0}),Object.defineProperty(this,Kg,{writable:!0,value:void 0}),Object.defineProperty(this,Yg,{writable:!0,value:void 0}),Object.defineProperty(this,Zg,{writable:!0,value:void 0}),Object.defineProperty(this,Xg,{writable:!0,value:void 0}),Object.defineProperty(this,Jg,{writable:!0,value:void 0}),Object.defineProperty(this,Qg,{writable:!0,value:void 0}),Object.defineProperty(this,ev,{writable:!0,value:void 0}),Object.defineProperty(this,tv,{writable:!0,value:void 0}),Object.defineProperty(this,rv,{writable:!0,value:void 0}),zg(this,Ug)[Ug]=void 0,zg(this,qg)[qg]=void 0,zg(this,Wg)[Wg]=void 0,zg(this,rv)[rv]=new Set,this.options=t,zg(this,Vg)[Vg]=e,zg(this,Yg)[Yg]=null,zg(this,Kg)[Kg]=ig(),this.bindMethods(),this.setOptions(t)}},dv);function gv(e,t){return function(e,t){return!1!==Nm(t.enabled,e)&&void 0===e.state.data&&!("error"===e.state.status&&!1===t.retryOnMount)}(e,t)||void 0!==e.state.data&&vv(e,t,t.refetchOnMount)}function vv(e,t,r){if(!1!==Nm(t.enabled,e)&&"static"!==Pm(t.staleTime,e)){const n="function"==typeof r?r(e):r;return"always"===n||!1!==n&&bv(e,t)}return!1}function yv(e,t,r,n){return(e!==t||!1===Nm(n.enabled,e))&&(!r.suspense||"error"!==e.state.status)&&bv(e,r)}function bv(e,t){return!1!==Nm(t.enabled,e)&&e.isStaleByTime(Pm(t.staleTime,e))}function wv(e){zg(this,uv)[uv]();let t=zg(this,Ug)[Ug].fetch(this.options,e);return e?.throwOnError||(t=t.catch(Im)),t}function xv(){zg(this,lv)[lv]();const e=Pm(this.options.staleTime,zg(this,Ug)[Ug]);if(Rm||zg(this,Wg)[Wg].isStale||!Mm(e))return;const t=Am(zg(this,Wg)[Wg].dataUpdatedAt,e)+1;zg(this,Qg)[Qg]=Tm.setTimeout(()=>{zg(this,Wg)[Wg].isStale||this.updateResult()},t)}function _v(){return("function"==typeof this.options.refetchInterval?this.options.refetchInterval(zg(this,Ug)[Ug]):this.options.refetchInterval)??!1}function Sv(e){zg(this,cv)[cv](),zg(this,tv)[tv]=e,!Rm&&!1!==Nm(this.options.enabled,zg(this,Ug)[Ug])&&Mm(zg(this,tv)[tv])&&0!==zg(this,tv)[tv]&&(zg(this,ev)[ev]=Tm.setInterval(()=>{(this.options.refetchIntervalInBackground||og.isFocused())&&zg(this,nv)[nv]()},zg(this,tv)[tv]))}function kv(){zg(this,ov)[ov](),zg(this,sv)[sv](zg(this,iv)[iv]())}function Cv(){zg(this,Qg)[Qg]&&(Tm.clearTimeout(zg(this,Qg)[Qg]),zg(this,Qg)[Qg]=void 0)}function Ov(){zg(this,ev)[ev]&&(Tm.clearInterval(zg(this,ev)[ev]),zg(this,ev)[ev]=void 0)}function Ev(){const e=zg(this,Vg)[Vg].getQueryCache().build(zg(this,Vg)[Vg],this.options);if(e===zg(this,Ug)[Ug])return;const t=zg(this,Ug)[Ug];zg(this,Ug)[Ug]=e,zg(this,qg)[qg]=e.state,this.hasListeners()&&(t?.removeObserver(this),e.addObserver(this))}function Tv(e){ag.batch(()=>{e.listeners&&this.listeners.forEach(e=>{e(zg(this,Wg)[Wg])}),zg(this,Vg)[Vg].getQueryCache().notify({query:zg(this,Ug)[Ug],type:"observerResultsUpdated"})})}function Rv(e){return{onFetch:(t,r)=>{const n=t.options,o=t.fetchOptions?.meta?.fetchMore?.direction,i=t.state.data?.pages||[],s=t.state.data?.pageParams||[];let a={pages:[],pageParams:[]},l=0;const c=async()=>{let r=!1;const c=e=>{!function(e,r,n){let o,i=!1;Object.defineProperty(e,"signal",{enumerable:!0,get:()=>(o??(o=t.signal),i||(i=!0,o.aborted?n():o.addEventListener("abort",n,{once:!0})),o)})}(e,0,()=>r=!0)},u=Zm(t.options,t.fetchOptions),p=async(e,n,o)=>{if(r)return Promise.reject();if(null==n&&e.pages.length)return Promise.resolve(e);const i=(()=>{const e={client:t.client,queryKey:t.queryKey,pageParam:n,direction:o?"backward":"forward",meta:t.options.meta};return c(e),e})(),s=await u(i),{maxPages:a}=t.options,l=o?Km:Gm;return{pages:l(e.pages,s,a),pageParams:l(e.pageParams,n,a)}};if(o&&i.length){const e="backward"===o,t={pages:i,pageParams:s},r=(e?Mv:Iv)(n,t);a=await p(t,r,e)}else{const t=e??i.length;do{const e=0===l?s[0]??n.initialPageParam:Iv(n,a);if(l>0&&null==e)break;a=await p(a,e),l++}while(l<t)}return a};t.options.persister?t.fetchFn=()=>t.options.persister?.(c,{client:t.client,queryKey:t.queryKey,meta:t.options.meta,signal:t.signal},r):t.fetchFn=c}}}function Iv(e,{pages:t,pageParams:r}){const n=t.length-1;return t.length>0?e.getNextPageParam(t[n],t,r[n],r):void 0}function Mv(e,{pages:t,pageParams:r}){return t.length>0?e.getPreviousPageParam?.(t[0],t,r[0],r):void 0}function Av(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var Pv,Nv,jv,Lv,Dv,Fv,$v=0;function Bv(e){return"__private_"+$v+++"_"+e}var zv=(Pv=Bv("_client"),Nv=Bv("_observers"),jv=Bv("_mutationCache"),Lv=Bv("_retryer"),Dv=Bv("_dispatch"),Fv=class extends Sg{setOptions(e){this.options=e,this.updateGcTime(this.options.gcTime)}get meta(){return this.options.meta}addObserver(e){Av(this,Nv)[Nv].includes(e)||(Av(this,Nv)[Nv].push(e),this.clearGcTimeout(),Av(this,jv)[jv].notify({type:"observerAdded",mutation:this,observer:e}))}removeObserver(e){Av(this,Nv)[Nv]=Av(this,Nv)[Nv].filter(t=>t!==e),this.scheduleGc(),Av(this,jv)[jv].notify({type:"observerRemoved",mutation:this,observer:e})}optionalRemove(){Av(this,Nv)[Nv].length||("pending"===this.state.status?this.scheduleGc():Av(this,jv)[jv].remove(this))}continue(){return Av(this,Lv)[Lv]?.continue()??this.execute(this.state.variables)}async execute(e){const t=()=>{Av(this,Dv)[Dv]({type:"continue"})},r={client:Av(this,Pv)[Pv],meta:this.options.meta,mutationKey:this.options.mutationKey};Av(this,Lv)[Lv]=yg({fn:()=>this.options.mutationFn?this.options.mutationFn(e,r):Promise.reject(new Error("No mutationFn found")),onFail:(e,t)=>{Av(this,Dv)[Dv]({type:"failed",failureCount:e,error:t})},onPause:()=>{Av(this,Dv)[Dv]({type:"pause"})},onContinue:t,retry:this.options.retry??0,retryDelay:this.options.retryDelay,networkMode:this.options.networkMode,canRun:()=>Av(this,jv)[jv].canRun(this)});const n="pending"===this.state.status,o=!Av(this,Lv)[Lv].canStart();try{if(n)t();else{Av(this,Dv)[Dv]({type:"pending",variables:e,isPaused:o}),Av(this,jv)[jv].config.onMutate&&await Av(this,jv)[jv].config.onMutate(e,this,r);const t=await(this.options.onMutate?.(e,r));t!==this.state.context&&Av(this,Dv)[Dv]({type:"pending",context:t,variables:e,isPaused:o})}const i=await Av(this,Lv)[Lv].start();return await(Av(this,jv)[jv].config.onSuccess?.(i,e,this.state.context,this,r)),await(this.options.onSuccess?.(i,e,this.state.context,r)),await(Av(this,jv)[jv].config.onSettled?.(i,null,this.state.variables,this.state.context,this,r)),await(this.options.onSettled?.(i,null,e,this.state.context,r)),Av(this,Dv)[Dv]({type:"success",data:i}),i}catch(t){try{await(Av(this,jv)[jv].config.onError?.(t,e,this.state.context,this,r))}catch(e){Promise.reject(e)}try{await(this.options.onError?.(t,e,this.state.context,r))}catch(e){Promise.reject(e)}try{await(Av(this,jv)[jv].config.onSettled?.(void 0,t,this.state.variables,this.state.context,this,r))}catch(e){Promise.reject(e)}try{await(this.options.onSettled?.(void 0,t,e,this.state.context,r))}catch(e){Promise.reject(e)}throw Av(this,Dv)[Dv]({type:"error",error:t}),t}finally{Av(this,jv)[jv].runNext(this)}}constructor(e){super(),Object.defineProperty(this,Dv,{value:Vv}),Object.defineProperty(this,Pv,{writable:!0,value:void 0}),Object.defineProperty(this,Nv,{writable:!0,value:void 0}),Object.defineProperty(this,jv,{writable:!0,value:void 0}),Object.defineProperty(this,Lv,{writable:!0,value:void 0}),Av(this,Pv)[Pv]=e.client,this.mutationId=e.mutationId,Av(this,jv)[jv]=e.mutationCache,Av(this,Nv)[Nv]=[],this.state=e.state||{context:void 0,data:void 0,error:null,failureCount:0,failureReason:null,isPaused:!1,status:"idle",variables:void 0,submittedAt:0},this.setOptions(e.options),this.scheduleGc()}},Fv);function Vv(e){this.state=(t=>{switch(e.type){case"failed":return{...t,failureCount:e.failureCount,failureReason:e.error};case"pause":return{...t,isPaused:!0};case"continue":return{...t,isPaused:!1};case"pending":return{...t,context:e.context,data:void 0,failureCount:0,failureReason:null,error:null,isPaused:e.isPaused,status:"pending",variables:e.variables,submittedAt:Date.now()};case"success":return{...t,data:e.data,failureCount:0,failureReason:null,error:null,status:"success",isPaused:!1};case"error":return{...t,data:void 0,error:e.error,failureCount:t.failureCount+1,failureReason:e.error,isPaused:!1,status:"error"}}})(this.state),ag.batch(()=>{Av(this,Nv)[Nv].forEach(t=>{t.onMutationUpdate(e)}),Av(this,jv)[jv].notify({mutation:this,type:"updated",action:e})})}function Uv(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var qv,Wv,Hv,Gv=0;function Kv(e){return"__private_"+Gv+++"_"+e}var Yv=(qv=Kv("_mutations"),Wv=Kv("_scopes"),Hv=Kv("_mutationId"),class extends xm{build(e,t,r){const n=new zv({client:e,mutationCache:this,mutationId:++Uv(this,Hv)[Hv],options:e.defaultMutationOptions(t),state:r});return this.add(n),n}add(e){Uv(this,qv)[qv].add(e);const t=Zv(e);if("string"==typeof t){const r=Uv(this,Wv)[Wv].get(t);r?r.push(e):Uv(this,Wv)[Wv].set(t,[e])}this.notify({type:"added",mutation:e})}remove(e){if(Uv(this,qv)[qv].delete(e)){const t=Zv(e);if("string"==typeof t){const r=Uv(this,Wv)[Wv].get(t);if(r)if(r.length>1){const t=r.indexOf(e);-1!==t&&r.splice(t,1)}else r[0]===e&&Uv(this,Wv)[Wv].delete(t)}}this.notify({type:"removed",mutation:e})}canRun(e){const t=Zv(e);if("string"==typeof t){const r=Uv(this,Wv)[Wv].get(t),n=r?.find(e=>"pending"===e.state.status);return!n||n===e}return!0}runNext(e){const t=Zv(e);if("string"==typeof t){const r=Uv(this,Wv)[Wv].get(t)?.find(t=>t!==e&&t.state.isPaused);return r?.continue()??Promise.resolve()}return Promise.resolve()}clear(){ag.batch(()=>{Uv(this,qv)[qv].forEach(e=>{this.notify({type:"removed",mutation:e})}),Uv(this,qv)[qv].clear(),Uv(this,Wv)[Wv].clear()})}getAll(){return Array.from(Uv(this,qv)[qv])}find(e){const t={exact:!0,...e};return this.getAll().find(e=>Lm(t,e))}findAll(e={}){return this.getAll().filter(t=>Lm(e,t))}notify(e){ag.batch(()=>{this.listeners.forEach(t=>{t(e)})})}resumePausedMutations(){const e=this.getAll().filter(e=>e.state.isPaused);return ag.batch(()=>Promise.all(e.map(e=>e.continue().catch(Im))))}constructor(e={}){super(),Object.defineProperty(this,qv,{writable:!0,value:void 0}),Object.defineProperty(this,Wv,{writable:!0,value:void 0}),Object.defineProperty(this,Hv,{writable:!0,value:void 0}),this.config=e,Uv(this,qv)[qv]=new Set,Uv(this,Wv)[Wv]=new Map,Uv(this,Hv)[Hv]=0}});function Zv(e){return e.options.scope?.id}function Xv(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var Jv,Qv,ey,ty,ry,ny,oy=0;function iy(e){return"__private_"+oy+++"_"+e}var sy=(Jv=iy("_client"),Qv=iy("_currentResult"),ey=iy("_currentMutation"),ty=iy("_mutateOptions"),ry=iy("_updateResult"),ny=iy("_notify"),class extends xm{bindMethods(){this.mutate=this.mutate.bind(this),this.reset=this.reset.bind(this)}setOptions(e){const t=this.options;this.options=Xv(this,Jv)[Jv].defaultMutationOptions(e),Vm(this.options,t)||Xv(this,Jv)[Jv].getMutationCache().notify({type:"observerOptionsUpdated",mutation:Xv(this,ey)[ey],observer:this}),t?.mutationKey&&this.options.mutationKey&&Fm(t.mutationKey)!==Fm(this.options.mutationKey)?this.reset():"pending"===Xv(this,ey)[ey]?.state.status&&Xv(this,ey)[ey].setOptions(this.options)}onUnsubscribe(){this.hasListeners()||Xv(this,ey)[ey]?.removeObserver(this)}onMutationUpdate(e){Xv(this,ry)[ry](),Xv(this,ny)[ny](e)}getCurrentResult(){return Xv(this,Qv)[Qv]}reset(){Xv(this,ey)[ey]?.removeObserver(this),Xv(this,ey)[ey]=void 0,Xv(this,ry)[ry](),Xv(this,ny)[ny]()}mutate(e,t){return Xv(this,ty)[ty]=t,Xv(this,ey)[ey]?.removeObserver(this),Xv(this,ey)[ey]=Xv(this,Jv)[Jv].getMutationCache().build(Xv(this,Jv)[Jv],this.options),Xv(this,ey)[ey].addObserver(this),Xv(this,ey)[ey].execute(e)}constructor(e,t){super(),Object.defineProperty(this,ry,{value:ay}),Object.defineProperty(this,ny,{value:ly}),Object.defineProperty(this,Jv,{writable:!0,value:void 0}),Object.defineProperty(this,Qv,{writable:!0,value:void 0}),Object.defineProperty(this,ey,{writable:!0,value:void 0}),Object.defineProperty(this,ty,{writable:!0,value:void 0}),Xv(this,Qv)[Qv]=void 0,Xv(this,Jv)[Jv]=e,this.setOptions(t),this.bindMethods(),Xv(this,ry)[ry]()}});function ay(){const e=Xv(this,ey)[ey]?.state??{context:void 0,data:void 0,error:null,failureCount:0,failureReason:null,isPaused:!1,status:"idle",variables:void 0,submittedAt:0};Xv(this,Qv)[Qv]={...e,isPending:"pending"===e.status,isSuccess:"success"===e.status,isError:"error"===e.status,isIdle:"idle"===e.status,mutate:this.mutate,reset:this.reset}}function ly(e){ag.batch(()=>{if(Xv(this,ty)[ty]&&this.hasListeners()){const t=Xv(this,Qv)[Qv].variables,r=Xv(this,Qv)[Qv].context,n={client:Xv(this,Jv)[Jv],meta:this.options.meta,mutationKey:this.options.mutationKey};if("success"===e?.type){try{Xv(this,ty)[ty].onSuccess?.(e.data,t,r,n)}catch(e){Promise.reject(e)}try{Xv(this,ty)[ty].onSettled?.(e.data,null,t,r,n)}catch(e){Promise.reject(e)}}else if("error"===e?.type){try{Xv(this,ty)[ty].onError?.(e.error,t,r,n)}catch(e){Promise.reject(e)}try{Xv(this,ty)[ty].onSettled?.(void 0,e.error,t,r,n)}catch(e){Promise.reject(e)}}}this.listeners.forEach(e=>{e(Xv(this,Qv)[Qv])})})}function cy(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var uy,py=0;function dy(e){return"__private_"+py+++"_"+e}var fy=(uy=dy("_queries"),class extends xm{build(e,t,r){const n=t.queryKey,o=t.queryHash??Dm(n,t);let i=this.get(o);return i||(i=new Lg({client:e,queryKey:n,queryHash:o,options:e.defaultQueryOptions(t),state:r,defaultOptions:e.getQueryDefaults(n)}),this.add(i)),i}add(e){cy(this,uy)[uy].has(e.queryHash)||(cy(this,uy)[uy].set(e.queryHash,e),this.notify({type:"added",query:e}))}remove(e){const t=cy(this,uy)[uy].get(e.queryHash);t&&(e.destroy(),t===e&&cy(this,uy)[uy].delete(e.queryHash),this.notify({type:"removed",query:e}))}clear(){ag.batch(()=>{this.getAll().forEach(e=>{this.remove(e)})})}get(e){return cy(this,uy)[uy].get(e)}getAll(){return[...cy(this,uy)[uy].values()]}find(e){const t={exact:!0,...e};return this.getAll().find(e=>jm(t,e))}findAll(e={}){const t=this.getAll();return Object.keys(e).length>0?t.filter(t=>jm(e,t)):t}notify(e){ag.batch(()=>{this.listeners.forEach(t=>{t(e)})})}onFocus(){ag.batch(()=>{this.getAll().forEach(e=>{e.onFocus()})})}onOnline(){ag.batch(()=>{this.getAll().forEach(e=>{e.onOnline()})})}constructor(e={}){super(),Object.defineProperty(this,uy,{writable:!0,value:void 0}),this.config=e,cy(this,uy)[uy]=new Map}});function hy(e,t){if(!Object.prototype.hasOwnProperty.call(e,t))throw new TypeError("attempted to use private field on non-instance");return e}var my,gy,vy,yy,by,wy,xy,_y,Sy=0;function ky(e){return"__private_"+Sy+++"_"+e}var Cy=(my=ky("_queryCache"),gy=ky("_mutationCache"),vy=ky("_defaultOptions"),yy=ky("_queryDefaults"),by=ky("_mutationDefaults"),wy=ky("_mountCount"),xy=ky("_unsubscribeFocus"),_y=ky("_unsubscribeOnline"),class{mount(){hy(this,wy)[wy]++,1===hy(this,wy)[wy]&&(hy(this,xy)[xy]=og.subscribe(async e=>{e&&(await this.resumePausedMutations(),hy(this,my)[my].onFocus())}),hy(this,_y)[_y]=hg.subscribe(async e=>{e&&(await this.resumePausedMutations(),hy(this,my)[my].onOnline())}))}unmount(){hy(this,wy)[wy]--,0===hy(this,wy)[wy]&&(null==hy(this,xy)[xy]||hy(this,xy)[xy].call(this),hy(this,xy)[xy]=void 0,null==hy(this,_y)[_y]||hy(this,_y)[_y].call(this),hy(this,_y)[_y]=void 0)}isFetching(e){return hy(this,my)[my].findAll({...e,fetchStatus:"fetching"}).length}isMutating(e){return hy(this,gy)[gy].findAll({...e,status:"pending"}).length}getQueryData(e){const t=this.defaultQueryOptions({queryKey:e});return hy(this,my)[my].get(t.queryHash)?.state.data}ensureQueryData(e){const t=this.defaultQueryOptions(e),r=hy(this,my)[my].build(this,t),n=r.state.data;return void 0===n?this.fetchQuery(e):(e.revalidateIfStale&&r.isStaleByTime(Pm(t.staleTime,r))&&this.prefetchQuery(t),Promise.resolve(n))}getQueriesData(e){return hy(this,my)[my].findAll(e).map(({queryKey:e,state:t})=>[e,t.data])}setQueryData(e,t,r){const n=this.defaultQueryOptions({queryKey:e}),o=hy(this,my)[my].get(n.queryHash),i=o?.state.data,s=function(e,t){return"function"==typeof e?e(t):e}(t,i);if(void 0!==s)return hy(this,my)[my].build(this,n).setData(s,{...r,manual:!0})}setQueriesData(e,t,r){return ag.batch(()=>hy(this,my)[my].findAll(e).map(({queryKey:e})=>[e,this.setQueryData(e,t,r)]))}getQueryState(e){const t=this.defaultQueryOptions({queryKey:e});return hy(this,my)[my].get(t.queryHash)?.state}removeQueries(e){const t=hy(this,my)[my];ag.batch(()=>{t.findAll(e).forEach(e=>{t.remove(e)})})}resetQueries(e,t){const r=hy(this,my)[my];return ag.batch(()=>(r.findAll(e).forEach(e=>{e.reset()}),this.refetchQueries({type:"active",...e},t)))}cancelQueries(e,t={}){const r={revert:!0,...t},n=ag.batch(()=>hy(this,my)[my].findAll(e).map(e=>e.cancel(r)));return Promise.all(n).then(Im).catch(Im)}invalidateQueries(e,t={}){return ag.batch(()=>(hy(this,my)[my].findAll(e).forEach(e=>{e.invalidate()}),"none"===e?.refetchType?Promise.resolve():this.refetchQueries({...e,type:e?.refetchType??e?.type??"active"},t)))}refetchQueries(e,t={}){const r={...t,cancelRefetch:t.cancelRefetch??!0},n=ag.batch(()=>hy(this,my)[my].findAll(e).filter(e=>!e.isDisabled()&&!e.isStatic()).map(e=>{let t=e.fetch(void 0,r);return r.throwOnError||(t=t.catch(Im)),"paused"===e.state.fetchStatus?Promise.resolve():t}));return Promise.all(n).then(Im)}fetchQuery(e){const t=this.defaultQueryOptions(e);void 0===t.retry&&(t.retry=!1);const r=hy(this,my)[my].build(this,t);return r.isStaleByTime(Pm(t.staleTime,r))?r.fetch(t):Promise.resolve(r.state.data)}prefetchQuery(e){return this.fetchQuery(e).then(Im).catch(Im)}fetchInfiniteQuery(e){return e.behavior=Rv(e.pages),this.fetchQuery(e)}prefetchInfiniteQuery(e){return this.fetchInfiniteQuery(e).then(Im).catch(Im)}ensureInfiniteQueryData(e){return e.behavior=Rv(e.pages),this.ensureQueryData(e)}resumePausedMutations(){return hg.isOnline()?hy(this,gy)[gy].resumePausedMutations():Promise.resolve()}getQueryCache(){return hy(this,my)[my]}getMutationCache(){return hy(this,gy)[gy]}getDefaultOptions(){return hy(this,vy)[vy]}setDefaultOptions(e){hy(this,vy)[vy]=e}setQueryDefaults(e,t){hy(this,yy)[yy].set(Fm(e),{queryKey:e,defaultOptions:t})}getQueryDefaults(e){const t=[...hy(this,yy)[yy].values()],r={};return t.forEach(t=>{$m(e,t.queryKey)&&Object.assign(r,t.defaultOptions)}),r}setMutationDefaults(e,t){hy(this,by)[by].set(Fm(e),{mutationKey:e,defaultOptions:t})}getMutationDefaults(e){const t=[...hy(this,by)[by].values()],r={};return t.forEach(t=>{$m(e,t.mutationKey)&&Object.assign(r,t.defaultOptions)}),r}defaultQueryOptions(e){if(e._defaulted)return e;const t={...hy(this,vy)[vy].queries,...this.getQueryDefaults(e.queryKey),...e,_defaulted:!0};return t.queryHash||(t.queryHash=Dm(t.queryKey,t)),void 0===t.refetchOnReconnect&&(t.refetchOnReconnect="always"!==t.networkMode),void 0===t.throwOnError&&(t.throwOnError=!!t.suspense),!t.networkMode&&t.persister&&(t.networkMode="offlineFirst"),t.queryFn===Ym&&(t.enabled=!1),t}defaultMutationOptions(e){return e?._defaulted?e:{...hy(this,vy)[vy].mutations,...e?.mutationKey&&this.getMutationDefaults(e.mutationKey),...e,_defaulted:!0}}clear(){hy(this,my)[my].clear(),hy(this,gy)[gy].clear()}constructor(e={}){Object.defineProperty(this,my,{writable:!0,value:void 0}),Object.defineProperty(this,gy,{writable:!0,value:void 0}),Object.defineProperty(this,vy,{writable:!0,value:void 0}),Object.defineProperty(this,yy,{writable:!0,value:void 0}),Object.defineProperty(this,by,{writable:!0,value:void 0}),Object.defineProperty(this,wy,{writable:!0,value:void 0}),Object.defineProperty(this,xy,{writable:!0,value:void 0}),Object.defineProperty(this,_y,{writable:!0,value:void 0}),hy(this,my)[my]=e.queryCache||new fy,hy(this,gy)[gy]=e.mutationCache||new Yv,hy(this,vy)[vy]=e.defaultOptions||{},hy(this,yy)[yy]=new Map,hy(this,by)[by]=new Map,hy(this,wy)[wy]=0}}),Oy=o.createContext(void 0),Ey=e=>{const t=o.useContext(Oy);if(e)return e;if(!t)throw new Error("No QueryClient set, use QueryClientProvider to set one");return t},Ty=({client:t,children:r})=>(o.useEffect(()=>(t.mount(),()=>{t.unmount()}),[t]),e.jsx(Oy.Provider,{value:t,children:r})),Ry=o.createContext(!1),Iy=o.createContext(function(){let e=!1;return{clearReset:()=>{e=!1},reset:()=>{e=!0},isReset:()=>e}}()),My=(e,t,r)=>t.fetchOptimistic(e).catch(()=>{r.clearReset()});function Ay(e,t){return function(e,t,r){if( true&&("object"!=typeof e||Array.isArray(e)))throw new Error('Bad argument type. Starting with v5, only the "Object" form is allowed when calling query related functions. Please use the error stack to find the culprit call. More info here: https://tanstack.com/query/latest/docs/react/guides/migrating-to-v5#supports-a-single-signature-one-object');const n=o.useContext(Ry),i=o.useContext(Iy),s=Ey(r),a=s.defaultQueryOptions(e);s.getDefaultOptions().queries?._experimental_beforeQuery?.(a);const l=s.getQueryCache().get(a.queryHash); true&&(a.queryFn||console.error(`[${a.queryHash}]: No queryFn was passed as an option, and no default queryFn was found. The queryFn parameter is only optional when using a default queryFn. More info here: https://tanstack.com/query/latest/docs/framework/react/guides/default-query-function`)),a._optimisticResults=n?"isRestoring":"optimistic",(e=>{if(e.suspense){const t=1e3,r=e=>"static"===e?e:Math.max(e??t,t),n=e.staleTime;e.staleTime="function"==typeof n?(...e)=>r(n(...e)):r(n),"number"==typeof e.gcTime&&(e.gcTime=Math.max(e.gcTime,t))}})(a),((e,t,r)=>{const n=r?.state.error&&"function"==typeof e.throwOnError?Xm(e.throwOnError,[r.state.error,r]):e.throwOnError;(e.suspense||e.experimental_prefetchInRender||n)&&(t.isReset()||(e.retryOnMount=!1))})(a,i,l),(e=>{o.useEffect(()=>{e.clearReset()},[e])})(i);const c=!s.getQueryCache().get(a.queryHash),[u]=o.useState(()=>new t(s,a)),p=u.getOptimisticResult(a),d=!n&&!1!==e.subscribed;if(o.useSyncExternalStore(o.useCallback(e=>{const t=d?u.subscribe(ag.batchCalls(e)):Im;return u.updateResult(),t},[u,d]),()=>u.getCurrentResult(),()=>u.getCurrentResult()),o.useEffect(()=>{u.setOptions(a)},[a,u]),((e,t)=>e?.suspense&&t.isPending)(a,p))throw My(a,u,i);if((({result:e,errorResetBoundary:t,throwOnError:r,query:n,suspense:o})=>e.isError&&!t.isReset()&&!e.isFetching&&n&&(o&&void 0===e.data||Xm(r,[e.error,n])))({result:p,errorResetBoundary:i,throwOnError:a.throwOnError,query:l,suspense:a.suspense}))throw p.error;if(s.getDefaultOptions().queries?._experimental_afterQuery?.(a,p),a.experimental_prefetchInRender&&!Rm&&((e,t)=>e.isLoading&&e.isFetching&&!t)(p,n)){const e=c?My(a,u,i):l?.promise;e?.catch(Im).finally(()=>{u.updateResult()})}return a.notifyOnChangeProps?p:u.trackResult(p)}(e,mv,t)}function Py(e,t){const r=Ey(t),[n]=o.useState(()=>new sy(r,e));o.useEffect(()=>{n.setOptions(e)},[n,e]);const i=o.useSyncExternalStore(o.useCallback(e=>n.subscribe(ag.batchCalls(e)),[n]),()=>n.getCurrentResult(),()=>n.getCurrentResult()),s=o.useCallback((e,t)=>{n.mutate(e,t).catch(Im)},[n]);if(i.error&&Xm(n.options.throwOnError,[i.error]))throw i.error;return{...i,mutate:s,mutateAsync:i.mutate}}const Ny={local:{SUPPORT_FORM_URL:"https://my.stg.elementor.red/support-form/",FEEDBACK_API:"https://my.stg.elementor.red/feedback/api/v1",WHATS_NEW_API:"https://my.stg.elementor.red/whats-new/api/v1",MY_ELEMENTOR_URL:"https://my.stg.elementor.red"},development:{SUPPORT_FORM_URL:"https://my.dev.elementor.red/support-form/",FEEDBACK_API:"https://my.dev.elementor.red/feedback/api/v1",WHATS_NEW_API:"https://my.dev.elementor.red/whats-new/api/v1",MY_ELEMENTOR_URL:"https://my.dev.elementor.red"},staging:{SUPPORT_FORM_URL:"https://my.stg.elementor.red/support-form/",FEEDBACK_API:"https://my.stg.elementor.red/feedback/api/v1",WHATS_NEW_API:"https://my.stg.elementor.red/whats-new/api/v1",MY_ELEMENTOR_URL:"https://my.stg.elementor.red"},production:{SUPPORT_FORM_URL:"https://my.elementor.com/support-form/",FEEDBACK_API:"https://my.elementor.com/feedback/api/v1",WHATS_NEW_API:"https://my.elementor.com/whats-new/api/v1",MY_ELEMENTOR_URL:"https://my.elementor.com"}};function jy(e,t){return function(){return e.apply(t,arguments)}}const{toString:Ly}=Object.prototype,{getPrototypeOf:Dy}=Object,{iterator:Fy,toStringTag:$y}=Symbol,By=(zy=Object.create(null),e=>{const t=Ly.call(e);return zy[t]||(zy[t]=t.slice(8,-1).toLowerCase())});var zy;const Vy=e=>(e=e.toLowerCase(),t=>By(t)===e),Uy=e=>t=>typeof t===e,{isArray:qy}=Array,Wy=Uy("undefined");function Hy(e){return null!==e&&!Wy(e)&&null!==e.constructor&&!Wy(e.constructor)&&Yy(e.constructor.isBuffer)&&e.constructor.isBuffer(e)}const Gy=Vy("ArrayBuffer"),Ky=Uy("string"),Yy=Uy("function"),Zy=Uy("number"),Xy=e=>null!==e&&"object"==typeof e,Jy=e=>{if("object"!==By(e))return!1;const t=Dy(e);return!(null!==t&&t!==Object.prototype&&null!==Object.getPrototypeOf(t)||$y in e||Fy in e)},Qy=Vy("Date"),eb=Vy("File"),tb=Vy("Blob"),rb=Vy("FileList"),nb="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:"undefined"!=typeof window?window:"undefined"!=typeof __webpack_require__.g?__webpack_require__.g:{},ob=void 0!==nb.FormData?nb.FormData:void 0,ib=Vy("URLSearchParams"),[sb,ab,lb,cb]=["ReadableStream","Request","Response","Headers"].map(Vy);function ub(e,t,{allOwnKeys:r=!1}={}){if(null==e)return;let n,o;if("object"!=typeof e&&(e=[e]),qy(e))for(n=0,o=e.length;n<o;n++)t.call(null,e[n],n,e);else{if(Hy(e))return;const o=r?Object.getOwnPropertyNames(e):Object.keys(e),i=o.length;let s;for(n=0;n<i;n++)s=o[n],t.call(null,e[s],s,e)}}function pb(e,t){if(Hy(e))return null;t=t.toLowerCase();const r=Object.keys(e);let n,o=r.length;for(;o-- >0;)if(n=r[o],t===n.toLowerCase())return n;return null}const db="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:"undefined"!=typeof window?window:__webpack_require__.g,fb=e=>!Wy(e)&&e!==db,hb=(mb="undefined"!=typeof Uint8Array&&Dy(Uint8Array),e=>mb&&e instanceof mb);var mb;const gb=Vy("HTMLFormElement"),vb=(({hasOwnProperty:e})=>(t,r)=>e.call(t,r))(Object.prototype),yb=Vy("RegExp"),bb=(e,t)=>{const r=Object.getOwnPropertyDescriptors(e),n={};ub(r,(r,o)=>{let i;!1!==(i=t(r,o,e))&&(n[o]=i||r)}),Object.defineProperties(e,n)},wb=Vy("AsyncFunction"),xb=(_b="function"==typeof setImmediate,Sb=Yy(db.postMessage),_b?setImmediate:Sb?((e,t)=>(db.addEventListener("message",({source:r,data:n})=>{r===db&&n===e&&t.length&&t.shift()()},!1),r=>{t.push(r),db.postMessage(e,"*")}))(`axios@${Math.random()}`,[]):e=>setTimeout(e));var _b,Sb;const kb="undefined"!=typeof queueMicrotask?queueMicrotask.bind(db):"undefined"!=typeof process&&process.nextTick||xb,Cb={isArray:qy,isArrayBuffer:Gy,isBuffer:Hy,isFormData:e=>{let t;return e&&(ob&&e instanceof ob||Yy(e.append)&&("formdata"===(t=By(e))||"object"===t&&Yy(e.toString)&&"[object FormData]"===e.toString()))},isArrayBufferView:function(e){let t;return t="undefined"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer.isView(e):e&&e.buffer&&Gy(e.buffer),t},isString:Ky,isNumber:Zy,isBoolean:e=>!0===e||!1===e,isObject:Xy,isPlainObject:Jy,isEmptyObject:e=>{if(!Xy(e)||Hy(e))return!1;try{return 0===Object.keys(e).length&&Object.getPrototypeOf(e)===Object.prototype}catch(e){return!1}},isReadableStream:sb,isRequest:ab,isResponse:lb,isHeaders:cb,isUndefined:Wy,isDate:Qy,isFile:eb,isReactNativeBlob:e=>!(!e||void 0===e.uri),isReactNative:e=>e&&void 0!==e.getParts,isBlob:tb,isRegExp:yb,isFunction:Yy,isStream:e=>Xy(e)&&Yy(e.pipe),isURLSearchParams:ib,isTypedArray:hb,isFileList:rb,forEach:ub,merge:function e(){const{caseless:t,skipUndefined:r}=fb(this)&&this||{},n={},o=(o,i)=>{if("__proto__"===i||"constructor"===i||"prototype"===i)return;const s=t&&pb(n,i)||i;Jy(n[s])&&Jy(o)?n[s]=e(n[s],o):Jy(o)?n[s]=e({},o):qy(o)?n[s]=o.slice():r&&Wy(o)||(n[s]=o)};for(let e=0,t=arguments.length;e<t;e++)arguments[e]&&ub(arguments[e],o);return n},extend:(e,t,r,{allOwnKeys:n}={})=>(ub(t,(t,n)=>{r&&Yy(t)?Object.defineProperty(e,n,{value:jy(t,r),writable:!0,enumerable:!0,configurable:!0}):Object.defineProperty(e,n,{value:t,writable:!0,enumerable:!0,configurable:!0})},{allOwnKeys:n}),e),trim:e=>e.trim?e.trim():e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,""),stripBOM:e=>(65279===e.charCodeAt(0)&&(e=e.slice(1)),e),inherits:(e,t,r,n)=>{e.prototype=Object.create(t.prototype,n),Object.defineProperty(e.prototype,"constructor",{value:e,writable:!0,enumerable:!1,configurable:!0}),Object.defineProperty(e,"super",{value:t.prototype}),r&&Object.assign(e.prototype,r)},toFlatObject:(e,t,r,n)=>{let o,i,s;const a={};if(t=t||{},null==e)return t;do{for(o=Object.getOwnPropertyNames(e),i=o.length;i-- >0;)s=o[i],n&&!n(s,e,t)||a[s]||(t[s]=e[s],a[s]=!0);e=!1!==r&&Dy(e)}while(e&&(!r||r(e,t))&&e!==Object.prototype);return t},kindOf:By,kindOfTest:Vy,endsWith:(e,t,r)=>{e=String(e),(void 0===r||r>e.length)&&(r=e.length),r-=t.length;const n=e.indexOf(t,r);return-1!==n&&n===r},toArray:e=>{if(!e)return null;if(qy(e))return e;let t=e.length;if(!Zy(t))return null;const r=new Array(t);for(;t-- >0;)r[t]=e[t];return r},forEachEntry:(e,t)=>{const r=(e&&e[Fy]).call(e);let n;for(;(n=r.next())&&!n.done;){const r=n.value;t.call(e,r[0],r[1])}},matchAll:(e,t)=>{let r;const n=[];for(;null!==(r=e.exec(t));)n.push(r);return n},isHTMLForm:gb,hasOwnProperty:vb,hasOwnProp:vb,reduceDescriptors:bb,freezeMethods:e=>{bb(e,(t,r)=>{if(Yy(e)&&-1!==["arguments","caller","callee"].indexOf(r))return!1;const n=e[r];Yy(n)&&(t.enumerable=!1,"writable"in t?t.writable=!1:t.set||(t.set=()=>{throw Error("Can not rewrite read-only method '"+r+"'")}))})},toObjectSet:(e,t)=>{const r={},n=e=>{e.forEach(e=>{r[e]=!0})};return qy(e)?n(e):n(String(e).split(t)),r},toCamelCase:e=>e.toLowerCase().replace(/[-_\s]([a-z\d])(\w*)/g,function(e,t,r){return t.toUpperCase()+r}),noop:()=>{},toFiniteNumber:(e,t)=>null!=e&&Number.isFinite(e=+e)?e:t,findKey:pb,global:db,isContextDefined:fb,isSpecCompliantForm:function(e){return!!(e&&Yy(e.append)&&"FormData"===e[$y]&&e[Fy])},toJSONObject:e=>{const t=new Array(10),r=(e,n)=>{if(Xy(e)){if(t.indexOf(e)>=0)return;if(Hy(e))return e;if(!("toJSON"in e)){t[n]=e;const o=qy(e)?[]:{};return ub(e,(e,t)=>{const i=r(e,n+1);!Wy(i)&&(o[t]=i)}),t[n]=void 0,o}}return e};return r(e,0)},isAsyncFn:wb,isThenable:e=>e&&(Xy(e)||Yy(e))&&Yy(e.then)&&Yy(e.catch),setImmediate:xb,asap:kb,isIterable:e=>null!=e&&Yy(e[Fy])};class Ob extends Error{static from(e,t,r,n,o,i){const s=new Ob(e.message,t||e.code,r,n,o);return s.cause=e,s.name=e.name,null!=e.status&&null==s.status&&(s.status=e.status),i&&Object.assign(s,i),s}toJSON(){return{message:this.message,name:this.name,description:this.description,number:this.number,fileName:this.fileName,lineNumber:this.lineNumber,columnNumber:this.columnNumber,stack:this.stack,config:Cb.toJSONObject(this.config),code:this.code,status:this.status}}constructor(e,t,r,n,o){super(e),Object.defineProperty(this,"message",{value:e,enumerable:!0,writable:!0,configurable:!0}),this.name="AxiosError",this.isAxiosError=!0,t&&(this.code=t),r&&(this.config=r),n&&(this.request=n),o&&(this.response=o,this.status=o.status)}}Ob.ERR_BAD_OPTION_VALUE="ERR_BAD_OPTION_VALUE",Ob.ERR_BAD_OPTION="ERR_BAD_OPTION",Ob.ECONNABORTED="ECONNABORTED",Ob.ETIMEDOUT="ETIMEDOUT",Ob.ERR_NETWORK="ERR_NETWORK",Ob.ERR_FR_TOO_MANY_REDIRECTS="ERR_FR_TOO_MANY_REDIRECTS",Ob.ERR_DEPRECATED="ERR_DEPRECATED",Ob.ERR_BAD_RESPONSE="ERR_BAD_RESPONSE",Ob.ERR_BAD_REQUEST="ERR_BAD_REQUEST",Ob.ERR_CANCELED="ERR_CANCELED",Ob.ERR_NOT_SUPPORT="ERR_NOT_SUPPORT",Ob.ERR_INVALID_URL="ERR_INVALID_URL";const Eb=Ob;function Tb(e){return Cb.isPlainObject(e)||Cb.isArray(e)}function Rb(e){return Cb.endsWith(e,"[]")?e.slice(0,-2):e}function Ib(e,t,r){return e?e.concat(t).map(function(e,t){return e=Rb(e),!r&&t?"["+e+"]":e}).join(r?".":""):t}const Mb=Cb.toFlatObject(Cb,{},null,function(e){return/^is[A-Z]/.test(e)});function Ab(e,t,r){if(!Cb.isObject(e))throw new TypeError("target must be an object");t=t||new FormData;const n=(r=Cb.toFlatObject(r,{metaTokens:!0,dots:!1,indexes:!1},!1,function(e,t){return!Cb.isUndefined(t[e])})).metaTokens,o=r.visitor||c,i=r.dots,s=r.indexes,a=(r.Blob||"undefined"!=typeof Blob&&Blob)&&Cb.isSpecCompliantForm(t);if(!Cb.isFunction(o))throw new TypeError("visitor must be a function");function l(e){if(null===e)return"";if(Cb.isDate(e))return e.toISOString();if(Cb.isBoolean(e))return e.toString();if(!a&&Cb.isBlob(e))throw new Eb("Blob is not supported. Use a Buffer instead.");return Cb.isArrayBuffer(e)||Cb.isTypedArray(e)?a&&"function"==typeof Blob?new Blob([e]):Buffer.from(e):e}function c(e,r,o){let a=e;if(Cb.isReactNative(t)&&Cb.isReactNativeBlob(e))return t.append(Ib(o,r,i),l(e)),!1;if(e&&!o&&"object"==typeof e)if(Cb.endsWith(r,"{}"))r=n?r:r.slice(0,-2),e=JSON.stringify(e);else if(Cb.isArray(e)&&function(e){return Cb.isArray(e)&&!e.some(Tb)}(e)||(Cb.isFileList(e)||Cb.endsWith(r,"[]"))&&(a=Cb.toArray(e)))return r=Rb(r),a.forEach(function(e,n){!Cb.isUndefined(e)&&null!==e&&t.append(!0===s?Ib([r],n,i):null===s?r:r+"[]",l(e))}),!1;return!!Tb(e)||(t.append(Ib(o,r,i),l(e)),!1)}const u=[],p=Object.assign(Mb,{defaultVisitor:c,convertValue:l,isVisitable:Tb});if(!Cb.isObject(e))throw new TypeError("data must be an object");return function e(r,n){if(!Cb.isUndefined(r)){if(-1!==u.indexOf(r))throw Error("Circular reference detected in "+n.join("."));u.push(r),Cb.forEach(r,function(r,i){!0===(!(Cb.isUndefined(r)||null===r)&&o.call(t,r,Cb.isString(i)?i.trim():i,n,p))&&e(r,n?n.concat(i):[i])}),u.pop()}}(e),t}function Pb(e){const t={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+","%00":"\0"};return encodeURIComponent(e).replace(/[!'()~]|%20|%00/g,function(e){return t[e]})}function Nb(e,t){this._pairs=[],e&&Ab(e,this,t)}const jb=Nb.prototype;function Lb(e){return encodeURIComponent(e).replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+")}function Db(e,t,r){if(!t)return e;const n=r&&r.encode||Lb,o=Cb.isFunction(r)?{serialize:r}:r,i=o&&o.serialize;let s;if(s=i?i(t,o):Cb.isURLSearchParams(t)?t.toString():new Nb(t,o).toString(n),s){const t=e.indexOf("#");-1!==t&&(e=e.slice(0,t)),e+=(-1===e.indexOf("?")?"?":"&")+s}return e}jb.append=function(e,t){this._pairs.push([e,t])},jb.toString=function(e){const t=e?function(t){return e.call(this,t,Pb)}:Pb;return this._pairs.map(function(e){return t(e[0])+"="+t(e[1])},"").join("&")};class Fb{use(e,t,r){return this.handlers.push({fulfilled:e,rejected:t,synchronous:!!r&&r.synchronous,runWhen:r?r.runWhen:null}),this.handlers.length-1}eject(e){this.handlers[e]&&(this.handlers[e]=null)}clear(){this.handlers&&(this.handlers=[])}forEach(e){Cb.forEach(this.handlers,function(t){null!==t&&e(t)})}constructor(){this.handlers=[]}}const $b={silentJSONParsing:!0,forcedJSONParsing:!0,clarifyTimeoutError:!1,legacyInterceptorReqResOrdering:!0},Bb={isBrowser:!0,classes:{URLSearchParams:"undefined"!=typeof URLSearchParams?URLSearchParams:Nb,FormData:"undefined"!=typeof FormData?FormData:null,Blob:"undefined"!=typeof Blob?Blob:null},protocols:["http","https","file","blob","url","data"]},zb="undefined"!=typeof window&&"undefined"!=typeof document,Vb="object"==typeof navigator&&navigator||void 0,Ub=zb&&(!Vb||["ReactNative","NativeScript","NS"].indexOf(Vb.product)<0),qb="undefined"!=typeof WorkerGlobalScope&&self instanceof WorkerGlobalScope&&"function"==typeof self.importScripts,Wb=zb&&window.location.href||"http://localhost",Hb={...Object.freeze(Object.defineProperty({__proto__:null,hasBrowserEnv:zb,hasStandardBrowserEnv:Ub,hasStandardBrowserWebWorkerEnv:qb,navigator:Vb,origin:Wb},Symbol.toStringTag,{value:"Module"})),...Bb};function Gb(e){function t(e,r,n,o){let i=e[o++];if("__proto__"===i)return!0;const s=Number.isFinite(+i),a=o>=e.length;return i=!i&&Cb.isArray(n)?n.length:i,a?(Cb.hasOwnProp(n,i)?n[i]=[n[i],r]:n[i]=r,!s):(n[i]&&Cb.isObject(n[i])||(n[i]=[]),t(e,r,n[i],o)&&Cb.isArray(n[i])&&(n[i]=function(e){const t={},r=Object.keys(e);let n;const o=r.length;let i;for(n=0;n<o;n++)i=r[n],t[i]=e[i];return t}(n[i])),!s)}if(Cb.isFormData(e)&&Cb.isFunction(e.entries)){const r={};return Cb.forEachEntry(e,(e,n)=>{t(function(e){return Cb.matchAll(/\w+|\[(\w*)]/g,e).map(e=>"[]"===e[0]?"":e[1]||e[0])}(e),n,r,0)}),r}return null}const Kb={transitional:$b,adapter:["xhr","http","fetch"],transformRequest:[function(e,t){const r=t.getContentType()||"",n=r.indexOf("application/json")>-1,o=Cb.isObject(e);if(o&&Cb.isHTMLForm(e)&&(e=new FormData(e)),Cb.isFormData(e))return n?JSON.stringify(Gb(e)):e;if(Cb.isArrayBuffer(e)||Cb.isBuffer(e)||Cb.isStream(e)||Cb.isFile(e)||Cb.isBlob(e)||Cb.isReadableStream(e))return e;if(Cb.isArrayBufferView(e))return e.buffer;if(Cb.isURLSearchParams(e))return t.setContentType("application/x-www-form-urlencoded;charset=utf-8",!1),e.toString();let i;if(o){if(r.indexOf("application/x-www-form-urlencoded")>-1)return function(e,t){return Ab(e,new Hb.classes.URLSearchParams,{visitor:function(e,t,r,n){return Hb.isNode&&Cb.isBuffer(e)?(this.append(t,e.toString("base64")),!1):n.defaultVisitor.apply(this,arguments)},...t})}(e,this.formSerializer).toString();if((i=Cb.isFileList(e))||r.indexOf("multipart/form-data")>-1){const t=this.env&&this.env.FormData;return Ab(i?{"files[]":e}:e,t&&new t,this.formSerializer)}}return o||n?(t.setContentType("application/json",!1),function(e){if(Cb.isString(e))try{return(0,JSON.parse)(e),Cb.trim(e)}catch(e){if("SyntaxError"!==e.name)throw e}return(0,JSON.stringify)(e)}(e)):e}],transformResponse:[function(e){const t=this.transitional||Kb.transitional,r=t&&t.forcedJSONParsing,n="json"===this.responseType;if(Cb.isResponse(e)||Cb.isReadableStream(e))return e;if(e&&Cb.isString(e)&&(r&&!this.responseType||n)){const r=!(t&&t.silentJSONParsing)&&n;try{return JSON.parse(e,this.parseReviver)}catch(e){if(r){if("SyntaxError"===e.name)throw Eb.from(e,Eb.ERR_BAD_RESPONSE,this,null,this.response);throw e}}}return e}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,maxBodyLength:-1,env:{FormData:Hb.classes.FormData,Blob:Hb.classes.Blob},validateStatus:function(e){return e>=200&&e<300},headers:{common:{Accept:"application/json, text/plain, */*","Content-Type":void 0}}};Cb.forEach(["delete","get","head","post","put","patch"],e=>{Kb.headers[e]={}});const Yb=Kb,Zb=Cb.toObjectSet(["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"]),Xb=Symbol("internals");function Jb(e,t){if(!1!==e&&null!=e)if(Cb.isArray(e))e.forEach(e=>Jb(e,t));else if(!(e=>!/[\r\n]/.test(e))(String(e)))throw new Error(`Invalid character in header content ["${t}"]`)}function Qb(e){return e&&String(e).trim().toLowerCase()}function ew(e){return!1===e||null==e?e:Cb.isArray(e)?e.map(ew):function(e){let t=e.length;for(;t>0;){const r=e.charCodeAt(t-1);if(10!==r&&13!==r)break;t-=1}return t===e.length?e:e.slice(0,t)}(String(e))}function tw(e,t,r,n,o){return Cb.isFunction(n)?n.call(this,t,r):(o&&(t=r),Cb.isString(t)?Cb.isString(n)?-1!==t.indexOf(n):Cb.isRegExp(n)?n.test(t):void 0:void 0)}class rw{set(e,t,r){const n=this;function o(e,t,r){const o=Qb(t);if(!o)throw new Error("header name must be a non-empty string");const i=Cb.findKey(n,o);(!i||void 0===n[i]||!0===r||void 0===r&&!1!==n[i])&&(Jb(e,t),n[i||t]=ew(e))}const i=(e,t)=>Cb.forEach(e,(e,r)=>o(e,r,t));if(Cb.isPlainObject(e)||e instanceof this.constructor)i(e,t);else if(Cb.isString(e)&&(e=e.trim())&&!/^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(e.trim()))i((e=>{const t={};let r,n,o;return e&&e.split("\n").forEach(function(e){o=e.indexOf(":"),r=e.substring(0,o).trim().toLowerCase(),n=e.substring(o+1).trim(),!r||t[r]&&Zb[r]||("set-cookie"===r?t[r]?t[r].push(n):t[r]=[n]:t[r]=t[r]?t[r]+", "+n:n)}),t})(e),t);else if(Cb.isObject(e)&&Cb.isIterable(e)){let r,n,o={};for(const t of e){if(!Cb.isArray(t))throw TypeError("Object iterator must return a key-value pair");o[n=t[0]]=(r=o[n])?Cb.isArray(r)?[...r,t[1]]:[r,t[1]]:t[1]}i(o,t)}else null!=e&&o(t,e,r);return this}get(e,t){if(e=Qb(e)){const r=Cb.findKey(this,e);if(r){const e=this[r];if(!t)return e;if(!0===t)return function(e){const t=Object.create(null),r=/([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;let n;for(;n=r.exec(e);)t[n[1]]=n[2];return t}(e);if(Cb.isFunction(t))return t.call(this,e,r);if(Cb.isRegExp(t))return t.exec(e);throw new TypeError("parser must be boolean|regexp|function")}}}has(e,t){if(e=Qb(e)){const r=Cb.findKey(this,e);return!(!r||void 0===this[r]||t&&!tw(0,this[r],r,t))}return!1}delete(e,t){const r=this;let n=!1;function o(e){if(e=Qb(e)){const o=Cb.findKey(r,e);!o||t&&!tw(0,r[o],o,t)||(delete r[o],n=!0)}}return Cb.isArray(e)?e.forEach(o):o(e),n}clear(e){const t=Object.keys(this);let r=t.length,n=!1;for(;r--;){const o=t[r];e&&!tw(0,this[o],o,e,!0)||(delete this[o],n=!0)}return n}normalize(e){const t=this,r={};return Cb.forEach(this,(n,o)=>{const i=Cb.findKey(r,o);if(i)return t[i]=ew(n),void delete t[o];const s=e?function(e){return e.trim().toLowerCase().replace(/([a-z\d])(\w*)/g,(e,t,r)=>t.toUpperCase()+r)}(o):String(o).trim();s!==o&&delete t[o],t[s]=ew(n),r[s]=!0}),this}concat(...e){return this.constructor.concat(this,...e)}toJSON(e){const t=Object.create(null);return Cb.forEach(this,(r,n)=>{null!=r&&!1!==r&&(t[n]=e&&Cb.isArray(r)?r.join(", "):r)}),t}[Symbol.iterator](){return Object.entries(this.toJSON())[Symbol.iterator]()}toString(){return Object.entries(this.toJSON()).map(([e,t])=>e+": "+t).join("\n")}getSetCookie(){return this.get("set-cookie")||[]}get[Symbol.toStringTag](){return"AxiosHeaders"}static from(e){return e instanceof this?e:new this(e)}static concat(e,...t){const r=new this(e);return t.forEach(e=>r.set(e)),r}static accessor(e){const t=(this[Xb]=this[Xb]={accessors:{}}).accessors,r=this.prototype;function n(e){const n=Qb(e);t[n]||(function(e,t){const r=Cb.toCamelCase(" "+t);["get","set","has"].forEach(n=>{Object.defineProperty(e,n+r,{value:function(e,r,o){return this[n].call(this,t,e,r,o)},configurable:!0})})}(r,e),t[n]=!0)}return Cb.isArray(e)?e.forEach(n):n(e),this}constructor(e){e&&this.set(e)}}rw.accessor(["Content-Type","Content-Length","Accept","Accept-Encoding","User-Agent","Authorization"]),Cb.reduceDescriptors(rw.prototype,({value:e},t)=>{let r=t[0].toUpperCase()+t.slice(1);return{get:()=>e,set(e){this[r]=e}}}),Cb.freezeMethods(rw);const nw=rw;function ow(e,t){const r=this||Yb,n=t||r,o=nw.from(n.headers);let i=n.data;return Cb.forEach(e,function(e){i=e.call(r,i,o.normalize(),t?t.status:void 0)}),o.normalize(),i}function iw(e){return!(!e||!e.__CANCEL__)}const sw=class extends Eb{constructor(e,t,r){super(null==e?"canceled":e,Eb.ERR_CANCELED,t,r),this.name="CanceledError",this.__CANCEL__=!0}};function aw(e,t,r){const n=r.config.validateStatus;r.status&&n&&!n(r.status)?t(new Eb("Request failed with status code "+r.status,[Eb.ERR_BAD_REQUEST,Eb.ERR_BAD_RESPONSE][Math.floor(r.status/100)-4],r.config,r.request,r)):e(r)}const lw=(e,t,r=3)=>{let n=0;const o=function(e,t){e=e||10;const r=new Array(e),n=new Array(e);let o,i=0,s=0;return t=void 0!==t?t:1e3,function(a){const l=Date.now(),c=n[s];o||(o=l),r[i]=a,n[i]=l;let u=s,p=0;for(;u!==i;)p+=r[u++],u%=e;if(i=(i+1)%e,i===s&&(s=(s+1)%e),l-o<t)return;const d=c&&l-c;return d?Math.round(1e3*p/d):void 0}}(50,250);return function(r,i){let s,a,l=0,c=1e3/i;const u=(r,i=Date.now())=>{l=i,s=null,a&&(clearTimeout(a),a=null),(r=>{const i=r.loaded,s=r.lengthComputable?r.total:void 0,a=i-n,l=o(a);n=i,e({loaded:i,total:s,progress:s?i/s:void 0,bytes:a,rate:l||void 0,estimated:l&&s&&i<=s?(s-i)/l:void 0,event:r,lengthComputable:null!=s,[t?"download":"upload"]:!0})})(...r)};return[(...e)=>{const t=Date.now(),r=t-l;r>=c?u(e,t):(s=e,a||(a=setTimeout(()=>{a=null,u(s)},c-r)))},()=>s&&u(s)]}(0,r)},cw=(e,t)=>{const r=null!=e;return[n=>t[0]({lengthComputable:r,total:e,loaded:n}),t[1]]},uw=e=>(...t)=>Cb.asap(()=>e(...t)),pw=Hb.hasStandardBrowserEnv?((e,t)=>r=>(r=new URL(r,Hb.origin),e.protocol===r.protocol&&e.host===r.host&&(t||e.port===r.port)))(new URL(Hb.origin),Hb.navigator&&/(msie|trident)/i.test(Hb.navigator.userAgent)):()=>!0,dw=Hb.hasStandardBrowserEnv?{write(e,t,r,n,o,i,s){if("undefined"==typeof document)return;const a=[`${e}=${encodeURIComponent(t)}`];Cb.isNumber(r)&&a.push(`expires=${new Date(r).toUTCString()}`),Cb.isString(n)&&a.push(`path=${n}`),Cb.isString(o)&&a.push(`domain=${o}`),!0===i&&a.push("secure"),Cb.isString(s)&&a.push(`SameSite=${s}`),document.cookie=a.join("; ")},read(e){if("undefined"==typeof document)return null;const t=document.cookie.match(new RegExp("(?:^|; )"+e+"=([^;]*)"));return t?decodeURIComponent(t[1]):null},remove(e){this.write(e,"",Date.now()-864e5,"/")}}:{write(){},read:()=>null,remove(){}};function fw(e,t,r){let n=!("string"==typeof(o=t)&&/^([a-z][a-z\d+\-.]*:)?\/\//i.test(o));var o;return e&&(n||0==r)?function(e,t){return t?e.replace(/\/?\/$/,"")+"/"+t.replace(/^\/+/,""):e}(e,t):t}const hw=e=>e instanceof nw?{...e}:e;function mw(e,t){t=t||{};const r={};function n(e,t,r,n){return Cb.isPlainObject(e)&&Cb.isPlainObject(t)?Cb.merge.call({caseless:n},e,t):Cb.isPlainObject(t)?Cb.merge({},t):Cb.isArray(t)?t.slice():t}function o(e,t,r,o){return Cb.isUndefined(t)?Cb.isUndefined(e)?void 0:n(void 0,e,0,o):n(e,t,0,o)}function i(e,t){if(!Cb.isUndefined(t))return n(void 0,t)}function s(e,t){return Cb.isUndefined(t)?Cb.isUndefined(e)?void 0:n(void 0,e):n(void 0,t)}function a(r,o,i){return i in t?n(r,o):i in e?n(void 0,r):void 0}const l={url:i,method:i,data:i,baseURL:s,transformRequest:s,transformResponse:s,paramsSerializer:s,timeout:s,timeoutMessage:s,withCredentials:s,withXSRFToken:s,adapter:s,responseType:s,xsrfCookieName:s,xsrfHeaderName:s,onUploadProgress:s,onDownloadProgress:s,decompress:s,maxContentLength:s,maxBodyLength:s,beforeRedirect:s,transport:s,httpAgent:s,httpsAgent:s,cancelToken:s,socketPath:s,responseEncoding:s,validateStatus:a,headers:(e,t,r)=>o(hw(e),hw(t),0,!0)};return Cb.forEach(Object.keys({...e,...t}),function(n){if("__proto__"===n||"constructor"===n||"prototype"===n)return;const i=Cb.hasOwnProp(l,n)?l[n]:o,s=i(e[n],t[n],n);Cb.isUndefined(s)&&i!==a||(r[n]=s)}),r}const gw=e=>{const t=mw({},e);let{data:r,withXSRFToken:n,xsrfHeaderName:o,xsrfCookieName:i,headers:s,auth:a}=t;if(t.headers=s=nw.from(s),t.url=Db(fw(t.baseURL,t.url,t.allowAbsoluteUrls),e.params,e.paramsSerializer),a&&s.set("Authorization","Basic "+btoa((a.username||"")+":"+(a.password?unescape(encodeURIComponent(a.password)):""))),Cb.isFormData(r))if(Hb.hasStandardBrowserEnv||Hb.hasStandardBrowserWebWorkerEnv)s.setContentType(void 0);else if(Cb.isFunction(r.getHeaders)){const e=r.getHeaders(),t=["content-type","content-length"];Object.entries(e).forEach(([e,r])=>{t.includes(e.toLowerCase())&&s.set(e,r)})}if(Hb.hasStandardBrowserEnv&&(n&&Cb.isFunction(n)&&(n=n(t)),n||!1!==n&&pw(t.url))){const e=o&&i&&dw.read(i);e&&s.set(o,e)}return t},vw="undefined"!=typeof XMLHttpRequest&&function(e){return new Promise(function(t,r){const n=gw(e);let o=n.data;const i=nw.from(n.headers).normalize();let s,a,l,c,u,{responseType:p,onUploadProgress:d,onDownloadProgress:f}=n;function h(){c&&c(),u&&u(),n.cancelToken&&n.cancelToken.unsubscribe(s),n.signal&&n.signal.removeEventListener("abort",s)}let m=new XMLHttpRequest;function g(){if(!m)return;const n=nw.from("getAllResponseHeaders"in m&&m.getAllResponseHeaders());aw(function(e){t(e),h()},function(e){r(e),h()},{data:p&&"text"!==p&&"json"!==p?m.response:m.responseText,status:m.status,statusText:m.statusText,headers:n,config:e,request:m}),m=null}m.open(n.method.toUpperCase(),n.url,!0),m.timeout=n.timeout,"onloadend"in m?m.onloadend=g:m.onreadystatechange=function(){m&&4===m.readyState&&(0!==m.status||m.responseURL&&0===m.responseURL.indexOf("file:"))&&setTimeout(g)},m.onabort=function(){m&&(r(new Eb("Request aborted",Eb.ECONNABORTED,e,m)),m=null)},m.onerror=function(t){const n=t&&t.message?t.message:"Network Error",o=new Eb(n,Eb.ERR_NETWORK,e,m);o.event=t||null,r(o),m=null},m.ontimeout=function(){let t=n.timeout?"timeout of "+n.timeout+"ms exceeded":"timeout exceeded";const o=n.transitional||$b;n.timeoutErrorMessage&&(t=n.timeoutErrorMessage),r(new Eb(t,o.clarifyTimeoutError?Eb.ETIMEDOUT:Eb.ECONNABORTED,e,m)),m=null},void 0===o&&i.setContentType(null),"setRequestHeader"in m&&Cb.forEach(i.toJSON(),function(e,t){m.setRequestHeader(t,e)}),Cb.isUndefined(n.withCredentials)||(m.withCredentials=!!n.withCredentials),p&&"json"!==p&&(m.responseType=n.responseType),f&&([l,u]=lw(f,!0),m.addEventListener("progress",l)),d&&m.upload&&([a,c]=lw(d),m.upload.addEventListener("progress",a),m.upload.addEventListener("loadend",c)),(n.cancelToken||n.signal)&&(s=t=>{m&&(r(!t||t.type?new sw(null,e,m):t),m.abort(),m=null)},n.cancelToken&&n.cancelToken.subscribe(s),n.signal&&(n.signal.aborted?s():n.signal.addEventListener("abort",s)));const v=function(e){const t=/^([-+\w]{1,25})(:?\/\/|:)/.exec(e);return t&&t[1]||""}(n.url);v&&-1===Hb.protocols.indexOf(v)?r(new Eb("Unsupported protocol "+v+":",Eb.ERR_BAD_REQUEST,e)):m.send(o||null)})},yw=(e,t)=>{const{length:r}=e=e?e.filter(Boolean):[];if(t||r){let r,n=new AbortController;const o=function(e){if(!r){r=!0,s();const t=e instanceof Error?e:this.reason;n.abort(t instanceof Eb?t:new sw(t instanceof Error?t.message:t))}};let i=t&&setTimeout(()=>{i=null,o(new Eb(`timeout of ${t}ms exceeded`,Eb.ETIMEDOUT))},t);const s=()=>{e&&(i&&clearTimeout(i),i=null,e.forEach(e=>{e.unsubscribe?e.unsubscribe(o):e.removeEventListener("abort",o)}),e=null)};e.forEach(e=>e.addEventListener("abort",o));const{signal:a}=n;return a.unsubscribe=()=>Cb.asap(s),a}},bw=function*(e,t){let r=e.byteLength;if(!t||r<t)return void(yield e);let n,o=0;for(;o<r;)n=o+t,yield e.slice(o,n),o=n},ww=(e,t,r,n)=>{const o=async function*(e,t){for await(const r of async function*(e){if(e[Symbol.asyncIterator])return void(yield*e);const t=e.getReader();try{for(;;){const{done:e,value:r}=await t.read();if(e)break;yield r}}finally{await t.cancel()}}(e))yield*bw(r,t)}(e,t);let i,s=0,a=e=>{i||(i=!0,n&&n(e))};return new ReadableStream({async pull(e){try{const{done:t,value:n}=await o.next();if(t)return a(),void e.close();let i=n.byteLength;if(r){let e=s+=i;r(e)}e.enqueue(new Uint8Array(n))}catch(e){throw a(e),e}},cancel:e=>(a(e),o.return())},{highWaterMark:2})},{isFunction:xw}=Cb,_w=(({Request:e,Response:t})=>({Request:e,Response:t}))(Cb.global),{ReadableStream:Sw,TextEncoder:kw}=Cb.global,Cw=(e,...t)=>{try{return!!e(...t)}catch(e){return!1}},Ow=e=>{e=Cb.merge.call({skipUndefined:!0},_w,e);const{fetch:t,Request:r,Response:n}=e,o=t?xw(t):"function"==typeof fetch,i=xw(r),s=xw(n);if(!o)return!1;const a=o&&xw(Sw),l=o&&("function"==typeof kw?(c=new kw,e=>c.encode(e)):async e=>new Uint8Array(await new r(e).arrayBuffer()));var c;const u=i&&a&&Cw(()=>{let e=!1;const t=new Sw,n=new r(Hb.origin,{body:t,method:"POST",get duplex(){return e=!0,"half"}}).headers.has("Content-Type");return t.cancel(),e&&!n}),p=s&&a&&Cw(()=>Cb.isReadableStream(new n("").body)),d={stream:p&&(e=>e.body)};o&&["text","arrayBuffer","blob","formData","stream"].forEach(e=>{!d[e]&&(d[e]=(t,r)=>{let n=t&&t[e];if(n)return n.call(t);throw new Eb(`Response type '${e}' is not supported`,Eb.ERR_NOT_SUPPORT,r)})});return async e=>{let{url:o,method:s,data:a,signal:c,cancelToken:f,timeout:h,onDownloadProgress:m,onUploadProgress:g,responseType:v,headers:y,withCredentials:b="same-origin",fetchOptions:w}=gw(e),x=t||fetch;v=v?(v+"").toLowerCase():"text";let _=yw([c,f&&f.toAbortSignal()],h),S=null;const k=_&&_.unsubscribe&&(()=>{_.unsubscribe()});let C;try{if(g&&u&&"get"!==s&&"head"!==s&&0!==(C=await(async(e,t)=>{const n=Cb.toFiniteNumber(e.getContentLength());return null==n?(async e=>{if(null==e)return 0;if(Cb.isBlob(e))return e.size;if(Cb.isSpecCompliantForm(e)){const t=new r(Hb.origin,{method:"POST",body:e});return(await t.arrayBuffer()).byteLength}return Cb.isArrayBufferView(e)||Cb.isArrayBuffer(e)?e.byteLength:(Cb.isURLSearchParams(e)&&(e+=""),Cb.isString(e)?(await l(e)).byteLength:void 0)})(t):n})(y,a))){let e,t=new r(o,{method:"POST",body:a,duplex:"half"});if(Cb.isFormData(a)&&(e=t.headers.get("content-type"))&&y.setContentType(e),t.body){const[e,r]=cw(C,lw(uw(g)));a=ww(t.body,65536,e,r)}}Cb.isString(b)||(b=b?"include":"omit");const t=i&&"credentials"in r.prototype,c={...w,signal:_,method:s.toUpperCase(),headers:y.normalize().toJSON(),body:a,duplex:"half",credentials:t?b:void 0};S=i&&new r(o,c);let f=await(i?x(S,w):x(o,c));const h=p&&("stream"===v||"response"===v);if(p&&(m||h&&k)){const e={};["status","statusText","headers"].forEach(t=>{e[t]=f[t]});const t=Cb.toFiniteNumber(f.headers.get("content-length")),[r,o]=m&&cw(t,lw(uw(m),!0))||[];f=new n(ww(f.body,65536,r,()=>{o&&o(),k&&k()}),e)}v=v||"text";let O=await d[Cb.findKey(d,v)||"text"](f,e);return!h&&k&&k(),await new Promise((t,r)=>{aw(t,r,{data:O,headers:nw.from(f.headers),status:f.status,statusText:f.statusText,config:e,request:S})})}catch(t){if(k&&k(),t&&"TypeError"===t.name&&/Load failed|fetch/i.test(t.message))throw Object.assign(new Eb("Network Error",Eb.ERR_NETWORK,e,S,t&&t.response),{cause:t.cause||t});throw Eb.from(t,t&&t.code,e,S,t&&t.response)}}},Ew=new Map,Tw=e=>{let t=e&&e.env||{};const{fetch:r,Request:n,Response:o}=t,i=[n,o,r];let s,a,l=i.length,c=Ew;for(;l--;)s=i[l],a=c.get(s),void 0===a&&c.set(s,a=l?new Map:Ow(t)),c=a;return a};Tw();const Rw={http:null,xhr:vw,fetch:{get:Tw}};Cb.forEach(Rw,(e,t)=>{if(e){try{Object.defineProperty(e,"name",{value:t})}catch(e){}Object.defineProperty(e,"adapterName",{value:t})}});const Iw=e=>`- ${e}`,Mw=e=>Cb.isFunction(e)||null===e||!1===e,Aw=function(e,t){e=Cb.isArray(e)?e:[e];const{length:r}=e;let n,o;const i={};for(let s=0;s<r;s++){let r;if(n=e[s],o=n,!Mw(n)&&(o=Rw[(r=String(n)).toLowerCase()],void 0===o))throw new Eb(`Unknown adapter '${r}'`);if(o&&(Cb.isFunction(o)||(o=o.get(t))))break;i[r||"#"+s]=o}if(!o){const e=Object.entries(i).map(([e,t])=>`adapter ${e} `+(!1===t?"is not supported by the environment":"is not available in the build"));let t=r?e.length>1?"since :\n"+e.map(Iw).join("\n"):" "+Iw(e[0]):"as no adapter specified";throw new Eb("There is no suitable adapter to dispatch the request "+t,"ERR_NOT_SUPPORT")}return o};function Pw(e){if(e.cancelToken&&e.cancelToken.throwIfRequested(),e.signal&&e.signal.aborted)throw new sw(null,e)}function Nw(e){return Pw(e),e.headers=nw.from(e.headers),e.data=ow.call(e,e.transformRequest),-1!==["post","put","patch"].indexOf(e.method)&&e.headers.setContentType("application/x-www-form-urlencoded",!1),Aw(e.adapter||Yb.adapter,e)(e).then(function(t){return Pw(e),t.data=ow.call(e,e.transformResponse,t),t.headers=nw.from(t.headers),t},function(t){return iw(t)||(Pw(e),t&&t.response&&(t.response.data=ow.call(e,e.transformResponse,t.response),t.response.headers=nw.from(t.response.headers))),Promise.reject(t)})}const jw="1.15.0",Lw={};["object","boolean","number","function","string","symbol"].forEach((e,t)=>{Lw[e]=function(r){return typeof r===e||"a"+(t<1?"n ":" ")+e}});const Dw={};Lw.transitional=function(e,t,r){function n(e,t){return"[Axios v"+jw+"] Transitional option '"+e+"'"+t+(r?". "+r:"")}return(r,o,i)=>{if(!1===e)throw new Eb(n(o," has been removed"+(t?" in "+t:"")),Eb.ERR_DEPRECATED);return t&&!Dw[o]&&(Dw[o]=!0,console.warn(n(o," has been deprecated since v"+t+" and will be removed in the near future"))),!e||e(r,o,i)}},Lw.spelling=function(e){return(t,r)=>(console.warn(`${r} is likely a misspelling of ${e}`),!0)};const Fw={assertOptions:function(e,t,r){if("object"!=typeof e)throw new Eb("options must be an object",Eb.ERR_BAD_OPTION_VALUE);const n=Object.keys(e);let o=n.length;for(;o-- >0;){const i=n[o],s=t[i];if(s){const t=e[i],r=void 0===t||s(t,i,e);if(!0!==r)throw new Eb("option "+i+" must be "+r,Eb.ERR_BAD_OPTION_VALUE);continue}if(!0!==r)throw new Eb("Unknown option "+i,Eb.ERR_BAD_OPTION)}},validators:Lw},$w=Fw.validators;class Bw{async request(e,t){try{return await this._request(e,t)}catch(e){if(e instanceof Error){let t={};Error.captureStackTrace?Error.captureStackTrace(t):t=new Error;const r=(()=>{if(!t.stack)return"";const e=t.stack.indexOf("\n");return-1===e?"":t.stack.slice(e+1)})();try{if(e.stack){if(r){const t=r.indexOf("\n"),n=-1===t?-1:r.indexOf("\n",t+1),o=-1===n?"":r.slice(n+1);String(e.stack).endsWith(o)||(e.stack+="\n"+r)}}else e.stack=r}catch(e){}}throw e}}_request(e,t){"string"==typeof e?(t=t||{}).url=e:t=e||{},t=mw(this.defaults,t);const{transitional:r,paramsSerializer:n,headers:o}=t;void 0!==r&&Fw.assertOptions(r,{silentJSONParsing:$w.transitional($w.boolean),forcedJSONParsing:$w.transitional($w.boolean),clarifyTimeoutError:$w.transitional($w.boolean),legacyInterceptorReqResOrdering:$w.transitional($w.boolean)},!1),null!=n&&(Cb.isFunction(n)?t.paramsSerializer={serialize:n}:Fw.assertOptions(n,{encode:$w.function,serialize:$w.function},!0)),void 0!==t.allowAbsoluteUrls||(void 0!==this.defaults.allowAbsoluteUrls?t.allowAbsoluteUrls=this.defaults.allowAbsoluteUrls:t.allowAbsoluteUrls=!0),Fw.assertOptions(t,{baseUrl:$w.spelling("baseURL"),withXsrfToken:$w.spelling("withXSRFToken")},!0),t.method=(t.method||this.defaults.method||"get").toLowerCase();let i=o&&Cb.merge(o.common,o[t.method]);o&&Cb.forEach(["delete","get","head","post","put","patch","common"],e=>{delete o[e]}),t.headers=nw.concat(i,o);const s=[];let a=!0;this.interceptors.request.forEach(function(e){if("function"==typeof e.runWhen&&!1===e.runWhen(t))return;a=a&&e.synchronous;const r=t.transitional||$b;r&&r.legacyInterceptorReqResOrdering?s.unshift(e.fulfilled,e.rejected):s.push(e.fulfilled,e.rejected)});const l=[];let c;this.interceptors.response.forEach(function(e){l.push(e.fulfilled,e.rejected)});let u,p=0;if(!a){const e=[Nw.bind(this),void 0];for(e.unshift(...s),e.push(...l),u=e.length,c=Promise.resolve(t);p<u;)c=c.then(e[p++],e[p++]);return c}u=s.length;let d=t;for(;p<u;){const e=s[p++],t=s[p++];try{d=e(d)}catch(e){t.call(this,e);break}}try{c=Nw.call(this,d)}catch(e){return Promise.reject(e)}for(p=0,u=l.length;p<u;)c=c.then(l[p++],l[p++]);return c}getUri(e){return Db(fw((e=mw(this.defaults,e)).baseURL,e.url,e.allowAbsoluteUrls),e.params,e.paramsSerializer)}constructor(e){this.defaults=e||{},this.interceptors={request:new Fb,response:new Fb}}}Cb.forEach(["delete","get","head","options"],function(e){Bw.prototype[e]=function(t,r){return this.request(mw(r||{},{method:e,url:t,data:(r||{}).data}))}}),Cb.forEach(["post","put","patch"],function(e){function t(t){return function(r,n,o){return this.request(mw(o||{},{method:e,headers:t?{"Content-Type":"multipart/form-data"}:{},url:r,data:n}))}}Bw.prototype[e]=t(),Bw.prototype[e+"Form"]=t(!0)});const zw=Bw;class Vw{throwIfRequested(){if(this.reason)throw this.reason}subscribe(e){this.reason?e(this.reason):this._listeners?this._listeners.push(e):this._listeners=[e]}unsubscribe(e){if(!this._listeners)return;const t=this._listeners.indexOf(e);-1!==t&&this._listeners.splice(t,1)}toAbortSignal(){const e=new AbortController,t=t=>{e.abort(t)};return this.subscribe(t),e.signal.unsubscribe=()=>this.unsubscribe(t),e.signal}static source(){let e;return{token:new Vw(function(t){e=t}),cancel:e}}constructor(e){if("function"!=typeof e)throw new TypeError("executor must be a function.");let t;this.promise=new Promise(function(e){t=e});const r=this;this.promise.then(e=>{if(!r._listeners)return;let t=r._listeners.length;for(;t-- >0;)r._listeners[t](e);r._listeners=null}),this.promise.then=e=>{let t;const n=new Promise(e=>{r.subscribe(e),t=e}).then(e);return n.cancel=function(){r.unsubscribe(t)},n},e(function(e,n,o){r.reason||(r.reason=new sw(e,n,o),t(r.reason))})}}const Uw=Vw,qw={Continue:100,SwitchingProtocols:101,Processing:102,EarlyHints:103,Ok:200,Created:201,Accepted:202,NonAuthoritativeInformation:203,NoContent:204,ResetContent:205,PartialContent:206,MultiStatus:207,AlreadyReported:208,ImUsed:226,MultipleChoices:300,MovedPermanently:301,Found:302,SeeOther:303,NotModified:304,UseProxy:305,Unused:306,TemporaryRedirect:307,PermanentRedirect:308,BadRequest:400,Unauthorized:401,PaymentRequired:402,Forbidden:403,NotFound:404,MethodNotAllowed:405,NotAcceptable:406,ProxyAuthenticationRequired:407,RequestTimeout:408,Conflict:409,Gone:410,LengthRequired:411,PreconditionFailed:412,PayloadTooLarge:413,UriTooLong:414,UnsupportedMediaType:415,RangeNotSatisfiable:416,ExpectationFailed:417,ImATeapot:418,MisdirectedRequest:421,UnprocessableEntity:422,Locked:423,FailedDependency:424,TooEarly:425,UpgradeRequired:426,PreconditionRequired:428,TooManyRequests:429,RequestHeaderFieldsTooLarge:431,UnavailableForLegalReasons:451,InternalServerError:500,NotImplemented:501,BadGateway:502,ServiceUnavailable:503,GatewayTimeout:504,HttpVersionNotSupported:505,VariantAlsoNegotiates:506,InsufficientStorage:507,LoopDetected:508,NotExtended:510,NetworkAuthenticationRequired:511,WebServerIsDown:521,ConnectionTimedOut:522,OriginIsUnreachable:523,TimeoutOccurred:524,SslHandshakeFailed:525,InvalidSslCertificate:526};Object.entries(qw).forEach(([e,t])=>{qw[t]=e});const Ww=qw,Hw=function e(t){const r=new zw(t),n=jy(zw.prototype.request,r);return Cb.extend(n,zw.prototype,r,{allOwnKeys:!0}),Cb.extend(n,r,null,{allOwnKeys:!0}),n.create=function(r){return e(mw(t,r))},n}(Yb);Hw.Axios=zw,Hw.CanceledError=sw,Hw.CancelToken=Uw,Hw.isCancel=iw,Hw.VERSION=jw,Hw.toFormData=Ab,Hw.AxiosError=Eb,Hw.Cancel=Hw.CanceledError,Hw.all=function(e){return Promise.all(e)},Hw.spread=function(e){return function(t){return e.apply(null,t)}},Hw.isAxiosError=function(e){return Cb.isObject(e)&&!0===e.isAxiosError},Hw.mergeConfig=mw,Hw.AxiosHeaders=nw,Hw.formToJSON=e=>Gb(Cb.isHTMLForm(e)?new FormData(e):e),Hw.getAdapter=Aw,Hw.HttpStatusCode=Ww,Hw.default=Hw;class Gw{static initialize(e){Gw.config=e}static create(e,t=3e4,r){if(!Gw.config)throw new Error("HttpClient must be initialized with config before use. Call HttpClient.initialize(config) first.");const n=Gw.config[e];if(!n)throw new Error(`Configuration key "${e}" is not found in the environment config`);return new Gw(n,t,r)}async get(e,t,r){return this.http.get(e,{params:t,...r})}async post(e,t,r){return this.http.post(e,t,r)}async put(e,t,r){return this.http.put(e,t,r)}async delete(e,t){return this.http.delete(e,t)}getInstance(){return this.http}constructor(e,t=3e4,r){const n={Accept:"application/json","Content-Type":"application/json",...r||{}};this.http=Hw.create({baseURL:e,timeout:t,responseType:"json",headers:n})}}var Kw,Yw,Zw,Xw;Gw.config=null,Kw={"(":9,"!":8,"*":7,"/":7,"%":7,"+":6,"-":6,"<":5,"<=":5,">":5,">=":5,"==":4,"!=":4,"&&":3,"||":2,"?":1,"?:":1},Yw=["(","?"],Zw={")":["("],":":["?","?:"]},Xw=/<=|>=|==|!=|&&|\|\||\?:|\(|!|\*|\/|%|\+|-|<|>|\?|\)|:/;var Jw={"!":function(e){return!e},"*":function(e,t){return e*t},"/":function(e,t){return e/t},"%":function(e,t){return e%t},"+":function(e,t){return e+t},"-":function(e,t){return e-t},"<":function(e,t){return e<t},"<=":function(e,t){return e<=t},">":function(e,t){return e>t},">=":function(e,t){return e>=t},"==":function(e,t){return e===t},"!=":function(e,t){return e!==t},"&&":function(e,t){return e&&t},"||":function(e,t){return e||t},"?:":function(e,t,r){if(e)throw t;return r}};var Qw={contextDelimiter:"",onMissingKey:null};function ex(e,t){var r;for(r in this.data=e,this.pluralForms={},this.options={},Qw)this.options[r]=void 0!==t&&r in t?t[r]:Qw[r]}ex.prototype.getPluralForm=function(e,t){var r,n,o,i,s=this.pluralForms[e];return s||("function"!=typeof(o=(r=this.data[e][""])["Plural-Forms"]||r["plural-forms"]||r.plural_forms)&&(n=function(e){var t,r,n;for(t=e.split(";"),r=0;r<t.length;r++)if(0===(n=t[r].trim()).indexOf("plural="))return n.substr(7)}(r["Plural-Forms"]||r["plural-forms"]||r.plural_forms),i=function(e){var t=function(e){for(var t,r,n,o,i=[],s=[];t=e.match(Xw);){for(r=t[0],(n=e.substr(0,t.index).trim())&&i.push(n);o=s.pop();){if(Zw[r]){if(Zw[r][0]===o){r=Zw[r][1]||r;break}}else if(Yw.indexOf(o)>=0||Kw[o]<Kw[r]){s.push(o);break}i.push(o)}Zw[r]||s.push(r),e=e.substr(t.index+r.length)}return(e=e.trim())&&i.push(e),i.concat(s.reverse())}(e);return function(e){return function(e,t){var r,n,o,i,s,a,l=[];for(r=0;r<e.length;r++){if(s=e[r],i=Jw[s]){for(n=i.length,o=Array(n);n--;)o[n]=l.pop();try{a=i.apply(null,o)}catch(e){return e}}else a=t.hasOwnProperty(s)?t[s]:+s;l.push(a)}return l[0]}(t,e)}}(n),o=function(e){return+i({n:e})}),s=this.pluralForms[e]=o),s(t)},ex.prototype.dcnpgettext=function(e,t,r,n,o){var i,s,a;return i=void 0===o?0:this.getPluralForm(e,o),s=r,t&&(s=t+this.options.contextDelimiter+r),(a=this.data[e][s])&&a[i]?a[i]:(this.options.onMissingKey&&this.options.onMissingKey(r,e),0===i?r:n)};const tx={plural_forms:e=>1===e?0:1},rx=/^i18n\.(n?gettext|has_translation)(_|$)/;var nx=function(e){return"string"!=typeof e||""===e?(console.error("The namespace must be a non-empty string."),!1):!!/^[a-zA-Z][a-zA-Z0-9_.\-\/]*$/.test(e)||(console.error("The namespace can only contain numbers, letters, dashes, periods, underscores and slashes."),!1)},ox=function(e){return"string"!=typeof e||""===e?(console.error("The hook name must be a non-empty string."),!1):/^__/.test(e)?(console.error("The hook name cannot begin with `__`."),!1):!!/^[a-zA-Z][a-zA-Z0-9_.-]*$/.test(e)||(console.error("The hook name can only contain numbers, letters, dashes, periods and underscores."),!1)},ix=function(e,t){return function(r,n,o,i=10){const s=e[t];if(!ox(r))return;if(!nx(n))return;if("function"!=typeof o)return void console.error("The hook callback must be a function.");if("number"!=typeof i)return void console.error("If specified, the hook priority must be a number.");const a={callback:o,priority:i,namespace:n};if(s[r]){const e=s[r].handlers;let t;for(t=e.length;t>0&&!(i>=e[t-1].priority);t--);t===e.length?e[t]=a:e.splice(t,0,a),s.__current.forEach(e=>{e.name===r&&e.currentIndex>=t&&e.currentIndex++})}else s[r]={handlers:[a],runs:0};"hookAdded"!==r&&e.doAction("hookAdded",r,n,o,i)}},sx=function(e,t,r=!1){return function(n,o){const i=e[t];if(!ox(n))return;if(!r&&!nx(o))return;if(!i[n])return 0;let s=0;if(r)s=i[n].handlers.length,i[n]={runs:i[n].runs,handlers:[]};else{const e=i[n].handlers;for(let t=e.length-1;t>=0;t--)e[t].namespace===o&&(e.splice(t,1),s++,i.__current.forEach(e=>{e.name===n&&e.currentIndex>=t&&e.currentIndex--}))}return"hookRemoved"!==n&&e.doAction("hookRemoved",n,o),s}},ax=function(e,t){return function(r,n){const o=e[t];return void 0!==n?r in o&&o[r].handlers.some(e=>e.namespace===n):r in o}},lx=function(e,t,r,n){return function(o,...i){const s=e[t];s[o]||(s[o]={handlers:[],runs:0}),s[o].runs++;const a=s[o].handlers;if( true&&"hookAdded"!==o&&s.all&&a.push(...s.all.handlers),!a||!a.length)return r?i[0]:void 0;const l={name:o,currentIndex:0};return(n?async function(){try{s.__current.add(l);let e=r?i[0]:void 0;for(;l.currentIndex<a.length;){const t=a[l.currentIndex];e=await t.callback.apply(null,i),r&&(i[0]=e),l.currentIndex++}return r?e:void 0}finally{s.__current.delete(l)}}:function(){try{s.__current.add(l);let e=r?i[0]:void 0;for(;l.currentIndex<a.length;)e=a[l.currentIndex].callback.apply(null,i),r&&(i[0]=e),l.currentIndex++;return r?e:void 0}finally{s.__current.delete(l)}})()}},cx=function(e,t){return function(){const r=e[t],n=Array.from(r.__current);return n.at(-1)?.name??null}},ux=function(e,t){return function(r){const n=e[t];return void 0===r?n.__current.size>0:Array.from(n.__current).some(e=>e.name===r)}},px=function(e,t){return function(r){const n=e[t];if(ox(r))return n[r]&&n[r].runs?n[r].runs:0}};const dx=((e,t,r)=>{const n=new ex({}),o=new Set,i=()=>{o.forEach(e=>e())},s=(e,t="default")=>{n.data[t]={...n.data[t],...e},n.data[t][""]={...tx,...n.data[t]?.[""]},delete n.pluralForms[t]},a=(e,t)=>{s(e,t),i()},l=(e="default",t,r,o,i)=>(n.data[e]||s(void 0,e),n.dcnpgettext(e,t,r,o,i)),c=(e="default")=>e,u=(e,t,n)=>{let o=l(n,t,e);return r?(o=r.applyFilters("i18n.gettext_with_context",o,e,t,n),r.applyFilters("i18n.gettext_with_context_"+c(n),o,e,t,n)):o};if(r){const e=e=>{rx.test(e)&&i()};r.addAction("hookAdded","core/i18n",e),r.addAction("hookRemoved","core/i18n",e)}return{getLocaleData:(e="default")=>n.data[e],setLocaleData:a,addLocaleData:(e,t="default")=>{n.data[t]={...n.data[t],...e,"":{...tx,...n.data[t]?.[""],...e?.[""]}},delete n.pluralForms[t],i()},resetLocaleData:(e,t)=>{n.data={},n.pluralForms={},a(e,t)},subscribe:e=>(o.add(e),()=>o.delete(e)),__:(e,t)=>{let n=l(t,void 0,e);return r?(n=r.applyFilters("i18n.gettext",n,e,t),r.applyFilters("i18n.gettext_"+c(t),n,e,t)):n},_x:u,_n:(e,t,n,o)=>{let i=l(o,void 0,e,t,n);return r?(i=r.applyFilters("i18n.ngettext",i,e,t,n,o),r.applyFilters("i18n.ngettext_"+c(o),i,e,t,n,o)):i},_nx:(e,t,n,o,i)=>{let s=l(i,o,e,t,n);return r?(s=r.applyFilters("i18n.ngettext_with_context",s,e,t,n,o,i),r.applyFilters("i18n.ngettext_with_context_"+c(i),s,e,t,n,o,i)):s},isRTL:()=>"rtl"===u("ltr","text direction"),hasTranslation:(e,t,o)=>{const i=t?t+""+e:e;let s=!!n.data?.[null!=o?o:"default"]?.[i];return r&&(s=r.applyFilters("i18n.has_translation",s,e,t,o),s=r.applyFilters("i18n.has_translation_"+c(o),s,e,t,o)),s}}})(0,0,new class{constructor(){this.actions=Object.create(null),this.actions.__current=new Set,this.filters=Object.create(null),this.filters.__current=new Set,this.addAction=ix(this,"actions"),this.addFilter=ix(this,"filters"),this.removeAction=sx(this,"actions"),this.removeFilter=sx(this,"filters"),this.hasAction=ax(this,"actions"),this.hasFilter=ax(this,"filters"),this.removeAllActions=sx(this,"actions",!0),this.removeAllFilters=sx(this,"filters",!0),this.doAction=lx(this,"actions",!1,!1),this.doActionAsync=lx(this,"actions",!1,!0),this.applyFilters=lx(this,"filters",!0,!1),this.applyFiltersAsync=lx(this,"filters",!0,!0),this.currentAction=cx(this,"actions"),this.currentFilter=cx(this,"filters"),this.doingAction=ux(this,"actions"),this.doingFilter=ux(this,"filters"),this.didAction=px(this,"actions"),this.didFilter=px(this,"filters")}});dx.getLocaleData.bind(dx),dx.setLocaleData.bind(dx),dx.resetLocaleData.bind(dx),dx.subscribe.bind(dx);const fx=dx.__.bind(dx);dx._x.bind(dx),dx._n.bind(dx),dx._nx.bind(dx),dx.isRTL.bind(dx),dx.hasTranslation.bind(dx);const hx=(e,t)=>{let r,n,o=e.path;return"string"==typeof e.namespace&&"string"==typeof e.endpoint&&(r=e.namespace.replace(/^\/|\/$/g,""),n=e.endpoint.replace(/^\//,""),o=n?r+"/"+n:r),delete e.namespace,delete e.endpoint,t({...e,path:o})};function mx(e){let t="";const r=Object.entries(e);let n;for(;n=r.shift();){let[e,o]=n;if(Array.isArray(o)||o&&o.constructor===Object){const t=Object.entries(o).reverse();for(const[n,o]of t)r.unshift([`${e}[${n}]`,o])}else void 0!==o&&(null===o&&(o=""),t+="&"+[e,o].map(encodeURIComponent).join("="))}return t.substr(1)}function gx(e){try{return decodeURIComponent(e)}catch(t){return e}}function vx(e){return(function(e){let t;try{t=new URL(e,"http://example.com").search.substring(1)}catch(e){}if(t)return t}(e)||"").replace(/\+/g,"%20").split("&").reduce((e,t)=>{const[r,n=""]=t.split("=").filter(Boolean).map(gx);return r&&function(e,t,r){const n=t.length,o=n-1;for(let i=0;i<n;i++){let n=t[i];!n&&Array.isArray(e)&&(n=e.length.toString()),n=["__proto__","constructor","prototype"].includes(n)?n.toUpperCase():n;const s=!isNaN(Number(t[i+1]));e[n]=i===o?r:e[n]||(s?[]:{}),Array.isArray(e[n])&&!s&&(e[n]={...e[n]}),e=e[n]}}(e,r.replace(/\]/g,"").split("["),n),e},Object.create(null))}function yx(e="",t){if(!t||!Object.keys(t).length)return e;let r=e;const n=e.indexOf("?");return-1!==n&&(t=Object.assign(vx(e),t),r=r.substr(0,n)),r+"?"+mx(t)}function bx(e,t){return vx(e)[t]}function wx(e,t){return void 0!==bx(e,t)}function xx(e,...t){const r=e.indexOf("?");if(-1===r)return e;const n=vx(e),o=e.substr(0,r);t.forEach(e=>delete n[e]);const i=mx(n);return i?o+"?"+i:o}function _x(e){const t=e.split("?"),r=t[1],n=t[0];return r?n+"?"+r.split("&").map(e=>e.split("=")).map(e=>e.map(decodeURIComponent)).sort((e,t)=>e[0].localeCompare(t[0])).map(e=>e.map(encodeURIComponent)).map(e=>e.join("=")).join("&"):n}function Sx(e,t){return Promise.resolve(t?e.body:new window.Response(JSON.stringify(e.body),{status:200,statusText:"OK",headers:e.headers}))}const kx=({path:e,url:t,...r},n)=>({...r,url:t&&yx(t,n),path:e&&yx(e,n)}),Cx=e=>e.json?e.json():Promise.reject(e),Ox=e=>{const{next:t}=(e=>{if(!e)return{};const t=e.match(/<([^>]+)>; rel="next"/);return t?{next:t[1]}:{}})(e.headers.get("link"));return t},Ex=async(e,t)=>{if(!1===e.parse)return t(e);if(!(e=>{const t=!!e.path&&-1!==e.path.indexOf("per_page=-1"),r=!!e.url&&-1!==e.url.indexOf("per_page=-1");return t||r})(e))return t(e);const r=await Dx({...kx(e,{per_page:100}),parse:!1}),n=await Cx(r);if(!Array.isArray(n))return n;let o=Ox(r);if(!o)return n;let i=[].concat(n);for(;o;){const t=await Dx({...e,path:void 0,url:o,parse:!1}),r=await Cx(t);i=i.concat(r),o=Ox(t)}return i},Tx=new Set(["PATCH","PUT","DELETE"]),Rx="GET",Ix=(e,t=!0)=>Promise.resolve(((e,t=!0)=>t?204===e.status?null:e.json?e.json():Promise.reject(e):e)(e,t)).catch(e=>Mx(e,t));function Mx(e,t=!0){if(!t)throw e;return(e=>{const t={code:"invalid_json",message:fx("The response is not a valid JSON response.")};if(!e||!e.json)throw t;return e.json().catch(()=>{throw t})})(e).then(e=>{const t={code:"unknown_error",message:fx("An unknown error occurred.")};throw e||t})}const Ax={Accept:"application/json, */*;q=0.1"},Px={credentials:"include"},Nx=[(e,t)=>("string"!=typeof e.url||wx(e.url,"_locale")||(e.url=yx(e.url,{_locale:"user"})),"string"!=typeof e.path||wx(e.path,"_locale")||(e.path=yx(e.path,{_locale:"user"})),t(e)),hx,(e,t)=>{const{method:r=Rx}=e;return Tx.has(r.toUpperCase())&&(e={...e,headers:{...e.headers,"X-HTTP-Method-Override":r,"Content-Type":"application/json"},method:"POST"}),t(e)},Ex],jx=e=>{if(e.status>=200&&e.status<300)return e;throw e};let Lx=e=>{const{url:t,path:r,data:n,parse:o=!0,...i}=e;let{body:s,headers:a}=e;return a={...Ax,...a},n&&(s=JSON.stringify(n),a["Content-Type"]="application/json"),window.fetch(t||r||window.location.href,{...Px,...i,body:s,headers:a}).then(e=>Promise.resolve(e).then(jx).catch(e=>Mx(e,o)).then(e=>Ix(e,o)),e=>{if(e&&"AbortError"===e.name)throw e;throw{code:"fetch_error",message:fx("You are probably offline.")}})};function Dx(e){const t=Nx.reduceRight((e,t)=>r=>t(r,e),Lx);return t(e).catch(t=>"rest_cookie_invalid_nonce"!==t.code?Promise.reject(t):window.fetch(Dx.nonceEndpoint).then(jx).then(e=>e.text()).then(t=>(Dx.nonceMiddleware.nonce=t,Dx(e))))}Dx.use=function(e){Nx.unshift(e)},Dx.setFetchHandler=function(e){Lx=e},Dx.createNonceMiddleware=function(e){const t=(e,r)=>{const{headers:n={}}=e;for(const o in n)if("x-wp-nonce"===o.toLowerCase()&&n[o]===t.nonce)return r(e);return r({...e,headers:{...n,"X-WP-Nonce":t.nonce}})};return t.nonce=e,t},Dx.createPreloadingMiddleware=function(e){const t=Object.fromEntries(Object.entries(e).map(([e,t])=>[_x(e),t]));return(e,r)=>{const{parse:n=!0}=e;let o=e.path;if(!o&&e.url){const{rest_route:t,...r}=vx(e.url);"string"==typeof t&&(o=yx(t,r))}if("string"!=typeof o)return r(e);const i=e.method||"GET",s=_x(o);if("GET"===i&&t[s]){const e=t[s];return delete t[s],Sx(e,!!n)}if("OPTIONS"===i&&t[i]&&t[i][s]){const e=t[i][s];return delete t[i][s],Sx(e,!!n)}return r(e)}},Dx.createRootURLMiddleware=e=>(t,r)=>hx(t,t=>{let n,o=t.url,i=t.path;return"string"==typeof i&&(n=e,-1!==e.indexOf("?")&&(i=i.replace("?","&")),i=i.replace(/^\//,""),"string"==typeof n&&-1!==n.indexOf("?")&&(i=i.replace("?","&")),o=n+i),r({...t,url:o})}),Dx.fetchAllMiddleware=Ex,Dx.mediaUploadMiddleware=(e,t)=>{if(!function(e){const t=!!e.method&&"POST"===e.method;return(!!e.path&&-1!==e.path.indexOf("/wp/v2/media")||!!e.url&&-1!==e.url.indexOf("/wp/v2/media"))&&t}(e))return t(e);let r=0;const n=e=>(r++,t({path:`/wp/v2/media/${e}/post-process`,method:"POST",data:{action:"create-image-subsizes"},parse:!1}).catch(()=>r<5?n(e):(t({path:`/wp/v2/media/${e}?force=true`,method:"DELETE"}),Promise.reject())));return t({...e,parse:!1}).catch(t=>{const r=t.headers.get("x-wp-upload-attachment-id");return t.status>=500&&t.status<600&&r?n(r).catch(()=>!1!==e.parse?Promise.reject({code:"post_process",message:fx("Media upload failed. If this is a photo or a large image, please scale it down and try again.")}):Promise.reject(t)):Mx(t,e.parse)}).then(t=>Ix(t,e.parse))},Dx.createThemePreviewMiddleware=e=>(t,r)=>{if("string"==typeof t.url){const r=bx(t.url,"wp_theme_preview");void 0===r?t.url=yx(t.url,{wp_theme_preview:e}):""===r&&(t.url=xx(t.url,"wp_theme_preview"))}if("string"==typeof t.path){const r=bx(t.path,"wp_theme_preview");void 0===r?t.path=yx(t.path,{wp_theme_preview:e}):""===r&&(t.path=xx(t.path,"wp_theme_preview"))}return r(t)};class Fx extends Error{constructor(e){super(e),this.name="APIError"}}var $x=function(e){return e.GET="GET",e.POST="POST",e.PUT="PUT",e.PATCH="PATCH",e.DELETE="DELETE",e.HEAD="HEAD",e}({});const Bx="/wp/v2";class zx{static async request({path:e,data:t,method:r="POST"}){try{const n=(window?.elementorOneSettingsData?.wpRestUrl||"/wp-json/").replace(/\/$/,""),o=window?.elementorOneSettingsData?.wpRestNonce||"";let i=`${n}${e}`;"GET"!==r||e.startsWith(Bx)||(i=yx(i,{sb_time:(new Date).getTime()}));const s=await Dx({url:i,method:r,data:t,headers:{"X-WP-Nonce":o}});if(e.startsWith(Bx))return s;if(void 0===s?.success)return s;if(!s.success)throw new Fx(s.data?.message||"Unknown error");return s.data}catch(e){throw e instanceof Fx?e:new Fx(e?.message||"Unknown error")}}}const Vx="/elementor-one/v1";class Ux extends zx{static async initConnect(e="new"){const t={wp_rest:window?.elementorOneSettingsData?.wpRestNonce};return"update"===e&&(t.update_redirect_uri=!0),zx.request({method:$x.POST,path:`${Vx}/connect/authorize`,data:t})}static async disconnect(){return zx.request({method:$x.POST,path:`${Vx}/connect/disconnect`,data:{wp_rest:window?.elementorOneSettingsData?.wpRestNonce}})}static async getPluginSettings(){return zx.request({method:$x.GET,path:`${Vx}/settings`})}static async getNotifications(e,t){return zx.request({method:$x.GET,path:`${Vx}/top-bar/notifications?app_name=${e}&app_version=${t}`})}static async sendFeedback(e){return zx.request({method:$x.POST,path:`${Vx}/top-bar/feedback`,data:e})}}const qx=new Gw("https://ipapi.co/json/");class Wx{static async getCountryCode(){const{data:e}=await qx.get("");return e.country}}var Hx;if("undefined"==typeof window){var Gx={hostname:""};Hx={crypto:{randomUUID:function(){throw Error("unsupported")}},navigator:{userAgent:"",onLine:!0},document:{createElement:function(){return{}},location:Gx,referrer:""},screen:{width:0,height:0},location:Gx,addEventListener:function(){},removeEventListener:function(){},dispatchEvent:function(){},CustomEvent:function(){}}}else Hx=window;var Kx={DEBUG:!1,LIB_VERSION:"2.77.0"},Yx="__mp_targeting",Zx="__mp_recorder",Xx="__MP_TARGETING_FILENAME__";function Jx(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=new Array(t);r<t;r++)n[r]=e[r];return n}function Qx(e,t,r,n,o,i,s){try{var a=e[i](s),l=a.value}catch(e){return void r(e)}a.done?t(l):Promise.resolve(l).then(n,o)}function e_(e){return function(){var t=this,r=arguments;return new Promise(function(n,o){var i=e.apply(t,r);function s(e){Qx(i,n,o,s,a,"next",e)}function a(e){Qx(i,n,o,s,a,"throw",e)}s(void 0)})}}function t_(e,t,r){return t_=p_()?Reflect.construct:function(e,t,r){var n=[null];n.push.apply(n,t);var o=new(Function.bind.apply(e,n));return r&&l_(o,r.prototype),o},t_.apply(null,arguments)}function r_(e,t,r){return t&&function(e,t){for(var r=0;r<t.length;r++){var n=t[r];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,n.key,n)}}(e.prototype,t),e}function n_(){return n_=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},n_.apply(this,arguments)}function o_(e){return o_=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)},o_(e)}function i_(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),t&&l_(e,t)}function s_(e,t){return null!=t&&"undefined"!=typeof Symbol&&t[Symbol.hasInstance]?!!t[Symbol.hasInstance](e):e instanceof t}function a_(e,t){if(null==e)return{};var r,n,o={},i=Object.keys(e);for(n=0;n<i.length;n++)r=i[n],t.indexOf(r)>=0||(o[r]=e[r]);return o}function l_(e,t){return l_=Object.setPrototypeOf||function(e,t){return e.__proto__=t,e},l_(e,t)}function c_(e){return e&&"undefined"!=typeof Symbol&&e.constructor===Symbol?"symbol":typeof e}function u_(e){var t="function"==typeof Map?new Map:void 0;return u_=function(e){if(null===e||(r=e,-1===Function.toString.call(r).indexOf("[native code]")))return e;var r;if("function"!=typeof e)throw new TypeError("Super expression must either be null or a function");if(void 0!==t){if(t.has(e))return t.get(e);t.set(e,n)}function n(){return t_(e,arguments,o_(this).constructor)}return n.prototype=Object.create(e.prototype,{constructor:{value:n,enumerable:!1,writable:!0,configurable:!0}}),l_(n,e)},u_(e)}function p_(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch(e){}return(p_=function(){return!!e})()}function d_(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(r)return(r=r.call(e)).next.bind(r);if(Array.isArray(e)||(r=function(e,t){if(e){if("string"==typeof e)return Jx(e,t);var r=Object.prototype.toString.call(e).slice(8,-1);return"Object"===r&&e.constructor&&(r=e.constructor.name),"Map"===r||"Set"===r?Array.from(r):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?Jx(e,t):void 0}}(e))||t){r&&(e=r);var n=0;return function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}function f_(e,t){var r,n,o,i,s={label:0,sent:function(){if(1&o[0])throw o[1];return o[1]},trys:[],ops:[]};return i={next:a(0),throw:a(1),return:a(2)},"function"==typeof Symbol&&(i[Symbol.iterator]=function(){return this}),i;function a(i){return function(a){return function(i){if(r)throw new TypeError("Generator is already executing.");for(;s;)try{if(r=1,n&&(o=2&i[0]?n.return:i[0]?n.throw||((o=n.return)&&o.call(n),0):n.next)&&!(o=o.call(n,i[1])).done)return o;switch(n=0,o&&(i=[2&i[0],o.value]),i[0]){case 0:case 1:o=i;break;case 4:return s.label++,{value:i[1],done:!1};case 5:s.label++,n=i[1],i=[0];continue;case 7:i=s.ops.pop(),s.trys.pop();continue;default:if(!((o=(o=s.trys).length>0&&o[o.length-1])||6!==i[0]&&2!==i[0])){s=0;continue}if(3===i[0]&&(!o||i[1]>o[0]&&i[1]<o[3])){s.label=i[1];break}if(6===i[0]&&s.label<o[1]){s.label=o[1],o=i;break}if(o&&s.label<o[2]){s.label=o[2],s.ops.push(i);break}o[2]&&s.ops.pop(),s.trys.pop();continue}i=t.call(e,s)}catch(e){i=[6,e],n=0}finally{r=o=0}if(5&i[0])throw i[1];return{value:i[0]?i[1]:void 0,done:!0}}([i,a])}}}function h_(e){var t="function"==typeof Symbol&&Symbol.iterator,r=t&&e[t],n=0;if(r)return r.call(e);if(e&&"number"==typeof e.length)return{next:function(){return e&&n>=e.length&&(e=void 0),{value:e&&e[n++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")}var m_,g_=Object.defineProperty,v_=function(e,t,r){return function(e,t,r){return t in e?g_(e,t,{enumerable:!0,configurable:!0,writable:!0,value:r}):e[t]=r}(e,"symbol"!==(void 0===t?"undefined":c_(t))?t+"":t,r)},y_=Object.defineProperty,b_=function(e,t,r){return function(e,t,r){return t in e?y_(e,t,{enumerable:!0,configurable:!0,writable:!0,value:r}):e[t]=r}(e,"symbol"!==(void 0===t?"undefined":c_(t))?t+"":t,r)},w_=function(e){return e[e.Document=0]="Document",e[e.DocumentType=1]="DocumentType",e[e.Element=2]="Element",e[e.Text=3]="Text",e[e.CDATA=4]="CDATA",e[e.Comment=5]="Comment",e}(w_||{}),x_={Node:["childNodes","parentNode","parentElement","textContent"],ShadowRoot:["host","styleSheets"],Element:["shadowRoot","querySelector","querySelectorAll"],MutationObserver:[]},__={Node:["contains","getRootNode"],ShadowRoot:["getSelection"],Element:[],MutationObserver:["constructor"]},S_={};function k_(e){if(S_[e])return S_[e];var t=globalThis[e],r=t.prototype,n=e in x_?x_[e]:void 0,o=Boolean(n&&n.every(function(e){var t,n;return Boolean(null==(n=null==(t=Object.getOwnPropertyDescriptor(r,e))?void 0:t.get)?void 0:n.toString().includes("[native code]"))})),i=e in __?__[e]:void 0,s=Boolean(i&&i.every(function(e){var t;return"function"==typeof r[e]&&(null==(t=r[e])?void 0:t.toString().includes("[native code]"))}));if(o&&s&&!globalThis.Zone)return S_[e]=t.prototype,t.prototype;try{var a=document.createElement("iframe");document.body.appendChild(a);var l=a.contentWindow;if(!l)return t.prototype;var c=l[e].prototype;return document.body.removeChild(a),c?S_[e]=c:r}catch(e){return r}}var C_={};function O_(e,t,r){var n,o=e+"."+String(r);if(C_[o])return C_[o].call(t);var i=k_(e),s=null==(n=Object.getOwnPropertyDescriptor(i,r))?void 0:n.get;return s?(C_[o]=s,s.call(t)):t[r]}var E_=function(e){return O_("Node",e,"childNodes")},T_=function(e){return O_("Node",e,"parentNode")},R_=function(e){return O_("Node",e,"parentElement")},I_=function(e){return O_("Node",e,"textContent")},M_=function(e){return e&&"host"in e?O_("ShadowRoot",e,"host"):null},A_=function(e){return e&&"shadowRoot"in e?O_("Element",e,"shadowRoot"):null};function P_(e){return e.nodeType===e.ELEMENT_NODE}function N_(e){var t=e&&"host"in e&&"mode"in e&&M_(e)||null;return Boolean(t&&"shadowRoot"in t&&A_(t)===e)}function j_(e){return"[object ShadowRoot]"===Object.prototype.toString.call(e)}function L_(e){try{var t=e.rules||e.cssRules;if(!t)return null;var r=e.href;return!r&&e.ownerNode&&e.ownerNode.ownerDocument&&(r=e.ownerNode.ownerDocument.location.href),(n=Array.from(t,function(e){return D_(e,r)}).join("")).includes(" background-clip: text;")&&!n.includes(" -webkit-background-clip: text;")&&(n=n.replace(/\sbackground-clip:\s*text;/g," -webkit-background-clip: text; background-clip: text;")),n}catch(e){return null}// removed by dead control flow
 var n; }function D_(e,t){if(function(e){return"styleSheet"in e}(e)){var r;try{r=L_(e.styleSheet)||function(e){var t=e.cssText;if(t.split('"').length<3)return t;var r=["@import","url("+JSON.stringify(e.href)+")"];return""===e.layerName?r.push("layer"):e.layerName&&r.push("layer("+e.layerName+")"),e.supportsText&&r.push("supports("+e.supportsText+")"),e.media.length&&r.push(e.media.mediaText),r.join(" ")+";"}(e)}catch(t){r=e.cssText}return e.styleSheet.href?K_(r,e.styleSheet.href):r}var n,o=e.cssText;return function(e){return"selectorText"in e}(e)&&e.selectorText.includes(":")&&(n=/(\[(?:[\w-]+)[^\\])(:(?:[\w-]+)\])/gm,o=o.replace(n,"$1\\$2")),t?K_(o,t):o}var F_=function(){function e(){b_(this,"idNodeMap",new Map),b_(this,"nodeMetaMap",new WeakMap)}var t=e.prototype;return t.getId=function(e){var t;if(!e)return-1;var r=null==(t=this.getMeta(e))?void 0:t.id;return null!=r?r:-1},t.getNode=function(e){return this.idNodeMap.get(e)||null},t.getIds=function(){return Array.from(this.idNodeMap.keys())},t.getMeta=function(e){return this.nodeMetaMap.get(e)||null},t.removeNodeFromMap=function(e,t){var r=this;void 0===t&&(t=!1);var n=this.getId(e);this.idNodeMap.delete(n),t&&this.nodeMetaMap.delete(e),e.childNodes&&e.childNodes.forEach(function(e){return r.removeNodeFromMap(e,t)})},t.has=function(e){return this.idNodeMap.has(e)},t.hasNode=function(e){return this.nodeMetaMap.has(e)},t.add=function(e,t){var r=t.id;this.idNodeMap.set(r,e),this.nodeMetaMap.set(e,t)},t.replace=function(e,t){var r=this.getNode(e);if(r){var n=this.nodeMetaMap.get(r);n&&this.nodeMetaMap.set(t,n)}this.idNodeMap.set(e,t)},t.reset=function(){this.idNodeMap=new Map,this.nodeMetaMap=new WeakMap},e}();function $_(e){var t=e.element,r=e.maskInputOptions,n=e.tagName,o=e.type,i=e.value,s=e.maskInputFn,a=i||"",l=o&&B_(o);return(r[n.toLowerCase()]||l&&r[l])&&(a=s?s(a,t):"*".repeat(a.length)),a}function B_(e){return e.toLowerCase()}var z_="__rrweb_original__";function V_(e){var t=e.type;return e.hasAttribute("data-rr-is-password")?"password":t?B_(t):null}function U_(e,t){var r;try{r=new URL(e,null!=t?t:window.location.href)}catch(e){return null}var n,o=r.pathname.match(/\.([0-9a-z]+)(?:$)/i);return null!=(n=null==o?void 0:o[1])?n:null}var q_=/url\((?:(')([^']*)'|(")(.*?)"|([^)]*))\)/gm,W_=/^(?:[a-z+]+:)?\/\//i,H_=/^www\..*/i,G_=/^(data:)([^,]*),(.*)/i;function K_(e,t){return(e||"").replace(q_,function(e,r,n,o,i,s){var a,l=n||i||s,c=r||o||"";if(!l)return e;if(W_.test(l)||H_.test(l))return"url("+c+l+c+")";if(G_.test(l))return"url("+c+l+c+")";if("/"===l[0])return"url("+c+(((a=t).indexOf("//")>-1?a.split("/").slice(0,3).join("/"):a.split("/")[0]).split("?")[0]+l)+c+")";var u=t.split("/"),p=l.split("/");u.pop();for(var d,f=d_(p);!(d=f()).done;){var h=d.value;"."!==h&&(".."===h?u.pop():u.push(h))}return"url("+c+u.join("/")+c+")"})}function Y_(e,t){return void 0===t&&(t=!1),t?e.replace(/(\/\*[^*]*\*\/)|[\s;]/g,""):e.replace(/(\/\*[^*]*\*\/)|[\s;]/g,"").replace(/0px/g,"0")}var Z_,X_,J_=1,Q_=new RegExp("[^a-z0-9-_:]");function eS(){return J_++}var tS=/^[^ \t\n\r\u000c]+/,rS=/^[, \t\n\r\u000c]+/,nS=new WeakMap;function oS(e,t){return t&&""!==t.trim()?iS(e,t):t}function iS(e,t){var r=nS.get(e);if(r||(r=e.createElement("a"),nS.set(e,r)),t){if(t.startsWith("blob:")||t.startsWith("data:"))return t}else t="";return r.setAttribute("href",t),r.href}function sS(e,t,r,n){return n?"src"===r||"href"===r&&("use"!==t||"#"!==n[0])||"xlink:href"===r&&"#"!==n[0]?oS(e,n):"background"!==r||"table"!==t&&"td"!==t&&"th"!==t?"srcset"===r?function(e,t){if(""===t.trim())return t;var r=0;function n(e){var n,o=e.exec(t.substring(r));return o?(n=o[0],r+=n.length,n):""}for(var o=[];n(rS),!(r>=t.length);){var i=n(tS);if(","===i.slice(-1))i=oS(e,i.substring(0,i.length-1)),o.push(i);else{var s="";i=oS(e,i);for(var a=!1;;){var l=t.charAt(r);if(""===l){o.push((i+s).trim());break}if(a)")"===l&&(a=!1);else{if(","===l){r+=1,o.push((i+s).trim());break}"("===l&&(a=!0)}s+=l,r+=1}}}return o.join(", ")}(e,n):"style"===r?K_(n,iS(e)):"object"===t&&"data"===r?oS(e,n):n:oS(e,n):n}function aS(e,t,r){return("video"===e||"audio"===e)&&"autoplay"===t}function lS(e,t,r){if(!e)return!1;if(e.nodeType!==e.ELEMENT_NODE)return!!r&&lS(T_(e),t,r);for(var n=e.classList.length;n--;){var o=e.classList[n];if(t.test(o))return!0}return!!r&&lS(T_(e),t,r)}function cS(e,t,r,n){var o;if(P_(e)){if(!E_(o=e).length)return!1}else{if(null===R_(e))return!1;o=R_(e)}try{if("string"==typeof t){if(n){if(o.closest("."+t))return!0}else if(o.classList.contains(t))return!0}else if(lS(o,t,n))return!0;if(r)if(n){if(o.closest(r))return!0}else if(o.matches(r))return!0}catch(e){}return!1}function uS(e,t){var r=t.doc,n=t.mirror,o=t.blockClass,i=t.blockSelector,s=t.needsMask,a=t.inlineStylesheet,l=t.maskInputOptions,c=void 0===l?{}:l,u=t.maskTextFn,p=t.maskInputFn,d=t.dataURLOptions,f=void 0===d?{}:d,h=t.inlineImages,m=t.recordCanvas,g=t.keepIframeSrcFn,v=t.newlyAddedElement,y=void 0!==v&&v,b=t.cssCaptured,w=void 0!==b&&b,x=function(e,t){if(t.hasNode(e)){var r=t.getId(e);return 1===r?void 0:r}}(r,n);switch(e.nodeType){case e.DOCUMENT_NODE:return"CSS1Compat"!==e.compatMode?{type:w_.Document,childNodes:[],compatMode:e.compatMode}:{type:w_.Document,childNodes:[]};case e.DOCUMENT_TYPE_NODE:return{type:w_.DocumentType,name:e.name,publicId:e.publicId,systemId:e.systemId,rootId:x};case e.ELEMENT_NODE:return function(e,t){for(var r,n=t.doc,o=t.inlineStylesheet,i=t.maskInputOptions,s=void 0===i?{}:i,a=t.maskInputFn,l=t.dataURLOptions,c=void 0===l?{}:l,u=t.inlineImages,p=t.recordCanvas,d=t.keepIframeSrcFn,f=t.newlyAddedElement,h=void 0!==f&&f,m=t.rootId,g=function(e,t,r){try{if("string"==typeof t){if(e.classList.contains(t))return!0}else for(var n=e.classList.length;n--;){var o=e.classList[n];if(t.test(o))return!0}if(r)return e.matches(r)}catch(e){}return!1}(e,t.blockClass,t.blockSelector),v=function(e){if(s_(e,HTMLFormElement))return"form";var t=B_(e.tagName);return Q_.test(t)?"div":t}(e),y={},b=e.attributes.length,w=0;w<b;w++){var x=e.attributes[w];aS(v,x.name)||(y[x.name]=sS(n,v,B_(x.name),x.value))}if("link"===v&&o){var _=Array.from(n.styleSheets).find(function(t){return t.href===e.href}),S=null;_&&(S=L_(_)),S&&(delete y.rel,delete y.href,y._cssText=S)}if("style"===v&&e.sheet){var k=L_(e.sheet);k&&(e.childNodes.length>1&&(k=function(e,t){return function(e,t,r){void 0===r&&(r=!1);var n=Array.from(t.childNodes),o=[],i=0;if(n.length>1&&e&&"string"==typeof e)for(var s=Y_(e,r),a=s.length/e.length,l=1;l<n.length;l++)if(n[l].textContent&&"string"==typeof n[l].textContent){for(var c=Y_(n[l].textContent,r),u=3;u<c.length&&(c[u].match(/[a-zA-Z0-9]/)||-1!==c.indexOf(c.substring(0,u),1));u++);for(;u<c.length;u++){var p=c.substring(0,u),d=s.split(p),f=-1;if(2===d.length)f=d[0].length;else if(d.length>2&&""===d[0]&&""!==n[l-1].textContent)f=s.indexOf(p,1);else if(1===d.length){if(p=p.substring(0,p.length-1),(d=s.split(p)).length<=1)return o.push(e),o;u=101}else u===c.length-1&&(f=s.indexOf(p));if(d.length>=2&&u>100){var h=n[l-1].textContent;if(h&&"string"==typeof h){var m=Y_(h).length;f=s.indexOf(p,m)}-1===f&&(f=d[0].length)}if(-1!==f){for(var g=Math.floor(f/a);g>0&&g<e.length;){if((i+=1)>50*n.length)return o.push(e),o;var v=Y_(e.substring(0,g),r);if(v.length===f){o.push(e.substring(0,g)),e=e.substring(g),s=s.substring(f);break}v.length<f?g+=Math.max(1,Math.floor((f-v.length)/a)):g-=Math.max(1,Math.floor((v.length-f)*a))}break}}}return o.push(e),o}(e,t).join("/* rr_split */")}(k,e)),y._cssText=k)}if("input"===v||"textarea"===v||"select"===v){var C=e.value,O=e.checked;"radio"!==y.type&&"checkbox"!==y.type&&"submit"!==y.type&&"button"!==y.type&&C?y.value=$_({element:e,type:V_(e),tagName:v,value:C,maskInputOptions:s,maskInputFn:a}):O&&(y.checked=O)}if("option"===v&&(e.selected&&!s.select?y.selected=!0:delete y.selected),"dialog"===v&&e.open&&(y.rr_open_mode=e.matches("dialog:modal")?"modal":"non-modal"),"canvas"===v&&p)if("2d"===e.__context)(function(e){var t=e.getContext("2d");if(!t)return!0;for(var r=0;r<e.width;r+=50)for(var n=0;n<e.height;n+=50){var o=t.getImageData,i=z_ in o?o[z_]:o;if(new Uint32Array(i.call(t,r,n,Math.min(50,e.width-r),Math.min(50,e.height-n)).data.buffer).some(function(e){return 0!==e}))return!1}return!0})(e)||(y.rr_dataURL=e.toDataURL(c.type,c.quality));else if(!("__context"in e)){var E=e.toDataURL(c.type,c.quality),T=n.createElement("canvas");T.width=e.width,T.height=e.height,E!==T.toDataURL(c.type,c.quality)&&(y.rr_dataURL=E)}if("img"===v&&u){Z_||(Z_=n.createElement("canvas"),X_=Z_.getContext("2d"));var R=e,I=R.currentSrc||R.getAttribute("src")||"<unknown-src>",M=R.crossOrigin,A=function(){R.removeEventListener("load",A);try{Z_.width=R.naturalWidth,Z_.height=R.naturalHeight,X_.drawImage(R,0,0),y.rr_dataURL=Z_.toDataURL(c.type,c.quality)}catch(e){if("anonymous"!==R.crossOrigin)return R.crossOrigin="anonymous",void(R.complete&&0!==R.naturalWidth?A():R.addEventListener("load",A));console.warn("Cannot inline img src="+I+"! Error: "+e)}"anonymous"===R.crossOrigin&&(M?y.crossOrigin=M:R.removeAttribute("crossorigin"))};R.complete&&0!==R.naturalWidth?A():R.addEventListener("load",A)}if("audio"===v||"video"===v){var P=y;P.rr_mediaState=e.paused?"paused":"played",P.rr_mediaCurrentTime=e.currentTime,P.rr_mediaPlaybackRate=e.playbackRate,P.rr_mediaMuted=e.muted,P.rr_mediaLoop=e.loop,P.rr_mediaVolume=e.volume}if(h||(e.scrollLeft&&(y.rr_scrollLeft=e.scrollLeft),e.scrollTop&&(y.rr_scrollTop=e.scrollTop)),g){var N=e.getBoundingClientRect(),j=N.width,L=N.height;y={class:y.class,rr_width:j+"px",rr_height:L+"px"}}"iframe"!==v||d(y.src)||(e.contentDocument||(y.rr_src=y.src),delete y.src);try{customElements.get(v)&&(r=!0)}catch(e){}return{type:w_.Element,tagName:v,attributes:y,childNodes:[],isSVG:(D=e,Boolean("svg"===D.tagName||D.ownerSVGElement)||void 0),needBlock:g,rootId:m,isCustom:r};// removed by dead control flow
 var D; }(e,{doc:r,blockClass:o,blockSelector:i,inlineStylesheet:a,maskInputOptions:c,maskInputFn:p,dataURLOptions:f,inlineImages:h,recordCanvas:m,keepIframeSrcFn:g,newlyAddedElement:y,rootId:x});case e.TEXT_NODE:return function(e,t){var r=t.needsMask,n=t.maskTextFn,o=t.rootId,i=t.cssCaptured,s=T_(e),a=s&&s.tagName,l="",c="STYLE"===a||void 0,u="SCRIPT"===a||void 0;return u?l="SCRIPT_PLACEHOLDER":i||(l=I_(e),c&&l&&(l=K_(l,iS(t.doc)))),!c&&!u&&l&&r&&(l=n?n(l,R_(e)):l.replace(/[\S]/g,"*")),{type:w_.Text,textContent:l||"",rootId:o}}(e,{doc:r,needsMask:s,maskTextFn:u,rootId:x,cssCaptured:w});case e.CDATA_SECTION_NODE:return{type:w_.CDATA,textContent:"",rootId:x};case e.COMMENT_NODE:return{type:w_.Comment,textContent:I_(e)||"",rootId:x};default:return!1}}function pS(e){return null==e?"":e.toLowerCase()}function dS(e,t){var r=t.doc,n=t.mirror,o=t.blockClass,i=t.blockSelector,s=t.maskTextClass,a=t.maskTextSelector,l=t.skipChild,c=void 0!==l&&l,u=t.inlineStylesheet,p=void 0===u||u,d=t.maskInputOptions,f=void 0===d?{}:d,h=t.maskTextFn,m=t.maskInputFn,g=t.slimDOMOptions,v=t.dataURLOptions,y=void 0===v?{}:v,b=t.inlineImages,w=void 0!==b&&b,x=t.recordCanvas,_=void 0!==x&&x,S=t.onSerialize,k=t.onIframeLoad,C=t.iframeLoadTimeout,O=void 0===C?5e3:C,E=t.onStylesheetLoad,T=t.stylesheetLoadTimeout,R=void 0===T?5e3:T,I=t.keepIframeSrcFn,M=void 0===I?function(){return!1}:I,A=t.newlyAddedElement,P=void 0!==A&&A,N=t.cssCaptured,j=void 0!==N&&N,L=t.needsMask,D=t.preserveWhiteSpace,F=void 0===D||D;L||(L=cS(e,s,a,void 0===L));var $,B=uS(e,{doc:r,mirror:n,blockClass:o,blockSelector:i,needsMask:L,inlineStylesheet:p,maskInputOptions:f,maskTextFn:h,maskInputFn:m,dataURLOptions:y,inlineImages:w,recordCanvas:_,keepIframeSrcFn:M,newlyAddedElement:P,cssCaptured:j});if(!B)return console.warn(e,"not serialized"),null;$=n.hasNode(e)?n.getId(e):function(e,t){if(t.comment&&e.type===w_.Comment)return!0;if(e.type===w_.Element){if(t.script&&("script"===e.tagName||"link"===e.tagName&&("preload"===e.attributes.rel&&"script"===e.attributes.as||"modulepreload"===e.attributes.rel)||"link"===e.tagName&&"prefetch"===e.attributes.rel&&"string"==typeof e.attributes.href&&"js"===U_(e.attributes.href)))return!0;if(t.headFavicon&&("link"===e.tagName&&"shortcut icon"===e.attributes.rel||"meta"===e.tagName&&(pS(e.attributes.name).match(/^msapplication-tile(image|color)$/)||"application-name"===pS(e.attributes.name)||"icon"===pS(e.attributes.rel)||"apple-touch-icon"===pS(e.attributes.rel)||"shortcut icon"===pS(e.attributes.rel))))return!0;if("meta"===e.tagName){if(t.headMetaDescKeywords&&pS(e.attributes.name).match(/^description|keywords$/))return!0;if(t.headMetaSocial&&(pS(e.attributes.property).match(/^(og|twitter|fb):/)||pS(e.attributes.name).match(/^(og|twitter):/)||"pinterest"===pS(e.attributes.name)))return!0;if(t.headMetaRobots&&("robots"===pS(e.attributes.name)||"googlebot"===pS(e.attributes.name)||"bingbot"===pS(e.attributes.name)))return!0;if(t.headMetaHttpEquiv&&void 0!==e.attributes["http-equiv"])return!0;if(t.headMetaAuthorship&&("author"===pS(e.attributes.name)||"generator"===pS(e.attributes.name)||"framework"===pS(e.attributes.name)||"publisher"===pS(e.attributes.name)||"progid"===pS(e.attributes.name)||pS(e.attributes.property).match(/^article:/)||pS(e.attributes.property).match(/^product:/)))return!0;if(t.headMetaVerification&&("google-site-verification"===pS(e.attributes.name)||"yandex-verification"===pS(e.attributes.name)||"csrf-token"===pS(e.attributes.name)||"p:domain_verify"===pS(e.attributes.name)||"verify-v1"===pS(e.attributes.name)||"verification"===pS(e.attributes.name)||"shopify-checkout-api-token"===pS(e.attributes.name)))return!0}}return!1}(B,g)||!F&&B.type===w_.Text&&!B.textContent.replace(/^\s+|\s+$/gm,"").length?-2:eS();var z=Object.assign(B,{id:$});if(n.add(e,z),-2===$)return null;S&&S(e);var V=!c;if(z.type===w_.Element){V=V&&!z.needBlock,delete z.needBlock;var U=A_(e);U&&j_(U)&&(z.isShadowHost=!0)}if((z.type===w_.Document||z.type===w_.Element)&&V){g.headWhitespace&&z.type===w_.Element&&"head"===z.tagName&&(F=!1);var q={doc:r,mirror:n,blockClass:o,blockSelector:i,needsMask:L,maskTextClass:s,maskTextSelector:a,skipChild:c,inlineStylesheet:p,maskInputOptions:f,maskTextFn:h,maskInputFn:m,slimDOMOptions:g,dataURLOptions:y,inlineImages:w,recordCanvas:_,preserveWhiteSpace:F,onSerialize:S,onIframeLoad:k,iframeLoadTimeout:O,onStylesheetLoad:E,stylesheetLoadTimeout:R,keepIframeSrcFn:M,cssCaptured:!1};if(z.type===w_.Element&&"textarea"===z.tagName&&void 0!==z.attributes.value);else{z.type===w_.Element&&void 0!==z.attributes._cssText&&"string"==typeof z.attributes._cssText&&(q.cssCaptured=!0);for(var W,H=d_(Array.from(E_(e)));!(W=H()).done;){var G=dS(W.value,q);G&&z.childNodes.push(G)}}var K=null;if(P_(e)&&(K=A_(e)))for(var Y,Z=d_(Array.from(E_(K)));!(Y=Z()).done;){var X=dS(Y.value,q);X&&(j_(K)&&(X.isShadow=!0),z.childNodes.push(X))}}var J=T_(e);return J&&N_(J)&&j_(J)&&(z.isShadow=!0),z.type===w_.Element&&"iframe"===z.tagName&&function(e,t,r){var n=e.contentWindow;if(n){var o,i=!1;try{o=n.document.readyState}catch(e){return}if("complete"===o){var s="about:blank";if(n.location.href!==s||e.src===s||""===e.src)return setTimeout(t,0),e.addEventListener("load",t);e.addEventListener("load",t)}else{var a=setTimeout(function(){i||(t(),i=!0)},r);e.addEventListener("load",function(){clearTimeout(a),i=!0,t()})}}}(e,function(){var t=e.contentDocument;if(t&&k){var r=dS(t,{doc:t,mirror:n,blockClass:o,blockSelector:i,needsMask:L,maskTextClass:s,maskTextSelector:a,skipChild:!1,inlineStylesheet:p,maskInputOptions:f,maskTextFn:h,maskInputFn:m,slimDOMOptions:g,dataURLOptions:y,inlineImages:w,recordCanvas:_,preserveWhiteSpace:F,onSerialize:S,onIframeLoad:k,iframeLoadTimeout:O,onStylesheetLoad:E,stylesheetLoadTimeout:R,keepIframeSrcFn:M});r&&k(e,r)}},O),z.type===w_.Element&&"link"===z.tagName&&"string"==typeof z.attributes.rel&&("stylesheet"===z.attributes.rel||"preload"===z.attributes.rel&&"string"==typeof z.attributes.href&&"css"===U_(z.attributes.href))&&function(e,t,r){var n,o=!1;try{n=e.sheet}catch(e){return}if(!n){var i=setTimeout(function(){o||(t(),o=!0)},r);e.addEventListener("load",function(){clearTimeout(i),o=!0,t()})}}(e,function(){if(E){var t=dS(e,{doc:r,mirror:n,blockClass:o,blockSelector:i,needsMask:L,maskTextClass:s,maskTextSelector:a,skipChild:!1,inlineStylesheet:p,maskInputOptions:f,maskTextFn:h,maskInputFn:m,slimDOMOptions:g,dataURLOptions:y,inlineImages:w,recordCanvas:_,preserveWhiteSpace:F,onSerialize:S,onIframeLoad:k,iframeLoadTimeout:O,onStylesheetLoad:E,stylesheetLoadTimeout:R,keepIframeSrcFn:M});t&&E(e,t)}},R),z}function fS(e){if(e.__esModule)return e;var t=e.default;if("function"==typeof t){var r=function e(){return s_(this,e)?Reflect.construct(t,arguments,this.constructor):t.apply(this,arguments)};r.prototype=t.prototype}else r={};return Object.defineProperty(r,"__esModule",{value:!0}),Object.keys(e).forEach(function(t){var n=Object.getOwnPropertyDescriptor(e,t);Object.defineProperty(r,t,n.get?n:{enumerable:!0,get:function(){return e[t]}})}),r}var hS={exports:{}},mS=String,gS=function(){return{isColorSupported:!1,reset:mS,bold:mS,dim:mS,italic:mS,underline:mS,inverse:mS,hidden:mS,strikethrough:mS,black:mS,red:mS,green:mS,yellow:mS,blue:mS,magenta:mS,cyan:mS,white:mS,gray:mS,bgBlack:mS,bgRed:mS,bgGreen:mS,bgYellow:mS,bgBlue:mS,bgMagenta:mS,bgCyan:mS,bgWhite:mS}};hS.exports=gS(),hS.exports.createColors=gS;var vS=hS.exports,yS=fS(Object.freeze(Object.defineProperty({__proto__:null,default:{}},Symbol.toStringTag,{value:"Module"}))),bS=vS,wS=yS,xS=function(e){function t(r,n,o,i,s,a){var l;return(l=e.call(this,r)||this).name="CssSyntaxError",l.reason=r,s&&(l.file=s),i&&(l.source=i),a&&(l.plugin=a),void 0!==n&&void 0!==o&&("number"==typeof n?(l.line=n,l.column=o):(l.line=n.line,l.column=n.column,l.endLine=o.line,l.endColumn=o.column)),l.setMessage(),Error.captureStackTrace&&Error.captureStackTrace(l,t),l}i_(t,e);var r=t.prototype;return r.setMessage=function(){this.message=this.plugin?this.plugin+": ":"",this.message+=this.file?this.file:"<css input>",void 0!==this.line&&(this.message+=":"+this.line+":"+this.column),this.message+=": "+this.reason},r.showSourceCode=function(e){var t=this;if(!this.source)return"";var r=this.source;null==e&&(e=bS.isColorSupported),wS&&e&&(r=wS(r));var n,o,i=r.split(/\r?\n/),s=Math.max(this.line-3,0),a=Math.min(this.line+2,i.length),l=String(a).length;if(e){var c=bS.createColors(!0),u=c.bold,p=c.gray,d=c.red;n=function(e){return u(d(e))},o=function(e){return p(e)}}else n=o=function(e){return e};return i.slice(s,a).map(function(e,r){var i=s+1+r,a=" "+(" "+i).slice(-l)+" | ";if(i===t.line){var c=o(a.replace(/\d/g," "))+e.slice(0,t.column-1).replace(/[^\t]/g," ");return n(">")+o(a)+e+"\n "+c+n("^")}return" "+o(a)+e}).join("\n")},r.toString=function(){var e=this.showSourceCode();return e&&(e="\n\n"+e+"\n"),this.name+": "+this.message+e},t}(u_(Error)),_S=xS;xS.default=xS;var SS={};SS.isClean=Symbol("isClean"),SS.my=Symbol("my");var kS={after:"\n",beforeClose:"\n",beforeComment:"\n",beforeDecl:"\n",beforeOpen:" ",beforeRule:"\n",colon:": ",commentLeft:" ",commentRight:" ",emptyBody:"",indent:"    ",semicolon:!1},CS=function(){function e(e){this.builder=e}var t=e.prototype;return t.atrule=function(e,t){var r="@"+e.name,n=e.params?this.rawValue(e,"params"):"";if(void 0!==e.raws.afterName?r+=e.raws.afterName:n&&(r+=" "),e.nodes)this.block(e,r+n);else{var o=(e.raws.between||"")+(t?";":"");this.builder(r+n+o,e)}},t.beforeAfter=function(e,t){var r;r="decl"===e.type?this.raw(e,null,"beforeDecl"):"comment"===e.type?this.raw(e,null,"beforeComment"):"before"===t?this.raw(e,null,"beforeRule"):this.raw(e,null,"beforeClose");for(var n=e.parent,o=0;n&&"root"!==n.type;)o+=1,n=n.parent;if(r.includes("\n")){var i=this.raw(e,null,"indent");if(i.length)for(var s=0;s<o;s++)r+=i}return r},t.block=function(e,t){var r,n=this.raw(e,"between","beforeOpen");this.builder(t+n+"{",e,"start"),e.nodes&&e.nodes.length?(this.body(e),r=this.raw(e,"after")):r=this.raw(e,"after","emptyBody"),r&&this.builder(r),this.builder("}",e,"end")},t.body=function(e){for(var t=e.nodes.length-1;t>0&&"comment"===e.nodes[t].type;)t-=1;for(var r=this.raw(e,"semicolon"),n=0;n<e.nodes.length;n++){var o=e.nodes[n],i=this.raw(o,"before");i&&this.builder(i),this.stringify(o,t!==n||r)}},t.comment=function(e){var t=this.raw(e,"left","commentLeft"),r=this.raw(e,"right","commentRight");this.builder("/*"+t+e.text+r+"*/",e)},t.decl=function(e,t){var r=this.raw(e,"between","colon"),n=e.prop+r+this.rawValue(e,"value");e.important&&(n+=e.raws.important||" !important"),t&&(n+=";"),this.builder(n,e)},t.document=function(e){this.body(e)},t.raw=function(e,t,r){var n;if(r||(r=t),t&&void 0!==(n=e.raws[t]))return n;var o=e.parent;if("before"===r){if(!o||"root"===o.type&&o.first===e)return"";if(o&&"document"===o.type)return""}if(!o)return kS[r];var i=e.root();if(i.rawCache||(i.rawCache={}),void 0!==i.rawCache[r])return i.rawCache[r];if("before"===r||"after"===r)return this.beforeAfter(e,r);var s,a="raw"+((s=r)[0].toUpperCase()+s.slice(1));return this[a]?n=this[a](i,e):i.walk(function(e){if(void 0!==(n=e.raws[t]))return!1}),void 0===n&&(n=kS[r]),i.rawCache[r]=n,n},t.rawBeforeClose=function(e){var t;return e.walk(function(e){if(e.nodes&&e.nodes.length>0&&void 0!==e.raws.after)return(t=e.raws.after).includes("\n")&&(t=t.replace(/[^\n]+$/,"")),!1}),t&&(t=t.replace(/\S/g,"")),t},t.rawBeforeComment=function(e,t){var r;return e.walkComments(function(e){if(void 0!==e.raws.before)return(r=e.raws.before).includes("\n")&&(r=r.replace(/[^\n]+$/,"")),!1}),void 0===r?r=this.raw(t,null,"beforeDecl"):r&&(r=r.replace(/\S/g,"")),r},t.rawBeforeDecl=function(e,t){var r;return e.walkDecls(function(e){if(void 0!==e.raws.before)return(r=e.raws.before).includes("\n")&&(r=r.replace(/[^\n]+$/,"")),!1}),void 0===r?r=this.raw(t,null,"beforeRule"):r&&(r=r.replace(/\S/g,"")),r},t.rawBeforeOpen=function(e){var t;return e.walk(function(e){if("decl"!==e.type&&void 0!==(t=e.raws.between))return!1}),t},t.rawBeforeRule=function(e){var t;return e.walk(function(r){if(r.nodes&&(r.parent!==e||e.first!==r)&&void 0!==r.raws.before)return(t=r.raws.before).includes("\n")&&(t=t.replace(/[^\n]+$/,"")),!1}),t&&(t=t.replace(/\S/g,"")),t},t.rawColon=function(e){var t;return e.walkDecls(function(e){if(void 0!==e.raws.between)return t=e.raws.between.replace(/[^\s:]/g,""),!1}),t},t.rawEmptyBody=function(e){var t;return e.walk(function(e){if(e.nodes&&0===e.nodes.length&&void 0!==(t=e.raws.after))return!1}),t},t.rawIndent=function(e){return e.raws.indent?e.raws.indent:(e.walk(function(r){var n=r.parent;if(n&&n!==e&&n.parent&&n.parent===e&&void 0!==r.raws.before){var o=r.raws.before.split("\n");return t=(t=o[o.length-1]).replace(/\S/g,""),!1}}),t);// removed by dead control flow
 var t; },t.rawSemicolon=function(e){var t;return e.walk(function(e){if(e.nodes&&e.nodes.length&&"decl"===e.last.type&&void 0!==(t=e.raws.semicolon))return!1}),t},t.rawValue=function(e,t){var r=e[t],n=e.raws[t];return n&&n.value===r?n.raw:r},t.root=function(e){this.body(e),e.raws.after&&this.builder(e.raws.after)},t.rule=function(e){this.block(e,this.rawValue(e,"selector")),e.raws.ownSemicolon&&this.builder(e.raws.ownSemicolon,e,"end")},t.stringify=function(e,t){if(!this[e.type])throw new Error("Unknown AST node type "+e.type+". Maybe you need to change PostCSS stringifier.");this[e.type](e,t)},e}(),OS=CS;CS.default=CS;var ES=OS;function TS(e,t){new ES(t).stringify(e)}var RS=TS;TS.default=TS;var IS=SS.isClean,MS=SS.my,AS=_S,PS=OS,NS=RS;function jS(e,t){var r=new e.constructor;for(var n in e)if(Object.prototype.hasOwnProperty.call(e,n)&&"proxyCache"!==n){var o=e[n],i=void 0===o?"undefined":c_(o);"parent"===n&&"object"===i?t&&(r[n]=t):"source"===n?r[n]=o:Array.isArray(o)?r[n]=o.map(function(e){return jS(e,r)}):("object"===i&&null!==o&&(o=jS(o)),r[n]=o)}return r}var LS=function(){function e(e){for(var t in void 0===e&&(e={}),this.raws={},this[IS]=!1,this[MS]=!0,e)if("nodes"===t){this.nodes=[];for(var r,n=d_(e[t]);!(r=n()).done;){var o=r.value;"function"==typeof o.clone?this.append(o.clone()):this.append(o)}}else this[t]=e[t]}var t=e.prototype;return t.addToError=function(e){if(e.postcssNode=this,e.stack&&this.source&&/\n\s{4}at /.test(e.stack)){var t=this.source;e.stack=e.stack.replace(/\n\s{4}at /,"$&"+t.input.from+":"+t.start.line+":"+t.start.column+"$&")}return e},t.after=function(e){return this.parent.insertAfter(this,e),this},t.assign=function(e){for(var t in void 0===e&&(e={}),e)this[t]=e[t];return this},t.before=function(e){return this.parent.insertBefore(this,e),this},t.cleanRaws=function(e){delete this.raws.before,delete this.raws.after,e||delete this.raws.between},t.clone=function(e){void 0===e&&(e={});var t=jS(this);for(var r in e)t[r]=e[r];return t},t.cloneAfter=function(e){void 0===e&&(e={});var t=this.clone(e);return this.parent.insertAfter(this,t),t},t.cloneBefore=function(e){void 0===e&&(e={});var t=this.clone(e);return this.parent.insertBefore(this,t),t},t.error=function(e,t){if(void 0===t&&(t={}),this.source){var r=this.rangeBy(t),n=r.end,o=r.start;return this.source.input.error(e,{column:o.column,line:o.line},{column:n.column,line:n.line},t)}return new AS(e)},t.getProxyProcessor=function(){return{get:function(e,t){return"proxyOf"===t?e:"root"===t?function(){return e.root().toProxy()}:e[t]},set:function(e,t,r){return e[t]===r||(e[t]=r,"prop"!==t&&"value"!==t&&"name"!==t&&"params"!==t&&"important"!==t&&"text"!==t||e.markDirty()),!0}}},t.markDirty=function(){if(this[IS]){this[IS]=!1;for(var e=this;e=e.parent;)e[IS]=!1}},t.next=function(){if(this.parent){var e=this.parent.index(this);return this.parent.nodes[e+1]}},t.positionBy=function(e,t){var r=this.source.start;if(e.index)r=this.positionInside(e.index,t);else if(e.word){var n=(t=this.toString()).indexOf(e.word);-1!==n&&(r=this.positionInside(n,t))}return r},t.positionInside=function(e,t){for(var r=t||this.toString(),n=this.source.start.column,o=this.source.start.line,i=0;i<e;i++)"\n"===r[i]?(n=1,o+=1):n+=1;return{column:n,line:o}},t.prev=function(){if(this.parent){var e=this.parent.index(this);return this.parent.nodes[e-1]}},t.rangeBy=function(e){var t={column:this.source.start.column,line:this.source.start.line},r=this.source.end?{column:this.source.end.column+1,line:this.source.end.line}:{column:t.column+1,line:t.line};if(e.word){var n=this.toString(),o=n.indexOf(e.word);-1!==o&&(t=this.positionInside(o,n),r=this.positionInside(o+e.word.length,n))}else e.start?t={column:e.start.column,line:e.start.line}:e.index&&(t=this.positionInside(e.index)),e.end?r={column:e.end.column,line:e.end.line}:"number"==typeof e.endIndex?r=this.positionInside(e.endIndex):e.index&&(r=this.positionInside(e.index+1));return(r.line<t.line||r.line===t.line&&r.column<=t.column)&&(r={column:t.column+1,line:t.line}),{end:r,start:t}},t.raw=function(e,t){return(new PS).raw(this,e,t)},t.remove=function(){return this.parent&&this.parent.removeChild(this),this.parent=void 0,this},t.replaceWith=function(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];if(this.parent){for(var n,o=this,i=!1,s=d_(t);!(n=s()).done;){var a=n.value;a===this?i=!0:i?(this.parent.insertAfter(o,a),o=a):this.parent.insertBefore(o,a)}i||this.remove()}return this},t.root=function(){for(var e=this;e.parent&&"document"!==e.parent.type;)e=e.parent;return e},t.toJSON=function(e,t){var r={},n=null==t;t=t||new Map;var o=0;for(var i in this)if(Object.prototype.hasOwnProperty.call(this,i)&&"parent"!==i&&"proxyCache"!==i){var s=this[i];if(Array.isArray(s))r[i]=s.map(function(e){return"object"===(void 0===e?"undefined":c_(e))&&e.toJSON?e.toJSON(null,t):e});else if("object"===(void 0===s?"undefined":c_(s))&&s.toJSON)r[i]=s.toJSON(null,t);else if("source"===i){var a=t.get(s.input);null==a&&(a=o,t.set(s.input,o),o++),r[i]={end:s.end,inputId:a,start:s.start}}else r[i]=s}return n&&(r.inputs=[].concat(t.keys()).map(function(e){return e.toJSON()})),r},t.toProxy=function(){return this.proxyCache||(this.proxyCache=new Proxy(this,this.getProxyProcessor())),this.proxyCache},t.toString=function(e){void 0===e&&(e=NS),e.stringify&&(e=e.stringify);var t="";return e(this,function(e){t+=e}),t},t.warn=function(e,t,r){var n={node:this};for(var o in r)n[o]=r[o];return e.warn(t,n)},r_(e,[{key:"proxyOf",get:function(){return this}}]),e}(),DS=LS;LS.default=LS;var FS=function(e){function t(t){var r;return t&&void 0!==t.value&&"string"!=typeof t.value&&(t=n_({},t,{value:String(t.value)})),(r=e.call(this,t)||this).type="decl",r}return i_(t,e),r_(t,[{key:"variable",get:function(){return this.prop.startsWith("--")||"$"===this.prop[0]}}]),t}(DS),$S=FS;FS.default=FS;var BS=yS.SourceMapConsumer,zS=yS.SourceMapGenerator,VS=yS.existsSync,US=yS.readFileSync,qS=yS.dirname,WS=yS.join,HS=function(){function e(e,t){if(!1!==t.map){this.loadAnnotation(e),this.inline=this.startWith(this.annotation,"data:");var r=t.map?t.map.prev:void 0,n=this.loadMap(t.from,r);!this.mapFile&&t.from&&(this.mapFile=t.from),this.mapFile&&(this.root=qS(this.mapFile)),n&&(this.text=n)}}var t=e.prototype;return t.consumer=function(){return this.consumerCache||(this.consumerCache=new BS(this.text)),this.consumerCache},t.decodeInline=function(e){var t;if(/^data:application\/json;charset=utf-?8,/.test(e)||/^data:application\/json,/.test(e))return decodeURIComponent(e.substr(RegExp.lastMatch.length));if(/^data:application\/json;charset=utf-?8;base64,/.test(e)||/^data:application\/json;base64,/.test(e))return t=e.substr(RegExp.lastMatch.length),Buffer?Buffer.from(t,"base64").toString():window.atob(t);var r=e.match(/data:application\/json;([^,]+),/)[1];throw new Error("Unsupported source map encoding "+r)},t.getAnnotationURL=function(e){return e.replace(/^\/\*\s*# sourceMappingURL=/,"").trim()},t.isMap=function(e){return"object"===(void 0===e?"undefined":c_(e))&&("string"==typeof e.mappings||"string"==typeof e._mappings||Array.isArray(e.sections))},t.loadAnnotation=function(e){var t=e.match(/\/\*\s*# sourceMappingURL=/gm);if(t){var r=e.lastIndexOf(t.pop()),n=e.indexOf("*/",r);r>-1&&n>-1&&(this.annotation=this.getAnnotationURL(e.substring(r,n)))}},t.loadFile=function(e){if(this.root=qS(e),VS(e))return this.mapFile=e,US(e,"utf-8").toString().trim()},t.loadMap=function(e,t){if(!1===t)return!1;if(t){if("string"==typeof t)return t;if("function"!=typeof t){if(s_(t,BS))return zS.fromSourceMap(t).toString();if(s_(t,zS))return t.toString();if(this.isMap(t))return JSON.stringify(t);throw new Error("Unsupported previous source map format: "+t.toString())}var r=t(e);if(r){var n=this.loadFile(r);if(!n)throw new Error("Unable to load previous source map: "+r.toString());return n}}else{if(this.inline)return this.decodeInline(this.annotation);if(this.annotation){var o=this.annotation;return e&&(o=WS(qS(e),o)),this.loadFile(o)}}},t.startWith=function(e,t){return!!e&&e.substr(0,t.length)===t},t.withContent=function(){return!!(this.consumer().sourcesContent&&this.consumer().sourcesContent.length>0)},e}(),GS=HS;HS.default=HS;var KS=yS.SourceMapConsumer,YS=yS.SourceMapGenerator,ZS=yS.fileURLToPath,XS=yS.pathToFileURL,JS=yS.isAbsolute,QS=yS.resolve,ek=function(e){void 0===e&&(e=21);for(var t="",r=e;r--;)t+="useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict"[64*Math.random()|0];return t},tk=yS,rk=_S,nk=GS,ok=Symbol("fromOffsetCache"),ik=Boolean(KS&&YS),sk=Boolean(QS&&JS),ak=function(){function e(e,t){if(void 0===t&&(t={}),null==e||"object"===(void 0===e?"undefined":c_(e))&&!e.toString)throw new Error("PostCSS received "+e+" instead of CSS string");if(this.css=e.toString(),"\ufeff"===this.css[0]||""===this.css[0]?(this.hasBOM=!0,this.css=this.css.slice(1)):this.hasBOM=!1,t.from&&(!sk||/^\w+:\/\//.test(t.from)||JS(t.from)?this.file=t.from:this.file=QS(t.from)),sk&&ik){var r=new nk(this.css,t);if(r.text){this.map=r;var n=r.consumer().file;!this.file&&n&&(this.file=this.mapResolve(n))}}this.file||(this.id="<input css "+ek(6)+">"),this.map&&(this.map.file=this.from)}var t=e.prototype;return t.error=function(e,t,r,n){var o,i,s;if(void 0===n&&(n={}),t&&"object"===(void 0===t?"undefined":c_(t))){var a=t,l=r;if("number"==typeof a.offset){var c=this.fromOffset(a.offset);t=c.line,r=c.col}else t=a.line,r=a.column;if("number"==typeof l.offset){var u=this.fromOffset(l.offset);i=u.line,s=u.col}else i=l.line,s=l.column}else if(!r){var p=this.fromOffset(t);t=p.line,r=p.col}var d=this.origin(t,r,i,s);return(o=d?new rk(e,void 0===d.endLine?d.line:{column:d.column,line:d.line},void 0===d.endLine?d.column:{column:d.endColumn,line:d.endLine},d.source,d.file,n.plugin):new rk(e,void 0===i?t:{column:r,line:t},void 0===i?r:{column:s,line:i},this.css,this.file,n.plugin)).input={column:r,endColumn:s,endLine:i,line:t,source:this.css},this.file&&(XS&&(o.input.url=XS(this.file).toString()),o.input.file=this.file),o},t.fromOffset=function(e){var t;if(this[ok])t=this[ok];else{var r=this.css.split("\n");t=new Array(r.length);for(var n=0,o=0,i=r.length;o<i;o++)t[o]=n,n+=r[o].length+1;this[ok]=t}var s=0;if(e>=t[t.length-1])s=t.length-1;else for(var a,l=t.length-2;s<l;)if(e<t[a=s+(l-s>>1)])l=a-1;else{if(!(e>=t[a+1])){s=a;break}s=a+1}return{col:e-t[s]+1,line:s+1}},t.mapResolve=function(e){return/^\w+:\/\//.test(e)?e:QS(this.map.consumer().sourceRoot||this.map.root||".",e)},t.origin=function(e,t,r,n){if(!this.map)return!1;var o,i,s=this.map.consumer(),a=s.originalPositionFor({column:t,line:e});if(!a.source)return!1;"number"==typeof r&&(o=s.originalPositionFor({column:n,line:r})),i=JS(a.source)?XS(a.source):new URL(a.source,this.map.consumer().sourceRoot||XS(this.map.mapFile));var l={column:a.column,endColumn:o&&o.column,endLine:o&&o.line,line:a.line,url:i.toString()};if("file:"===i.protocol){if(!ZS)throw new Error("file: protocol is not available in this PostCSS build");l.file=ZS(i)}var c=s.sourceContentFor(a.source);return c&&(l.source=c),l},t.toJSON=function(){for(var e={},t=0,r=["hasBOM","css","file","id"];t<r.length;t++){var n=r[t];null!=this[n]&&(e[n]=this[n])}return this.map&&(e.map=n_({},this.map),e.map.consumerCache&&(e.map.consumerCache=void 0)),e},r_(e,[{key:"from",get:function(){return this.file||this.id}}]),e}(),lk=ak;ak.default=ak,tk&&tk.registerInput&&tk.registerInput(ak);var ck=yS.SourceMapConsumer,uk=yS.SourceMapGenerator,pk=yS.dirname,dk=yS.relative,fk=yS.resolve,hk=yS.sep,mk=yS.pathToFileURL,gk=lk,vk=Boolean(ck&&uk),yk=Boolean(pk&&fk&&dk&&hk),bk=function(){function e(e,t,r,n){this.stringify=e,this.mapOpts=r.map||{},this.root=t,this.opts=r,this.css=n,this.originalCSS=n,this.usesFileUrls=!this.mapOpts.from&&this.mapOpts.absolute,this.memoizedFileURLs=new Map,this.memoizedPaths=new Map,this.memoizedURLs=new Map}var t=e.prototype;return t.addAnnotation=function(){var e;e=this.isInline()?"data:application/json;base64,"+this.toBase64(this.map.toString()):"string"==typeof this.mapOpts.annotation?this.mapOpts.annotation:"function"==typeof this.mapOpts.annotation?this.mapOpts.annotation(this.opts.to,this.root):this.outputFile()+".map";var t="\n";this.css.includes("\r\n")&&(t="\r\n"),this.css+=t+"/*# sourceMappingURL="+e+" */"},t.applyPrevMaps=function(){for(var e,t=d_(this.previous());!(e=t()).done;){var r=e.value,n=this.toUrl(this.path(r.file)),o=r.root||pk(r.file),i=void 0;!1===this.mapOpts.sourcesContent?(i=new ck(r.text)).sourcesContent&&(i.sourcesContent=null):i=r.consumer(),this.map.applySourceMap(i,n,this.toUrl(this.path(o)))}},t.clearAnnotation=function(){if(!1!==this.mapOpts.annotation)if(this.root)for(var e,t=this.root.nodes.length-1;t>=0;t--)"comment"===(e=this.root.nodes[t]).type&&0===e.text.indexOf("# sourceMappingURL=")&&this.root.removeChild(t);else this.css&&(this.css=this.css.replace(/\n*?\/\*#[\S\s]*?\*\/$/gm,""))},t.generate=function(){if(this.clearAnnotation(),yk&&vk&&this.isMap())return this.generateMap();var e="";return this.stringify(this.root,function(t){e+=t}),[e]},t.generateMap=function(){if(this.root)this.generateString();else if(1===this.previous().length){var e=this.previous()[0].consumer();e.file=this.outputFile(),this.map=uk.fromSourceMap(e,{ignoreInvalidMapping:!0})}else this.map=new uk({file:this.outputFile(),ignoreInvalidMapping:!0}),this.map.addMapping({generated:{column:0,line:1},original:{column:0,line:1},source:this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>"});return this.isSourcesContent()&&this.setSourcesContent(),this.root&&this.previous().length>0&&this.applyPrevMaps(),this.isAnnotation()&&this.addAnnotation(),this.isInline()?[this.css]:[this.css,this.map]},t.generateString=function(){var e=this;this.css="",this.map=new uk({file:this.outputFile(),ignoreInvalidMapping:!0});var t,r,n=1,o=1,i="<no source>",s={generated:{column:0,line:0},original:{column:0,line:0},source:""};this.stringify(this.root,function(a,l,c){if(e.css+=a,l&&"end"!==c&&(s.generated.line=n,s.generated.column=o-1,l.source&&l.source.start?(s.source=e.sourcePath(l),s.original.line=l.source.start.line,s.original.column=l.source.start.column-1,e.map.addMapping(s)):(s.source=i,s.original.line=1,s.original.column=0,e.map.addMapping(s))),(t=a.match(/\n/g))?(n+=t.length,r=a.lastIndexOf("\n"),o=a.length-r):o+=a.length,l&&"start"!==c){var u=l.parent||{raws:{}};("decl"===l.type||"atrule"===l.type&&!l.nodes)&&l===u.last&&!u.raws.semicolon||(l.source&&l.source.end?(s.source=e.sourcePath(l),s.original.line=l.source.end.line,s.original.column=l.source.end.column-1,s.generated.line=n,s.generated.column=o-2,e.map.addMapping(s)):(s.source=i,s.original.line=1,s.original.column=0,s.generated.line=n,s.generated.column=o-1,e.map.addMapping(s)))}})},t.isAnnotation=function(){return!!this.isInline()||(void 0!==this.mapOpts.annotation?this.mapOpts.annotation:!this.previous().length||this.previous().some(function(e){return e.annotation}))},t.isInline=function(){if(void 0!==this.mapOpts.inline)return this.mapOpts.inline;var e=this.mapOpts.annotation;return(void 0===e||!0===e)&&(!this.previous().length||this.previous().some(function(e){return e.inline}))},t.isMap=function(){return void 0!==this.opts.map?!!this.opts.map:this.previous().length>0},t.isSourcesContent=function(){return void 0!==this.mapOpts.sourcesContent?this.mapOpts.sourcesContent:!this.previous().length||this.previous().some(function(e){return e.withContent()})},t.outputFile=function(){return this.opts.to?this.path(this.opts.to):this.opts.from?this.path(this.opts.from):"to.css"},t.path=function(e){if(this.mapOpts.absolute)return e;if(60===e.charCodeAt(0))return e;if(/^\w+:\/\//.test(e))return e;var t=this.memoizedPaths.get(e);if(t)return t;var r=this.opts.to?pk(this.opts.to):".";"string"==typeof this.mapOpts.annotation&&(r=pk(fk(r,this.mapOpts.annotation)));var n=dk(r,e);return this.memoizedPaths.set(e,n),n},t.previous=function(){var e=this;if(!this.previousMaps)if(this.previousMaps=[],this.root)this.root.walk(function(t){if(t.source&&t.source.input.map){var r=t.source.input.map;e.previousMaps.includes(r)||e.previousMaps.push(r)}});else{var t=new gk(this.originalCSS,this.opts);t.map&&this.previousMaps.push(t.map)}return this.previousMaps},t.setSourcesContent=function(){var e=this,t={};if(this.root)this.root.walk(function(r){if(r.source){var n=r.source.input.from;if(n&&!t[n]){t[n]=!0;var o=e.usesFileUrls?e.toFileUrl(n):e.toUrl(e.path(n));e.map.setSourceContent(o,r.source.input.css)}}});else if(this.css){var r=this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>";this.map.setSourceContent(r,this.css)}},t.sourcePath=function(e){return this.mapOpts.from?this.toUrl(this.mapOpts.from):this.usesFileUrls?this.toFileUrl(e.source.input.from):this.toUrl(this.path(e.source.input.from))},t.toBase64=function(e){return Buffer?Buffer.from(e).toString("base64"):window.btoa(unescape(encodeURIComponent(e)))},t.toFileUrl=function(e){var t=this.memoizedFileURLs.get(e);if(t)return t;if(mk){var r=mk(e).toString();return this.memoizedFileURLs.set(e,r),r}throw new Error("`map.absolute` option is not available in this PostCSS build")},t.toUrl=function(e){var t=this.memoizedURLs.get(e);if(t)return t;"\\"===hk&&(e=e.replace(/\\/g,"/"));var r=encodeURI(e).replace(/[#?]/g,encodeURIComponent);return this.memoizedURLs.set(e,r),r},e}(),wk=bk,xk=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="comment",r}return i_(t,e),t}(DS),_k=xk;xk.default=xk;var Sk,kk,Ck,Ok,Ek=SS.isClean,Tk=SS.my,Rk=$S,Ik=_k;function Mk(e){return e.map(function(e){return e.nodes&&(e.nodes=Mk(e.nodes)),delete e.source,e})}function Ak(e){if(e[Ek]=!1,e.proxyOf.nodes)for(var t,r=d_(e.proxyOf.nodes);!(t=r()).done;)Ak(t.value)}var Pk=function(e){function t(){return e.apply(this,arguments)||this}i_(t,e);var r=t.prototype;return r.append=function(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];for(var n,o=d_(t);!(n=o()).done;)for(var i,s=n.value,a=d_(this.normalize(s,this.last));!(i=a()).done;){var l=i.value;this.proxyOf.nodes.push(l)}return this.markDirty(),this},r.cleanRaws=function(t){if(e.prototype.cleanRaws.call(this,t),this.nodes)for(var r,n=d_(this.nodes);!(r=n()).done;)r.value.cleanRaws(t)},r.each=function(e){if(this.proxyOf.nodes){for(var t,r,n=this.getIterator();this.indexes[n]<this.proxyOf.nodes.length&&(t=this.indexes[n],!1!==(r=e(this.proxyOf.nodes[t],t)));)this.indexes[n]+=1;return delete this.indexes[n],r}},r.every=function(e){return this.nodes.every(e)},r.getIterator=function(){this.lastEach||(this.lastEach=0),this.indexes||(this.indexes={}),this.lastEach+=1;var e=this.lastEach;return this.indexes[e]=0,e},r.getProxyProcessor=function(){return{get:function(e,t){return"proxyOf"===t?e:e[t]?"each"===t||"string"==typeof t&&t.startsWith("walk")?function(){for(var r=arguments.length,n=new Array(r),o=0;o<r;o++)n[o]=arguments[o];var i;return(i=e)[t].apply(i,[].concat(n.map(function(e){return"function"==typeof e?function(t,r){return e(t.toProxy(),r)}:e})))}:"every"===t||"some"===t?function(r){return e[t](function(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),o=1;o<t;o++)n[o-1]=arguments[o];return r.apply(void 0,[].concat([e.toProxy()],n))})}:"root"===t?function(){return e.root().toProxy()}:"nodes"===t?e.nodes.map(function(e){return e.toProxy()}):"first"===t||"last"===t?e[t].toProxy():e[t]:e[t]},set:function(e,t,r){return e[t]===r||(e[t]=r,"name"!==t&&"params"!==t&&"selector"!==t||e.markDirty()),!0}}},r.index=function(e){return"number"==typeof e?e:(e.proxyOf&&(e=e.proxyOf),this.proxyOf.nodes.indexOf(e))},r.insertAfter=function(e,t){var r,n=this.index(e),o=this.normalize(t,this.proxyOf.nodes[n]).reverse();n=this.index(e);for(var i,s=d_(o);!(i=s()).done;){var a=i.value;this.proxyOf.nodes.splice(n+1,0,a)}for(var l in this.indexes)n<(r=this.indexes[l])&&(this.indexes[l]=r+o.length);return this.markDirty(),this},r.insertBefore=function(e,t){var r,n=this.index(e),o=0===n&&"prepend",i=this.normalize(t,this.proxyOf.nodes[n],o).reverse();n=this.index(e);for(var s,a=d_(i);!(s=a()).done;){var l=s.value;this.proxyOf.nodes.splice(n,0,l)}for(var c in this.indexes)n<=(r=this.indexes[c])&&(this.indexes[c]=r+i.length);return this.markDirty(),this},r.normalize=function(e,r){var n=this;if("string"==typeof e)e=Mk(Sk(e).nodes);else if(void 0===e)e=[];else if(Array.isArray(e))for(var o,i=d_(e=e.slice(0));!(o=i()).done;){var s=o.value;s.parent&&s.parent.removeChild(s,"ignore")}else if("root"===e.type&&"document"!==this.type)for(var a,l=d_(e=e.nodes.slice(0));!(a=l()).done;){var c=a.value;c.parent&&c.parent.removeChild(c,"ignore")}else if(e.type)e=[e];else if(e.prop){if(void 0===e.value)throw new Error("Value field is missed in node creation");"string"!=typeof e.value&&(e.value=String(e.value)),e=[new Rk(e)]}else if(e.selector)e=[new kk(e)];else if(e.name)e=[new Ck(e)];else{if(!e.text)throw new Error("Unknown node type in node creation");e=[new Ik(e)]}var u=e.map(function(e){return e[Tk]||t.rebuild(e),(e=e.proxyOf).parent&&e.parent.removeChild(e),e[Ek]&&Ak(e),void 0===e.raws.before&&r&&void 0!==r.raws.before&&(e.raws.before=r.raws.before.replace(/\S/g,"")),e.parent=n.proxyOf,e});return u},r.prepend=function(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];for(var n,o=d_(t=t.reverse());!(n=o()).done;){for(var i,s=n.value,a=this.normalize(s,this.first,"prepend").reverse(),l=d_(a);!(i=l()).done;){var c=i.value;this.proxyOf.nodes.unshift(c)}for(var u in this.indexes)this.indexes[u]=this.indexes[u]+a.length}return this.markDirty(),this},r.push=function(e){return e.parent=this,this.proxyOf.nodes.push(e),this},r.removeAll=function(){for(var e,t=d_(this.proxyOf.nodes);!(e=t()).done;)e.value.parent=void 0;return this.proxyOf.nodes=[],this.markDirty(),this},r.removeChild=function(e){var t;for(var r in e=this.index(e),this.proxyOf.nodes[e].parent=void 0,this.proxyOf.nodes.splice(e,1),this.indexes)(t=this.indexes[r])>=e&&(this.indexes[r]=t-1);return this.markDirty(),this},r.replaceValues=function(e,t,r){return r||(r=t,t={}),this.walkDecls(function(n){t.props&&!t.props.includes(n.prop)||t.fast&&!n.value.includes(t.fast)||(n.value=n.value.replace(e,r))}),this.markDirty(),this},r.some=function(e){return this.nodes.some(e)},r.walk=function(e){return this.each(function(t,r){var n;try{n=e(t,r)}catch(e){throw t.addToError(e)}return!1!==n&&t.walk&&(n=t.walk(e)),n})},r.walkAtRules=function(e,t){return t?s_(e,RegExp)?this.walk(function(r,n){if("atrule"===r.type&&e.test(r.name))return t(r,n)}):this.walk(function(r,n){if("atrule"===r.type&&r.name===e)return t(r,n)}):(t=e,this.walk(function(e,r){if("atrule"===e.type)return t(e,r)}))},r.walkComments=function(e){return this.walk(function(t,r){if("comment"===t.type)return e(t,r)})},r.walkDecls=function(e,t){return t?s_(e,RegExp)?this.walk(function(r,n){if("decl"===r.type&&e.test(r.prop))return t(r,n)}):this.walk(function(r,n){if("decl"===r.type&&r.prop===e)return t(r,n)}):(t=e,this.walk(function(e,r){if("decl"===e.type)return t(e,r)}))},r.walkRules=function(e,t){return t?s_(e,RegExp)?this.walk(function(r,n){if("rule"===r.type&&e.test(r.selector))return t(r,n)}):this.walk(function(r,n){if("rule"===r.type&&r.selector===e)return t(r,n)}):(t=e,this.walk(function(e,r){if("rule"===e.type)return t(e,r)}))},r_(t,[{key:"first",get:function(){if(this.proxyOf.nodes)return this.proxyOf.nodes[0]}},{key:"last",get:function(){if(this.proxyOf.nodes)return this.proxyOf.nodes[this.proxyOf.nodes.length-1]}}]),t}(DS);Pk.registerParse=function(e){Sk=e},Pk.registerRule=function(e){kk=e},Pk.registerAtRule=function(e){Ck=e},Pk.registerRoot=function(e){Ok=e};var Nk=Pk;Pk.default=Pk,Pk.rebuild=function(e){"atrule"===e.type?Object.setPrototypeOf(e,Ck.prototype):"rule"===e.type?Object.setPrototypeOf(e,kk.prototype):"decl"===e.type?Object.setPrototypeOf(e,Rk.prototype):"comment"===e.type?Object.setPrototypeOf(e,Ik.prototype):"root"===e.type&&Object.setPrototypeOf(e,Ok.prototype),e[Tk]=!0,e.nodes&&e.nodes.forEach(function(e){Pk.rebuild(e)})};var jk,Lk,Dk=function(e){function t(t){var r;return(r=e.call(this,n_({type:"document"},t))||this).nodes||(r.nodes=[]),r}return i_(t,e),t.prototype.toResult=function(e){return void 0===e&&(e={}),new jk(new Lk,this,e).stringify()},t}(Nk);Dk.registerLazyResult=function(e){jk=e},Dk.registerProcessor=function(e){Lk=e};var Fk=Dk;Dk.default=Dk;var $k={},Bk=function(e){$k[e]||($k[e]=!0,"undefined"!=typeof console&&console.warn&&console.warn(e))},zk=function(){function e(e,t){if(void 0===t&&(t={}),this.type="warning",this.text=e,t.node&&t.node.source){var r=t.node.rangeBy(t);this.line=r.start.line,this.column=r.start.column,this.endLine=r.end.line,this.endColumn=r.end.column}for(var n in t)this[n]=t[n]}return e.prototype.toString=function(){return this.node?this.node.error(this.text,{index:this.index,plugin:this.plugin,word:this.word}).message:this.plugin?this.plugin+": "+this.text:this.text},e}(),Vk=zk;zk.default=zk;var Uk=Vk,qk=function(){function e(e,t,r){this.processor=e,this.messages=[],this.root=t,this.opts=r,this.css=void 0,this.map=void 0}var t=e.prototype;return t.toString=function(){return this.css},t.warn=function(e,t){void 0===t&&(t={}),t.plugin||this.lastPlugin&&this.lastPlugin.postcssPlugin&&(t.plugin=this.lastPlugin.postcssPlugin);var r=new Uk(e,t);return this.messages.push(r),r},t.warnings=function(){return this.messages.filter(function(e){return"warning"===e.type})},r_(e,[{key:"content",get:function(){return this.css}}]),e}(),Wk=qk;qk.default=qk;var Hk="'".charCodeAt(0),Gk='"'.charCodeAt(0),Kk="\\".charCodeAt(0),Yk="/".charCodeAt(0),Zk="\n".charCodeAt(0),Xk=" ".charCodeAt(0),Jk="\f".charCodeAt(0),Qk="\t".charCodeAt(0),eC="\r".charCodeAt(0),tC="[".charCodeAt(0),rC="]".charCodeAt(0),nC="(".charCodeAt(0),oC=")".charCodeAt(0),iC="{".charCodeAt(0),sC="}".charCodeAt(0),aC=";".charCodeAt(0),lC="*".charCodeAt(0),cC=":".charCodeAt(0),uC="@".charCodeAt(0),pC=/[\t\n\f\r "#'()/;[\\\]{}]/g,dC=/[\t\n\f\r !"#'():;@[\\\]{}]|\/(?=\*)/g,fC=/.[\r\n"'(/\\]/,hC=/[\da-f]/i,mC=Nk,gC=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="atrule",r}i_(t,e);var r=t.prototype;return r.append=function(){for(var t=arguments.length,r=new Array(t),n=0;n<t;n++)r[n]=arguments[n];var o;return this.proxyOf.nodes||(this.nodes=[]),(o=e.prototype.append).call.apply(o,[].concat([this],r))},r.prepend=function(){for(var t=arguments.length,r=new Array(t),n=0;n<t;n++)r[n]=arguments[n];var o;return this.proxyOf.nodes||(this.nodes=[]),(o=e.prototype.prepend).call.apply(o,[].concat([this],r))},t}(mC),vC=gC;gC.default=gC,mC.registerAtRule(gC);var yC,bC,wC=Nk,xC=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="root",r.nodes||(r.nodes=[]),r}i_(t,e);var r=t.prototype;return r.normalize=function(t,r,n){var o=e.prototype.normalize.call(this,t);if(r)if("prepend"===n)this.nodes.length>1?r.raws.before=this.nodes[1].raws.before:delete r.raws.before;else if(this.first!==r)for(var i,s=d_(o);!(i=s()).done;)i.value.raws.before=r.raws.before;return o},r.removeChild=function(t,r){var n=this.index(t);return!r&&0===n&&this.nodes.length>1&&(this.nodes[1].raws.before=this.nodes[n].raws.before),e.prototype.removeChild.call(this,t)},r.toResult=function(e){return void 0===e&&(e={}),new yC(new bC,this,e).stringify()},t}(wC);xC.registerLazyResult=function(e){yC=e},xC.registerProcessor=function(e){bC=e};var _C=xC;xC.default=xC,wC.registerRoot(xC);var SC={comma:function(e){return SC.split(e,[","],!0)},space:function(e){return SC.split(e,[" ","\n","\t"])},split:function(e,t,r){for(var n,o=[],i="",s=!1,a=0,l=!1,c="",u=!1,p=d_(e);!(n=p()).done;){var d=n.value;u?u=!1:"\\"===d?u=!0:l?d===c&&(l=!1):'"'===d||"'"===d?(l=!0,c=d):"("===d?a+=1:")"===d?a>0&&(a-=1):0===a&&t.includes(d)&&(s=!0),s?(""!==i&&o.push(i.trim()),i="",s=!1):i+=d}return(r||""!==i)&&o.push(i.trim()),o}},kC=SC;SC.default=SC;var CC=Nk,OC=kC,EC=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="rule",r.nodes||(r.nodes=[]),r}return i_(t,e),r_(t,[{key:"selectors",get:function(){return OC.comma(this.selector)},set:function(e){var t=this.selector?this.selector.match(/,\s*/):null,r=t?t[0]:","+this.raw("between","beforeOpen");this.selector=e.join(r)}}]),t}(CC),TC=EC;EC.default=EC,CC.registerRule(EC);var RC=$S,IC=_k,MC=vC,AC=_C,PC=TC,NC={empty:!0,space:!0},jC=function(){function e(e){this.input=e,this.root=new AC,this.current=this.root,this.spaces="",this.semicolon=!1,this.createTokenizer(),this.root.source={input:e,start:{column:1,line:1,offset:0}}}var t=e.prototype;return t.atrule=function(e){var t,r,n,o=new MC;o.name=e[1].slice(1),""===o.name&&this.unnamedAtrule(o,e),this.init(o,e[2]);for(var i=!1,s=!1,a=[],l=[];!this.tokenizer.endOfFile();){if("("===(t=(e=this.tokenizer.nextToken())[0])||"["===t?l.push("("===t?")":"]"):"{"===t&&l.length>0?l.push("}"):t===l[l.length-1]&&l.pop(),0===l.length){if(";"===t){o.source.end=this.getPosition(e[2]),o.source.end.offset++,this.semicolon=!0;break}if("{"===t){s=!0;break}if("}"===t){if(a.length>0){for(r=a[n=a.length-1];r&&"space"===r[0];)r=a[--n];r&&(o.source.end=this.getPosition(r[3]||r[2]),o.source.end.offset++)}this.end(e);break}a.push(e)}else a.push(e);if(this.tokenizer.endOfFile()){i=!0;break}}o.raws.between=this.spacesAndCommentsFromEnd(a),a.length?(o.raws.afterName=this.spacesAndCommentsFromStart(a),this.raw(o,"params",a),i&&(e=a[a.length-1],o.source.end=this.getPosition(e[3]||e[2]),o.source.end.offset++,this.spaces=o.raws.between,o.raws.between="")):(o.raws.afterName="",o.params=""),s&&(o.nodes=[],this.current=o)},t.checkMissedSemicolon=function(e){var t=this.colon(e);if(!1!==t){for(var r,n=0,o=t-1;o>=0&&("space"===(r=e[o])[0]||2!==(n+=1));o--);throw this.input.error("Missed semicolon","word"===r[0]?r[3]+1:r[2])}},t.colon=function(e){for(var t,r,n,o,i=0,s=d_(e.entries());!(o=s()).done;){var a=o.value,l=a[0];if("("===(r=(t=a[1])[0])&&(i+=1),")"===r&&(i-=1),0===i&&":"===r){if(n){if("word"===n[0]&&"progid"===n[1])continue;return l}this.doubleColon(t)}n=t}return!1},t.comment=function(e){var t=new IC;this.init(t,e[2]),t.source.end=this.getPosition(e[3]||e[2]),t.source.end.offset++;var r=e[1].slice(2,-2);if(/^\s*$/.test(r))t.text="",t.raws.left=r,t.raws.right="";else{var n=r.match(/^(\s*)([^]*\S)(\s*)$/);t.text=n[2],t.raws.left=n[1],t.raws.right=n[3]}},t.createTokenizer=function(){this.tokenizer=function(e,t){void 0===t&&(t={});var r,n,o,i,s,a,l,c,u,p,d=e.css.valueOf(),f=t.ignoreErrors,h=d.length,m=0,g=[],v=[];function y(t){throw e.error("Unclosed "+t,m)}return{back:function(e){v.push(e)},endOfFile:function(){return 0===v.length&&m>=h},nextToken:function(e){if(v.length)return v.pop();if(!(m>=h)){var t=!!e&&e.ignoreUnclosed;switch(r=d.charCodeAt(m)){case Zk:case Xk:case Qk:case eC:case Jk:n=m;do{n+=1,r=d.charCodeAt(n)}while(r===Xk||r===Zk||r===Qk||r===eC||r===Jk);p=["space",d.slice(m,n)],m=n-1;break;case tC:case rC:case iC:case sC:case cC:case aC:case oC:var b=String.fromCharCode(r);p=[b,b,m];break;case nC:if(c=g.length?g.pop()[1]:"",u=d.charCodeAt(m+1),"url"===c&&u!==Hk&&u!==Gk&&u!==Xk&&u!==Zk&&u!==Qk&&u!==Jk&&u!==eC){n=m;do{if(a=!1,-1===(n=d.indexOf(")",n+1))){if(f||t){n=m;break}y("bracket")}for(l=n;d.charCodeAt(l-1)===Kk;)l-=1,a=!a}while(a);p=["brackets",d.slice(m,n+1),m,n],m=n}else n=d.indexOf(")",m+1),i=d.slice(m,n+1),-1===n||fC.test(i)?p=["(","(",m]:(p=["brackets",i,m,n],m=n);break;case Hk:case Gk:o=r===Hk?"'":'"',n=m;do{if(a=!1,-1===(n=d.indexOf(o,n+1))){if(f||t){n=m+1;break}y("string")}for(l=n;d.charCodeAt(l-1)===Kk;)l-=1,a=!a}while(a);p=["string",d.slice(m,n+1),m,n],m=n;break;case uC:pC.lastIndex=m+1,pC.test(d),n=0===pC.lastIndex?d.length-1:pC.lastIndex-2,p=["at-word",d.slice(m,n+1),m,n],m=n;break;case Kk:for(n=m,s=!0;d.charCodeAt(n+1)===Kk;)n+=1,s=!s;if(r=d.charCodeAt(n+1),s&&r!==Yk&&r!==Xk&&r!==Zk&&r!==Qk&&r!==eC&&r!==Jk&&(n+=1,hC.test(d.charAt(n)))){for(;hC.test(d.charAt(n+1));)n+=1;d.charCodeAt(n+1)===Xk&&(n+=1)}p=["word",d.slice(m,n+1),m,n],m=n;break;default:r===Yk&&d.charCodeAt(m+1)===lC?(0===(n=d.indexOf("*/",m+2)+1)&&(f||t?n=d.length:y("comment")),p=["comment",d.slice(m,n+1),m,n],m=n):(dC.lastIndex=m+1,dC.test(d),n=0===dC.lastIndex?d.length-1:dC.lastIndex-2,p=["word",d.slice(m,n+1),m,n],g.push(p),m=n)}return m++,p}},position:function(){return m}}}(this.input)},t.decl=function(e,t){var r=new RC;this.init(r,e[0][2]);var n,o=e[e.length-1];for(";"===o[0]&&(this.semicolon=!0,e.pop()),r.source.end=this.getPosition(o[3]||o[2]||function(e){for(var t=e.length-1;t>=0;t--){var r=e[t],n=r[3]||r[2];if(n)return n}}(e)),r.source.end.offset++;"word"!==e[0][0];)1===e.length&&this.unknownWord(e),r.raws.before+=e.shift()[1];for(r.source.start=this.getPosition(e[0][2]),r.prop="";e.length;){var i=e[0][0];if(":"===i||"space"===i||"comment"===i)break;r.prop+=e.shift()[1]}for(r.raws.between="";e.length;){if(":"===(n=e.shift())[0]){r.raws.between+=n[1];break}"word"===n[0]&&/\w/.test(n[1])&&this.unknownWord([n]),r.raws.between+=n[1]}"_"!==r.prop[0]&&"*"!==r.prop[0]||(r.raws.before+=r.prop[0],r.prop=r.prop.slice(1));for(var s,a=[];e.length&&("space"===(s=e[0][0])||"comment"===s);)a.push(e.shift());this.precheckMissedSemicolon(e);for(var l=e.length-1;l>=0;l--){if("!important"===(n=e[l])[1].toLowerCase()){r.important=!0;var c=this.stringFrom(e,l);" !important"!==(c=this.spacesFromEnd(e)+c)&&(r.raws.important=c);break}if("important"===n[1].toLowerCase()){for(var u=e.slice(0),p="",d=l;d>0;d--){var f=u[d][0];if(0===p.trim().indexOf("!")&&"space"!==f)break;p=u.pop()[1]+p}0===p.trim().indexOf("!")&&(r.important=!0,r.raws.important=p,e=u)}if("space"!==n[0]&&"comment"!==n[0])break}var h=e.some(function(e){return"space"!==e[0]&&"comment"!==e[0]});h&&(r.raws.between+=a.map(function(e){return e[1]}).join(""),a=[]),this.raw(r,"value",a.concat(e),t),r.value.includes(":")&&!t&&this.checkMissedSemicolon(e)},t.doubleColon=function(e){throw this.input.error("Double colon",{offset:e[2]},{offset:e[2]+e[1].length})},t.emptyRule=function(e){var t=new PC;this.init(t,e[2]),t.selector="",t.raws.between="",this.current=t},t.end=function(e){this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.semicolon=!1,this.current.raws.after=(this.current.raws.after||"")+this.spaces,this.spaces="",this.current.parent?(this.current.source.end=this.getPosition(e[2]),this.current.source.end.offset++,this.current=this.current.parent):this.unexpectedClose(e)},t.endFile=function(){this.current.parent&&this.unclosedBlock(),this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.current.raws.after=(this.current.raws.after||"")+this.spaces,this.root.source.end=this.getPosition(this.tokenizer.position())},t.freeSemicolon=function(e){if(this.spaces+=e[1],this.current.nodes){var t=this.current.nodes[this.current.nodes.length-1];t&&"rule"===t.type&&!t.raws.ownSemicolon&&(t.raws.ownSemicolon=this.spaces,this.spaces="")}},t.getPosition=function(e){var t=this.input.fromOffset(e);return{column:t.col,line:t.line,offset:e}},t.init=function(e,t){this.current.push(e),e.source={input:this.input,start:this.getPosition(t)},e.raws.before=this.spaces,this.spaces="","comment"!==e.type&&(this.semicolon=!1)},t.other=function(e){for(var t=!1,r=null,n=!1,o=null,i=[],s=e[1].startsWith("--"),a=[],l=e;l;){if(r=l[0],a.push(l),"("===r||"["===r)o||(o=l),i.push("("===r?")":"]");else if(s&&n&&"{"===r)o||(o=l),i.push("}");else if(0===i.length){if(";"===r){if(n)return void this.decl(a,s);break}if("{"===r)return void this.rule(a);if("}"===r){this.tokenizer.back(a.pop()),t=!0;break}":"===r&&(n=!0)}else r===i[i.length-1]&&(i.pop(),0===i.length&&(o=null));l=this.tokenizer.nextToken()}if(this.tokenizer.endOfFile()&&(t=!0),i.length>0&&this.unclosedBracket(o),t&&n){if(!s)for(;a.length&&("space"===(l=a[a.length-1][0])||"comment"===l);)this.tokenizer.back(a.pop());this.decl(a,s)}else this.unknownWord(a)},t.parse=function(){for(var e;!this.tokenizer.endOfFile();)switch((e=this.tokenizer.nextToken())[0]){case"space":this.spaces+=e[1];break;case";":this.freeSemicolon(e);break;case"}":this.end(e);break;case"comment":this.comment(e);break;case"at-word":this.atrule(e);break;case"{":this.emptyRule(e);break;default:this.other(e)}this.endFile()},t.precheckMissedSemicolon=function(){},t.raw=function(e,t,r,n){for(var o,i,s,a,l=r.length,c="",u=!0,p=0;p<l;p+=1)"space"!==(i=(o=r[p])[0])||p!==l-1||n?"comment"===i?(a=r[p-1]?r[p-1][0]:"empty",s=r[p+1]?r[p+1][0]:"empty",NC[a]||NC[s]||","===c.slice(-1)?u=!1:c+=o[1]):c+=o[1]:u=!1;if(!u){var d=r.reduce(function(e,t){return e+t[1]},"");e.raws[t]={raw:d,value:c}}e[t]=c},t.rule=function(e){e.pop();var t=new PC;this.init(t,e[0][2]),t.raws.between=this.spacesAndCommentsFromEnd(e),this.raw(t,"selector",e),this.current=t},t.spacesAndCommentsFromEnd=function(e){for(var t,r="";e.length&&("space"===(t=e[e.length-1][0])||"comment"===t);)r=e.pop()[1]+r;return r},t.spacesAndCommentsFromStart=function(e){for(var t,r="";e.length&&("space"===(t=e[0][0])||"comment"===t);)r+=e.shift()[1];return r},t.spacesFromEnd=function(e){for(var t="";e.length&&"space"===e[e.length-1][0];)t=e.pop()[1]+t;return t},t.stringFrom=function(e,t){for(var r="",n=t;n<e.length;n++)r+=e[n][1];return e.splice(t,e.length-t),r},t.unclosedBlock=function(){var e=this.current.source.start;throw this.input.error("Unclosed block",e.line,e.column)},t.unclosedBracket=function(e){throw this.input.error("Unclosed bracket",{offset:e[2]},{offset:e[2]+1})},t.unexpectedClose=function(e){throw this.input.error("Unexpected }",{offset:e[2]},{offset:e[2]+1})},t.unknownWord=function(e){throw this.input.error("Unknown word",{offset:e[0][2]},{offset:e[0][2]+e[0][1].length})},t.unnamedAtrule=function(e,t){throw this.input.error("At-rule without name",{offset:t[2]},{offset:t[2]+t[1].length})},e}(),LC=Nk,DC=jC,FC=lk;function $C(e,t){var r=new FC(e,t),n=new DC(r);try{n.parse()}catch(e){throw true&&"CssSyntaxError"===e.name&&t&&t.from&&(/\.scss$/i.test(t.from)?e.message+="\nYou tried to parse SCSS with the standard CSS parser; try again with the postcss-scss parser":/\.sass/i.test(t.from)?e.message+="\nYou tried to parse Sass with the standard CSS parser; try again with the postcss-sass parser":/\.less$/i.test(t.from)&&(e.message+="\nYou tried to parse Less with the standard CSS parser; try again with the postcss-less parser")),e}return n.root}var BC=$C;$C.default=$C,LC.registerParse($C);var zC=SS.isClean,VC=SS.my,UC=wk,qC=RS,WC=Nk,HC=Fk,GC=Bk,KC=Wk,YC=BC,ZC=_C,XC={atrule:"AtRule",comment:"Comment",decl:"Declaration",document:"Document",root:"Root",rule:"Rule"},JC={AtRule:!0,AtRuleExit:!0,Comment:!0,CommentExit:!0,Declaration:!0,DeclarationExit:!0,Document:!0,DocumentExit:!0,Once:!0,OnceExit:!0,postcssPlugin:!0,prepare:!0,Root:!0,RootExit:!0,Rule:!0,RuleExit:!0},QC={Once:!0,postcssPlugin:!0,prepare:!0};function eO(e){return"object"===(void 0===e?"undefined":c_(e))&&"function"==typeof e.then}function tO(e){var t=!1,r=XC[e.type];return"decl"===e.type?t=e.prop.toLowerCase():"atrule"===e.type&&(t=e.name.toLowerCase()),t&&e.append?[r,r+"-"+t,0,r+"Exit",r+"Exit-"+t]:t?[r,r+"-"+t,r+"Exit",r+"Exit-"+t]:e.append?[r,0,r+"Exit"]:[r,r+"Exit"]}function rO(e){return{eventIndex:0,events:"document"===e.type?["Document",0,"DocumentExit"]:"root"===e.type?["Root",0,"RootExit"]:tO(e),iterator:0,node:e,visitorIndex:0,visitors:[]}}function nO(e){return e[zC]=!1,e.nodes&&e.nodes.forEach(function(e){return nO(e)}),e}var oO={},iO=function(){function e(t,r,n){var o,i=this;if(this.stringified=!1,this.processed=!1,"object"!==(void 0===r?"undefined":c_(r))||null===r||"root"!==r.type&&"document"!==r.type)if(s_(r,e)||s_(r,KC))o=nO(r.root),r.map&&(void 0===n.map&&(n.map={}),n.map.inline||(n.map.inline=!1),n.map.prev=r.map);else{var s=YC;n.syntax&&(s=n.syntax.parse),n.parser&&(s=n.parser),s.parse&&(s=s.parse);try{o=s(r,n)}catch(e){this.processed=!0,this.error=e}o&&!o[VC]&&WC.rebuild(o)}else o=nO(r);this.result=new KC(t,o,n),this.helpers=n_({},oO,{postcss:oO,result:this.result}),this.plugins=this.processor.plugins.map(function(e){return"object"===(void 0===e?"undefined":c_(e))&&e.prepare?n_({},e,e.prepare(i.result)):e})}var t=e.prototype;return t.async=function(){return this.error?Promise.reject(this.error):this.processed?Promise.resolve(this.result):(this.processing||(this.processing=this.runAsync()),this.processing)},t.catch=function(e){return this.async().catch(e)},t.finally=function(e){return this.async().then(e,e)},t.getAsyncError=function(){throw new Error("Use process(css).then(cb) to work with async plugins")},t.handleError=function(e,t){var r=this.result.lastPlugin;try{if(t&&t.addToError(e),this.error=e,"CssSyntaxError"!==e.name||e.plugin){if(r.postcssVersion&&"production"!=="development"){var n=r.postcssPlugin,o=r.postcssVersion,i=this.result.processor.version,s=o.split("."),a=i.split(".");(s[0]!==a[0]||parseInt(s[1])>parseInt(a[1]))&&console.error("Unknown error from PostCSS plugin. Your current PostCSS version is "+i+", but "+n+" uses "+o+". Perhaps this is the source of the error below.")}}else e.plugin=r.postcssPlugin,e.setMessage()}catch(e){console&&console.error&&console.error(e)}return e},t.prepareVisitors=function(){var e=this;this.listeners={};for(var t,r=function(t,r,n){e.listeners[r]||(e.listeners[r]=[]),e.listeners[r].push([t,n])},n=d_(this.plugins);!(t=n()).done;){var o=t.value;if("object"===(void 0===o?"undefined":c_(o)))for(var i in o){if(!JC[i]&&/^[A-Z]/.test(i))throw new Error("Unknown event "+i+" in "+o.postcssPlugin+". Try to update PostCSS ("+this.processor.version+" now).");if(!QC[i])if("object"===c_(o[i]))for(var s in o[i])r(o,"*"===s?i:i+"-"+s.toLowerCase(),o[i][s]);else"function"==typeof o[i]&&r(o,i,o[i])}}this.hasListener=Object.keys(this.listeners).length>0},t.runAsync=function(){var e=this;return e_(function(){var t,r,n,o,i,s,a,l,c,u,p,d;return f_(this,function(f){switch(f.label){case 0:e.plugin=0,t=0,f.label=1;case 1:if(!(t<e.plugins.length))return[3,6];if(r=e.plugins[t],!eO(n=e.runOnRoot(r)))return[3,5];f.label=2;case 2:return f.trys.push([2,4,,5]),[4,n];case 3:return f.sent(),[3,5];case 4:throw o=f.sent(),e.handleError(o);case 5:return t++,[3,1];case 6:if(e.prepareVisitors(),!e.hasListener)return[3,18];i=e.result.root,f.label=7;case 7:if(i[zC])return[3,14];i[zC]=!0,s=[rO(i)],f.label=8;case 8:if(!(s.length>0))return[3,13];if(!eO(a=e.visitTick(s)))return[3,12];f.label=9;case 9:return f.trys.push([9,11,,12]),[4,a];case 10:return f.sent(),[3,12];case 11:throw l=f.sent(),c=s[s.length-1].node,e.handleError(l,c);case 12:return[3,8];case 13:return[3,7];case 14:if(!e.listeners.OnceExit)return[3,18];u=function(){var t,r,n,o,s;return f_(this,function(a){switch(a.label){case 0:t=d.value,r=t[0],n=t[1],e.result.lastPlugin=r,a.label=1;case 1:return a.trys.push([1,6,,7]),"document"!==i.type?[3,3]:(o=i.nodes.map(function(t){return n(t,e.helpers)}),[4,Promise.all(o)]);case 2:return a.sent(),[3,5];case 3:return[4,n(i,e.helpers)];case 4:a.sent(),a.label=5;case 5:return[3,7];case 6:throw s=a.sent(),e.handleError(s);case 7:return[2]}})},p=d_(e.listeners.OnceExit),f.label=15;case 15:return(d=p()).done?[3,18]:[5,h_(u())];case 16:f.sent(),f.label=17;case 17:return[3,15];case 18:return e.processed=!0,[2,e.stringify()]}})})()},t.runOnRoot=function(e){var t=this;this.result.lastPlugin=e;try{if("object"===(void 0===e?"undefined":c_(e))&&e.Once){if("document"===this.result.root.type){var r=this.result.root.nodes.map(function(r){return e.Once(r,t.helpers)});return eO(r[0])?Promise.all(r):r}return e.Once(this.result.root,this.helpers)}if("function"==typeof e)return e(this.result.root,this.result)}catch(e){throw this.handleError(e)}},t.stringify=function(){if(this.error)throw this.error;if(this.stringified)return this.result;this.stringified=!0,this.sync();var e=this.result.opts,t=qC;e.syntax&&(t=e.syntax.stringify),e.stringifier&&(t=e.stringifier),t.stringify&&(t=t.stringify);var r=new UC(t,this.result.root,this.result.opts).generate();return this.result.css=r[0],this.result.map=r[1],this.result},t.sync=function(){if(this.error)throw this.error;if(this.processed)return this.result;if(this.processed=!0,this.processing)throw this.getAsyncError();for(var e,t=d_(this.plugins);!(e=t()).done;){var r=e.value;if(eO(this.runOnRoot(r)))throw this.getAsyncError()}if(this.prepareVisitors(),this.hasListener){for(var n=this.result.root;!n[zC];)n[zC]=!0,this.walkSync(n);if(this.listeners.OnceExit)if("document"===n.type)for(var o,i=d_(n.nodes);!(o=i()).done;){var s=o.value;this.visitSync(this.listeners.OnceExit,s)}else this.visitSync(this.listeners.OnceExit,n)}return this.result},t.then=function(e,t){return true&&("from"in this.opts||GC("Without `from` option PostCSS could generate wrong source map and will not find Browserslist config. Set it to CSS file path or to `undefined` to prevent this warning.")),this.async().then(e,t)},t.toString=function(){return this.css},t.visitSync=function(e,t){for(var r,n=d_(e);!(r=n()).done;){var o=r.value,i=o[0],s=o[1];this.result.lastPlugin=i;var a=void 0;try{a=s(t,this.helpers)}catch(e){throw this.handleError(e,t.proxyOf)}if("root"!==t.type&&"document"!==t.type&&!t.parent)return!0;if(eO(a))throw this.getAsyncError()}},t.visitTick=function(e){var t=e[e.length-1],r=t.node,n=t.visitors;if("root"===r.type||"document"===r.type||r.parent){if(n.length>0&&t.visitorIndex<n.length){var o=n[t.visitorIndex],i=o[0],s=o[1];t.visitorIndex+=1,t.visitorIndex===n.length&&(t.visitors=[],t.visitorIndex=0),this.result.lastPlugin=i;try{return s(r.toProxy(),this.helpers)}catch(e){throw this.handleError(e,r)}}if(0!==t.iterator){for(var a,l=t.iterator;a=r.nodes[r.indexes[l]];)if(r.indexes[l]+=1,!a[zC])return a[zC]=!0,void e.push(rO(a));t.iterator=0,delete r.indexes[l]}for(var c=t.events;t.eventIndex<c.length;){var u=c[t.eventIndex];if(t.eventIndex+=1,0===u)return void(r.nodes&&r.nodes.length&&(r[zC]=!0,t.iterator=r.getIterator()));if(this.listeners[u])return void(t.visitors=this.listeners[u])}e.pop()}else e.pop()},t.walkSync=function(e){var t=this;e[zC]=!0;for(var r,n=d_(tO(e));!(r=n()).done;){var o=r.value;if(0===o)e.nodes&&e.each(function(e){e[zC]||t.walkSync(e)});else{var i=this.listeners[o];if(i&&this.visitSync(i,e.toProxy()))return}}},t.warnings=function(){return this.sync().warnings()},r_(e,[{key:"content",get:function(){return this.stringify().content}},{key:"css",get:function(){return this.stringify().css}},{key:"map",get:function(){return this.stringify().map}},{key:"messages",get:function(){return this.sync().messages}},{key:"opts",get:function(){return this.result.opts}},{key:"processor",get:function(){return this.result.processor}},{key:"root",get:function(){return this.sync().root}},{key:Symbol.toStringTag,get:function(){return"LazyResult"}}]),e}();iO.registerPostcss=function(e){oO=e};var sO=iO;iO.default=iO,ZC.registerLazyResult(iO),HC.registerLazyResult(iO);var aO=wk,lO=RS,cO=Bk,uO=BC,pO=Wk,dO=function(){function e(e,t,r){var n;t=t.toString(),this.stringified=!1,this._processor=e,this._css=t,this._opts=r,this._map=void 0;var o=lO;this.result=new pO(this._processor,n,this._opts),this.result.css=t;var i=this;Object.defineProperty(this.result,"root",{get:function(){return i.root}});var s=new aO(o,n,this._opts,t);if(s.isMap()){var a=s.generate(),l=a[0],c=a[1];l&&(this.result.css=l),c&&(this.result.map=c)}else s.clearAnnotation(),this.result.css=s.css}var t=e.prototype;return t.async=function(){return this.error?Promise.reject(this.error):Promise.resolve(this.result)},t.catch=function(e){return this.async().catch(e)},t.finally=function(e){return this.async().then(e,e)},t.sync=function(){if(this.error)throw this.error;return this.result},t.then=function(e,t){return true&&("from"in this._opts||cO("Without `from` option PostCSS could generate wrong source map and will not find Browserslist config. Set it to CSS file path or to `undefined` to prevent this warning.")),this.async().then(e,t)},t.toString=function(){return this._css},t.warnings=function(){return[]},r_(e,[{key:"content",get:function(){return this.result.css}},{key:"css",get:function(){return this.result.css}},{key:"map",get:function(){return this.result.map}},{key:"messages",get:function(){return[]}},{key:"opts",get:function(){return this.result.opts}},{key:"processor",get:function(){return this.result.processor}},{key:"root",get:function(){if(this._root)return this._root;var e,t=uO;try{e=t(this._css,this._opts)}catch(e){this.error=e}if(this.error)throw this.error;return this._root=e,e}},{key:Symbol.toStringTag,get:function(){return"NoWorkResult"}}]),e}(),fO=dO;dO.default=dO;var hO=fO,mO=sO,gO=Fk,vO=_C,yO=function(){function e(e){void 0===e&&(e=[]),this.version="8.4.38",this.plugins=this.normalize(e)}var t=e.prototype;return t.normalize=function(e){for(var t,r=[],n=d_(e);!(t=n()).done;){var o=t.value;if(!0===o.postcss?o=o():o.postcss&&(o=o.postcss),"object"===(void 0===o?"undefined":c_(o))&&Array.isArray(o.plugins))r=r.concat(o.plugins);else if("object"===(void 0===o?"undefined":c_(o))&&o.postcssPlugin)r.push(o);else if("function"==typeof o)r.push(o);else{if("object"!==(void 0===o?"undefined":c_(o))||!o.parse&&!o.stringify)throw new Error(o+" is not a PostCSS plugin");if(true)throw new Error("PostCSS syntaxes cannot be used as plugins. Instead, please use one of the syntax/parser/stringifier options as outlined in your PostCSS runner documentation.")}}return r},t.process=function(e,t){return void 0===t&&(t={}),this.plugins.length||t.parser||t.stringifier||t.syntax?new mO(this,e,t):new hO(this,e,t)},t.use=function(e){return this.plugins=this.plugins.concat(this.normalize([e])),this},e}(),bO=yO;yO.default=yO,vO.registerProcessor(yO),gO.registerProcessor(yO);var wO=$S,xO=GS,_O=_k,SO=vC,kO=lk,CO=_C,OO=TC;function EO(e,t){if(Array.isArray(e))return e.map(function(e){return EO(e)});var r=e.inputs,n=a_(e,["inputs"]);if(r){t=[];for(var o,i=d_(r);!(o=i()).done;){var s=n_({},o.value,{__proto__:kO.prototype});s.map&&(s.map=n_({},s.map,{__proto__:xO.prototype})),t.push(s)}}if(n.nodes&&(n.nodes=e.nodes.map(function(e){return EO(e,t)})),n.source){var a=n.source,l=a.inputId,c=a_(a,["inputId"]);n.source=c,null!=l&&(n.source.input=t[l])}if("root"===n.type)return new CO(n);if("decl"===n.type)return new wO(n);if("rule"===n.type)return new OO(n);if("comment"===n.type)return new _O(n);if("atrule"===n.type)return new SO(n);throw new Error("Unknown node type: "+e.type)}var TO=EO;EO.default=EO;var RO=_S,IO=$S,MO=sO,AO=Nk,PO=bO,NO=RS,jO=TO,LO=Fk,DO=Vk,FO=_k,$O=vC,BO=Wk,zO=lk,VO=BC,UO=kC,qO=TC,WO=_C,HO=DS;function GO(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];return 1===t.length&&Array.isArray(t[0])&&(t=t[0]),new PO(t)}GO.plugin=function(e,t){var r,n=!1;function o(){for(var r=arguments.length,o=new Array(r),i=0;i<r;i++)o[i]=arguments[i];console&&console.warn&&!n&&(n=!0,console.warn(e+": postcss.plugin was deprecated. Migration guide:\nhttps://evilmartians.com/chronicles/postcss-8-plugin-migration"),process.env.LANG&&process.env.LANG.startsWith("cn")&&console.warn(e+": 里面 postcss.plugin 被弃用. 迁移指南:\nhttps://www.w3ctech.com/topic/2226"));var s=t.apply(void 0,[].concat(o));return s.postcssPlugin=e,s.postcssVersion=(new PO).version,s}return Object.defineProperty(o,"postcss",{get:function(){return r||(r=o()),r}}),o.process=function(e,t,r){return GO([o(r)]).process(e,t)},o},GO.stringify=NO,GO.parse=VO,GO.fromJSON=jO,GO.list=UO,GO.comment=function(e){return new FO(e)},GO.atRule=function(e){return new $O(e)},GO.decl=function(e){return new IO(e)},GO.rule=function(e){return new qO(e)},GO.root=function(e){return new WO(e)},GO.document=function(e){return new LO(e)},GO.CssSyntaxError=RO,GO.Declaration=IO,GO.Container=AO,GO.Processor=PO,GO.Document=LO,GO.Comment=FO,GO.Warning=DO,GO.AtRule=$O,GO.Result=BO,GO.Input=zO,GO.Rule=qO,GO.Root=WO,GO.Node=HO,MO.registerPostcss(GO),GO.default=GO;var KO=Object.defineProperty,YO=function(e,t,r){return function(e,t,r){return t in e?KO(e,t,{enumerable:!0,configurable:!0,writable:!0,value:r}):e[t]=r}(e,"symbol"!==(void 0===t?"undefined":c_(t))?t+"":t,r)};function ZO(e){if(e.__esModule)return e;var t=e.default;if("function"==typeof t){var r=function e(){return s_(this,e)?Reflect.construct(t,arguments,this.constructor):t.apply(this,arguments)};r.prototype=t.prototype}else r={};return Object.defineProperty(r,"__esModule",{value:!0}),Object.keys(e).forEach(function(t){var n=Object.getOwnPropertyDescriptor(e,t);Object.defineProperty(r,t,n.get?n:{enumerable:!0,get:function(){return e[t]}})}),r}var XO={exports:{}},JO=String,QO=function(){return{isColorSupported:!1,reset:JO,bold:JO,dim:JO,italic:JO,underline:JO,inverse:JO,hidden:JO,strikethrough:JO,black:JO,red:JO,green:JO,yellow:JO,blue:JO,magenta:JO,cyan:JO,white:JO,gray:JO,bgBlack:JO,bgRed:JO,bgGreen:JO,bgYellow:JO,bgBlue:JO,bgMagenta:JO,bgCyan:JO,bgWhite:JO}};XO.exports=QO(),XO.exports.createColors=QO;var eE=XO.exports,tE=ZO(Object.freeze(Object.defineProperty({__proto__:null,default:{}},Symbol.toStringTag,{value:"Module"}))),rE=eE,nE=tE,oE=function(e){function t(r,n,o,i,s,a){var l;return(l=e.call(this,r)||this).name="CssSyntaxError",l.reason=r,s&&(l.file=s),i&&(l.source=i),a&&(l.plugin=a),void 0!==n&&void 0!==o&&("number"==typeof n?(l.line=n,l.column=o):(l.line=n.line,l.column=n.column,l.endLine=o.line,l.endColumn=o.column)),l.setMessage(),Error.captureStackTrace&&Error.captureStackTrace(l,t),l}i_(t,e);var r=t.prototype;return r.setMessage=function(){this.message=this.plugin?this.plugin+": ":"",this.message+=this.file?this.file:"<css input>",void 0!==this.line&&(this.message+=":"+this.line+":"+this.column),this.message+=": "+this.reason},r.showSourceCode=function(e){var t=this;if(!this.source)return"";var r=this.source;null==e&&(e=rE.isColorSupported),nE&&e&&(r=nE(r));var n,o,i=r.split(/\r?\n/),s=Math.max(this.line-3,0),a=Math.min(this.line+2,i.length),l=String(a).length;if(e){var c=rE.createColors(!0),u=c.bold,p=c.gray,d=c.red;n=function(e){return u(d(e))},o=function(e){return p(e)}}else n=o=function(e){return e};return i.slice(s,a).map(function(e,r){var i=s+1+r,a=" "+(" "+i).slice(-l)+" | ";if(i===t.line){var c=o(a.replace(/\d/g," "))+e.slice(0,t.column-1).replace(/[^\t]/g," ");return n(">")+o(a)+e+"\n "+c+n("^")}return" "+o(a)+e}).join("\n")},r.toString=function(){var e=this.showSourceCode();return e&&(e="\n\n"+e+"\n"),this.name+": "+this.message+e},t}(u_(Error)),iE=oE;oE.default=oE;var sE={};sE.isClean=Symbol("isClean"),sE.my=Symbol("my");var aE={after:"\n",beforeClose:"\n",beforeComment:"\n",beforeDecl:"\n",beforeOpen:" ",beforeRule:"\n",colon:": ",commentLeft:" ",commentRight:" ",emptyBody:"",indent:"    ",semicolon:!1},lE=function(){function e(e){this.builder=e}var t=e.prototype;return t.atrule=function(e,t){var r="@"+e.name,n=e.params?this.rawValue(e,"params"):"";if(void 0!==e.raws.afterName?r+=e.raws.afterName:n&&(r+=" "),e.nodes)this.block(e,r+n);else{var o=(e.raws.between||"")+(t?";":"");this.builder(r+n+o,e)}},t.beforeAfter=function(e,t){var r;r="decl"===e.type?this.raw(e,null,"beforeDecl"):"comment"===e.type?this.raw(e,null,"beforeComment"):"before"===t?this.raw(e,null,"beforeRule"):this.raw(e,null,"beforeClose");for(var n=e.parent,o=0;n&&"root"!==n.type;)o+=1,n=n.parent;if(r.includes("\n")){var i=this.raw(e,null,"indent");if(i.length)for(var s=0;s<o;s++)r+=i}return r},t.block=function(e,t){var r,n=this.raw(e,"between","beforeOpen");this.builder(t+n+"{",e,"start"),e.nodes&&e.nodes.length?(this.body(e),r=this.raw(e,"after")):r=this.raw(e,"after","emptyBody"),r&&this.builder(r),this.builder("}",e,"end")},t.body=function(e){for(var t=e.nodes.length-1;t>0&&"comment"===e.nodes[t].type;)t-=1;for(var r=this.raw(e,"semicolon"),n=0;n<e.nodes.length;n++){var o=e.nodes[n],i=this.raw(o,"before");i&&this.builder(i),this.stringify(o,t!==n||r)}},t.comment=function(e){var t=this.raw(e,"left","commentLeft"),r=this.raw(e,"right","commentRight");this.builder("/*"+t+e.text+r+"*/",e)},t.decl=function(e,t){var r=this.raw(e,"between","colon"),n=e.prop+r+this.rawValue(e,"value");e.important&&(n+=e.raws.important||" !important"),t&&(n+=";"),this.builder(n,e)},t.document=function(e){this.body(e)},t.raw=function(e,t,r){var n;if(r||(r=t),t&&void 0!==(n=e.raws[t]))return n;var o=e.parent;if("before"===r){if(!o||"root"===o.type&&o.first===e)return"";if(o&&"document"===o.type)return""}if(!o)return aE[r];var i=e.root();if(i.rawCache||(i.rawCache={}),void 0!==i.rawCache[r])return i.rawCache[r];if("before"===r||"after"===r)return this.beforeAfter(e,r);var s,a="raw"+((s=r)[0].toUpperCase()+s.slice(1));return this[a]?n=this[a](i,e):i.walk(function(e){if(void 0!==(n=e.raws[t]))return!1}),void 0===n&&(n=aE[r]),i.rawCache[r]=n,n},t.rawBeforeClose=function(e){var t;return e.walk(function(e){if(e.nodes&&e.nodes.length>0&&void 0!==e.raws.after)return(t=e.raws.after).includes("\n")&&(t=t.replace(/[^\n]+$/,"")),!1}),t&&(t=t.replace(/\S/g,"")),t},t.rawBeforeComment=function(e,t){var r;return e.walkComments(function(e){if(void 0!==e.raws.before)return(r=e.raws.before).includes("\n")&&(r=r.replace(/[^\n]+$/,"")),!1}),void 0===r?r=this.raw(t,null,"beforeDecl"):r&&(r=r.replace(/\S/g,"")),r},t.rawBeforeDecl=function(e,t){var r;return e.walkDecls(function(e){if(void 0!==e.raws.before)return(r=e.raws.before).includes("\n")&&(r=r.replace(/[^\n]+$/,"")),!1}),void 0===r?r=this.raw(t,null,"beforeRule"):r&&(r=r.replace(/\S/g,"")),r},t.rawBeforeOpen=function(e){var t;return e.walk(function(e){if("decl"!==e.type&&void 0!==(t=e.raws.between))return!1}),t},t.rawBeforeRule=function(e){var t;return e.walk(function(r){if(r.nodes&&(r.parent!==e||e.first!==r)&&void 0!==r.raws.before)return(t=r.raws.before).includes("\n")&&(t=t.replace(/[^\n]+$/,"")),!1}),t&&(t=t.replace(/\S/g,"")),t},t.rawColon=function(e){var t;return e.walkDecls(function(e){if(void 0!==e.raws.between)return t=e.raws.between.replace(/[^\s:]/g,""),!1}),t},t.rawEmptyBody=function(e){var t;return e.walk(function(e){if(e.nodes&&0===e.nodes.length&&void 0!==(t=e.raws.after))return!1}),t},t.rawIndent=function(e){return e.raws.indent?e.raws.indent:(e.walk(function(r){var n=r.parent;if(n&&n!==e&&n.parent&&n.parent===e&&void 0!==r.raws.before){var o=r.raws.before.split("\n");return t=(t=o[o.length-1]).replace(/\S/g,""),!1}}),t);// removed by dead control flow
 var t; },t.rawSemicolon=function(e){var t;return e.walk(function(e){if(e.nodes&&e.nodes.length&&"decl"===e.last.type&&void 0!==(t=e.raws.semicolon))return!1}),t},t.rawValue=function(e,t){var r=e[t],n=e.raws[t];return n&&n.value===r?n.raw:r},t.root=function(e){this.body(e),e.raws.after&&this.builder(e.raws.after)},t.rule=function(e){this.block(e,this.rawValue(e,"selector")),e.raws.ownSemicolon&&this.builder(e.raws.ownSemicolon,e,"end")},t.stringify=function(e,t){if(!this[e.type])throw new Error("Unknown AST node type "+e.type+". Maybe you need to change PostCSS stringifier.");this[e.type](e,t)},e}(),cE=lE;lE.default=lE;var uE=cE;function pE(e,t){new uE(t).stringify(e)}var dE=pE;pE.default=pE;var fE=sE.isClean,hE=sE.my,mE=iE,gE=cE,vE=dE;function yE(e,t){var r=new e.constructor;for(var n in e)if(Object.prototype.hasOwnProperty.call(e,n)&&"proxyCache"!==n){var o=e[n],i=void 0===o?"undefined":c_(o);"parent"===n&&"object"===i?t&&(r[n]=t):"source"===n?r[n]=o:Array.isArray(o)?r[n]=o.map(function(e){return yE(e,r)}):("object"===i&&null!==o&&(o=yE(o)),r[n]=o)}return r}var bE=function(){function e(e){for(var t in void 0===e&&(e={}),this.raws={},this[fE]=!1,this[hE]=!0,e)if("nodes"===t){this.nodes=[];for(var r,n=d_(e[t]);!(r=n()).done;){var o=r.value;"function"==typeof o.clone?this.append(o.clone()):this.append(o)}}else this[t]=e[t]}var t=e.prototype;return t.addToError=function(e){if(e.postcssNode=this,e.stack&&this.source&&/\n\s{4}at /.test(e.stack)){var t=this.source;e.stack=e.stack.replace(/\n\s{4}at /,"$&"+t.input.from+":"+t.start.line+":"+t.start.column+"$&")}return e},t.after=function(e){return this.parent.insertAfter(this,e),this},t.assign=function(e){for(var t in void 0===e&&(e={}),e)this[t]=e[t];return this},t.before=function(e){return this.parent.insertBefore(this,e),this},t.cleanRaws=function(e){delete this.raws.before,delete this.raws.after,e||delete this.raws.between},t.clone=function(e){void 0===e&&(e={});var t=yE(this);for(var r in e)t[r]=e[r];return t},t.cloneAfter=function(e){void 0===e&&(e={});var t=this.clone(e);return this.parent.insertAfter(this,t),t},t.cloneBefore=function(e){void 0===e&&(e={});var t=this.clone(e);return this.parent.insertBefore(this,t),t},t.error=function(e,t){if(void 0===t&&(t={}),this.source){var r=this.rangeBy(t),n=r.end,o=r.start;return this.source.input.error(e,{column:o.column,line:o.line},{column:n.column,line:n.line},t)}return new mE(e)},t.getProxyProcessor=function(){return{get:function(e,t){return"proxyOf"===t?e:"root"===t?function(){return e.root().toProxy()}:e[t]},set:function(e,t,r){return e[t]===r||(e[t]=r,"prop"!==t&&"value"!==t&&"name"!==t&&"params"!==t&&"important"!==t&&"text"!==t||e.markDirty()),!0}}},t.markDirty=function(){if(this[fE]){this[fE]=!1;for(var e=this;e=e.parent;)e[fE]=!1}},t.next=function(){if(this.parent){var e=this.parent.index(this);return this.parent.nodes[e+1]}},t.positionBy=function(e,t){var r=this.source.start;if(e.index)r=this.positionInside(e.index,t);else if(e.word){var n=(t=this.toString()).indexOf(e.word);-1!==n&&(r=this.positionInside(n,t))}return r},t.positionInside=function(e,t){for(var r=t||this.toString(),n=this.source.start.column,o=this.source.start.line,i=0;i<e;i++)"\n"===r[i]?(n=1,o+=1):n+=1;return{column:n,line:o}},t.prev=function(){if(this.parent){var e=this.parent.index(this);return this.parent.nodes[e-1]}},t.rangeBy=function(e){var t={column:this.source.start.column,line:this.source.start.line},r=this.source.end?{column:this.source.end.column+1,line:this.source.end.line}:{column:t.column+1,line:t.line};if(e.word){var n=this.toString(),o=n.indexOf(e.word);-1!==o&&(t=this.positionInside(o,n),r=this.positionInside(o+e.word.length,n))}else e.start?t={column:e.start.column,line:e.start.line}:e.index&&(t=this.positionInside(e.index)),e.end?r={column:e.end.column,line:e.end.line}:"number"==typeof e.endIndex?r=this.positionInside(e.endIndex):e.index&&(r=this.positionInside(e.index+1));return(r.line<t.line||r.line===t.line&&r.column<=t.column)&&(r={column:t.column+1,line:t.line}),{end:r,start:t}},t.raw=function(e,t){return(new gE).raw(this,e,t)},t.remove=function(){return this.parent&&this.parent.removeChild(this),this.parent=void 0,this},t.replaceWith=function(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];if(this.parent){for(var n,o=this,i=!1,s=d_(t);!(n=s()).done;){var a=n.value;a===this?i=!0:i?(this.parent.insertAfter(o,a),o=a):this.parent.insertBefore(o,a)}i||this.remove()}return this},t.root=function(){for(var e=this;e.parent&&"document"!==e.parent.type;)e=e.parent;return e},t.toJSON=function(e,t){var r={},n=null==t;t=t||new Map;var o=0;for(var i in this)if(Object.prototype.hasOwnProperty.call(this,i)&&"parent"!==i&&"proxyCache"!==i){var s=this[i];if(Array.isArray(s))r[i]=s.map(function(e){return"object"===(void 0===e?"undefined":c_(e))&&e.toJSON?e.toJSON(null,t):e});else if("object"===(void 0===s?"undefined":c_(s))&&s.toJSON)r[i]=s.toJSON(null,t);else if("source"===i){var a=t.get(s.input);null==a&&(a=o,t.set(s.input,o),o++),r[i]={end:s.end,inputId:a,start:s.start}}else r[i]=s}return n&&(r.inputs=[].concat(t.keys()).map(function(e){return e.toJSON()})),r},t.toProxy=function(){return this.proxyCache||(this.proxyCache=new Proxy(this,this.getProxyProcessor())),this.proxyCache},t.toString=function(e){void 0===e&&(e=vE),e.stringify&&(e=e.stringify);var t="";return e(this,function(e){t+=e}),t},t.warn=function(e,t,r){var n={node:this};for(var o in r)n[o]=r[o];return e.warn(t,n)},r_(e,[{key:"proxyOf",get:function(){return this}}]),e}(),wE=bE;bE.default=bE;var xE=function(e){function t(t){var r;return t&&void 0!==t.value&&"string"!=typeof t.value&&(t=n_({},t,{value:String(t.value)})),(r=e.call(this,t)||this).type="decl",r}return i_(t,e),r_(t,[{key:"variable",get:function(){return this.prop.startsWith("--")||"$"===this.prop[0]}}]),t}(wE),_E=xE;xE.default=xE;var SE=tE.SourceMapConsumer,kE=tE.SourceMapGenerator,CE=tE.existsSync,OE=tE.readFileSync,EE=tE.dirname,TE=tE.join,RE=function(){function e(e,t){if(!1!==t.map){this.loadAnnotation(e),this.inline=this.startWith(this.annotation,"data:");var r=t.map?t.map.prev:void 0,n=this.loadMap(t.from,r);!this.mapFile&&t.from&&(this.mapFile=t.from),this.mapFile&&(this.root=EE(this.mapFile)),n&&(this.text=n)}}var t=e.prototype;return t.consumer=function(){return this.consumerCache||(this.consumerCache=new SE(this.text)),this.consumerCache},t.decodeInline=function(e){var t;if(/^data:application\/json;charset=utf-?8,/.test(e)||/^data:application\/json,/.test(e))return decodeURIComponent(e.substr(RegExp.lastMatch.length));if(/^data:application\/json;charset=utf-?8;base64,/.test(e)||/^data:application\/json;base64,/.test(e))return t=e.substr(RegExp.lastMatch.length),Buffer?Buffer.from(t,"base64").toString():window.atob(t);var r=e.match(/data:application\/json;([^,]+),/)[1];throw new Error("Unsupported source map encoding "+r)},t.getAnnotationURL=function(e){return e.replace(/^\/\*\s*# sourceMappingURL=/,"").trim()},t.isMap=function(e){return"object"===(void 0===e?"undefined":c_(e))&&("string"==typeof e.mappings||"string"==typeof e._mappings||Array.isArray(e.sections))},t.loadAnnotation=function(e){var t=e.match(/\/\*\s*# sourceMappingURL=/gm);if(t){var r=e.lastIndexOf(t.pop()),n=e.indexOf("*/",r);r>-1&&n>-1&&(this.annotation=this.getAnnotationURL(e.substring(r,n)))}},t.loadFile=function(e){if(this.root=EE(e),CE(e))return this.mapFile=e,OE(e,"utf-8").toString().trim()},t.loadMap=function(e,t){if(!1===t)return!1;if(t){if("string"==typeof t)return t;if("function"!=typeof t){if(s_(t,SE))return kE.fromSourceMap(t).toString();if(s_(t,kE))return t.toString();if(this.isMap(t))return JSON.stringify(t);throw new Error("Unsupported previous source map format: "+t.toString())}var r=t(e);if(r){var n=this.loadFile(r);if(!n)throw new Error("Unable to load previous source map: "+r.toString());return n}}else{if(this.inline)return this.decodeInline(this.annotation);if(this.annotation){var o=this.annotation;return e&&(o=TE(EE(e),o)),this.loadFile(o)}}},t.startWith=function(e,t){return!!e&&e.substr(0,t.length)===t},t.withContent=function(){return!!(this.consumer().sourcesContent&&this.consumer().sourcesContent.length>0)},e}(),IE=RE;RE.default=RE;var ME=tE.SourceMapConsumer,AE=tE.SourceMapGenerator,PE=tE.fileURLToPath,NE=tE.pathToFileURL,jE=tE.isAbsolute,LE=tE.resolve,DE=function(e){void 0===e&&(e=21);for(var t="",r=e;r--;)t+="useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict"[64*Math.random()|0];return t},FE=tE,$E=iE,BE=IE,zE=Symbol("fromOffsetCache"),VE=Boolean(ME&&AE),UE=Boolean(LE&&jE),qE=function(){function e(e,t){if(void 0===t&&(t={}),null==e||"object"===(void 0===e?"undefined":c_(e))&&!e.toString)throw new Error("PostCSS received "+e+" instead of CSS string");if(this.css=e.toString(),"\ufeff"===this.css[0]||""===this.css[0]?(this.hasBOM=!0,this.css=this.css.slice(1)):this.hasBOM=!1,t.from&&(!UE||/^\w+:\/\//.test(t.from)||jE(t.from)?this.file=t.from:this.file=LE(t.from)),UE&&VE){var r=new BE(this.css,t);if(r.text){this.map=r;var n=r.consumer().file;!this.file&&n&&(this.file=this.mapResolve(n))}}this.file||(this.id="<input css "+DE(6)+">"),this.map&&(this.map.file=this.from)}var t=e.prototype;return t.error=function(e,t,r,n){var o,i,s;if(void 0===n&&(n={}),t&&"object"===(void 0===t?"undefined":c_(t))){var a=t,l=r;if("number"==typeof a.offset){var c=this.fromOffset(a.offset);t=c.line,r=c.col}else t=a.line,r=a.column;if("number"==typeof l.offset){var u=this.fromOffset(l.offset);i=u.line,s=u.col}else i=l.line,s=l.column}else if(!r){var p=this.fromOffset(t);t=p.line,r=p.col}var d=this.origin(t,r,i,s);return(o=d?new $E(e,void 0===d.endLine?d.line:{column:d.column,line:d.line},void 0===d.endLine?d.column:{column:d.endColumn,line:d.endLine},d.source,d.file,n.plugin):new $E(e,void 0===i?t:{column:r,line:t},void 0===i?r:{column:s,line:i},this.css,this.file,n.plugin)).input={column:r,endColumn:s,endLine:i,line:t,source:this.css},this.file&&(NE&&(o.input.url=NE(this.file).toString()),o.input.file=this.file),o},t.fromOffset=function(e){var t;if(this[zE])t=this[zE];else{var r=this.css.split("\n");t=new Array(r.length);for(var n=0,o=0,i=r.length;o<i;o++)t[o]=n,n+=r[o].length+1;this[zE]=t}var s=0;if(e>=t[t.length-1])s=t.length-1;else for(var a,l=t.length-2;s<l;)if(e<t[a=s+(l-s>>1)])l=a-1;else{if(!(e>=t[a+1])){s=a;break}s=a+1}return{col:e-t[s]+1,line:s+1}},t.mapResolve=function(e){return/^\w+:\/\//.test(e)?e:LE(this.map.consumer().sourceRoot||this.map.root||".",e)},t.origin=function(e,t,r,n){if(!this.map)return!1;var o,i,s=this.map.consumer(),a=s.originalPositionFor({column:t,line:e});if(!a.source)return!1;"number"==typeof r&&(o=s.originalPositionFor({column:n,line:r})),i=jE(a.source)?NE(a.source):new URL(a.source,this.map.consumer().sourceRoot||NE(this.map.mapFile));var l={column:a.column,endColumn:o&&o.column,endLine:o&&o.line,line:a.line,url:i.toString()};if("file:"===i.protocol){if(!PE)throw new Error("file: protocol is not available in this PostCSS build");l.file=PE(i)}var c=s.sourceContentFor(a.source);return c&&(l.source=c),l},t.toJSON=function(){for(var e={},t=0,r=["hasBOM","css","file","id"];t<r.length;t++){var n=r[t];null!=this[n]&&(e[n]=this[n])}return this.map&&(e.map=n_({},this.map),e.map.consumerCache&&(e.map.consumerCache=void 0)),e},r_(e,[{key:"from",get:function(){return this.file||this.id}}]),e}(),WE=qE;qE.default=qE,FE&&FE.registerInput&&FE.registerInput(qE);var HE=tE.SourceMapConsumer,GE=tE.SourceMapGenerator,KE=tE.dirname,YE=tE.relative,ZE=tE.resolve,XE=tE.sep,JE=tE.pathToFileURL,QE=WE,eT=Boolean(HE&&GE),tT=Boolean(KE&&ZE&&YE&&XE),rT=function(){function e(e,t,r,n){this.stringify=e,this.mapOpts=r.map||{},this.root=t,this.opts=r,this.css=n,this.originalCSS=n,this.usesFileUrls=!this.mapOpts.from&&this.mapOpts.absolute,this.memoizedFileURLs=new Map,this.memoizedPaths=new Map,this.memoizedURLs=new Map}var t=e.prototype;return t.addAnnotation=function(){var e;e=this.isInline()?"data:application/json;base64,"+this.toBase64(this.map.toString()):"string"==typeof this.mapOpts.annotation?this.mapOpts.annotation:"function"==typeof this.mapOpts.annotation?this.mapOpts.annotation(this.opts.to,this.root):this.outputFile()+".map";var t="\n";this.css.includes("\r\n")&&(t="\r\n"),this.css+=t+"/*# sourceMappingURL="+e+" */"},t.applyPrevMaps=function(){for(var e,t=d_(this.previous());!(e=t()).done;){var r=e.value,n=this.toUrl(this.path(r.file)),o=r.root||KE(r.file),i=void 0;!1===this.mapOpts.sourcesContent?(i=new HE(r.text)).sourcesContent&&(i.sourcesContent=null):i=r.consumer(),this.map.applySourceMap(i,n,this.toUrl(this.path(o)))}},t.clearAnnotation=function(){if(!1!==this.mapOpts.annotation)if(this.root)for(var e,t=this.root.nodes.length-1;t>=0;t--)"comment"===(e=this.root.nodes[t]).type&&0===e.text.indexOf("# sourceMappingURL=")&&this.root.removeChild(t);else this.css&&(this.css=this.css.replace(/\n*?\/\*#[\S\s]*?\*\/$/gm,""))},t.generate=function(){if(this.clearAnnotation(),tT&&eT&&this.isMap())return this.generateMap();var e="";return this.stringify(this.root,function(t){e+=t}),[e]},t.generateMap=function(){if(this.root)this.generateString();else if(1===this.previous().length){var e=this.previous()[0].consumer();e.file=this.outputFile(),this.map=GE.fromSourceMap(e,{ignoreInvalidMapping:!0})}else this.map=new GE({file:this.outputFile(),ignoreInvalidMapping:!0}),this.map.addMapping({generated:{column:0,line:1},original:{column:0,line:1},source:this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>"});return this.isSourcesContent()&&this.setSourcesContent(),this.root&&this.previous().length>0&&this.applyPrevMaps(),this.isAnnotation()&&this.addAnnotation(),this.isInline()?[this.css]:[this.css,this.map]},t.generateString=function(){var e=this;this.css="",this.map=new GE({file:this.outputFile(),ignoreInvalidMapping:!0});var t,r,n=1,o=1,i="<no source>",s={generated:{column:0,line:0},original:{column:0,line:0},source:""};this.stringify(this.root,function(a,l,c){if(e.css+=a,l&&"end"!==c&&(s.generated.line=n,s.generated.column=o-1,l.source&&l.source.start?(s.source=e.sourcePath(l),s.original.line=l.source.start.line,s.original.column=l.source.start.column-1,e.map.addMapping(s)):(s.source=i,s.original.line=1,s.original.column=0,e.map.addMapping(s))),(t=a.match(/\n/g))?(n+=t.length,r=a.lastIndexOf("\n"),o=a.length-r):o+=a.length,l&&"start"!==c){var u=l.parent||{raws:{}};("decl"===l.type||"atrule"===l.type&&!l.nodes)&&l===u.last&&!u.raws.semicolon||(l.source&&l.source.end?(s.source=e.sourcePath(l),s.original.line=l.source.end.line,s.original.column=l.source.end.column-1,s.generated.line=n,s.generated.column=o-2,e.map.addMapping(s)):(s.source=i,s.original.line=1,s.original.column=0,s.generated.line=n,s.generated.column=o-1,e.map.addMapping(s)))}})},t.isAnnotation=function(){return!!this.isInline()||(void 0!==this.mapOpts.annotation?this.mapOpts.annotation:!this.previous().length||this.previous().some(function(e){return e.annotation}))},t.isInline=function(){if(void 0!==this.mapOpts.inline)return this.mapOpts.inline;var e=this.mapOpts.annotation;return(void 0===e||!0===e)&&(!this.previous().length||this.previous().some(function(e){return e.inline}))},t.isMap=function(){return void 0!==this.opts.map?!!this.opts.map:this.previous().length>0},t.isSourcesContent=function(){return void 0!==this.mapOpts.sourcesContent?this.mapOpts.sourcesContent:!this.previous().length||this.previous().some(function(e){return e.withContent()})},t.outputFile=function(){return this.opts.to?this.path(this.opts.to):this.opts.from?this.path(this.opts.from):"to.css"},t.path=function(e){if(this.mapOpts.absolute)return e;if(60===e.charCodeAt(0))return e;if(/^\w+:\/\//.test(e))return e;var t=this.memoizedPaths.get(e);if(t)return t;var r=this.opts.to?KE(this.opts.to):".";"string"==typeof this.mapOpts.annotation&&(r=KE(ZE(r,this.mapOpts.annotation)));var n=YE(r,e);return this.memoizedPaths.set(e,n),n},t.previous=function(){var e=this;if(!this.previousMaps)if(this.previousMaps=[],this.root)this.root.walk(function(t){if(t.source&&t.source.input.map){var r=t.source.input.map;e.previousMaps.includes(r)||e.previousMaps.push(r)}});else{var t=new QE(this.originalCSS,this.opts);t.map&&this.previousMaps.push(t.map)}return this.previousMaps},t.setSourcesContent=function(){var e=this,t={};if(this.root)this.root.walk(function(r){if(r.source){var n=r.source.input.from;if(n&&!t[n]){t[n]=!0;var o=e.usesFileUrls?e.toFileUrl(n):e.toUrl(e.path(n));e.map.setSourceContent(o,r.source.input.css)}}});else if(this.css){var r=this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>";this.map.setSourceContent(r,this.css)}},t.sourcePath=function(e){return this.mapOpts.from?this.toUrl(this.mapOpts.from):this.usesFileUrls?this.toFileUrl(e.source.input.from):this.toUrl(this.path(e.source.input.from))},t.toBase64=function(e){return Buffer?Buffer.from(e).toString("base64"):window.btoa(unescape(encodeURIComponent(e)))},t.toFileUrl=function(e){var t=this.memoizedFileURLs.get(e);if(t)return t;if(JE){var r=JE(e).toString();return this.memoizedFileURLs.set(e,r),r}throw new Error("`map.absolute` option is not available in this PostCSS build")},t.toUrl=function(e){var t=this.memoizedURLs.get(e);if(t)return t;"\\"===XE&&(e=e.replace(/\\/g,"/"));var r=encodeURI(e).replace(/[#?]/g,encodeURIComponent);return this.memoizedURLs.set(e,r),r},e}(),nT=rT,oT=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="comment",r}return i_(t,e),t}(wE),iT=oT;oT.default=oT;var sT,aT,lT,cT,uT=sE.isClean,pT=sE.my,dT=_E,fT=iT;function hT(e){return e.map(function(e){return e.nodes&&(e.nodes=hT(e.nodes)),delete e.source,e})}function mT(e){if(e[uT]=!1,e.proxyOf.nodes)for(var t,r=d_(e.proxyOf.nodes);!(t=r()).done;)mT(t.value)}var gT=function(e){function t(){return e.apply(this,arguments)||this}i_(t,e);var r=t.prototype;return r.append=function(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];for(var n,o=d_(t);!(n=o()).done;)for(var i,s=n.value,a=d_(this.normalize(s,this.last));!(i=a()).done;){var l=i.value;this.proxyOf.nodes.push(l)}return this.markDirty(),this},r.cleanRaws=function(t){if(e.prototype.cleanRaws.call(this,t),this.nodes)for(var r,n=d_(this.nodes);!(r=n()).done;)r.value.cleanRaws(t)},r.each=function(e){if(this.proxyOf.nodes){for(var t,r,n=this.getIterator();this.indexes[n]<this.proxyOf.nodes.length&&(t=this.indexes[n],!1!==(r=e(this.proxyOf.nodes[t],t)));)this.indexes[n]+=1;return delete this.indexes[n],r}},r.every=function(e){return this.nodes.every(e)},r.getIterator=function(){this.lastEach||(this.lastEach=0),this.indexes||(this.indexes={}),this.lastEach+=1;var e=this.lastEach;return this.indexes[e]=0,e},r.getProxyProcessor=function(){return{get:function(e,t){return"proxyOf"===t?e:e[t]?"each"===t||"string"==typeof t&&t.startsWith("walk")?function(){for(var r=arguments.length,n=new Array(r),o=0;o<r;o++)n[o]=arguments[o];var i;return(i=e)[t].apply(i,[].concat(n.map(function(e){return"function"==typeof e?function(t,r){return e(t.toProxy(),r)}:e})))}:"every"===t||"some"===t?function(r){return e[t](function(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),o=1;o<t;o++)n[o-1]=arguments[o];return r.apply(void 0,[].concat([e.toProxy()],n))})}:"root"===t?function(){return e.root().toProxy()}:"nodes"===t?e.nodes.map(function(e){return e.toProxy()}):"first"===t||"last"===t?e[t].toProxy():e[t]:e[t]},set:function(e,t,r){return e[t]===r||(e[t]=r,"name"!==t&&"params"!==t&&"selector"!==t||e.markDirty()),!0}}},r.index=function(e){return"number"==typeof e?e:(e.proxyOf&&(e=e.proxyOf),this.proxyOf.nodes.indexOf(e))},r.insertAfter=function(e,t){var r,n=this.index(e),o=this.normalize(t,this.proxyOf.nodes[n]).reverse();n=this.index(e);for(var i,s=d_(o);!(i=s()).done;){var a=i.value;this.proxyOf.nodes.splice(n+1,0,a)}for(var l in this.indexes)n<(r=this.indexes[l])&&(this.indexes[l]=r+o.length);return this.markDirty(),this},r.insertBefore=function(e,t){var r,n=this.index(e),o=0===n&&"prepend",i=this.normalize(t,this.proxyOf.nodes[n],o).reverse();n=this.index(e);for(var s,a=d_(i);!(s=a()).done;){var l=s.value;this.proxyOf.nodes.splice(n,0,l)}for(var c in this.indexes)n<=(r=this.indexes[c])&&(this.indexes[c]=r+i.length);return this.markDirty(),this},r.normalize=function(e,r){var n=this;if("string"==typeof e)e=hT(sT(e).nodes);else if(void 0===e)e=[];else if(Array.isArray(e))for(var o,i=d_(e=e.slice(0));!(o=i()).done;){var s=o.value;s.parent&&s.parent.removeChild(s,"ignore")}else if("root"===e.type&&"document"!==this.type)for(var a,l=d_(e=e.nodes.slice(0));!(a=l()).done;){var c=a.value;c.parent&&c.parent.removeChild(c,"ignore")}else if(e.type)e=[e];else if(e.prop){if(void 0===e.value)throw new Error("Value field is missed in node creation");"string"!=typeof e.value&&(e.value=String(e.value)),e=[new dT(e)]}else if(e.selector)e=[new aT(e)];else if(e.name)e=[new lT(e)];else{if(!e.text)throw new Error("Unknown node type in node creation");e=[new fT(e)]}var u=e.map(function(e){return e[pT]||t.rebuild(e),(e=e.proxyOf).parent&&e.parent.removeChild(e),e[uT]&&mT(e),void 0===e.raws.before&&r&&void 0!==r.raws.before&&(e.raws.before=r.raws.before.replace(/\S/g,"")),e.parent=n.proxyOf,e});return u},r.prepend=function(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];for(var n,o=d_(t=t.reverse());!(n=o()).done;){for(var i,s=n.value,a=this.normalize(s,this.first,"prepend").reverse(),l=d_(a);!(i=l()).done;){var c=i.value;this.proxyOf.nodes.unshift(c)}for(var u in this.indexes)this.indexes[u]=this.indexes[u]+a.length}return this.markDirty(),this},r.push=function(e){return e.parent=this,this.proxyOf.nodes.push(e),this},r.removeAll=function(){for(var e,t=d_(this.proxyOf.nodes);!(e=t()).done;)e.value.parent=void 0;return this.proxyOf.nodes=[],this.markDirty(),this},r.removeChild=function(e){var t;for(var r in e=this.index(e),this.proxyOf.nodes[e].parent=void 0,this.proxyOf.nodes.splice(e,1),this.indexes)(t=this.indexes[r])>=e&&(this.indexes[r]=t-1);return this.markDirty(),this},r.replaceValues=function(e,t,r){return r||(r=t,t={}),this.walkDecls(function(n){t.props&&!t.props.includes(n.prop)||t.fast&&!n.value.includes(t.fast)||(n.value=n.value.replace(e,r))}),this.markDirty(),this},r.some=function(e){return this.nodes.some(e)},r.walk=function(e){return this.each(function(t,r){var n;try{n=e(t,r)}catch(e){throw t.addToError(e)}return!1!==n&&t.walk&&(n=t.walk(e)),n})},r.walkAtRules=function(e,t){return t?s_(e,RegExp)?this.walk(function(r,n){if("atrule"===r.type&&e.test(r.name))return t(r,n)}):this.walk(function(r,n){if("atrule"===r.type&&r.name===e)return t(r,n)}):(t=e,this.walk(function(e,r){if("atrule"===e.type)return t(e,r)}))},r.walkComments=function(e){return this.walk(function(t,r){if("comment"===t.type)return e(t,r)})},r.walkDecls=function(e,t){return t?s_(e,RegExp)?this.walk(function(r,n){if("decl"===r.type&&e.test(r.prop))return t(r,n)}):this.walk(function(r,n){if("decl"===r.type&&r.prop===e)return t(r,n)}):(t=e,this.walk(function(e,r){if("decl"===e.type)return t(e,r)}))},r.walkRules=function(e,t){return t?s_(e,RegExp)?this.walk(function(r,n){if("rule"===r.type&&e.test(r.selector))return t(r,n)}):this.walk(function(r,n){if("rule"===r.type&&r.selector===e)return t(r,n)}):(t=e,this.walk(function(e,r){if("rule"===e.type)return t(e,r)}))},r_(t,[{key:"first",get:function(){if(this.proxyOf.nodes)return this.proxyOf.nodes[0]}},{key:"last",get:function(){if(this.proxyOf.nodes)return this.proxyOf.nodes[this.proxyOf.nodes.length-1]}}]),t}(wE);gT.registerParse=function(e){sT=e},gT.registerRule=function(e){aT=e},gT.registerAtRule=function(e){lT=e},gT.registerRoot=function(e){cT=e};var vT=gT;gT.default=gT,gT.rebuild=function(e){"atrule"===e.type?Object.setPrototypeOf(e,lT.prototype):"rule"===e.type?Object.setPrototypeOf(e,aT.prototype):"decl"===e.type?Object.setPrototypeOf(e,dT.prototype):"comment"===e.type?Object.setPrototypeOf(e,fT.prototype):"root"===e.type&&Object.setPrototypeOf(e,cT.prototype),e[pT]=!0,e.nodes&&e.nodes.forEach(function(e){gT.rebuild(e)})};var yT,bT,wT=function(e){function t(t){var r;return(r=e.call(this,n_({type:"document"},t))||this).nodes||(r.nodes=[]),r}return i_(t,e),t.prototype.toResult=function(e){return void 0===e&&(e={}),new yT(new bT,this,e).stringify()},t}(vT);wT.registerLazyResult=function(e){yT=e},wT.registerProcessor=function(e){bT=e};var xT=wT;wT.default=wT;var _T={},ST=function(e){_T[e]||(_T[e]=!0,"undefined"!=typeof console&&console.warn&&console.warn(e))},kT=function(){function e(e,t){if(void 0===t&&(t={}),this.type="warning",this.text=e,t.node&&t.node.source){var r=t.node.rangeBy(t);this.line=r.start.line,this.column=r.start.column,this.endLine=r.end.line,this.endColumn=r.end.column}for(var n in t)this[n]=t[n]}return e.prototype.toString=function(){return this.node?this.node.error(this.text,{index:this.index,plugin:this.plugin,word:this.word}).message:this.plugin?this.plugin+": "+this.text:this.text},e}(),CT=kT;kT.default=kT;var OT=CT,ET=function(){function e(e,t,r){this.processor=e,this.messages=[],this.root=t,this.opts=r,this.css=void 0,this.map=void 0}var t=e.prototype;return t.toString=function(){return this.css},t.warn=function(e,t){void 0===t&&(t={}),t.plugin||this.lastPlugin&&this.lastPlugin.postcssPlugin&&(t.plugin=this.lastPlugin.postcssPlugin);var r=new OT(e,t);return this.messages.push(r),r},t.warnings=function(){return this.messages.filter(function(e){return"warning"===e.type})},r_(e,[{key:"content",get:function(){return this.css}}]),e}(),TT=ET;ET.default=ET;var RT="'".charCodeAt(0),IT='"'.charCodeAt(0),MT="\\".charCodeAt(0),AT="/".charCodeAt(0),PT="\n".charCodeAt(0),NT=" ".charCodeAt(0),jT="\f".charCodeAt(0),LT="\t".charCodeAt(0),DT="\r".charCodeAt(0),FT="[".charCodeAt(0),$T="]".charCodeAt(0),BT="(".charCodeAt(0),zT=")".charCodeAt(0),VT="{".charCodeAt(0),UT="}".charCodeAt(0),qT=";".charCodeAt(0),WT="*".charCodeAt(0),HT=":".charCodeAt(0),GT="@".charCodeAt(0),KT=/[\t\n\f\r "#'()/;[\\\]{}]/g,YT=/[\t\n\f\r !"#'():;@[\\\]{}]|\/(?=\*)/g,ZT=/.[\r\n"'(/\\]/,XT=/[\da-f]/i,JT=vT,QT=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="atrule",r}i_(t,e);var r=t.prototype;return r.append=function(){for(var t=arguments.length,r=new Array(t),n=0;n<t;n++)r[n]=arguments[n];var o;return this.proxyOf.nodes||(this.nodes=[]),(o=e.prototype.append).call.apply(o,[].concat([this],r))},r.prepend=function(){for(var t=arguments.length,r=new Array(t),n=0;n<t;n++)r[n]=arguments[n];var o;return this.proxyOf.nodes||(this.nodes=[]),(o=e.prototype.prepend).call.apply(o,[].concat([this],r))},t}(JT),eR=QT;QT.default=QT,JT.registerAtRule(QT);var tR,rR,nR=vT,oR=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="root",r.nodes||(r.nodes=[]),r}i_(t,e);var r=t.prototype;return r.normalize=function(t,r,n){var o=e.prototype.normalize.call(this,t);if(r)if("prepend"===n)this.nodes.length>1?r.raws.before=this.nodes[1].raws.before:delete r.raws.before;else if(this.first!==r)for(var i,s=d_(o);!(i=s()).done;)i.value.raws.before=r.raws.before;return o},r.removeChild=function(t,r){var n=this.index(t);return!r&&0===n&&this.nodes.length>1&&(this.nodes[1].raws.before=this.nodes[n].raws.before),e.prototype.removeChild.call(this,t)},r.toResult=function(e){return void 0===e&&(e={}),new tR(new rR,this,e).stringify()},t}(nR);oR.registerLazyResult=function(e){tR=e},oR.registerProcessor=function(e){rR=e};var iR=oR;oR.default=oR,nR.registerRoot(oR);var sR={comma:function(e){return sR.split(e,[","],!0)},space:function(e){return sR.split(e,[" ","\n","\t"])},split:function(e,t,r){for(var n,o=[],i="",s=!1,a=0,l=!1,c="",u=!1,p=d_(e);!(n=p()).done;){var d=n.value;u?u=!1:"\\"===d?u=!0:l?d===c&&(l=!1):'"'===d||"'"===d?(l=!0,c=d):"("===d?a+=1:")"===d?a>0&&(a-=1):0===a&&t.includes(d)&&(s=!0),s?(""!==i&&o.push(i.trim()),i="",s=!1):i+=d}return(r||""!==i)&&o.push(i.trim()),o}},aR=sR;sR.default=sR;var lR=vT,cR=aR,uR=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="rule",r.nodes||(r.nodes=[]),r}return i_(t,e),r_(t,[{key:"selectors",get:function(){return cR.comma(this.selector)},set:function(e){var t=this.selector?this.selector.match(/,\s*/):null,r=t?t[0]:","+this.raw("between","beforeOpen");this.selector=e.join(r)}}]),t}(lR),pR=uR;uR.default=uR,lR.registerRule(uR);var dR=_E,fR=iT,hR=eR,mR=iR,gR=pR,vR={empty:!0,space:!0},yR=function(){function e(e){this.input=e,this.root=new mR,this.current=this.root,this.spaces="",this.semicolon=!1,this.createTokenizer(),this.root.source={input:e,start:{column:1,line:1,offset:0}}}var t=e.prototype;return t.atrule=function(e){var t,r,n,o=new hR;o.name=e[1].slice(1),""===o.name&&this.unnamedAtrule(o,e),this.init(o,e[2]);for(var i=!1,s=!1,a=[],l=[];!this.tokenizer.endOfFile();){if("("===(t=(e=this.tokenizer.nextToken())[0])||"["===t?l.push("("===t?")":"]"):"{"===t&&l.length>0?l.push("}"):t===l[l.length-1]&&l.pop(),0===l.length){if(";"===t){o.source.end=this.getPosition(e[2]),o.source.end.offset++,this.semicolon=!0;break}if("{"===t){s=!0;break}if("}"===t){if(a.length>0){for(r=a[n=a.length-1];r&&"space"===r[0];)r=a[--n];r&&(o.source.end=this.getPosition(r[3]||r[2]),o.source.end.offset++)}this.end(e);break}a.push(e)}else a.push(e);if(this.tokenizer.endOfFile()){i=!0;break}}o.raws.between=this.spacesAndCommentsFromEnd(a),a.length?(o.raws.afterName=this.spacesAndCommentsFromStart(a),this.raw(o,"params",a),i&&(e=a[a.length-1],o.source.end=this.getPosition(e[3]||e[2]),o.source.end.offset++,this.spaces=o.raws.between,o.raws.between="")):(o.raws.afterName="",o.params=""),s&&(o.nodes=[],this.current=o)},t.checkMissedSemicolon=function(e){var t=this.colon(e);if(!1!==t){for(var r,n=0,o=t-1;o>=0&&("space"===(r=e[o])[0]||2!==(n+=1));o--);throw this.input.error("Missed semicolon","word"===r[0]?r[3]+1:r[2])}},t.colon=function(e){for(var t,r,n,o,i=0,s=d_(e.entries());!(o=s()).done;){var a=o.value,l=a[0];if("("===(r=(t=a[1])[0])&&(i+=1),")"===r&&(i-=1),0===i&&":"===r){if(n){if("word"===n[0]&&"progid"===n[1])continue;return l}this.doubleColon(t)}n=t}return!1},t.comment=function(e){var t=new fR;this.init(t,e[2]),t.source.end=this.getPosition(e[3]||e[2]),t.source.end.offset++;var r=e[1].slice(2,-2);if(/^\s*$/.test(r))t.text="",t.raws.left=r,t.raws.right="";else{var n=r.match(/^(\s*)([^]*\S)(\s*)$/);t.text=n[2],t.raws.left=n[1],t.raws.right=n[3]}},t.createTokenizer=function(){this.tokenizer=function(e,t){void 0===t&&(t={});var r,n,o,i,s,a,l,c,u,p,d=e.css.valueOf(),f=t.ignoreErrors,h=d.length,m=0,g=[],v=[];function y(t){throw e.error("Unclosed "+t,m)}return{back:function(e){v.push(e)},endOfFile:function(){return 0===v.length&&m>=h},nextToken:function(e){if(v.length)return v.pop();if(!(m>=h)){var t=!!e&&e.ignoreUnclosed;switch(r=d.charCodeAt(m)){case PT:case NT:case LT:case DT:case jT:n=m;do{n+=1,r=d.charCodeAt(n)}while(r===NT||r===PT||r===LT||r===DT||r===jT);p=["space",d.slice(m,n)],m=n-1;break;case FT:case $T:case VT:case UT:case HT:case qT:case zT:var b=String.fromCharCode(r);p=[b,b,m];break;case BT:if(c=g.length?g.pop()[1]:"",u=d.charCodeAt(m+1),"url"===c&&u!==RT&&u!==IT&&u!==NT&&u!==PT&&u!==LT&&u!==jT&&u!==DT){n=m;do{if(a=!1,-1===(n=d.indexOf(")",n+1))){if(f||t){n=m;break}y("bracket")}for(l=n;d.charCodeAt(l-1)===MT;)l-=1,a=!a}while(a);p=["brackets",d.slice(m,n+1),m,n],m=n}else n=d.indexOf(")",m+1),i=d.slice(m,n+1),-1===n||ZT.test(i)?p=["(","(",m]:(p=["brackets",i,m,n],m=n);break;case RT:case IT:o=r===RT?"'":'"',n=m;do{if(a=!1,-1===(n=d.indexOf(o,n+1))){if(f||t){n=m+1;break}y("string")}for(l=n;d.charCodeAt(l-1)===MT;)l-=1,a=!a}while(a);p=["string",d.slice(m,n+1),m,n],m=n;break;case GT:KT.lastIndex=m+1,KT.test(d),n=0===KT.lastIndex?d.length-1:KT.lastIndex-2,p=["at-word",d.slice(m,n+1),m,n],m=n;break;case MT:for(n=m,s=!0;d.charCodeAt(n+1)===MT;)n+=1,s=!s;if(r=d.charCodeAt(n+1),s&&r!==AT&&r!==NT&&r!==PT&&r!==LT&&r!==DT&&r!==jT&&(n+=1,XT.test(d.charAt(n)))){for(;XT.test(d.charAt(n+1));)n+=1;d.charCodeAt(n+1)===NT&&(n+=1)}p=["word",d.slice(m,n+1),m,n],m=n;break;default:r===AT&&d.charCodeAt(m+1)===WT?(0===(n=d.indexOf("*/",m+2)+1)&&(f||t?n=d.length:y("comment")),p=["comment",d.slice(m,n+1),m,n],m=n):(YT.lastIndex=m+1,YT.test(d),n=0===YT.lastIndex?d.length-1:YT.lastIndex-2,p=["word",d.slice(m,n+1),m,n],g.push(p),m=n)}return m++,p}},position:function(){return m}}}(this.input)},t.decl=function(e,t){var r=new dR;this.init(r,e[0][2]);var n,o=e[e.length-1];for(";"===o[0]&&(this.semicolon=!0,e.pop()),r.source.end=this.getPosition(o[3]||o[2]||function(e){for(var t=e.length-1;t>=0;t--){var r=e[t],n=r[3]||r[2];if(n)return n}}(e)),r.source.end.offset++;"word"!==e[0][0];)1===e.length&&this.unknownWord(e),r.raws.before+=e.shift()[1];for(r.source.start=this.getPosition(e[0][2]),r.prop="";e.length;){var i=e[0][0];if(":"===i||"space"===i||"comment"===i)break;r.prop+=e.shift()[1]}for(r.raws.between="";e.length;){if(":"===(n=e.shift())[0]){r.raws.between+=n[1];break}"word"===n[0]&&/\w/.test(n[1])&&this.unknownWord([n]),r.raws.between+=n[1]}"_"!==r.prop[0]&&"*"!==r.prop[0]||(r.raws.before+=r.prop[0],r.prop=r.prop.slice(1));for(var s,a=[];e.length&&("space"===(s=e[0][0])||"comment"===s);)a.push(e.shift());this.precheckMissedSemicolon(e);for(var l=e.length-1;l>=0;l--){if("!important"===(n=e[l])[1].toLowerCase()){r.important=!0;var c=this.stringFrom(e,l);" !important"!==(c=this.spacesFromEnd(e)+c)&&(r.raws.important=c);break}if("important"===n[1].toLowerCase()){for(var u=e.slice(0),p="",d=l;d>0;d--){var f=u[d][0];if(0===p.trim().indexOf("!")&&"space"!==f)break;p=u.pop()[1]+p}0===p.trim().indexOf("!")&&(r.important=!0,r.raws.important=p,e=u)}if("space"!==n[0]&&"comment"!==n[0])break}var h=e.some(function(e){return"space"!==e[0]&&"comment"!==e[0]});h&&(r.raws.between+=a.map(function(e){return e[1]}).join(""),a=[]),this.raw(r,"value",a.concat(e),t),r.value.includes(":")&&!t&&this.checkMissedSemicolon(e)},t.doubleColon=function(e){throw this.input.error("Double colon",{offset:e[2]},{offset:e[2]+e[1].length})},t.emptyRule=function(e){var t=new gR;this.init(t,e[2]),t.selector="",t.raws.between="",this.current=t},t.end=function(e){this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.semicolon=!1,this.current.raws.after=(this.current.raws.after||"")+this.spaces,this.spaces="",this.current.parent?(this.current.source.end=this.getPosition(e[2]),this.current.source.end.offset++,this.current=this.current.parent):this.unexpectedClose(e)},t.endFile=function(){this.current.parent&&this.unclosedBlock(),this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.current.raws.after=(this.current.raws.after||"")+this.spaces,this.root.source.end=this.getPosition(this.tokenizer.position())},t.freeSemicolon=function(e){if(this.spaces+=e[1],this.current.nodes){var t=this.current.nodes[this.current.nodes.length-1];t&&"rule"===t.type&&!t.raws.ownSemicolon&&(t.raws.ownSemicolon=this.spaces,this.spaces="")}},t.getPosition=function(e){var t=this.input.fromOffset(e);return{column:t.col,line:t.line,offset:e}},t.init=function(e,t){this.current.push(e),e.source={input:this.input,start:this.getPosition(t)},e.raws.before=this.spaces,this.spaces="","comment"!==e.type&&(this.semicolon=!1)},t.other=function(e){for(var t=!1,r=null,n=!1,o=null,i=[],s=e[1].startsWith("--"),a=[],l=e;l;){if(r=l[0],a.push(l),"("===r||"["===r)o||(o=l),i.push("("===r?")":"]");else if(s&&n&&"{"===r)o||(o=l),i.push("}");else if(0===i.length){if(";"===r){if(n)return void this.decl(a,s);break}if("{"===r)return void this.rule(a);if("}"===r){this.tokenizer.back(a.pop()),t=!0;break}":"===r&&(n=!0)}else r===i[i.length-1]&&(i.pop(),0===i.length&&(o=null));l=this.tokenizer.nextToken()}if(this.tokenizer.endOfFile()&&(t=!0),i.length>0&&this.unclosedBracket(o),t&&n){if(!s)for(;a.length&&("space"===(l=a[a.length-1][0])||"comment"===l);)this.tokenizer.back(a.pop());this.decl(a,s)}else this.unknownWord(a)},t.parse=function(){for(var e;!this.tokenizer.endOfFile();)switch((e=this.tokenizer.nextToken())[0]){case"space":this.spaces+=e[1];break;case";":this.freeSemicolon(e);break;case"}":this.end(e);break;case"comment":this.comment(e);break;case"at-word":this.atrule(e);break;case"{":this.emptyRule(e);break;default:this.other(e)}this.endFile()},t.precheckMissedSemicolon=function(){},t.raw=function(e,t,r,n){for(var o,i,s,a,l=r.length,c="",u=!0,p=0;p<l;p+=1)"space"!==(i=(o=r[p])[0])||p!==l-1||n?"comment"===i?(a=r[p-1]?r[p-1][0]:"empty",s=r[p+1]?r[p+1][0]:"empty",vR[a]||vR[s]||","===c.slice(-1)?u=!1:c+=o[1]):c+=o[1]:u=!1;if(!u){var d=r.reduce(function(e,t){return e+t[1]},"");e.raws[t]={raw:d,value:c}}e[t]=c},t.rule=function(e){e.pop();var t=new gR;this.init(t,e[0][2]),t.raws.between=this.spacesAndCommentsFromEnd(e),this.raw(t,"selector",e),this.current=t},t.spacesAndCommentsFromEnd=function(e){for(var t,r="";e.length&&("space"===(t=e[e.length-1][0])||"comment"===t);)r=e.pop()[1]+r;return r},t.spacesAndCommentsFromStart=function(e){for(var t,r="";e.length&&("space"===(t=e[0][0])||"comment"===t);)r+=e.shift()[1];return r},t.spacesFromEnd=function(e){for(var t="";e.length&&"space"===e[e.length-1][0];)t=e.pop()[1]+t;return t},t.stringFrom=function(e,t){for(var r="",n=t;n<e.length;n++)r+=e[n][1];return e.splice(t,e.length-t),r},t.unclosedBlock=function(){var e=this.current.source.start;throw this.input.error("Unclosed block",e.line,e.column)},t.unclosedBracket=function(e){throw this.input.error("Unclosed bracket",{offset:e[2]},{offset:e[2]+1})},t.unexpectedClose=function(e){throw this.input.error("Unexpected }",{offset:e[2]},{offset:e[2]+1})},t.unknownWord=function(e){throw this.input.error("Unknown word",{offset:e[0][2]},{offset:e[0][2]+e[0][1].length})},t.unnamedAtrule=function(e,t){throw this.input.error("At-rule without name",{offset:t[2]},{offset:t[2]+t[1].length})},e}(),bR=vT,wR=yR,xR=WE;function _R(e,t){var r=new xR(e,t),n=new wR(r);try{n.parse()}catch(e){throw true&&"CssSyntaxError"===e.name&&t&&t.from&&(/\.scss$/i.test(t.from)?e.message+="\nYou tried to parse SCSS with the standard CSS parser; try again with the postcss-scss parser":/\.sass/i.test(t.from)?e.message+="\nYou tried to parse Sass with the standard CSS parser; try again with the postcss-sass parser":/\.less$/i.test(t.from)&&(e.message+="\nYou tried to parse Less with the standard CSS parser; try again with the postcss-less parser")),e}return n.root}var SR=_R;_R.default=_R,bR.registerParse(_R);var kR=sE.isClean,CR=sE.my,OR=nT,ER=dE,TR=vT,RR=xT,IR=ST,MR=TT,AR=SR,PR=iR,NR={atrule:"AtRule",comment:"Comment",decl:"Declaration",document:"Document",root:"Root",rule:"Rule"},jR={AtRule:!0,AtRuleExit:!0,Comment:!0,CommentExit:!0,Declaration:!0,DeclarationExit:!0,Document:!0,DocumentExit:!0,Once:!0,OnceExit:!0,postcssPlugin:!0,prepare:!0,Root:!0,RootExit:!0,Rule:!0,RuleExit:!0},LR={Once:!0,postcssPlugin:!0,prepare:!0};function DR(e){return"object"===(void 0===e?"undefined":c_(e))&&"function"==typeof e.then}function FR(e){var t=!1,r=NR[e.type];return"decl"===e.type?t=e.prop.toLowerCase():"atrule"===e.type&&(t=e.name.toLowerCase()),t&&e.append?[r,r+"-"+t,0,r+"Exit",r+"Exit-"+t]:t?[r,r+"-"+t,r+"Exit",r+"Exit-"+t]:e.append?[r,0,r+"Exit"]:[r,r+"Exit"]}function $R(e){return{eventIndex:0,events:"document"===e.type?["Document",0,"DocumentExit"]:"root"===e.type?["Root",0,"RootExit"]:FR(e),iterator:0,node:e,visitorIndex:0,visitors:[]}}function BR(e){return e[kR]=!1,e.nodes&&e.nodes.forEach(function(e){return BR(e)}),e}var zR={},VR=function(){function e(t,r,n){var o,i=this;if(this.stringified=!1,this.processed=!1,"object"!==(void 0===r?"undefined":c_(r))||null===r||"root"!==r.type&&"document"!==r.type)if(s_(r,e)||s_(r,MR))o=BR(r.root),r.map&&(void 0===n.map&&(n.map={}),n.map.inline||(n.map.inline=!1),n.map.prev=r.map);else{var s=AR;n.syntax&&(s=n.syntax.parse),n.parser&&(s=n.parser),s.parse&&(s=s.parse);try{o=s(r,n)}catch(e){this.processed=!0,this.error=e}o&&!o[CR]&&TR.rebuild(o)}else o=BR(r);this.result=new MR(t,o,n),this.helpers=n_({},zR,{postcss:zR,result:this.result}),this.plugins=this.processor.plugins.map(function(e){return"object"===(void 0===e?"undefined":c_(e))&&e.prepare?n_({},e,e.prepare(i.result)):e})}var t=e.prototype;return t.async=function(){return this.error?Promise.reject(this.error):this.processed?Promise.resolve(this.result):(this.processing||(this.processing=this.runAsync()),this.processing)},t.catch=function(e){return this.async().catch(e)},t.finally=function(e){return this.async().then(e,e)},t.getAsyncError=function(){throw new Error("Use process(css).then(cb) to work with async plugins")},t.handleError=function(e,t){var r=this.result.lastPlugin;try{if(t&&t.addToError(e),this.error=e,"CssSyntaxError"!==e.name||e.plugin){if(r.postcssVersion&&"production"!=="development"){var n=r.postcssPlugin,o=r.postcssVersion,i=this.result.processor.version,s=o.split("."),a=i.split(".");(s[0]!==a[0]||parseInt(s[1])>parseInt(a[1]))&&console.error("Unknown error from PostCSS plugin. Your current PostCSS version is "+i+", but "+n+" uses "+o+". Perhaps this is the source of the error below.")}}else e.plugin=r.postcssPlugin,e.setMessage()}catch(e){console&&console.error&&console.error(e)}return e},t.prepareVisitors=function(){var e=this;this.listeners={};for(var t,r=function(t,r,n){e.listeners[r]||(e.listeners[r]=[]),e.listeners[r].push([t,n])},n=d_(this.plugins);!(t=n()).done;){var o=t.value;if("object"===(void 0===o?"undefined":c_(o)))for(var i in o){if(!jR[i]&&/^[A-Z]/.test(i))throw new Error("Unknown event "+i+" in "+o.postcssPlugin+". Try to update PostCSS ("+this.processor.version+" now).");if(!LR[i])if("object"===c_(o[i]))for(var s in o[i])r(o,"*"===s?i:i+"-"+s.toLowerCase(),o[i][s]);else"function"==typeof o[i]&&r(o,i,o[i])}}this.hasListener=Object.keys(this.listeners).length>0},t.runAsync=function(){var e=this;return e_(function(){var t,r,n,o,i,s,a,l,c,u,p,d;return f_(this,function(f){switch(f.label){case 0:e.plugin=0,t=0,f.label=1;case 1:if(!(t<e.plugins.length))return[3,6];if(r=e.plugins[t],!DR(n=e.runOnRoot(r)))return[3,5];f.label=2;case 2:return f.trys.push([2,4,,5]),[4,n];case 3:return f.sent(),[3,5];case 4:throw o=f.sent(),e.handleError(o);case 5:return t++,[3,1];case 6:if(e.prepareVisitors(),!e.hasListener)return[3,18];i=e.result.root,f.label=7;case 7:if(i[kR])return[3,14];i[kR]=!0,s=[$R(i)],f.label=8;case 8:if(!(s.length>0))return[3,13];if(!DR(a=e.visitTick(s)))return[3,12];f.label=9;case 9:return f.trys.push([9,11,,12]),[4,a];case 10:return f.sent(),[3,12];case 11:throw l=f.sent(),c=s[s.length-1].node,e.handleError(l,c);case 12:return[3,8];case 13:return[3,7];case 14:if(!e.listeners.OnceExit)return[3,18];u=function(){var t,r,n,o,s;return f_(this,function(a){switch(a.label){case 0:t=d.value,r=t[0],n=t[1],e.result.lastPlugin=r,a.label=1;case 1:return a.trys.push([1,6,,7]),"document"!==i.type?[3,3]:(o=i.nodes.map(function(t){return n(t,e.helpers)}),[4,Promise.all(o)]);case 2:return a.sent(),[3,5];case 3:return[4,n(i,e.helpers)];case 4:a.sent(),a.label=5;case 5:return[3,7];case 6:throw s=a.sent(),e.handleError(s);case 7:return[2]}})},p=d_(e.listeners.OnceExit),f.label=15;case 15:return(d=p()).done?[3,18]:[5,h_(u())];case 16:f.sent(),f.label=17;case 17:return[3,15];case 18:return e.processed=!0,[2,e.stringify()]}})})()},t.runOnRoot=function(e){var t=this;this.result.lastPlugin=e;try{if("object"===(void 0===e?"undefined":c_(e))&&e.Once){if("document"===this.result.root.type){var r=this.result.root.nodes.map(function(r){return e.Once(r,t.helpers)});return DR(r[0])?Promise.all(r):r}return e.Once(this.result.root,this.helpers)}if("function"==typeof e)return e(this.result.root,this.result)}catch(e){throw this.handleError(e)}},t.stringify=function(){if(this.error)throw this.error;if(this.stringified)return this.result;this.stringified=!0,this.sync();var e=this.result.opts,t=ER;e.syntax&&(t=e.syntax.stringify),e.stringifier&&(t=e.stringifier),t.stringify&&(t=t.stringify);var r=new OR(t,this.result.root,this.result.opts).generate();return this.result.css=r[0],this.result.map=r[1],this.result},t.sync=function(){if(this.error)throw this.error;if(this.processed)return this.result;if(this.processed=!0,this.processing)throw this.getAsyncError();for(var e,t=d_(this.plugins);!(e=t()).done;){var r=e.value;if(DR(this.runOnRoot(r)))throw this.getAsyncError()}if(this.prepareVisitors(),this.hasListener){for(var n=this.result.root;!n[kR];)n[kR]=!0,this.walkSync(n);if(this.listeners.OnceExit)if("document"===n.type)for(var o,i=d_(n.nodes);!(o=i()).done;){var s=o.value;this.visitSync(this.listeners.OnceExit,s)}else this.visitSync(this.listeners.OnceExit,n)}return this.result},t.then=function(e,t){return true&&("from"in this.opts||IR("Without `from` option PostCSS could generate wrong source map and will not find Browserslist config. Set it to CSS file path or to `undefined` to prevent this warning.")),this.async().then(e,t)},t.toString=function(){return this.css},t.visitSync=function(e,t){for(var r,n=d_(e);!(r=n()).done;){var o=r.value,i=o[0],s=o[1];this.result.lastPlugin=i;var a=void 0;try{a=s(t,this.helpers)}catch(e){throw this.handleError(e,t.proxyOf)}if("root"!==t.type&&"document"!==t.type&&!t.parent)return!0;if(DR(a))throw this.getAsyncError()}},t.visitTick=function(e){var t=e[e.length-1],r=t.node,n=t.visitors;if("root"===r.type||"document"===r.type||r.parent){if(n.length>0&&t.visitorIndex<n.length){var o=n[t.visitorIndex],i=o[0],s=o[1];t.visitorIndex+=1,t.visitorIndex===n.length&&(t.visitors=[],t.visitorIndex=0),this.result.lastPlugin=i;try{return s(r.toProxy(),this.helpers)}catch(e){throw this.handleError(e,r)}}if(0!==t.iterator){for(var a,l=t.iterator;a=r.nodes[r.indexes[l]];)if(r.indexes[l]+=1,!a[kR])return a[kR]=!0,void e.push($R(a));t.iterator=0,delete r.indexes[l]}for(var c=t.events;t.eventIndex<c.length;){var u=c[t.eventIndex];if(t.eventIndex+=1,0===u)return void(r.nodes&&r.nodes.length&&(r[kR]=!0,t.iterator=r.getIterator()));if(this.listeners[u])return void(t.visitors=this.listeners[u])}e.pop()}else e.pop()},t.walkSync=function(e){var t=this;e[kR]=!0;for(var r,n=d_(FR(e));!(r=n()).done;){var o=r.value;if(0===o)e.nodes&&e.each(function(e){e[kR]||t.walkSync(e)});else{var i=this.listeners[o];if(i&&this.visitSync(i,e.toProxy()))return}}},t.warnings=function(){return this.sync().warnings()},r_(e,[{key:"content",get:function(){return this.stringify().content}},{key:"css",get:function(){return this.stringify().css}},{key:"map",get:function(){return this.stringify().map}},{key:"messages",get:function(){return this.sync().messages}},{key:"opts",get:function(){return this.result.opts}},{key:"processor",get:function(){return this.result.processor}},{key:"root",get:function(){return this.sync().root}},{key:Symbol.toStringTag,get:function(){return"LazyResult"}}]),e}();VR.registerPostcss=function(e){zR=e};var UR=VR;VR.default=VR,PR.registerLazyResult(VR),RR.registerLazyResult(VR);var qR=nT,WR=dE,HR=ST,GR=SR,KR=TT,YR=function(){function e(e,t,r){var n;t=t.toString(),this.stringified=!1,this._processor=e,this._css=t,this._opts=r,this._map=void 0;var o=WR;this.result=new KR(this._processor,n,this._opts),this.result.css=t;var i=this;Object.defineProperty(this.result,"root",{get:function(){return i.root}});var s=new qR(o,n,this._opts,t);if(s.isMap()){var a=s.generate(),l=a[0],c=a[1];l&&(this.result.css=l),c&&(this.result.map=c)}else s.clearAnnotation(),this.result.css=s.css}var t=e.prototype;return t.async=function(){return this.error?Promise.reject(this.error):Promise.resolve(this.result)},t.catch=function(e){return this.async().catch(e)},t.finally=function(e){return this.async().then(e,e)},t.sync=function(){if(this.error)throw this.error;return this.result},t.then=function(e,t){return true&&("from"in this._opts||HR("Without `from` option PostCSS could generate wrong source map and will not find Browserslist config. Set it to CSS file path or to `undefined` to prevent this warning.")),this.async().then(e,t)},t.toString=function(){return this._css},t.warnings=function(){return[]},r_(e,[{key:"content",get:function(){return this.result.css}},{key:"css",get:function(){return this.result.css}},{key:"map",get:function(){return this.result.map}},{key:"messages",get:function(){return[]}},{key:"opts",get:function(){return this.result.opts}},{key:"processor",get:function(){return this.result.processor}},{key:"root",get:function(){if(this._root)return this._root;var e,t=GR;try{e=t(this._css,this._opts)}catch(e){this.error=e}if(this.error)throw this.error;return this._root=e,e}},{key:Symbol.toStringTag,get:function(){return"NoWorkResult"}}]),e}(),ZR=YR;YR.default=YR;var XR=ZR,JR=UR,QR=xT,eI=iR,tI=function(){function e(e){void 0===e&&(e=[]),this.version="8.4.38",this.plugins=this.normalize(e)}var t=e.prototype;return t.normalize=function(e){for(var t,r=[],n=d_(e);!(t=n()).done;){var o=t.value;if(!0===o.postcss?o=o():o.postcss&&(o=o.postcss),"object"===(void 0===o?"undefined":c_(o))&&Array.isArray(o.plugins))r=r.concat(o.plugins);else if("object"===(void 0===o?"undefined":c_(o))&&o.postcssPlugin)r.push(o);else if("function"==typeof o)r.push(o);else{if("object"!==(void 0===o?"undefined":c_(o))||!o.parse&&!o.stringify)throw new Error(o+" is not a PostCSS plugin");if(true)throw new Error("PostCSS syntaxes cannot be used as plugins. Instead, please use one of the syntax/parser/stringifier options as outlined in your PostCSS runner documentation.")}}return r},t.process=function(e,t){return void 0===t&&(t={}),this.plugins.length||t.parser||t.stringifier||t.syntax?new JR(this,e,t):new XR(this,e,t)},t.use=function(e){return this.plugins=this.plugins.concat(this.normalize([e])),this},e}(),rI=tI;tI.default=tI,eI.registerProcessor(tI),QR.registerProcessor(tI);var nI=_E,oI=IE,iI=iT,sI=eR,aI=WE,lI=iR,cI=pR;function uI(e,t){if(Array.isArray(e))return e.map(function(e){return uI(e)});var r=e.inputs,n=a_(e,["inputs"]);if(r){t=[];for(var o,i=d_(r);!(o=i()).done;){var s=n_({},o.value,{__proto__:aI.prototype});s.map&&(s.map=n_({},s.map,{__proto__:oI.prototype})),t.push(s)}}if(n.nodes&&(n.nodes=e.nodes.map(function(e){return uI(e,t)})),n.source){var a=n.source,l=a.inputId,c=a_(a,["inputId"]);n.source=c,null!=l&&(n.source.input=t[l])}if("root"===n.type)return new lI(n);if("decl"===n.type)return new nI(n);if("rule"===n.type)return new cI(n);if("comment"===n.type)return new iI(n);if("atrule"===n.type)return new sI(n);throw new Error("Unknown node type: "+e.type)}var pI=uI;uI.default=uI;var dI=iE,fI=_E,hI=UR,mI=vT,gI=rI,vI=dE,yI=pI,bI=xT,wI=CT,xI=iT,_I=eR,SI=TT,kI=WE,CI=SR,OI=aR,EI=pR,TI=iR,RI=wE;function II(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];return 1===t.length&&Array.isArray(t[0])&&(t=t[0]),new gI(t)}II.plugin=function(e,t){var r,n=!1;function o(){for(var r=arguments.length,o=new Array(r),i=0;i<r;i++)o[i]=arguments[i];console&&console.warn&&!n&&(n=!0,console.warn(e+": postcss.plugin was deprecated. Migration guide:\nhttps://evilmartians.com/chronicles/postcss-8-plugin-migration"),process.env.LANG&&process.env.LANG.startsWith("cn")&&console.warn(e+": 里面 postcss.plugin 被弃用. 迁移指南:\nhttps://www.w3ctech.com/topic/2226"));var s=t.apply(void 0,[].concat(o));return s.postcssPlugin=e,s.postcssVersion=(new gI).version,s}return Object.defineProperty(o,"postcss",{get:function(){return r||(r=o()),r}}),o.process=function(e,t,r){return II([o(r)]).process(e,t)},o},II.stringify=vI,II.parse=CI,II.fromJSON=yI,II.list=OI,II.comment=function(e){return new xI(e)},II.atRule=function(e){return new _I(e)},II.decl=function(e){return new fI(e)},II.rule=function(e){return new EI(e)},II.root=function(e){return new TI(e)},II.document=function(e){return new bI(e)},II.CssSyntaxError=dI,II.Declaration=fI,II.Container=mI,II.Processor=gI,II.Document=bI,II.Comment=xI,II.Warning=wI,II.AtRule=_I,II.Result=SI,II.Input=kI,II.Rule=EI,II.Root=TI,II.Node=RI,hI.registerPostcss(II),II.default=II;var MI=function(){function e(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];YO(this,"parentElement",null),YO(this,"parentNode",null),YO(this,"ownerDocument"),YO(this,"firstChild",null),YO(this,"lastChild",null),YO(this,"previousSibling",null),YO(this,"nextSibling",null),YO(this,"ELEMENT_NODE",1),YO(this,"TEXT_NODE",3),YO(this,"nodeType"),YO(this,"nodeName"),YO(this,"RRNodeType")}var t=e.prototype;return t.contains=function(t){if(!s_(t,e))return!1;if(t.ownerDocument!==this.ownerDocument)return!1;if(t===this)return!0;for(;t.parentNode;){if(t.parentNode===this)return!0;t=t.parentNode}return!1},t.appendChild=function(e){throw new Error("RRDomException: Failed to execute 'appendChild' on 'RRNode': This RRNode type does not support this method.")},t.insertBefore=function(e,t){throw new Error("RRDomException: Failed to execute 'insertBefore' on 'RRNode': This RRNode type does not support this method.")},t.removeChild=function(e){throw new Error("RRDomException: Failed to execute 'removeChild' on 'RRNode': This RRNode type does not support this method.")},t.toString=function(){return"RRNode"},r_(e,[{key:"childNodes",get:function(){for(var e=[],t=this.firstChild;t;)e.push(t),t=t.nextSibling;return e}}]),e}(),AI={Node:["childNodes","parentNode","parentElement","textContent"],ShadowRoot:["host","styleSheets"],Element:["shadowRoot","querySelector","querySelectorAll"],MutationObserver:[]},PI={Node:["contains","getRootNode"],ShadowRoot:["getSelection"],Element:[],MutationObserver:["constructor"]},NI={};function jI(e){if(NI[e])return NI[e];var t=globalThis[e],r=t.prototype,n=e in AI?AI[e]:void 0,o=Boolean(n&&n.every(function(e){var t,n;return Boolean(null==(n=null==(t=Object.getOwnPropertyDescriptor(r,e))?void 0:t.get)?void 0:n.toString().includes("[native code]"))})),i=e in PI?PI[e]:void 0,s=Boolean(i&&i.every(function(e){var t;return"function"==typeof r[e]&&(null==(t=r[e])?void 0:t.toString().includes("[native code]"))}));if(o&&s&&!globalThis.Zone)return NI[e]=t.prototype,t.prototype;try{var a=document.createElement("iframe");document.body.appendChild(a);var l=a.contentWindow;if(!l)return t.prototype;var c=l[e].prototype;return document.body.removeChild(a),c?NI[e]=c:r}catch(e){return r}}var LI={};function DI(e,t,r){var n,o=e+"."+String(r);if(LI[o])return LI[o].call(t);var i=jI(e),s=null==(n=Object.getOwnPropertyDescriptor(i,r))?void 0:n.get;return s?(LI[o]=s,s.call(t)):t[r]}var FI={};function $I(e,t,r){var n=e+"."+String(r);if(FI[n])return FI[n].bind(t);var o=jI(e)[r];return"function"!=typeof o?t[r]:(FI[n]=o,o.bind(t))}function BI(){return jI("MutationObserver").constructor}function zI(e,t,r){try{if(!(t in e))return function(){};var n=e[t],o=r(n);return"function"==typeof o&&(o.prototype=o.prototype||{},Object.defineProperties(o,{__rrweb_original__:{enumerable:!1,value:n}})),e[t]=o,function(){e[t]=n}}catch(e){return function(){}}}var VI=function(e){return DI("Node",e,"childNodes")},UI=function(e){return DI("Node",e,"parentNode")},qI=function(e){return DI("Node",e,"parentElement")},WI=function(e){return DI("Node",e,"textContent")},HI=function(e,t){return $I("Node",e,"contains")(t)},GI=function(e){return $I("Node",e,"getRootNode")()},KI=function(e){return e&&"host"in e?DI("ShadowRoot",e,"host"):null},YI=function(e){return e&&"shadowRoot"in e?DI("Element",e,"shadowRoot"):null};function ZI(e,t,r){void 0===r&&(r=document);var n={capture:!0,passive:!0};return r.addEventListener(e,t,n),function(){return r.removeEventListener(e,t,n)}}var XI="Please stop import mirror directly. Instead of that,\r\nnow you can use replayer.getMirror() to access the mirror instance of a replayer,\r\nor you can use record.mirror to access the mirror instance during recording.",JI={map:{},getId:function(){return console.error(XI),-1},getNode:function(){return console.error(XI),null},removeNodeFromMap:function(){console.error(XI)},has:function(){return console.error(XI),!1},reset:function(){console.error(XI)}};function QI(e,t,r){void 0===r&&(r={});var n=null,o=0;return function(){for(var i=arguments.length,s=new Array(i),a=0;a<i;a++)s[a]=arguments[a];var l=Date.now();o||!1!==r.leading||(o=l);var c=t-(l-o),u=this;c<=0||c>t?(n&&(clearTimeout(n),n=null),o=l,e.apply(u,s)):n||!1===r.trailing||(n=setTimeout(function(){o=!1===r.leading?0:Date.now(),n=null,e.apply(u,s)},c))}}function eM(e,t,r,n,o){void 0===o&&(o=window);var i=o.Object.getOwnPropertyDescriptor(e,t);return o.Object.defineProperty(e,t,n?r:{set:function(e){var t=this;setTimeout(function(){r.set.call(t,e)},0),i&&i.set&&i.set.call(this,e)}}),function(){return eM(e,t,i||{},!0)}}"undefined"!=typeof window&&window.Proxy&&window.Reflect&&(JI=new Proxy(JI,{get:function(e,t,r){return"map"===t&&console.error(XI),Reflect.get(e,t,r)}}));var tM=Date.now;function rM(e){var t,r,n,o,i=e.document;return{left:i.scrollingElement?i.scrollingElement.scrollLeft:void 0!==e.pageXOffset?e.pageXOffset:i.documentElement.scrollLeft||(null==i?void 0:i.body)&&(null==(t=qI(i.body))?void 0:t.scrollLeft)||(null==(r=null==i?void 0:i.body)?void 0:r.scrollLeft)||0,top:i.scrollingElement?i.scrollingElement.scrollTop:void 0!==e.pageYOffset?e.pageYOffset:(null==i?void 0:i.documentElement.scrollTop)||(null==i?void 0:i.body)&&(null==(n=qI(i.body))?void 0:n.scrollTop)||(null==(o=null==i?void 0:i.body)?void 0:o.scrollTop)||0}}function nM(){return window.innerHeight||document.documentElement&&document.documentElement.clientHeight||document.body&&document.body.clientHeight}function oM(){return window.innerWidth||document.documentElement&&document.documentElement.clientWidth||document.body&&document.body.clientWidth}function iM(e){return e?e.nodeType===e.ELEMENT_NODE?e:qI(e):null}function sM(e,t,r,n){if(!e)return!1;var o=iM(e);if(!o)return!1;try{if("string"==typeof t){if(o.classList.contains(t))return!0;if(n&&null!==o.closest("."+t))return!0}else if(lS(o,t,n))return!0}catch(e){}if(r){if(o.matches(r))return!0;if(n&&null!==o.closest(r))return!0}return!1}function aM(e,t,r){return!("TITLE"!==e.tagName||!r.headTitleMutations)||-2===t.getId(e)}function lM(e,t){if(N_(e))return!1;var r=t.getId(e);if(!t.has(r))return!0;var n=UI(e);return(!n||n.nodeType!==e.DOCUMENT_NODE)&&(!n||lM(n,t))}function cM(e){return Boolean(e.changedTouches)}function uM(e,t){return Boolean("IFRAME"===e.nodeName&&t.getMeta(e))}function pM(e,t){return Boolean("LINK"===e.nodeName&&e.nodeType===e.ELEMENT_NODE&&e.getAttribute&&"stylesheet"===e.getAttribute("rel")&&t.getMeta(e))}function dM(e){return!!e&&(s_(e,MI)&&"shadowRoot"in e?Boolean(e.shadowRoot):Boolean(YI(e)))}/[1-9][0-9]{12}/.test(Date.now().toString())||(tM=function(){return(new Date).getTime()});var fM=function(){function e(){v_(this,"id",1),v_(this,"styleIDMap",new WeakMap),v_(this,"idStyleMap",new Map)}var t=e.prototype;return t.getId=function(e){var t;return null!=(t=this.styleIDMap.get(e))?t:-1},t.has=function(e){return this.styleIDMap.has(e)},t.add=function(e,t){return this.has(e)?this.getId(e):(r=void 0===t?this.id++:t,this.styleIDMap.set(e,r),this.idStyleMap.set(r,e),r);// removed by dead control flow
 var r; },t.getStyle=function(e){return this.idStyleMap.get(e)||null},t.reset=function(){this.styleIDMap=new WeakMap,this.idStyleMap=new Map,this.id=1},t.generateId=function(){return this.id++},t.remove=function(e){var t=this.styleIDMap.get(e);return void 0!==t&&(this.styleIDMap.delete(e),this.idStyleMap.delete(t),!0)},e}();function hM(e){var t,r=null;return"getRootNode"in e&&(null==(t=GI(e))?void 0:t.nodeType)===Node.DOCUMENT_FRAGMENT_NODE&&KI(GI(e))&&(r=KI(GI(e))),r}function mM(e){var t=e.ownerDocument;return!!t&&(HI(t,e)||function(e){var t=e.ownerDocument;if(!t)return!1;var r=function(e){for(var t,r=e;t=hM(r);)r=t;return r}(e);return HI(t,r)}(e))}var gM=function(e){return e[e.DomContentLoaded=0]="DomContentLoaded",e[e.Load=1]="Load",e[e.FullSnapshot=2]="FullSnapshot",e[e.IncrementalSnapshot=3]="IncrementalSnapshot",e[e.Meta=4]="Meta",e[e.Custom=5]="Custom",e[e.Plugin=6]="Plugin",e}(gM||{}),vM=function(e){return e[e.Mutation=0]="Mutation",e[e.MouseMove=1]="MouseMove",e[e.MouseInteraction=2]="MouseInteraction",e[e.Scroll=3]="Scroll",e[e.ViewportResize=4]="ViewportResize",e[e.Input=5]="Input",e[e.TouchMove=6]="TouchMove",e[e.MediaInteraction=7]="MediaInteraction",e[e.StyleSheetRule=8]="StyleSheetRule",e[e.CanvasMutation=9]="CanvasMutation",e[e.Font=10]="Font",e[e.Log=11]="Log",e[e.Drag=12]="Drag",e[e.StyleDeclaration=13]="StyleDeclaration",e[e.Selection=14]="Selection",e[e.AdoptedStyleSheet=15]="AdoptedStyleSheet",e[e.CustomElement=16]="CustomElement",e}(vM||{}),yM=function(e){return e[e.MouseUp=0]="MouseUp",e[e.MouseDown=1]="MouseDown",e[e.Click=2]="Click",e[e.ContextMenu=3]="ContextMenu",e[e.DblClick=4]="DblClick",e[e.Focus=5]="Focus",e[e.Blur=6]="Blur",e[e.TouchStart=7]="TouchStart",e[e.TouchMove_Departed=8]="TouchMove_Departed",e[e.TouchEnd=9]="TouchEnd",e[e.TouchCancel=10]="TouchCancel",e}(yM||{}),bM=function(e){return e[e.Mouse=0]="Mouse",e[e.Pen=1]="Pen",e[e.Touch=2]="Touch",e}(bM||{}),wM=function(e){return e[e["2D"]=0]="2D",e[e.WebGL=1]="WebGL",e[e.WebGL2=2]="WebGL2",e}(wM||{}),xM=function(e){return e[e.Play=0]="Play",e[e.Pause=1]="Pause",e[e.Seeked=2]="Seeked",e[e.VolumeChange=3]="VolumeChange",e[e.RateChange=4]="RateChange",e}(xM||{}),_M=function(e){return e[e.Document=0]="Document",e[e.DocumentType=1]="DocumentType",e[e.Element=2]="Element",e[e.Text=3]="Text",e[e.CDATA=4]="CDATA",e[e.Comment=5]="Comment",e}(_M||{});function SM(e){return"__ln"in e}var kM,CM=function(){function e(){v_(this,"length",0),v_(this,"head",null),v_(this,"tail",null)}var t=e.prototype;return t.get=function(e){if(e>=this.length)throw new Error("Position outside of list range");for(var t=this.head,r=0;r<e;r++)t=(null==t?void 0:t.next)||null;return t},t.addNode=function(e){var t={value:e,previous:null,next:null};if(e.__ln=t,e.previousSibling&&SM(e.previousSibling)){var r=e.previousSibling.__ln.next;t.next=r,t.previous=e.previousSibling.__ln,e.previousSibling.__ln.next=t,r&&(r.previous=t)}else if(e.nextSibling&&SM(e.nextSibling)&&e.nextSibling.__ln.previous){var n=e.nextSibling.__ln.previous;t.previous=n,t.next=e.nextSibling.__ln,e.nextSibling.__ln.previous=t,n&&(n.next=t)}else this.head&&(this.head.previous=t),t.next=this.head,this.head=t;null===t.next&&(this.tail=t),this.length++},t.removeNode=function(e){var t=e.__ln;this.head&&(t.previous?(t.previous.next=t.next,t.next?t.next.previous=t.previous:this.tail=t.previous):(this.head=t.next,this.head?this.head.previous=null:this.tail=null),e.__ln&&delete e.__ln,this.length--)},e}(),OM=function(e,t){return e+"@"+t},EM=function(){function e(){var e=this;v_(this,"frozen",!1),v_(this,"locked",!1),v_(this,"texts",[]),v_(this,"attributes",[]),v_(this,"attributeMap",new WeakMap),v_(this,"removes",[]),v_(this,"mapRemoves",[]),v_(this,"movedMap",{}),v_(this,"addedSet",new Set),v_(this,"movedSet",new Set),v_(this,"droppedSet",new Set),v_(this,"removesSubTreeCache",new Set),v_(this,"mutationCb"),v_(this,"blockClass"),v_(this,"blockSelector"),v_(this,"maskTextClass"),v_(this,"maskTextSelector"),v_(this,"inlineStylesheet"),v_(this,"maskInputOptions"),v_(this,"maskTextFn"),v_(this,"maskInputFn"),v_(this,"keepIframeSrcFn"),v_(this,"recordCanvas"),v_(this,"inlineImages"),v_(this,"slimDOMOptions"),v_(this,"dataURLOptions"),v_(this,"doc"),v_(this,"mirror"),v_(this,"iframeManager"),v_(this,"stylesheetManager"),v_(this,"shadowDomManager"),v_(this,"canvasManager"),v_(this,"processedNodeManager"),v_(this,"unattachedDoc"),v_(this,"processMutations",function(t){t.forEach(e.processMutation),e.emit()}),v_(this,"emit",function(){if(!e.frozen&&!e.locked){for(var t=[],r=new Set,n=new CM,o=function(t){for(var r=t,n=-2;-2===n;)n=(r=r&&r.nextSibling)&&e.mirror.getId(r);return n},i=function(i){var s=UI(i);if(s&&mM(i)){var a=!1;if(i.nodeType===Node.TEXT_NODE){var l=s.tagName;if("TEXTAREA"===l)return;"STYLE"===l&&e.addedSet.has(s)&&(a=!0)}var c=N_(s)?e.mirror.getId(hM(i)):e.mirror.getId(s),u=o(i);if(-1===c||-1===u)return n.addNode(i);var p=dS(i,{doc:e.doc,mirror:e.mirror,blockClass:e.blockClass,blockSelector:e.blockSelector,maskTextClass:e.maskTextClass,maskTextSelector:e.maskTextSelector,skipChild:!0,newlyAddedElement:!0,inlineStylesheet:e.inlineStylesheet,maskInputOptions:e.maskInputOptions,maskTextFn:e.maskTextFn,maskInputFn:e.maskInputFn,slimDOMOptions:e.slimDOMOptions,dataURLOptions:e.dataURLOptions,recordCanvas:e.recordCanvas,inlineImages:e.inlineImages,onSerialize:function(t){uM(t,e.mirror)&&e.iframeManager.addIframe(t),pM(t,e.mirror)&&e.stylesheetManager.trackLinkElement(t),dM(i)&&e.shadowDomManager.addShadowRoot(YI(i),e.doc)},onIframeLoad:function(t,r){e.iframeManager.attachIframe(t,r),e.shadowDomManager.observeAttachShadow(t)},onStylesheetLoad:function(t,r){e.stylesheetManager.attachLinkElement(t,r)},cssCaptured:a});p&&(t.push({parentId:c,nextId:u,node:p}),r.add(p.id))}};e.mapRemoves.length;){var s=e.mapRemoves.shift();e.cleanupRemovedNode(s),e.mirror.removeNodeFromMap(s)}for(var a,l=d_(e.movedSet);!(a=l()).done;){var c=a.value;RM(e.removesSubTreeCache,c)&&!e.movedSet.has(UI(c))||i(c)}for(var u,p=d_(e.addedSet);!(u=p()).done;){var d=u.value;IM(e.droppedSet,d)||RM(e.removesSubTreeCache,d)?IM(e.movedSet,d)?i(d):e.droppedSet.add(d):i(d)}for(var f=null;n.length;){var h=null;if(f){var m=e.mirror.getId(UI(f.value)),g=o(f.value);-1!==m&&-1!==g&&(h=f)}if(!h)for(var v=n.tail;v;){var y=v;if(v=v.previous,y){var b=e.mirror.getId(UI(y.value));if(-1===o(y.value))continue;if(-1!==b){h=y;break}var w=y.value,x=UI(w);if(x&&x.nodeType===Node.DOCUMENT_FRAGMENT_NODE){var _=KI(x);if(-1!==e.mirror.getId(_)){h=y;break}}}}if(!h){for(;n.head;)n.removeNode(n.head.value);break}f=h.previous,n.removeNode(h.value),i(h.value)}var S={texts:e.texts.map(function(t){var r=t.node,n=UI(r);return n&&"TEXTAREA"===n.tagName&&e.genTextAreaValueMutation(n),{id:e.mirror.getId(r),value:t.value}}).filter(function(e){return!r.has(e.id)}).filter(function(t){return e.mirror.has(t.id)}),attributes:e.attributes.map(function(t){var r=t.attributes;if("string"==typeof r.style){var n=JSON.stringify(t.styleDiff),o=JSON.stringify(t._unchangedStyles);n.length<r.style.length&&(n+o).split("var(").length===r.style.split("var(").length&&(r.style=t.styleDiff)}return{id:e.mirror.getId(t.node),attributes:r}}).filter(function(e){return!r.has(e.id)}).filter(function(t){return e.mirror.has(t.id)}),removes:e.removes,adds:t};(S.texts.length||S.attributes.length||S.removes.length||S.adds.length)&&(e.texts=[],e.attributes=[],e.attributeMap=new WeakMap,e.removes=[],e.addedSet=new Set,e.movedSet=new Set,e.droppedSet=new Set,e.removesSubTreeCache=new Set,e.movedMap={},e.mutationCb(S))}}),v_(this,"genTextAreaValueMutation",function(t){var r=e.attributeMap.get(t);r||(r={node:t,attributes:{},styleDiff:{},_unchangedStyles:{}},e.attributes.push(r),e.attributeMap.set(t,r));var n=Array.from(VI(t),function(e){return WI(e)||""}).join("");r.attributes.value=$_({element:t,maskInputOptions:e.maskInputOptions,tagName:t.tagName,type:V_(t),value:n,maskInputFn:e.maskInputFn})}),v_(this,"processMutation",function(t){if(!aM(t.target,e.mirror,e.slimDOMOptions))switch(t.type){case"characterData":var r=WI(t.target);sM(t.target,e.blockClass,e.blockSelector,!1)||r===t.oldValue||e.texts.push({value:cS(t.target,e.maskTextClass,e.maskTextSelector,!0)&&r?e.maskTextFn?e.maskTextFn(r,iM(t.target)):r.replace(/[\S]/g,"*"):r,node:t.target});break;case"attributes":var n=t.target,o=t.attributeName,i=t.target.getAttribute(o);if("value"===o){var s=V_(n);i=$_({element:n,maskInputOptions:e.maskInputOptions,tagName:n.tagName,type:s,value:i,maskInputFn:e.maskInputFn})}if(sM(t.target,e.blockClass,e.blockSelector,!1)||i===t.oldValue)return;var a=e.attributeMap.get(t.target);if("IFRAME"===n.tagName&&"src"===o&&!e.keepIframeSrcFn(i)){if(n.contentDocument)return;o="rr_src"}if(a||(a={node:t.target,attributes:{},styleDiff:{},_unchangedStyles:{}},e.attributes.push(a),e.attributeMap.set(t.target,a)),"type"===o&&"INPUT"===n.tagName&&"password"===(t.oldValue||"").toLowerCase()&&n.setAttribute("data-rr-is-password","true"),!aS(n.tagName,o))if(a.attributes[o]=sS(e.doc,B_(n.tagName),B_(o),i),"style"===o){if(!e.unattachedDoc)try{e.unattachedDoc=document.implementation.createHTMLDocument()}catch(t){e.unattachedDoc=e.doc}var l=e.unattachedDoc.createElement("span");t.oldValue&&l.setAttribute("style",t.oldValue);for(var c,u=d_(Array.from(n.style));!(c=u()).done;){var p=c.value,d=n.style.getPropertyValue(p),f=n.style.getPropertyPriority(p);d!==l.style.getPropertyValue(p)||f!==l.style.getPropertyPriority(p)?a.styleDiff[p]=""===f?d:[d,f]:a._unchangedStyles[p]=[d,f]}for(var h,m=d_(Array.from(l.style));!(h=m()).done;){var g=h.value;""===n.style.getPropertyValue(g)&&(a.styleDiff[g]=!1)}}else"open"===o&&"DIALOG"===n.tagName&&(n.matches("dialog:modal")?a.attributes.rr_open_mode="modal":a.attributes.rr_open_mode="non-modal");break;case"childList":if(sM(t.target,e.blockClass,e.blockSelector,!0))return;if("TEXTAREA"===t.target.tagName)return void e.genTextAreaValueMutation(t.target);t.addedNodes.forEach(function(r){return e.genAdds(r,t.target)}),t.removedNodes.forEach(function(r){var n=e.mirror.getId(r),o=N_(t.target)?e.mirror.getId(KI(t.target)):e.mirror.getId(t.target);sM(t.target,e.blockClass,e.blockSelector,!1)||aM(r,e.mirror,e.slimDOMOptions)||!function(e,t){return-1!==t.getId(e)}(r,e.mirror)||(e.addedSet.has(r)?(TM(e.addedSet,r),e.droppedSet.add(r)):e.addedSet.has(t.target)&&-1===n||lM(t.target,e.mirror)||(e.movedSet.has(r)&&e.movedMap[OM(n,o)]?TM(e.movedSet,r):(e.removes.push({parentId:o,id:n,isShadow:!(!N_(t.target)||!j_(t.target))||void 0}),function(e,t){for(var r=[e];r.length;){var n=r.pop();t.has(n)||(t.add(n),VI(n).forEach(function(e){return r.push(e)}))}}(r,e.removesSubTreeCache))),e.mapRemoves.push(r))})}}),v_(this,"genAdds",function(t,r){if(!e.processedNodeManager.inOtherBuffer(t,e)&&!e.addedSet.has(t)&&!e.movedSet.has(t)){if(e.mirror.hasNode(t)){if(aM(t,e.mirror,e.slimDOMOptions))return;e.movedSet.add(t);var n=null;r&&e.mirror.hasNode(r)&&(n=e.mirror.getId(r)),n&&-1!==n&&(e.movedMap[OM(e.mirror.getId(t),n)]=!0)}else e.addedSet.add(t),e.droppedSet.delete(t);sM(t,e.blockClass,e.blockSelector,!1)||(VI(t).forEach(function(t){return e.genAdds(t)}),dM(t)&&VI(YI(t)).forEach(function(r){e.processedNodeManager.add(r,e),e.genAdds(r,t)}))}}),v_(this,"cleanupRemovedNode",function(t){if("IFRAME"===t.nodeName)try{e.iframeManager.removeIframe(t)}catch(e){}else try{e.stylesheetManager.cleanupStylesheetsForRemovedNode(t)}catch(e){}t.childNodes.forEach(function(t){e.cleanupRemovedNode(t)})})}var t=e.prototype;return t.init=function(e){var t=this;["mutationCb","blockClass","blockSelector","maskTextClass","maskTextSelector","inlineStylesheet","maskInputOptions","maskTextFn","maskInputFn","keepIframeSrcFn","recordCanvas","inlineImages","slimDOMOptions","dataURLOptions","doc","mirror","iframeManager","stylesheetManager","shadowDomManager","canvasManager","processedNodeManager"].forEach(function(r){t[r]=e[r]})},t.freeze=function(){this.frozen=!0,this.canvasManager.freeze()},t.unfreeze=function(){this.frozen=!1,this.canvasManager.unfreeze(),this.emit()},t.isFrozen=function(){return this.frozen},t.lock=function(){this.locked=!0,this.canvasManager.lock()},t.unlock=function(){this.locked=!1,this.canvasManager.unlock(),this.emit()},t.reset=function(){this.shadowDomManager.reset(),this.canvasManager.reset()},t.getDoc=function(){return this.doc},e}();function TM(e,t){e.delete(t),VI(t).forEach(function(t){return TM(e,t)})}function RM(e,t,r){return 0!==e.size&&function(e,t){var r=UI(t);return!!r&&e.has(r)}(e,t)}function IM(e,t){return 0!==e.size&&MM(e,t)}function MM(e,t){var r=UI(t);return!!r&&(!!e.has(r)||MM(e,r))}var AM=function(e){return kM?function(){for(var t=arguments.length,r=new Array(t),n=0;n<t;n++)r[n]=arguments[n];try{return e.apply(void 0,[].concat(r))}catch(e){if(kM&&!0===kM(e))return;throw e}}:e},PM=[];function NM(e){try{if("composedPath"in e){var t=e.composedPath();if(t.length)return t[0]}else if("path"in e&&e.path.length)return e.path[0]}catch(e){}return e&&e.target}function jM(e,t){var r=new EM;PM.push(r),r.init(e);var n=new(BI())(AM(r.processMutations.bind(r)));return n.observe(t,{attributes:!0,attributeOldValue:!0,characterData:!0,characterDataOldValue:!0,childList:!0,subtree:!0}),n}function LM(e){var t=e.scrollCb,r=e.doc,n=e.mirror,o=e.blockClass,i=e.blockSelector,s=e.sampling,a=AM(QI(AM(function(e){var s=NM(e);if(s&&!sM(s,o,i,!0)){var a=n.getId(s);if(s===r&&r.defaultView){var l=rM(r.defaultView);t({id:a,x:l.left,y:l.top})}else t({id:a,x:s.scrollLeft,y:s.scrollTop})}}),s.scroll||100));return ZI("scroll",a,r)}var DM=["INPUT","TEXTAREA","SELECT"],FM=new WeakMap;function $M(e){return function(e,t){if(UM("CSSGroupingRule")&&s_(e.parentRule,CSSGroupingRule)||UM("CSSMediaRule")&&s_(e.parentRule,CSSMediaRule)||UM("CSSSupportsRule")&&s_(e.parentRule,CSSSupportsRule)||UM("CSSConditionRule")&&s_(e.parentRule,CSSConditionRule)){var r=Array.from(e.parentRule.cssRules).indexOf(e);t.unshift(r)}else if(e.parentStyleSheet){var n=Array.from(e.parentStyleSheet.cssRules).indexOf(e);t.unshift(n)}return t}(e,[])}function BM(e,t,r){var n,o;return e?(e.ownerNode?n=t.getId(e.ownerNode):o=r.getId(e),{styleId:o,id:n}):{}}function zM(e,t){var r,n,o,i,s=e.mirror,a=e.stylesheetManager;i="#document"===t.nodeName?s.getId(t):s.getId(KI(t));var l="#document"===t.nodeName?null==(r=t.defaultView)?void 0:r.Document:null==(o=null==(n=t.ownerDocument)?void 0:n.defaultView)?void 0:o.ShadowRoot,c=(null==l?void 0:l.prototype)?Object.getOwnPropertyDescriptor(null==l?void 0:l.prototype,"adoptedStyleSheets"):void 0;return null!==i&&-1!==i&&l&&c?(Object.defineProperty(t,"adoptedStyleSheets",{configurable:c.configurable,enumerable:c.enumerable,get:function(){var e;return null==(e=c.get)?void 0:e.call(this)},set:function(e){var t,r=null==(t=c.set)?void 0:t.call(this,e);if(null!==i&&-1!==i)try{a.adoptStyleSheets(e,i)}catch(e){}return r}}),AM(function(){Object.defineProperty(t,"adoptedStyleSheets",{configurable:c.configurable,enumerable:c.enumerable,get:c.get,set:c.set})})):function(){}}function VM(e,t){void 0===t&&(t={});var r,n=e.doc.defaultView;if(!n)return function(){};!function(e,t){var r=e.mutationCb,n=e.mousemoveCb,o=e.mouseInteractionCb,i=e.scrollCb,s=e.viewportResizeCb,a=e.inputCb,l=e.mediaInteractionCb,c=e.styleSheetRuleCb,u=e.styleDeclarationCb,p=e.canvasMutationCb,d=e.fontCb,f=e.selectionCb,h=e.customElementCb;e.mutationCb=function(){for(var e=arguments.length,n=new Array(e),o=0;o<e;o++)n[o]=arguments[o];var i;t.mutation&&(i=t).mutation.apply(i,[].concat(n)),r.apply(void 0,[].concat(n))},e.mousemoveCb=function(){for(var e=arguments.length,r=new Array(e),o=0;o<e;o++)r[o]=arguments[o];var i;t.mousemove&&(i=t).mousemove.apply(i,[].concat(r)),n.apply(void 0,[].concat(r))},e.mouseInteractionCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i;t.mouseInteraction&&(i=t).mouseInteraction.apply(i,[].concat(r)),o.apply(void 0,[].concat(r))},e.scrollCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.scroll&&(o=t).scroll.apply(o,[].concat(r)),i.apply(void 0,[].concat(r))},e.viewportResizeCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.viewportResize&&(o=t).viewportResize.apply(o,[].concat(r)),s.apply(void 0,[].concat(r))},e.inputCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.input&&(o=t).input.apply(o,[].concat(r)),a.apply(void 0,[].concat(r))},e.mediaInteractionCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.mediaInteaction&&(o=t).mediaInteaction.apply(o,[].concat(r)),l.apply(void 0,[].concat(r))},e.styleSheetRuleCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.styleSheetRule&&(o=t).styleSheetRule.apply(o,[].concat(r)),c.apply(void 0,[].concat(r))},e.styleDeclarationCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.styleDeclaration&&(o=t).styleDeclaration.apply(o,[].concat(r)),u.apply(void 0,[].concat(r))},e.canvasMutationCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.canvasMutation&&(o=t).canvasMutation.apply(o,[].concat(r)),p.apply(void 0,[].concat(r))},e.fontCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.font&&(o=t).font.apply(o,[].concat(r)),d.apply(void 0,[].concat(r))},e.selectionCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.selection&&(o=t).selection.apply(o,[].concat(r)),f.apply(void 0,[].concat(r))},e.customElementCb=function(){for(var e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var o;t.customElement&&(o=t).customElement.apply(o,[].concat(r)),h.apply(void 0,[].concat(r))}}(e,t),e.recordDOM&&(r=jM(e,e.doc));var o,i,s,a,l,c,u,p,d,f=function(e){var t=e.mousemoveCb,r=e.sampling,n=e.doc,o=e.mirror;if(!1===r.mousemove)return function(){};var i,s="number"==typeof r.mousemove?r.mousemove:50,a="number"==typeof r.mousemoveCallback?r.mousemoveCallback:500,l=[],c=QI(AM(function(e){var r=Date.now()-i;t(l.map(function(e){return e.timeOffset-=r,e}),e),l=[],i=null}),a),u=AM(QI(AM(function(e){var t=NM(e),r=cM(e)?e.changedTouches[0]:e,n=r.clientX,s=r.clientY;i||(i=tM()),l.push({x:n,y:s,id:o.getId(t),timeOffset:tM()-i}),c("undefined"!=typeof DragEvent&&s_(e,DragEvent)?vM.Drag:s_(e,MouseEvent)?vM.MouseMove:vM.TouchMove)}),s,{trailing:!1})),p=[ZI("mousemove",u,n),ZI("touchmove",u,n),ZI("drag",u,n)];return AM(function(){p.forEach(function(e){return e()})})}(e),h=function(e){var t=e.mouseInteractionCb,r=e.doc,n=e.mirror,o=e.blockClass,i=e.blockSelector,s=e.sampling;if(!1===s.mouseInteraction)return function(){};var a=!0===s.mouseInteraction||void 0===s.mouseInteraction?{}:s.mouseInteraction,l=[],c=null;return Object.keys(yM).filter(function(e){return Number.isNaN(Number(e))&&!e.endsWith("_Departed")&&!1!==a[e]}).forEach(function(e){var s=B_(e),a=function(e){return function(r){var s=NM(r);if(!sM(s,o,i,!0)){var a=null,l=e;if("pointerType"in r){switch(r.pointerType){case"mouse":a=bM.Mouse;break;case"touch":a=bM.Touch;break;case"pen":a=bM.Pen}a===bM.Touch&&(yM[e]===yM.MouseDown?l="TouchStart":yM[e]===yM.MouseUp&&(l="TouchEnd"))}else cM(r)&&(a=bM.Touch);null!==a?(c=a,(l.startsWith("Touch")&&a===bM.Touch||l.startsWith("Mouse")&&a===bM.Mouse)&&(a=null)):yM[e]===yM.Click&&(a=c,c=null);var u=cM(r)?r.changedTouches[0]:r;if(u){var p=n.getId(s),d=u.clientX,f=u.clientY;AM(t)(n_({type:yM[l],id:p,x:d,y:f},null!==a&&{pointerType:a}))}}}}(e);if(window.PointerEvent)switch(yM[e]){case yM.MouseDown:case yM.MouseUp:s=s.replace("mouse","pointer");break;case yM.TouchStart:case yM.TouchEnd:return}l.push(ZI(s,a,r))}),AM(function(){l.forEach(function(e){return e()})})}(e),m=LM(e),g=function(e,t){var r=e.viewportResizeCb,n=t.win,o=-1,i=-1,s=AM(QI(AM(function(){var e=nM(),t=oM();o===e&&i===t||(r({width:Number(t),height:Number(e)}),o=e,i=t)}),200));return ZI("resize",s,n)}(e,{win:n}),v=function(e){var t=e.inputCb,r=e.doc,n=e.mirror,o=e.blockClass,i=e.blockSelector,s=e.ignoreClass,a=e.ignoreSelector,l=e.maskInputOptions,c=e.maskInputFn,u=e.sampling,p=e.userTriggeredOnInput;function d(e){var t=NM(e),n=e.isTrusted,u=t&&t.tagName;if(t&&"OPTION"===u&&(t=qI(t)),t&&u&&!(DM.indexOf(u)<0)&&!sM(t,o,i,!0)&&!(t.classList.contains(s)||a&&t.matches(a))){var d=t.value,h=!1,m=V_(t)||"";"radio"===m||"checkbox"===m?h=t.checked:(l[u.toLowerCase()]||l[m])&&(d=$_({element:t,maskInputOptions:l,tagName:u,type:m,value:d,maskInputFn:c})),f(t,p?{text:d,isChecked:h,userTriggered:n}:{text:d,isChecked:h});var g=t.name;"radio"===m&&g&&h&&r.querySelectorAll('input[type="radio"][name="'+g+'"]').forEach(function(e){if(e!==t){var r=e.value;f(e,p?{text:r,isChecked:!h,userTriggered:!1}:{text:r,isChecked:!h})}})}}function f(e,r){var o=FM.get(e);if(!o||o.text!==r.text||o.isChecked!==r.isChecked){FM.set(e,r);var i=n.getId(e);AM(t)(n_({},r,{id:i}))}}var h=("last"===u.input?["change"]:["input","change"]).map(function(e){return ZI(e,AM(d),r)}),m=r.defaultView;if(!m)return function(){h.forEach(function(e){return e()})};var g,v=m.Object.getOwnPropertyDescriptor(m.HTMLInputElement.prototype,"value"),y=[[m.HTMLInputElement.prototype,"value"],[m.HTMLInputElement.prototype,"checked"],[m.HTMLSelectElement.prototype,"value"],[m.HTMLTextAreaElement.prototype,"value"],[m.HTMLSelectElement.prototype,"selectedIndex"],[m.HTMLOptionElement.prototype,"selected"]];return v&&v.set&&(g=h).push.apply(g,[].concat(y.map(function(e){return eM(e[0],e[1],{set:function(){AM(d)({target:this,isTrusted:!1})}},!1,m)}))),AM(function(){h.forEach(function(e){return e()})})}(e),y=(i=(o=e).mediaInteractionCb,s=o.blockClass,a=o.blockSelector,l=o.mirror,c=o.sampling,u=o.doc,p=AM(function(e){return QI(AM(function(t){var r=NM(t);if(r&&!sM(r,s,a,!0)){var n=r.currentTime,o=r.volume,c=r.muted,u=r.playbackRate,p=r.loop;i({type:e,id:l.getId(r),currentTime:n,volume:o,muted:c,playbackRate:u,loop:p})}}),c.media||500)}),d=[ZI("play",p(xM.Play),u),ZI("pause",p(xM.Pause),u),ZI("seeked",p(xM.Seeked),u),ZI("volumechange",p(xM.VolumeChange),u),ZI("ratechange",p(xM.RateChange),u)],AM(function(){d.forEach(function(e){return e()})})),b=function(){},w=function(){},x=function(){},_=function(){};e.recordDOM&&(b=function(e,t){var r=e.styleSheetRuleCb,n=e.mirror,o=e.stylesheetManager,i=t.win;if(!i.CSSStyleSheet||!i.CSSStyleSheet.prototype)return function(){};var s=i.CSSStyleSheet.prototype.insertRule;i.CSSStyleSheet.prototype.insertRule=new Proxy(s,{apply:AM(function(e,t,i){var s=i[0],a=i[1],l=BM(t,n,o.styleMirror),c=l.id,u=l.styleId;return(c&&-1!==c||u&&-1!==u)&&r({id:c,styleId:u,adds:[{rule:s,index:a}]}),e.apply(t,i)})}),i.CSSStyleSheet.prototype.addRule=function(e,t,r){void 0===r&&(r=this.cssRules.length);var n=e+" { "+t+" }";return i.CSSStyleSheet.prototype.insertRule.apply(this,[n,r])};var a,l,c=i.CSSStyleSheet.prototype.deleteRule;i.CSSStyleSheet.prototype.deleteRule=new Proxy(c,{apply:AM(function(e,t,i){var s=i[0],a=BM(t,n,o.styleMirror),l=a.id,c=a.styleId;return(l&&-1!==l||c&&-1!==c)&&r({id:l,styleId:c,removes:[{index:s}]}),e.apply(t,i)})}),i.CSSStyleSheet.prototype.removeRule=function(e){return i.CSSStyleSheet.prototype.deleteRule.apply(this,[e])},i.CSSStyleSheet.prototype.replace&&(a=i.CSSStyleSheet.prototype.replace,i.CSSStyleSheet.prototype.replace=new Proxy(a,{apply:AM(function(e,t,i){var s=i[0],a=BM(t,n,o.styleMirror),l=a.id,c=a.styleId;return(l&&-1!==l||c&&-1!==c)&&r({id:l,styleId:c,replace:s}),e.apply(t,i)})})),i.CSSStyleSheet.prototype.replaceSync&&(l=i.CSSStyleSheet.prototype.replaceSync,i.CSSStyleSheet.prototype.replaceSync=new Proxy(l,{apply:AM(function(e,t,i){var s=i[0],a=BM(t,n,o.styleMirror),l=a.id,c=a.styleId;return(l&&-1!==l||c&&-1!==c)&&r({id:l,styleId:c,replaceSync:s}),e.apply(t,i)})}));var u={};qM("CSSGroupingRule")?u.CSSGroupingRule=i.CSSGroupingRule:(qM("CSSMediaRule")&&(u.CSSMediaRule=i.CSSMediaRule),qM("CSSConditionRule")&&(u.CSSConditionRule=i.CSSConditionRule),qM("CSSSupportsRule")&&(u.CSSSupportsRule=i.CSSSupportsRule));var p={};return Object.entries(u).forEach(function(e){var t=e[0],i=e[1];p[t]={insertRule:i.prototype.insertRule,deleteRule:i.prototype.deleteRule},i.prototype.insertRule=new Proxy(p[t].insertRule,{apply:AM(function(e,t,i){var s=i[0],a=i[1],l=BM(t.parentStyleSheet,n,o.styleMirror),c=l.id,u=l.styleId;return(c&&-1!==c||u&&-1!==u)&&r({id:c,styleId:u,adds:[{rule:s,index:[].concat($M(t),[a||0])}]}),e.apply(t,i)})}),i.prototype.deleteRule=new Proxy(p[t].deleteRule,{apply:AM(function(e,t,i){var s=i[0],a=BM(t.parentStyleSheet,n,o.styleMirror),l=a.id,c=a.styleId;return(l&&-1!==l||c&&-1!==c)&&r({id:l,styleId:c,removes:[{index:[].concat($M(t),[s])}]}),e.apply(t,i)})})}),AM(function(){i.CSSStyleSheet.prototype.insertRule=s,i.CSSStyleSheet.prototype.deleteRule=c,a&&(i.CSSStyleSheet.prototype.replace=a),l&&(i.CSSStyleSheet.prototype.replaceSync=l),Object.entries(u).forEach(function(e){var t=e[0],r=e[1];r.prototype.insertRule=p[t].insertRule,r.prototype.deleteRule=p[t].deleteRule})})}(e,{win:n}),w=zM(e,e.doc),x=function(e,t){var r=e.styleDeclarationCb,n=e.mirror,o=e.ignoreCSSAttributes,i=e.stylesheetManager,s=t.win,a=s.CSSStyleDeclaration.prototype.setProperty;s.CSSStyleDeclaration.prototype.setProperty=new Proxy(a,{apply:AM(function(e,t,s){var l,c=s[0],u=s[1],p=s[2];if(o.has(c))return a.apply(t,[c,u,p]);var d=BM(null==(l=t.parentRule)?void 0:l.parentStyleSheet,n,i.styleMirror),f=d.id,h=d.styleId;return(f&&-1!==f||h&&-1!==h)&&r({id:f,styleId:h,set:{property:c,value:u,priority:p},index:$M(t.parentRule)}),e.apply(t,s)})});var l=s.CSSStyleDeclaration.prototype.removeProperty;return s.CSSStyleDeclaration.prototype.removeProperty=new Proxy(l,{apply:AM(function(e,t,s){var a,c=s[0];if(o.has(c))return l.apply(t,[c]);var u=BM(null==(a=t.parentRule)?void 0:a.parentStyleSheet,n,i.styleMirror),p=u.id,d=u.styleId;return(p&&-1!==p||d&&-1!==d)&&r({id:p,styleId:d,remove:{property:c},index:$M(t.parentRule)}),e.apply(t,s)})}),AM(function(){s.CSSStyleDeclaration.prototype.setProperty=a,s.CSSStyleDeclaration.prototype.removeProperty=l})}(e,{win:n}),e.collectFonts&&(_=function(e){var t=e.fontCb,r=e.doc,n=r.defaultView;if(!n)return function(){};var o=[],i=new WeakMap,s=n.FontFace;n.FontFace=function(e,t,r){var n=new s(e,t,r);return i.set(n,{family:e,buffer:"string"!=typeof t,descriptors:r,fontSource:"string"==typeof t?t:JSON.stringify(Array.from(new Uint8Array(t)))}),n};var a=zI(r.fonts,"add",function(e){return function(r){return setTimeout(AM(function(){var e=i.get(r);e&&(t(e),i.delete(r))}),0),e.apply(this,[r])}});return o.push(function(){n.FontFace=s}),o.push(a),AM(function(){o.forEach(function(e){return e()})})}(e)));for(var S,k=function(e){var t=e.doc,r=e.mirror,n=e.blockClass,o=e.blockSelector,i=e.selectionCb,s=!0,a=AM(function(){var e=t.getSelection();if(!(!e||s&&(null==e?void 0:e.isCollapsed))){s=e.isCollapsed||!1;for(var a=[],l=e.rangeCount||0,c=0;c<l;c++){var u=e.getRangeAt(c),p=u.startContainer,d=u.startOffset,f=u.endContainer,h=u.endOffset;sM(p,n,o,!0)||sM(f,n,o,!0)||a.push({start:r.getId(p),startOffset:d,end:r.getId(f),endOffset:h})}i({ranges:a})}});return a(),ZI("selectionchange",a)}(e),C=function(e){var t=e.doc,r=e.customElementCb,n=t.defaultView;return n&&n.customElements?zI(n.customElements,"define",function(e){return function(t,n,o){try{r({define:{name:t}})}catch(e){console.warn("Custom element callback failed for "+t)}return e.apply(this,[t,n,o])}}):function(){}}(e),O=[],E=d_(e.plugins);!(S=E()).done;){var T=S.value;O.push(T.observer(T.callback,n,T.options))}return AM(function(){PM.forEach(function(e){return e.reset()}),null==r||r.disconnect(),f(),h(),m(),g(),v(),y(),b(),w(),x(),_(),k(),C(),O.forEach(function(e){return e()})})}function UM(e){return void 0!==window[e]}function qM(e){return Boolean(void 0!==window[e]&&window[e].prototype&&"insertRule"in window[e].prototype&&"deleteRule"in window[e].prototype)}for(var WM=function(){function e(e){v_(this,"iframeIdToRemoteIdMap",new WeakMap),v_(this,"iframeRemoteIdToIdMap",new WeakMap),this.generateIdFn=e}var t=e.prototype;return t.getId=function(e,t,r,n){var o=r||this.getIdToRemoteIdMap(e),i=n||this.getRemoteIdToIdMap(e),s=o.get(t);return s||(s=this.generateIdFn(),o.set(t,s),i.set(s,t)),s},t.getIds=function(e,t){var r=this,n=this.getIdToRemoteIdMap(e),o=this.getRemoteIdToIdMap(e);return t.map(function(t){return r.getId(e,t,n,o)})},t.getRemoteId=function(e,t,r){var n=r||this.getRemoteIdToIdMap(e);return"number"!=typeof t?t:n.get(t)||-1},t.getRemoteIds=function(e,t){var r=this,n=this.getRemoteIdToIdMap(e);return t.map(function(t){return r.getRemoteId(e,t,n)})},t.reset=function(e){if(!e)return this.iframeIdToRemoteIdMap=new WeakMap,void(this.iframeRemoteIdToIdMap=new WeakMap);this.iframeIdToRemoteIdMap.delete(e),this.iframeRemoteIdToIdMap.delete(e)},t.getIdToRemoteIdMap=function(e){var t=this.iframeIdToRemoteIdMap.get(e);return t||(t=new Map,this.iframeIdToRemoteIdMap.set(e,t)),t},t.getRemoteIdToIdMap=function(e){var t=this.iframeRemoteIdToIdMap.get(e);return t||(t=new Map,this.iframeRemoteIdToIdMap.set(e,t)),t},e}(),HM=function(){function e(e){v_(this,"iframes",new WeakMap),v_(this,"crossOriginIframeMap",new WeakMap),v_(this,"crossOriginIframeMirror",new WM(eS)),v_(this,"crossOriginIframeStyleMirror"),v_(this,"crossOriginIframeRootIdMap",new WeakMap),v_(this,"iframeContentDocumentMap",new WeakMap),v_(this,"iframeObserverCleanupMap",new WeakMap),v_(this,"mirror"),v_(this,"mutationCb"),v_(this,"wrappedEmit"),v_(this,"loadListener"),v_(this,"stylesheetManager"),v_(this,"recordCrossOriginIframes"),this.mutationCb=e.mutationCb,this.wrappedEmit=e.wrappedEmit,this.stylesheetManager=e.stylesheetManager,this.recordCrossOriginIframes=e.recordCrossOriginIframes,this.crossOriginIframeStyleMirror=new WM(this.stylesheetManager.styleMirror.generateId.bind(this.stylesheetManager.styleMirror)),this.mirror=e.mirror,this.recordCrossOriginIframes&&window.addEventListener("message",this.handleMessage.bind(this))}var t=e.prototype;return t.addIframe=function(e){this.iframes.set(e,!0),e.contentWindow&&this.crossOriginIframeMap.set(e.contentWindow,e)},t.getIframeContentDocument=function(e){return this.iframeContentDocumentMap.get(e)},t.setObserverCleanup=function(e,t){this.iframeObserverCleanupMap.set(e,t)},t.getObserverCleanup=function(e){return this.iframeObserverCleanupMap.get(e)},t.removeIframe=function(e){var t=this.iframeContentDocumentMap.get(e);t&&(this.stylesheetManager.cleanupStylesheetsForRemovedNode(t),this.mirror.removeNodeFromMap(t,!0)),this.iframes.delete(e),this.iframeContentDocumentMap.delete(e);var r=this.iframeObserverCleanupMap.get(e);if(r){try{r()}catch(e){}this.iframeObserverCleanupMap.delete(e)}},t.addLoadListener=function(e){this.loadListener=e},t.attachIframe=function(e,t){var r,n;this.mutationCb({adds:[{parentId:this.mirror.getId(e),nextId:null,node:t}],removes:[],texts:[],attributes:[],isAttachIframe:!0}),e.contentDocument&&this.iframeContentDocumentMap.set(e,e.contentDocument),this.recordCrossOriginIframes&&(null==(r=e.contentWindow)||r.addEventListener("message",this.handleMessage.bind(this))),null==(n=this.loadListener)||n.call(this,e),e.contentDocument&&e.contentDocument.adoptedStyleSheets&&e.contentDocument.adoptedStyleSheets.length>0&&this.stylesheetManager.adoptStyleSheets(e.contentDocument.adoptedStyleSheets,this.mirror.getId(e.contentDocument))},t.handleMessage=function(e){var t=e;if("rrweb"===t.data.type&&t.origin===t.data.origin&&e.source){var r=this.crossOriginIframeMap.get(e.source);if(r){var n=this.transformCrossOriginEvent(r,t.data.event);n&&this.wrappedEmit(n,t.data.isCheckout)}}},t.transformCrossOriginEvent=function(e,t){var r,n=this;switch(t.type){case gM.FullSnapshot:this.crossOriginIframeMirror.reset(e),this.crossOriginIframeStyleMirror.reset(e),this.replaceIdOnNode(t.data.node,e);var o=t.data.node.id;return this.crossOriginIframeRootIdMap.set(e,o),this.patchRootIdOnNode(t.data.node,o),{timestamp:t.timestamp,type:gM.IncrementalSnapshot,data:{source:vM.Mutation,adds:[{parentId:this.mirror.getId(e),nextId:null,node:t.data.node}],removes:[],texts:[],attributes:[],isAttachIframe:!0}};case gM.Meta:case gM.Load:case gM.DomContentLoaded:return!1;case gM.Plugin:return t;case gM.Custom:return this.replaceIds(t.data.payload,e,["id","parentId","previousId","nextId"]),t;case gM.IncrementalSnapshot:switch(t.data.source){case vM.Mutation:return t.data.adds.forEach(function(t){n.replaceIds(t,e,["parentId","nextId","previousId"]),n.replaceIdOnNode(t.node,e);var r=n.crossOriginIframeRootIdMap.get(e);r&&n.patchRootIdOnNode(t.node,r)}),t.data.removes.forEach(function(t){n.replaceIds(t,e,["parentId","id"])}),t.data.attributes.forEach(function(t){n.replaceIds(t,e,["id"])}),t.data.texts.forEach(function(t){n.replaceIds(t,e,["id"])}),t;case vM.Drag:case vM.TouchMove:case vM.MouseMove:return t.data.positions.forEach(function(t){n.replaceIds(t,e,["id"])}),t;case vM.ViewportResize:return!1;case vM.MediaInteraction:case vM.MouseInteraction:case vM.Scroll:case vM.CanvasMutation:case vM.Input:return this.replaceIds(t.data,e,["id"]),t;case vM.StyleSheetRule:case vM.StyleDeclaration:return this.replaceIds(t.data,e,["id"]),this.replaceStyleIds(t.data,e,["styleId"]),t;case vM.Font:return t;case vM.Selection:return t.data.ranges.forEach(function(t){n.replaceIds(t,e,["start","end"])}),t;case vM.AdoptedStyleSheet:return this.replaceIds(t.data,e,["id"]),this.replaceStyleIds(t.data,e,["styleIds"]),null==(r=t.data.styles)||r.forEach(function(t){n.replaceStyleIds(t,e,["styleId"])}),t}}return!1},t.replace=function(e,t,r,n){for(var o,i=d_(n);!(o=i()).done;){var s=o.value;(Array.isArray(t[s])||"number"==typeof t[s])&&(Array.isArray(t[s])?t[s]=e.getIds(r,t[s]):t[s]=e.getId(r,t[s]))}return t},t.replaceIds=function(e,t,r){return this.replace(this.crossOriginIframeMirror,e,t,r)},t.replaceStyleIds=function(e,t,r){return this.replace(this.crossOriginIframeStyleMirror,e,t,r)},t.replaceIdOnNode=function(e,t){var r=this;this.replaceIds(e,t,["id","rootId"]),"childNodes"in e&&e.childNodes.forEach(function(e){r.replaceIdOnNode(e,t)})},t.patchRootIdOnNode=function(e,t){var r=this;e.type===_M.Document||e.rootId||(e.rootId=t),"childNodes"in e&&e.childNodes.forEach(function(e){r.patchRootIdOnNode(e,t)})},e}(),GM=function(){function e(e){v_(this,"shadowDoms",new WeakSet),v_(this,"mutationCb"),v_(this,"scrollCb"),v_(this,"bypassOptions"),v_(this,"mirror"),v_(this,"restoreHandlers",[]),this.mutationCb=e.mutationCb,this.scrollCb=e.scrollCb,this.bypassOptions=e.bypassOptions,this.mirror=e.mirror,this.init()}var t=e.prototype;return t.init=function(){this.reset(),this.patchAttachShadow(Element,document)},t.addShadowRoot=function(e,t){var r=this;if(j_(e)&&!this.shadowDoms.has(e)){this.shadowDoms.add(e);var n=jM(n_({},this.bypassOptions,{doc:t,mutationCb:this.mutationCb,mirror:this.mirror,shadowDomManager:this}),e);this.restoreHandlers.push(function(){return n.disconnect()}),this.restoreHandlers.push(LM(n_({},this.bypassOptions,{scrollCb:this.scrollCb,doc:e,mirror:this.mirror}))),setTimeout(function(){e.adoptedStyleSheets&&e.adoptedStyleSheets.length>0&&r.bypassOptions.stylesheetManager.adoptStyleSheets(e.adoptedStyleSheets,r.mirror.getId(KI(e))),r.restoreHandlers.push(zM({mirror:r.mirror,stylesheetManager:r.bypassOptions.stylesheetManager},e))},0)}},t.observeAttachShadow=function(e){e.contentWindow&&e.contentDocument&&this.patchAttachShadow(e.contentWindow.Element,e.contentDocument)},t.patchAttachShadow=function(e,t){var r=this;this.restoreHandlers.push(zI(e.prototype,"attachShadow",function(e){return function(n){var o=e.call(this,n),i=YI(this);return i&&mM(this)&&r.addShadowRoot(i,t),o}}))},t.reset=function(){this.restoreHandlers.forEach(function(e){try{e()}catch(e){}}),this.restoreHandlers=[],this.shadowDoms=new WeakSet},e}(),KM="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",YM="undefined"==typeof Uint8Array?[]:new Uint8Array(256),ZM=0;ZM<64;ZM++)YM[KM.charCodeAt(ZM)]=ZM;var XM=new Map,JM=function(e,t,r){if(e&&(tA(e,t)||"object"===(void 0===e?"undefined":c_(e)))){var n=function(e,t){var r=XM.get(e);return r||(r=new Map,XM.set(e,r)),r.has(t)||r.set(t,[]),r.get(t)}(r,e.constructor.name),o=n.indexOf(e);return-1===o&&(o=n.length,n.push(e)),o}};function QM(e,t,r){return s_(e,Array)?e.map(function(e){return QM(e,t,r)}):null===e?e:s_(e,Float32Array)||s_(e,Float64Array)||s_(e,Int32Array)||s_(e,Uint32Array)||s_(e,Uint8Array)||s_(e,Uint16Array)||s_(e,Int16Array)||s_(e,Int8Array)||s_(e,Uint8ClampedArray)?{rr_type:e.constructor.name,args:[Object.values(e)]}:s_(e,ArrayBuffer)?{rr_type:e.constructor.name,base64:function(e){var t,r=new Uint8Array(e),n=r.length,o="";for(t=0;t<n;t+=3)o+=KM[r[t]>>2],o+=KM[(3&r[t])<<4|r[t+1]>>4],o+=KM[(15&r[t+1])<<2|r[t+2]>>6],o+=KM[63&r[t+2]];return n%3==2?o=o.substring(0,o.length-1)+"=":n%3==1&&(o=o.substring(0,o.length-2)+"=="),o}(e)}:s_(e,DataView)?{rr_type:e.constructor.name,args:[QM(e.buffer,t,r),e.byteOffset,e.byteLength]}:s_(e,HTMLImageElement)?{rr_type:e.constructor.name,src:e.src}:s_(e,HTMLCanvasElement)?{rr_type:"HTMLImageElement",src:e.toDataURL()}:s_(e,ImageData)?{rr_type:e.constructor.name,args:[QM(e.data,t,r),e.width,e.height]}:tA(e,t)||"object"===(void 0===e?"undefined":c_(e))?{rr_type:e.constructor.name,index:JM(e,t,r)}:e}var eA=function(e,t,r){return e.map(function(e){return QM(e,t,r)})},tA=function(e,t){var r=["WebGLActiveInfo","WebGLBuffer","WebGLFramebuffer","WebGLProgram","WebGLRenderbuffer","WebGLShader","WebGLShaderPrecisionFormat","WebGLTexture","WebGLUniformLocation","WebGLVertexArrayObject","WebGLVertexArrayObjectOES"].filter(function(e){return"function"==typeof t[e]});return Boolean(r.find(function(r){return s_(e,t[r])}))};function rA(e,t,r,n){var o=[];try{var i=zI(e.HTMLCanvasElement.prototype,"getContext",function(e){return function(o){for(var i=arguments.length,s=new Array(i>1?i-1:0),a=1;a<i;a++)s[a-1]=arguments[a];if(!sM(this,t,r,!0)){var l=function(e){return"experimental-webgl"===e?"webgl":e}(o);if("__context"in this||(this.__context=l),n&&["webgl","webgl2"].includes(l))if(s[0]&&"object"===c_(s[0])){var c=s[0];c.preserveDrawingBuffer||(c.preserveDrawingBuffer=!0)}else s.splice(0,1,{preserveDrawingBuffer:!0})}return e.apply(this,[].concat([o],s))}});o.push(i)}catch(e){console.error("failed to patch HTMLCanvasElement.prototype.getContext")}return function(){o.forEach(function(e){return e()})}}function nA(e,t,r,n,o,i){for(var s,a=function(){var a=s.value;if(["isContextLost","canvas","drawingBufferWidth","drawingBufferHeight"].includes(a))return"continue";try{if("function"!=typeof e[a])return"continue";var c=zI(e,a,function(e){return function(){for(var s=arguments.length,l=new Array(s),c=0;c<s;c++)l[c]=arguments[c];var u=e.apply(this,l);if(JM(u,i,this),"tagName"in this.canvas&&!sM(this.canvas,n,o,!0)){var p=eA(l,i,this),d={type:t,property:a,args:p};r(this.canvas,d)}return u}});l.push(c)}catch(n){var u=eM(e,a,{set:function(e){r(this.canvas,{type:t,property:a,args:[e],setter:!0})}});l.push(u)}},l=[],c=d_(Object.getOwnPropertyNames(e));!(s=c()).done;)a();return l}var oA,iA="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",sA="undefined"!=typeof window&&window.Blob&&new Blob([(oA=iA,Uint8Array.from(atob(oA),function(e){return e.charCodeAt(0)}))],{type:"text/javascript;charset=utf-8"});function aA(e){var t;try{if(!(t=sA&&(window.URL||window.webkitURL).createObjectURL(sA)))throw"";var r=new Worker(t,{name:null==e?void 0:e.name});return r.addEventListener("error",function(){(window.URL||window.webkitURL).revokeObjectURL(t)}),r}catch(t){return new Worker("data:text/javascript;base64,"+iA,{name:null==e?void 0:e.name})}finally{t&&(window.URL||window.webkitURL).revokeObjectURL(t)}}var lA,cA,uA,pA=function(){function e(e){var t=this;v_(this,"pendingCanvasMutations",new Map),v_(this,"rafStamps",{latestId:0,invokeId:null}),v_(this,"mirror"),v_(this,"mutationCb"),v_(this,"resetObservers"),v_(this,"frozen",!1),v_(this,"locked",!1),v_(this,"processMutation",function(e,r){!(t.rafStamps.invokeId&&t.rafStamps.latestId!==t.rafStamps.invokeId)&&t.rafStamps.invokeId||(t.rafStamps.invokeId=t.rafStamps.latestId),t.pendingCanvasMutations.has(e)||t.pendingCanvasMutations.set(e,[]),t.pendingCanvasMutations.get(e).push(r)});var r=e.sampling,n=void 0===r?"all":r,o=e.win,i=e.blockClass,s=e.blockSelector,a=e.recordCanvas,l=e.dataURLOptions;this.mutationCb=e.mutationCb,this.mirror=e.mirror,a&&"all"===n&&this.initCanvasMutationObserver(o,i,s),a&&"number"==typeof n&&this.initCanvasFPSObserver(n,o,i,s,{dataURLOptions:l})}var t=e.prototype;return t.reset=function(){this.pendingCanvasMutations.clear(),this.resetObservers&&this.resetObservers()},t.freeze=function(){this.frozen=!0},t.unfreeze=function(){this.frozen=!1},t.lock=function(){this.locked=!0},t.unlock=function(){this.locked=!1},t.initCanvasFPSObserver=function(e,t,r,n,o){var i=this,s=rA(t,r,n,!0),a=new Map,l=new aA;l.onmessage=function(e){var t=e.data.id;if(a.set(t,!1),"base64"in e.data){var r=e.data,n=r.base64,o=r.type,s=r.width,l=r.height;i.mutationCb({id:t,type:wM["2D"],commands:[{property:"clearRect",args:[0,0,s,l]},{property:"drawImage",args:[{rr_type:"ImageBitmap",args:[{rr_type:"Blob",data:[{rr_type:"ArrayBuffer",base64:n}],type:o}]},0,0]}]})}};var c,u=1e3/e,p=0,d=function(e){if(p&&e-p<u)c=requestAnimationFrame(d);else{p=e;var s,f=i;(s=[],t.document.querySelectorAll("canvas").forEach(function(e){sM(e,r,n,!0)||s.push(e)}),s).forEach(e_(function(e){var t,r,n,i;return f_(this,function(s){switch(s.label){case 0:return r=f.mirror.getId(e),a.get(r)||0===e.width||0===e.height?[2]:(a.set(r,!0),["webgl","webgl2"].includes(e.__context)&&(n=e.getContext(e.__context),!1===(null==(t=null==n?void 0:n.getContextAttributes())?void 0:t.preserveDrawingBuffer)&&n.clear(n.COLOR_BUFFER_BIT)),[4,createImageBitmap(e)]);case 1:return i=s.sent(),l.postMessage({id:r,bitmap:i,width:e.width,height:e.height,dataURLOptions:o.dataURLOptions},[i]),[2]}})})),c=requestAnimationFrame(d)}};c=requestAnimationFrame(d),this.resetObservers=function(){s(),cancelAnimationFrame(c)}},t.initCanvasMutationObserver=function(e,t,r){this.startRAFTimestamping(),this.startPendingCanvasMutationFlusher();var n=rA(e,t,r,!1),o=function(e,t,r,n){for(var o,i=function(){var i=o.value;try{if("function"!=typeof t.CanvasRenderingContext2D.prototype[i])return"continue";var a=zI(t.CanvasRenderingContext2D.prototype,i,function(o){return function(){for(var s=this,a=arguments.length,l=new Array(a),c=0;c<a;c++)l[c]=arguments[c];return sM(this.canvas,r,n,!0)||setTimeout(function(){var r=eA(l,t,s);e(s.canvas,{type:wM["2D"],property:i,args:r})},0),o.apply(this,l)}});s.push(a)}catch(r){var l=eM(t.CanvasRenderingContext2D.prototype,i,{set:function(t){e(this.canvas,{type:wM["2D"],property:i,args:[t],setter:!0})}});s.push(l)}},s=[],a=d_(Object.getOwnPropertyNames(t.CanvasRenderingContext2D.prototype));!(o=a()).done;)i();return function(){s.forEach(function(e){return e()})}}(this.processMutation.bind(this),e,t,r),i=function(e,t,r,n){var o,i,s=[];return(o=s).push.apply(o,[].concat(nA(t.WebGLRenderingContext.prototype,wM.WebGL,e,r,n,t))),void 0!==t.WebGL2RenderingContext&&(i=s).push.apply(i,[].concat(nA(t.WebGL2RenderingContext.prototype,wM.WebGL2,e,r,n,t))),function(){s.forEach(function(e){return e()})}}(this.processMutation.bind(this),e,t,r);this.resetObservers=function(){n(),o(),i()}},t.startPendingCanvasMutationFlusher=function(){var e=this;requestAnimationFrame(function(){return e.flushPendingCanvasMutations()})},t.startRAFTimestamping=function(){var e=this,t=function(r){e.rafStamps.latestId=r,requestAnimationFrame(t)};requestAnimationFrame(t)},t.flushPendingCanvasMutations=function(){var e=this;this.pendingCanvasMutations.forEach(function(t,r){var n=e.mirror.getId(r);e.flushPendingCanvasMutationFor(r,n)}),requestAnimationFrame(function(){return e.flushPendingCanvasMutations()})},t.flushPendingCanvasMutationFor=function(e,t){if(!this.frozen&&!this.locked){var r=this.pendingCanvasMutations.get(e);if(r&&-1!==t){var n=r.map(function(e){return a_(e,["type"])}),o=r[0].type;this.mutationCb({id:t,type:o,commands:n}),this.pendingCanvasMutations.delete(e)}}},e}(),dA=function(){function e(e){v_(this,"trackedLinkElements",new WeakSet),v_(this,"mutationCb"),v_(this,"adoptedStyleSheetCb"),v_(this,"styleMirror",new fM),this.mutationCb=e.mutationCb,this.adoptedStyleSheetCb=e.adoptedStyleSheetCb}var t=e.prototype;return t.attachLinkElement=function(e,t){"_cssText"in t.attributes&&this.mutationCb({adds:[],removes:[],texts:[],attributes:[{id:t.id,attributes:t.attributes}]}),this.trackLinkElement(e)},t.trackLinkElement=function(e){this.trackedLinkElements.has(e)||(this.trackedLinkElements.add(e),this.trackStylesheetInLinkElement(e))},t.adoptStyleSheets=function(e,t){var r,n=function(){var e=o.value,t=void 0;r.styleMirror.has(e)?t=r.styleMirror.getId(e):(t=r.styleMirror.add(e),s.push({styleId:t,rules:Array.from(e.rules||CSSRule,function(t,r){return{rule:D_(t,e.href),index:r}})})),i.styleIds.push(t)};if(0!==e.length){for(var o,i={id:t,styleIds:[]},s=[],a=d_(e);!(o=a()).done;)r=this,n();s.length>0&&(i.styles=s),this.adoptedStyleSheetCb(i)}},t.reset=function(){this.styleMirror.reset(),this.trackedLinkElements=new WeakSet},t.cleanupStylesheetsForRemovedNode=function(e){var t=this;try{if(e.nodeType===Node.DOCUMENT_NODE){var r=e;if(r.adoptedStyleSheets)for(var n,o=d_(r.adoptedStyleSheets);!(n=o()).done;){var i=n.value;this.styleMirror.remove(i)}}if("STYLE"===e.nodeName){var s=e;s.sheet&&this.styleMirror.remove(s.sheet)}if("LINK"===e.nodeName&&"stylesheet"===e.rel){var a=e;a.sheet&&this.styleMirror.remove(a.sheet)}e.childNodes&&e.childNodes.forEach(function(e){t.cleanupStylesheetsForRemovedNode(e)})}catch(e){}},t.trackStylesheetInLinkElement=function(e){},e}(),fA=function(){function e(){v_(this,"nodeMap",new WeakMap),v_(this,"active",!1)}var t=e.prototype;return t.inOtherBuffer=function(e,t){var r=this.nodeMap.get(e);return r&&Array.from(r).some(function(e){return e!==t})},t.add=function(e,t){var r=this;this.active||(this.active=!0,requestAnimationFrame(function(){r.nodeMap=new WeakMap,r.active=!1})),this.nodeMap.set(e,(this.nodeMap.get(e)||new Set).add(t))},t.destroy=function(){},e}();function hA(e){try{var t=new URL(e).origin;return"null"!==t?t:null}catch(e){return null}}var mA=!1;try{if(2!==Array.from([1],function(e){return 2*e})[0]){var gA=document.createElement("iframe");document.body.appendChild(gA),Array.from=(null==(m_=gA.contentWindow)?void 0:m_.Array.from)||Array.from,document.body.removeChild(gA)}}catch(e){console.debug("Unable to override Array.from",e)}var vA,yA,bA=new F_;function wA(e){void 0===e&&(e={});var t,r=e.emit,n=e.checkoutEveryNms,o=e.checkoutEveryNth,i=e.blockClass,s=void 0===i?"rr-block":i,a=e.blockSelector,l=void 0===a?null:a,c=e.ignoreClass,u=void 0===c?"rr-ignore":c,p=e.ignoreSelector,d=void 0===p?null:p,f=e.maskTextClass,h=void 0===f?"rr-mask":f,m=e.maskTextSelector,g=void 0===m?null:m,v=e.inlineStylesheet,y=void 0===v||v,b=e.maskAllInputs,w=e.maskInputOptions,x=e.slimDOMOptions,_=e.maskInputFn,S=e.maskTextFn,k=e.hooks,C=e.packFn,O=e.sampling,E=void 0===O?{}:O,T=e.dataURLOptions,R=void 0===T?{}:T,I=e.mousemoveWait,M=e.recordDOM,A=void 0===M||M,P=e.recordCanvas,N=void 0!==P&&P,j=e.recordCrossOriginIframes,L=void 0!==j&&j,D=e.allowedIframeOrigins,F=e.recordAfter,$=void 0===F?"DOMContentLoaded"===e.recordAfter?e.recordAfter:"load":F,B=e.userTriggeredOnInput,z=void 0!==B&&B,V=e.collectFonts,U=void 0!==V&&V,q=e.inlineImages,W=void 0!==q&&q,H=e.plugins,G=e.keepIframeSrcFn,K=void 0===G?function(){return!1}:G,Y=e.ignoreCSSAttributes,Z=void 0===Y?new Set([]):Y,X=e.errorHandler;kM=X,L&&D&&D.length>0&&(t=function(e){if(!Array.isArray(e)||0===e.length)throw new Error("[rrweb] allowedIframeOrigins must be a non-empty array of origin strings.");for(var t=new Set,r=0;r<e.length;r++){var n=e[r];if("string"!=typeof n)throw new Error("[rrweb] allowedIframeOrigins["+r+"] must be a string, got "+(void 0===n?"undefined":c_(n))+".");var o=hA(n);o&&t.add(o)}return Object.freeze(t)}(D),0===t.size&&(t=void 0));var J=!L||window.parent===window,Q=!1;if(!J)try{window.parent.document&&(Q=!1)}catch(e){Q=!0}if(J&&!r)throw new Error("emit function is required");if(!J&&!Q)return function(){};void 0!==I&&void 0===E.mousemove&&(E.mousemove=I),bA.reset();var ee,te=!0===b?{color:!0,date:!0,"datetime-local":!0,email:!0,month:!0,number:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0,textarea:!0,select:!0,password:!0,hidden:!0}:void 0!==w?w:{password:!0},re=!0===x||"all"===x?{script:!0,comment:!0,headFavicon:!0,headWhitespace:!0,headMetaSocial:!0,headMetaRobots:!0,headMetaHttpEquiv:!0,headMetaVerification:!0,headMetaAuthorship:"all"===x,headMetaDescKeywords:"all"===x,headTitleMutations:"all"===x}:x||{};!function(e){void 0===e&&(e=window),"NodeList"in e&&!e.NodeList.prototype.forEach&&(e.NodeList.prototype.forEach=Array.prototype.forEach),"DOMTokenList"in e&&!e.DOMTokenList.prototype.forEach&&(e.DOMTokenList.prototype.forEach=Array.prototype.forEach)}();var ne=0,oe=function(e){for(var t,r=d_(H||[]);!(t=r()).done;){var n=t.value;n.eventProcessor&&(e=n.eventProcessor(e))}return C&&!Q&&(e=C(e)),e};lA=function(e,i){var s,a=e;if(a.timestamp=tM(),!(null==(s=PM[0])?void 0:s.isFrozen())||a.type===gM.FullSnapshot||a.type===gM.IncrementalSnapshot&&a.data.source===vM.Mutation||PM.forEach(function(e){return e.unfreeze()}),J)null==r||r(oe(a),i);else if(Q){var l={type:"rrweb",event:oe(a),origin:window.location.origin,isCheckout:i};if(t)for(var c,u=d_(t);!(c=u()).done;){var p=c.value;window.parent.postMessage(l,p)}else window.parent.postMessage(l,"*")}if(a.type===gM.FullSnapshot)ee=a,ne=0;else if(a.type===gM.IncrementalSnapshot){if(a.data.source===vM.Mutation&&a.data.isAttachIframe)return;ne++;var d=o&&ne>=o,f=n&&a.timestamp-ee.timestamp>n;(d||f)&&cA(!0)}};for(var ie,se=function(e){lA({type:gM.IncrementalSnapshot,data:n_({source:vM.Mutation},e)})},ae=function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.Scroll},e)})},le=function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.CanvasMutation},e)})},ce=new dA({mutationCb:se,adoptedStyleSheetCb:function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.AdoptedStyleSheet},e)})}}),ue=new HM({mirror:bA,mutationCb:se,stylesheetManager:ce,recordCrossOriginIframes:L,wrappedEmit:lA}),pe=d_(H||[]);!(ie=pe()).done;){var de=ie.value;de.getMirror&&de.getMirror({nodeMirror:bA,crossOriginIframeMirror:ue.crossOriginIframeMirror,crossOriginIframeStyleMirror:ue.crossOriginIframeStyleMirror})}var fe=new fA;uA=new pA({recordCanvas:N,mutationCb:le,win:window,blockClass:s,blockSelector:l,mirror:bA,sampling:E.canvas,dataURLOptions:R});var he=new GM({mutationCb:se,scrollCb:ae,bypassOptions:{blockClass:s,blockSelector:l,maskTextClass:h,maskTextSelector:g,inlineStylesheet:y,maskInputOptions:te,dataURLOptions:R,maskTextFn:S,maskInputFn:_,recordCanvas:N,inlineImages:W,sampling:E,slimDOMOptions:re,iframeManager:ue,stylesheetManager:ce,canvasManager:uA,keepIframeSrcFn:K,processedNodeManager:fe},mirror:bA});cA=function(e){if(void 0===e&&(e=!1),A){lA({type:gM.Meta,data:{href:window.location.href,width:oM(),height:nM()}},e),ce.reset(),he.init(),PM.forEach(function(e){return e.lock()});var t=function(e,t){var r=t||{},n=r.mirror,o=void 0===n?new F_:n,i=r.blockClass,s=r.blockSelector,a=r.maskTextClass,l=r.maskTextSelector,c=r.inlineStylesheet,u=r.inlineImages,p=r.recordCanvas,d=r.maskAllInputs,f=void 0!==d&&d,h=r.slimDOM,m=void 0!==h&&h,g=r.keepIframeSrcFn;return dS(e,{doc:e,mirror:o,blockClass:void 0===i?"rr-block":i,blockSelector:void 0===s?null:s,maskTextClass:void 0===a?"rr-mask":a,maskTextSelector:void 0===l?null:l,skipChild:!1,inlineStylesheet:void 0===c||c,maskInputOptions:!0===f?{color:!0,date:!0,"datetime-local":!0,email:!0,month:!0,number:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0,textarea:!0,select:!0,password:!0,hidden:!0}:!1===f?{password:!0}:f,maskTextFn:r.maskTextFn,maskInputFn:r.maskInputFn,slimDOMOptions:!0===m||"all"===m?{script:!0,comment:!0,headFavicon:!0,headWhitespace:!0,headMetaDescKeywords:"all"===m,headMetaSocial:!0,headMetaRobots:!0,headMetaHttpEquiv:!0,headMetaAuthorship:!0,headMetaVerification:!0}:!1===m?{}:m,dataURLOptions:r.dataURLOptions,inlineImages:void 0!==u&&u,recordCanvas:void 0!==p&&p,preserveWhiteSpace:r.preserveWhiteSpace,onSerialize:r.onSerialize,onIframeLoad:r.onIframeLoad,iframeLoadTimeout:r.iframeLoadTimeout,onStylesheetLoad:r.onStylesheetLoad,stylesheetLoadTimeout:r.stylesheetLoadTimeout,keepIframeSrcFn:void 0===g?function(){return!1}:g,newlyAddedElement:!1})}(document,{mirror:bA,blockClass:s,blockSelector:l,maskTextClass:h,maskTextSelector:g,inlineStylesheet:y,maskAllInputs:te,maskTextFn:S,maskInputFn:_,slimDOM:re,dataURLOptions:R,recordCanvas:N,inlineImages:W,onSerialize:function(e){uM(e,bA)&&ue.addIframe(e),pM(e,bA)&&ce.trackLinkElement(e),dM(e)&&he.addShadowRoot(YI(e),document)},onIframeLoad:function(e,t){ue.attachIframe(e,t),he.observeAttachShadow(e)},onStylesheetLoad:function(e,t){ce.attachLinkElement(e,t)},keepIframeSrcFn:K});if(!t)return console.warn("Failed to snapshot the document");lA({type:gM.FullSnapshot,data:{node:t,initialOffset:rM(window)}},e),PM.forEach(function(e){return e.unlock()}),document.adoptedStyleSheets&&document.adoptedStyleSheets.length>0&&ce.adoptStyleSheets(document.adoptedStyleSheets,bA.getId(document))}};try{var me=[],ge=function(e){var t;return AM(VM)({mutationCb:se,mousemoveCb:function(e,t){return lA({type:gM.IncrementalSnapshot,data:{source:t,positions:e}})},mouseInteractionCb:function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.MouseInteraction},e)})},scrollCb:ae,viewportResizeCb:function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.ViewportResize},e)})},inputCb:function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.Input},e)})},mediaInteractionCb:function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.MediaInteraction},e)})},styleSheetRuleCb:function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.StyleSheetRule},e)})},styleDeclarationCb:function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.StyleDeclaration},e)})},canvasMutationCb:le,fontCb:function(e){return lA({type:gM.IncrementalSnapshot,data:n_({source:vM.Font},e)})},selectionCb:function(e){lA({type:gM.IncrementalSnapshot,data:n_({source:vM.Selection},e)})},customElementCb:function(e){lA({type:gM.IncrementalSnapshot,data:n_({source:vM.CustomElement},e)})},blockClass:s,ignoreClass:u,ignoreSelector:d,maskTextClass:h,maskTextSelector:g,maskInputOptions:te,inlineStylesheet:y,sampling:E,recordDOM:A,recordCanvas:N,inlineImages:W,userTriggeredOnInput:z,collectFonts:U,doc:e,maskInputFn:_,maskTextFn:S,keepIframeSrcFn:K,blockSelector:l,slimDOMOptions:re,dataURLOptions:R,mirror:bA,iframeManager:ue,stylesheetManager:ce,shadowDomManager:he,processedNodeManager:fe,canvasManager:uA,ignoreCSSAttributes:Z,plugins:(null==(t=null==H?void 0:H.filter(function(e){return e.observer}))?void 0:t.map(function(e){return{observer:e.observer,options:e.options,callback:function(t){return lA({type:gM.Plugin,data:{plugin:e.name,payload:t}})}}}))||[]},k)};ue.addLoadListener(function(e){try{var t=e.contentDocument,r=ge(t);me.push(r);var n=ue.getObserverCleanup(e);ue.setObserverCleanup(e,function(){if(n)try{n()}catch(e){}try{r();var e=me.indexOf(r);-1!==e&&me.splice(e,1),function(e){for(var t=PM.length-1;t>=0;t--)PM[t].getDoc()===e&&PM.splice(t,1)}(t)}catch(e){}})}catch(e){console.warn(e)}});var ve=function(){cA(),me.push(ge(document)),mA=!0};return"interactive"===document.readyState||"complete"===document.readyState?ve():(me.push(ZI("DOMContentLoaded",function(){lA({type:gM.DomContentLoaded,data:{}}),"DOMContentLoaded"===$&&ve()})),me.push(ZI("load",function(){lA({type:gM.Load,data:{}}),"load"===$&&ve()},window))),function(){me.forEach(function(e){try{e()}catch(e){String(e).toLowerCase().includes("cross-origin")||console.warn(e)}}),fe.destroy(),mA=!1,kM=void 0}}catch(e){console.warn(e)}}wA.addCustomEvent=function(e,t){if(!mA)throw new Error("please add custom event after start recording");lA({type:gM.Custom,data:{tag:e,payload:t}})},wA.freezePage=function(){PM.forEach(function(e){return e.freeze()})},wA.takeFullSnapshot=function(e){if(!mA)throw new Error("please take full snapshot after start recording");cA(e)},wA.mirror=bA,(yA=vA||(vA={}))[yA.NotStarted=0]="NotStarted",yA[yA.Running=1]="Running",yA[yA.Stopped=2]="Stopped";var xA={Node:["childNodes","parentNode","parentElement","textContent"],ShadowRoot:["host","styleSheets"],Element:["shadowRoot","querySelector","querySelectorAll"],MutationObserver:[]},_A={Node:["contains","getRootNode"],ShadowRoot:["getSelection"],Element:[],MutationObserver:["constructor"]},SA={};function kA(e){if(SA[e])return SA[e];var t=globalThis[e],r=t.prototype,n=e in xA?xA[e]:void 0,o=Boolean(n&&n.every(function(e){var t,n;return Boolean(null==(n=null==(t=Object.getOwnPropertyDescriptor(r,e))?void 0:t.get)?void 0:n.toString().includes("[native code]"))})),i=e in _A?_A[e]:void 0,s=Boolean(i&&i.every(function(e){var t;return"function"==typeof r[e]&&(null==(t=r[e])?void 0:t.toString().includes("[native code]"))}));if(o&&s&&!globalThis.Zone)return SA[e]=t.prototype,t.prototype;try{var a=document.createElement("iframe");document.body.appendChild(a);var l=a.contentWindow;if(!l)return t.prototype;var c=l[e].prototype;return document.body.removeChild(a),c?SA[e]=c:r}catch(e){return r}}var CA={};function OA(e,t,r){var n,o=e+"."+String(r);if(CA[o])return CA[o].call(t);var i=kA(e),s=null==(n=Object.getOwnPropertyDescriptor(i,r))?void 0:n.get;return s?(CA[o]=s,s.call(t)):t[r]}var EA=function(e){return OA("Node",e,"parentNode")};function TA(e,t,r){if(!e)return!1;if(e.nodeType!==e.ELEMENT_NODE)return TA(EA(e),t);for(var n=e.classList.length;n--;){var o=e.classList[n];if(t.test(o))return!0}return TA(EA(e),t)}function RA(e){if(e.__esModule)return e;var t=e.default;if("function"==typeof t){var r=function e(){return s_(this,e)?Reflect.construct(t,arguments,this.constructor):t.apply(this,arguments)};r.prototype=t.prototype}else r={};return Object.defineProperty(r,"__esModule",{value:!0}),Object.keys(e).forEach(function(t){var n=Object.getOwnPropertyDescriptor(e,t);Object.defineProperty(r,t,n.get?n:{enumerable:!0,get:function(){return e[t]}})}),r}var IA={exports:{}},MA=String,AA=function(){return{isColorSupported:!1,reset:MA,bold:MA,dim:MA,italic:MA,underline:MA,inverse:MA,hidden:MA,strikethrough:MA,black:MA,red:MA,green:MA,yellow:MA,blue:MA,magenta:MA,cyan:MA,white:MA,gray:MA,bgBlack:MA,bgRed:MA,bgGreen:MA,bgYellow:MA,bgBlue:MA,bgMagenta:MA,bgCyan:MA,bgWhite:MA}};IA.exports=AA(),IA.exports.createColors=AA;var PA=IA.exports,NA=RA(Object.freeze(Object.defineProperty({__proto__:null,default:{}},Symbol.toStringTag,{value:"Module"}))),jA=PA,LA=NA,DA=function(e){function t(r,n,o,i,s,a){var l;return(l=e.call(this,r)||this).name="CssSyntaxError",l.reason=r,s&&(l.file=s),i&&(l.source=i),a&&(l.plugin=a),void 0!==n&&void 0!==o&&("number"==typeof n?(l.line=n,l.column=o):(l.line=n.line,l.column=n.column,l.endLine=o.line,l.endColumn=o.column)),l.setMessage(),Error.captureStackTrace&&Error.captureStackTrace(l,t),l}i_(t,e);var r=t.prototype;return r.setMessage=function(){this.message=this.plugin?this.plugin+": ":"",this.message+=this.file?this.file:"<css input>",void 0!==this.line&&(this.message+=":"+this.line+":"+this.column),this.message+=": "+this.reason},r.showSourceCode=function(e){var t=this;if(!this.source)return"";var r=this.source;null==e&&(e=jA.isColorSupported),LA&&e&&(r=LA(r));var n,o,i=r.split(/\r?\n/),s=Math.max(this.line-3,0),a=Math.min(this.line+2,i.length),l=String(a).length;if(e){var c=jA.createColors(!0),u=c.bold,p=c.gray,d=c.red;n=function(e){return u(d(e))},o=function(e){return p(e)}}else n=o=function(e){return e};return i.slice(s,a).map(function(e,r){var i=s+1+r,a=" "+(" "+i).slice(-l)+" | ";if(i===t.line){var c=o(a.replace(/\d/g," "))+e.slice(0,t.column-1).replace(/[^\t]/g," ");return n(">")+o(a)+e+"\n "+c+n("^")}return" "+o(a)+e}).join("\n")},r.toString=function(){var e=this.showSourceCode();return e&&(e="\n\n"+e+"\n"),this.name+": "+this.message+e},t}(u_(Error)),FA=DA;DA.default=DA;var $A={};$A.isClean=Symbol("isClean"),$A.my=Symbol("my");var BA={after:"\n",beforeClose:"\n",beforeComment:"\n",beforeDecl:"\n",beforeOpen:" ",beforeRule:"\n",colon:": ",commentLeft:" ",commentRight:" ",emptyBody:"",indent:"    ",semicolon:!1},zA=function(){function e(e){this.builder=e}var t=e.prototype;return t.atrule=function(e,t){var r="@"+e.name,n=e.params?this.rawValue(e,"params"):"";if(void 0!==e.raws.afterName?r+=e.raws.afterName:n&&(r+=" "),e.nodes)this.block(e,r+n);else{var o=(e.raws.between||"")+(t?";":"");this.builder(r+n+o,e)}},t.beforeAfter=function(e,t){var r;r="decl"===e.type?this.raw(e,null,"beforeDecl"):"comment"===e.type?this.raw(e,null,"beforeComment"):"before"===t?this.raw(e,null,"beforeRule"):this.raw(e,null,"beforeClose");for(var n=e.parent,o=0;n&&"root"!==n.type;)o+=1,n=n.parent;if(r.includes("\n")){var i=this.raw(e,null,"indent");if(i.length)for(var s=0;s<o;s++)r+=i}return r},t.block=function(e,t){var r,n=this.raw(e,"between","beforeOpen");this.builder(t+n+"{",e,"start"),e.nodes&&e.nodes.length?(this.body(e),r=this.raw(e,"after")):r=this.raw(e,"after","emptyBody"),r&&this.builder(r),this.builder("}",e,"end")},t.body=function(e){for(var t=e.nodes.length-1;t>0&&"comment"===e.nodes[t].type;)t-=1;for(var r=this.raw(e,"semicolon"),n=0;n<e.nodes.length;n++){var o=e.nodes[n],i=this.raw(o,"before");i&&this.builder(i),this.stringify(o,t!==n||r)}},t.comment=function(e){var t=this.raw(e,"left","commentLeft"),r=this.raw(e,"right","commentRight");this.builder("/*"+t+e.text+r+"*/",e)},t.decl=function(e,t){var r=this.raw(e,"between","colon"),n=e.prop+r+this.rawValue(e,"value");e.important&&(n+=e.raws.important||" !important"),t&&(n+=";"),this.builder(n,e)},t.document=function(e){this.body(e)},t.raw=function(e,t,r){var n;if(r||(r=t),t&&void 0!==(n=e.raws[t]))return n;var o=e.parent;if("before"===r){if(!o||"root"===o.type&&o.first===e)return"";if(o&&"document"===o.type)return""}if(!o)return BA[r];var i=e.root();if(i.rawCache||(i.rawCache={}),void 0!==i.rawCache[r])return i.rawCache[r];if("before"===r||"after"===r)return this.beforeAfter(e,r);var s,a="raw"+((s=r)[0].toUpperCase()+s.slice(1));return this[a]?n=this[a](i,e):i.walk(function(e){if(void 0!==(n=e.raws[t]))return!1}),void 0===n&&(n=BA[r]),i.rawCache[r]=n,n},t.rawBeforeClose=function(e){var t;return e.walk(function(e){if(e.nodes&&e.nodes.length>0&&void 0!==e.raws.after)return(t=e.raws.after).includes("\n")&&(t=t.replace(/[^\n]+$/,"")),!1}),t&&(t=t.replace(/\S/g,"")),t},t.rawBeforeComment=function(e,t){var r;return e.walkComments(function(e){if(void 0!==e.raws.before)return(r=e.raws.before).includes("\n")&&(r=r.replace(/[^\n]+$/,"")),!1}),void 0===r?r=this.raw(t,null,"beforeDecl"):r&&(r=r.replace(/\S/g,"")),r},t.rawBeforeDecl=function(e,t){var r;return e.walkDecls(function(e){if(void 0!==e.raws.before)return(r=e.raws.before).includes("\n")&&(r=r.replace(/[^\n]+$/,"")),!1}),void 0===r?r=this.raw(t,null,"beforeRule"):r&&(r=r.replace(/\S/g,"")),r},t.rawBeforeOpen=function(e){var t;return e.walk(function(e){if("decl"!==e.type&&void 0!==(t=e.raws.between))return!1}),t},t.rawBeforeRule=function(e){var t;return e.walk(function(r){if(r.nodes&&(r.parent!==e||e.first!==r)&&void 0!==r.raws.before)return(t=r.raws.before).includes("\n")&&(t=t.replace(/[^\n]+$/,"")),!1}),t&&(t=t.replace(/\S/g,"")),t},t.rawColon=function(e){var t;return e.walkDecls(function(e){if(void 0!==e.raws.between)return t=e.raws.between.replace(/[^\s:]/g,""),!1}),t},t.rawEmptyBody=function(e){var t;return e.walk(function(e){if(e.nodes&&0===e.nodes.length&&void 0!==(t=e.raws.after))return!1}),t},t.rawIndent=function(e){return e.raws.indent?e.raws.indent:(e.walk(function(r){var n=r.parent;if(n&&n!==e&&n.parent&&n.parent===e&&void 0!==r.raws.before){var o=r.raws.before.split("\n");return t=(t=o[o.length-1]).replace(/\S/g,""),!1}}),t);// removed by dead control flow
 var t; },t.rawSemicolon=function(e){var t;return e.walk(function(e){if(e.nodes&&e.nodes.length&&"decl"===e.last.type&&void 0!==(t=e.raws.semicolon))return!1}),t},t.rawValue=function(e,t){var r=e[t],n=e.raws[t];return n&&n.value===r?n.raw:r},t.root=function(e){this.body(e),e.raws.after&&this.builder(e.raws.after)},t.rule=function(e){this.block(e,this.rawValue(e,"selector")),e.raws.ownSemicolon&&this.builder(e.raws.ownSemicolon,e,"end")},t.stringify=function(e,t){if(!this[e.type])throw new Error("Unknown AST node type "+e.type+". Maybe you need to change PostCSS stringifier.");this[e.type](e,t)},e}(),VA=zA;zA.default=zA;var UA=VA;function qA(e,t){new UA(t).stringify(e)}var WA=qA;qA.default=qA;var HA=$A.isClean,GA=$A.my,KA=FA,YA=VA,ZA=WA;function XA(e,t){var r=new e.constructor;for(var n in e)if(Object.prototype.hasOwnProperty.call(e,n)&&"proxyCache"!==n){var o=e[n],i=void 0===o?"undefined":c_(o);"parent"===n&&"object"===i?t&&(r[n]=t):"source"===n?r[n]=o:Array.isArray(o)?r[n]=o.map(function(e){return XA(e,r)}):("object"===i&&null!==o&&(o=XA(o)),r[n]=o)}return r}var JA=function(){function e(e){for(var t in void 0===e&&(e={}),this.raws={},this[HA]=!1,this[GA]=!0,e)if("nodes"===t){this.nodes=[];for(var r,n=d_(e[t]);!(r=n()).done;){var o=r.value;"function"==typeof o.clone?this.append(o.clone()):this.append(o)}}else this[t]=e[t]}var t=e.prototype;return t.addToError=function(e){if(e.postcssNode=this,e.stack&&this.source&&/\n\s{4}at /.test(e.stack)){var t=this.source;e.stack=e.stack.replace(/\n\s{4}at /,"$&"+t.input.from+":"+t.start.line+":"+t.start.column+"$&")}return e},t.after=function(e){return this.parent.insertAfter(this,e),this},t.assign=function(e){for(var t in void 0===e&&(e={}),e)this[t]=e[t];return this},t.before=function(e){return this.parent.insertBefore(this,e),this},t.cleanRaws=function(e){delete this.raws.before,delete this.raws.after,e||delete this.raws.between},t.clone=function(e){void 0===e&&(e={});var t=XA(this);for(var r in e)t[r]=e[r];return t},t.cloneAfter=function(e){void 0===e&&(e={});var t=this.clone(e);return this.parent.insertAfter(this,t),t},t.cloneBefore=function(e){void 0===e&&(e={});var t=this.clone(e);return this.parent.insertBefore(this,t),t},t.error=function(e,t){if(void 0===t&&(t={}),this.source){var r=this.rangeBy(t),n=r.end,o=r.start;return this.source.input.error(e,{column:o.column,line:o.line},{column:n.column,line:n.line},t)}return new KA(e)},t.getProxyProcessor=function(){return{get:function(e,t){return"proxyOf"===t?e:"root"===t?function(){return e.root().toProxy()}:e[t]},set:function(e,t,r){return e[t]===r||(e[t]=r,"prop"!==t&&"value"!==t&&"name"!==t&&"params"!==t&&"important"!==t&&"text"!==t||e.markDirty()),!0}}},t.markDirty=function(){if(this[HA]){this[HA]=!1;for(var e=this;e=e.parent;)e[HA]=!1}},t.next=function(){if(this.parent){var e=this.parent.index(this);return this.parent.nodes[e+1]}},t.positionBy=function(e,t){var r=this.source.start;if(e.index)r=this.positionInside(e.index,t);else if(e.word){var n=(t=this.toString()).indexOf(e.word);-1!==n&&(r=this.positionInside(n,t))}return r},t.positionInside=function(e,t){for(var r=t||this.toString(),n=this.source.start.column,o=this.source.start.line,i=0;i<e;i++)"\n"===r[i]?(n=1,o+=1):n+=1;return{column:n,line:o}},t.prev=function(){if(this.parent){var e=this.parent.index(this);return this.parent.nodes[e-1]}},t.rangeBy=function(e){var t={column:this.source.start.column,line:this.source.start.line},r=this.source.end?{column:this.source.end.column+1,line:this.source.end.line}:{column:t.column+1,line:t.line};if(e.word){var n=this.toString(),o=n.indexOf(e.word);-1!==o&&(t=this.positionInside(o,n),r=this.positionInside(o+e.word.length,n))}else e.start?t={column:e.start.column,line:e.start.line}:e.index&&(t=this.positionInside(e.index)),e.end?r={column:e.end.column,line:e.end.line}:"number"==typeof e.endIndex?r=this.positionInside(e.endIndex):e.index&&(r=this.positionInside(e.index+1));return(r.line<t.line||r.line===t.line&&r.column<=t.column)&&(r={column:t.column+1,line:t.line}),{end:r,start:t}},t.raw=function(e,t){return(new YA).raw(this,e,t)},t.remove=function(){return this.parent&&this.parent.removeChild(this),this.parent=void 0,this},t.replaceWith=function(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];if(this.parent){for(var n,o=this,i=!1,s=d_(t);!(n=s()).done;){var a=n.value;a===this?i=!0:i?(this.parent.insertAfter(o,a),o=a):this.parent.insertBefore(o,a)}i||this.remove()}return this},t.root=function(){for(var e=this;e.parent&&"document"!==e.parent.type;)e=e.parent;return e},t.toJSON=function(e,t){var r={},n=null==t;t=t||new Map;var o=0;for(var i in this)if(Object.prototype.hasOwnProperty.call(this,i)&&"parent"!==i&&"proxyCache"!==i){var s=this[i];if(Array.isArray(s))r[i]=s.map(function(e){return"object"===(void 0===e?"undefined":c_(e))&&e.toJSON?e.toJSON(null,t):e});else if("object"===(void 0===s?"undefined":c_(s))&&s.toJSON)r[i]=s.toJSON(null,t);else if("source"===i){var a=t.get(s.input);null==a&&(a=o,t.set(s.input,o),o++),r[i]={end:s.end,inputId:a,start:s.start}}else r[i]=s}return n&&(r.inputs=[].concat(t.keys()).map(function(e){return e.toJSON()})),r},t.toProxy=function(){return this.proxyCache||(this.proxyCache=new Proxy(this,this.getProxyProcessor())),this.proxyCache},t.toString=function(e){void 0===e&&(e=ZA),e.stringify&&(e=e.stringify);var t="";return e(this,function(e){t+=e}),t},t.warn=function(e,t,r){var n={node:this};for(var o in r)n[o]=r[o];return e.warn(t,n)},r_(e,[{key:"proxyOf",get:function(){return this}}]),e}(),QA=JA;JA.default=JA;var eP=function(e){function t(t){var r;return t&&void 0!==t.value&&"string"!=typeof t.value&&(t=n_({},t,{value:String(t.value)})),(r=e.call(this,t)||this).type="decl",r}return i_(t,e),r_(t,[{key:"variable",get:function(){return this.prop.startsWith("--")||"$"===this.prop[0]}}]),t}(QA),tP=eP;eP.default=eP;var rP=NA.SourceMapConsumer,nP=NA.SourceMapGenerator,oP=NA.existsSync,iP=NA.readFileSync,sP=NA.dirname,aP=NA.join,lP=function(){function e(e,t){if(!1!==t.map){this.loadAnnotation(e),this.inline=this.startWith(this.annotation,"data:");var r=t.map?t.map.prev:void 0,n=this.loadMap(t.from,r);!this.mapFile&&t.from&&(this.mapFile=t.from),this.mapFile&&(this.root=sP(this.mapFile)),n&&(this.text=n)}}var t=e.prototype;return t.consumer=function(){return this.consumerCache||(this.consumerCache=new rP(this.text)),this.consumerCache},t.decodeInline=function(e){var t;if(/^data:application\/json;charset=utf-?8,/.test(e)||/^data:application\/json,/.test(e))return decodeURIComponent(e.substr(RegExp.lastMatch.length));if(/^data:application\/json;charset=utf-?8;base64,/.test(e)||/^data:application\/json;base64,/.test(e))return t=e.substr(RegExp.lastMatch.length),Buffer?Buffer.from(t,"base64").toString():window.atob(t);var r=e.match(/data:application\/json;([^,]+),/)[1];throw new Error("Unsupported source map encoding "+r)},t.getAnnotationURL=function(e){return e.replace(/^\/\*\s*# sourceMappingURL=/,"").trim()},t.isMap=function(e){return"object"===(void 0===e?"undefined":c_(e))&&("string"==typeof e.mappings||"string"==typeof e._mappings||Array.isArray(e.sections))},t.loadAnnotation=function(e){var t=e.match(/\/\*\s*# sourceMappingURL=/gm);if(t){var r=e.lastIndexOf(t.pop()),n=e.indexOf("*/",r);r>-1&&n>-1&&(this.annotation=this.getAnnotationURL(e.substring(r,n)))}},t.loadFile=function(e){if(this.root=sP(e),oP(e))return this.mapFile=e,iP(e,"utf-8").toString().trim()},t.loadMap=function(e,t){if(!1===t)return!1;if(t){if("string"==typeof t)return t;if("function"!=typeof t){if(s_(t,rP))return nP.fromSourceMap(t).toString();if(s_(t,nP))return t.toString();if(this.isMap(t))return JSON.stringify(t);throw new Error("Unsupported previous source map format: "+t.toString())}var r=t(e);if(r){var n=this.loadFile(r);if(!n)throw new Error("Unable to load previous source map: "+r.toString());return n}}else{if(this.inline)return this.decodeInline(this.annotation);if(this.annotation){var o=this.annotation;return e&&(o=aP(sP(e),o)),this.loadFile(o)}}},t.startWith=function(e,t){return!!e&&e.substr(0,t.length)===t},t.withContent=function(){return!!(this.consumer().sourcesContent&&this.consumer().sourcesContent.length>0)},e}(),cP=lP;lP.default=lP;var uP=NA.SourceMapConsumer,pP=NA.SourceMapGenerator,dP=NA.fileURLToPath,fP=NA.pathToFileURL,hP=NA.isAbsolute,mP=NA.resolve,gP=function(e){void 0===e&&(e=21);for(var t="",r=e;r--;)t+="useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict"[64*Math.random()|0];return t},vP=NA,yP=FA,bP=cP,wP=Symbol("fromOffsetCache"),xP=Boolean(uP&&pP),_P=Boolean(mP&&hP),SP=function(){function e(e,t){if(void 0===t&&(t={}),null==e||"object"===(void 0===e?"undefined":c_(e))&&!e.toString)throw new Error("PostCSS received "+e+" instead of CSS string");if(this.css=e.toString(),"\ufeff"===this.css[0]||""===this.css[0]?(this.hasBOM=!0,this.css=this.css.slice(1)):this.hasBOM=!1,t.from&&(!_P||/^\w+:\/\//.test(t.from)||hP(t.from)?this.file=t.from:this.file=mP(t.from)),_P&&xP){var r=new bP(this.css,t);if(r.text){this.map=r;var n=r.consumer().file;!this.file&&n&&(this.file=this.mapResolve(n))}}this.file||(this.id="<input css "+gP(6)+">"),this.map&&(this.map.file=this.from)}var t=e.prototype;return t.error=function(e,t,r,n){var o,i,s;if(void 0===n&&(n={}),t&&"object"===(void 0===t?"undefined":c_(t))){var a=t,l=r;if("number"==typeof a.offset){var c=this.fromOffset(a.offset);t=c.line,r=c.col}else t=a.line,r=a.column;if("number"==typeof l.offset){var u=this.fromOffset(l.offset);i=u.line,s=u.col}else i=l.line,s=l.column}else if(!r){var p=this.fromOffset(t);t=p.line,r=p.col}var d=this.origin(t,r,i,s);return(o=d?new yP(e,void 0===d.endLine?d.line:{column:d.column,line:d.line},void 0===d.endLine?d.column:{column:d.endColumn,line:d.endLine},d.source,d.file,n.plugin):new yP(e,void 0===i?t:{column:r,line:t},void 0===i?r:{column:s,line:i},this.css,this.file,n.plugin)).input={column:r,endColumn:s,endLine:i,line:t,source:this.css},this.file&&(fP&&(o.input.url=fP(this.file).toString()),o.input.file=this.file),o},t.fromOffset=function(e){var t;if(this[wP])t=this[wP];else{var r=this.css.split("\n");t=new Array(r.length);for(var n=0,o=0,i=r.length;o<i;o++)t[o]=n,n+=r[o].length+1;this[wP]=t}var s=0;if(e>=t[t.length-1])s=t.length-1;else for(var a,l=t.length-2;s<l;)if(e<t[a=s+(l-s>>1)])l=a-1;else{if(!(e>=t[a+1])){s=a;break}s=a+1}return{col:e-t[s]+1,line:s+1}},t.mapResolve=function(e){return/^\w+:\/\//.test(e)?e:mP(this.map.consumer().sourceRoot||this.map.root||".",e)},t.origin=function(e,t,r,n){if(!this.map)return!1;var o,i,s=this.map.consumer(),a=s.originalPositionFor({column:t,line:e});if(!a.source)return!1;"number"==typeof r&&(o=s.originalPositionFor({column:n,line:r})),i=hP(a.source)?fP(a.source):new URL(a.source,this.map.consumer().sourceRoot||fP(this.map.mapFile));var l={column:a.column,endColumn:o&&o.column,endLine:o&&o.line,line:a.line,url:i.toString()};if("file:"===i.protocol){if(!dP)throw new Error("file: protocol is not available in this PostCSS build");l.file=dP(i)}var c=s.sourceContentFor(a.source);return c&&(l.source=c),l},t.toJSON=function(){for(var e={},t=0,r=["hasBOM","css","file","id"];t<r.length;t++){var n=r[t];null!=this[n]&&(e[n]=this[n])}return this.map&&(e.map=n_({},this.map),e.map.consumerCache&&(e.map.consumerCache=void 0)),e},r_(e,[{key:"from",get:function(){return this.file||this.id}}]),e}(),kP=SP;SP.default=SP,vP&&vP.registerInput&&vP.registerInput(SP);var CP=NA.SourceMapConsumer,OP=NA.SourceMapGenerator,EP=NA.dirname,TP=NA.relative,RP=NA.resolve,IP=NA.sep,MP=NA.pathToFileURL,AP=kP,PP=Boolean(CP&&OP),NP=Boolean(EP&&RP&&TP&&IP),jP=function(){function e(e,t,r,n){this.stringify=e,this.mapOpts=r.map||{},this.root=t,this.opts=r,this.css=n,this.originalCSS=n,this.usesFileUrls=!this.mapOpts.from&&this.mapOpts.absolute,this.memoizedFileURLs=new Map,this.memoizedPaths=new Map,this.memoizedURLs=new Map}var t=e.prototype;return t.addAnnotation=function(){var e;e=this.isInline()?"data:application/json;base64,"+this.toBase64(this.map.toString()):"string"==typeof this.mapOpts.annotation?this.mapOpts.annotation:"function"==typeof this.mapOpts.annotation?this.mapOpts.annotation(this.opts.to,this.root):this.outputFile()+".map";var t="\n";this.css.includes("\r\n")&&(t="\r\n"),this.css+=t+"/*# sourceMappingURL="+e+" */"},t.applyPrevMaps=function(){for(var e,t=d_(this.previous());!(e=t()).done;){var r=e.value,n=this.toUrl(this.path(r.file)),o=r.root||EP(r.file),i=void 0;!1===this.mapOpts.sourcesContent?(i=new CP(r.text)).sourcesContent&&(i.sourcesContent=null):i=r.consumer(),this.map.applySourceMap(i,n,this.toUrl(this.path(o)))}},t.clearAnnotation=function(){if(!1!==this.mapOpts.annotation)if(this.root)for(var e,t=this.root.nodes.length-1;t>=0;t--)"comment"===(e=this.root.nodes[t]).type&&0===e.text.indexOf("# sourceMappingURL=")&&this.root.removeChild(t);else this.css&&(this.css=this.css.replace(/\n*?\/\*#[\S\s]*?\*\/$/gm,""))},t.generate=function(){if(this.clearAnnotation(),NP&&PP&&this.isMap())return this.generateMap();var e="";return this.stringify(this.root,function(t){e+=t}),[e]},t.generateMap=function(){if(this.root)this.generateString();else if(1===this.previous().length){var e=this.previous()[0].consumer();e.file=this.outputFile(),this.map=OP.fromSourceMap(e,{ignoreInvalidMapping:!0})}else this.map=new OP({file:this.outputFile(),ignoreInvalidMapping:!0}),this.map.addMapping({generated:{column:0,line:1},original:{column:0,line:1},source:this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>"});return this.isSourcesContent()&&this.setSourcesContent(),this.root&&this.previous().length>0&&this.applyPrevMaps(),this.isAnnotation()&&this.addAnnotation(),this.isInline()?[this.css]:[this.css,this.map]},t.generateString=function(){var e=this;this.css="",this.map=new OP({file:this.outputFile(),ignoreInvalidMapping:!0});var t,r,n=1,o=1,i="<no source>",s={generated:{column:0,line:0},original:{column:0,line:0},source:""};this.stringify(this.root,function(a,l,c){if(e.css+=a,l&&"end"!==c&&(s.generated.line=n,s.generated.column=o-1,l.source&&l.source.start?(s.source=e.sourcePath(l),s.original.line=l.source.start.line,s.original.column=l.source.start.column-1,e.map.addMapping(s)):(s.source=i,s.original.line=1,s.original.column=0,e.map.addMapping(s))),(t=a.match(/\n/g))?(n+=t.length,r=a.lastIndexOf("\n"),o=a.length-r):o+=a.length,l&&"start"!==c){var u=l.parent||{raws:{}};("decl"===l.type||"atrule"===l.type&&!l.nodes)&&l===u.last&&!u.raws.semicolon||(l.source&&l.source.end?(s.source=e.sourcePath(l),s.original.line=l.source.end.line,s.original.column=l.source.end.column-1,s.generated.line=n,s.generated.column=o-2,e.map.addMapping(s)):(s.source=i,s.original.line=1,s.original.column=0,s.generated.line=n,s.generated.column=o-1,e.map.addMapping(s)))}})},t.isAnnotation=function(){return!!this.isInline()||(void 0!==this.mapOpts.annotation?this.mapOpts.annotation:!this.previous().length||this.previous().some(function(e){return e.annotation}))},t.isInline=function(){if(void 0!==this.mapOpts.inline)return this.mapOpts.inline;var e=this.mapOpts.annotation;return(void 0===e||!0===e)&&(!this.previous().length||this.previous().some(function(e){return e.inline}))},t.isMap=function(){return void 0!==this.opts.map?!!this.opts.map:this.previous().length>0},t.isSourcesContent=function(){return void 0!==this.mapOpts.sourcesContent?this.mapOpts.sourcesContent:!this.previous().length||this.previous().some(function(e){return e.withContent()})},t.outputFile=function(){return this.opts.to?this.path(this.opts.to):this.opts.from?this.path(this.opts.from):"to.css"},t.path=function(e){if(this.mapOpts.absolute)return e;if(60===e.charCodeAt(0))return e;if(/^\w+:\/\//.test(e))return e;var t=this.memoizedPaths.get(e);if(t)return t;var r=this.opts.to?EP(this.opts.to):".";"string"==typeof this.mapOpts.annotation&&(r=EP(RP(r,this.mapOpts.annotation)));var n=TP(r,e);return this.memoizedPaths.set(e,n),n},t.previous=function(){var e=this;if(!this.previousMaps)if(this.previousMaps=[],this.root)this.root.walk(function(t){if(t.source&&t.source.input.map){var r=t.source.input.map;e.previousMaps.includes(r)||e.previousMaps.push(r)}});else{var t=new AP(this.originalCSS,this.opts);t.map&&this.previousMaps.push(t.map)}return this.previousMaps},t.setSourcesContent=function(){var e=this,t={};if(this.root)this.root.walk(function(r){if(r.source){var n=r.source.input.from;if(n&&!t[n]){t[n]=!0;var o=e.usesFileUrls?e.toFileUrl(n):e.toUrl(e.path(n));e.map.setSourceContent(o,r.source.input.css)}}});else if(this.css){var r=this.opts.from?this.toUrl(this.path(this.opts.from)):"<no source>";this.map.setSourceContent(r,this.css)}},t.sourcePath=function(e){return this.mapOpts.from?this.toUrl(this.mapOpts.from):this.usesFileUrls?this.toFileUrl(e.source.input.from):this.toUrl(this.path(e.source.input.from))},t.toBase64=function(e){return Buffer?Buffer.from(e).toString("base64"):window.btoa(unescape(encodeURIComponent(e)))},t.toFileUrl=function(e){var t=this.memoizedFileURLs.get(e);if(t)return t;if(MP){var r=MP(e).toString();return this.memoizedFileURLs.set(e,r),r}throw new Error("`map.absolute` option is not available in this PostCSS build")},t.toUrl=function(e){var t=this.memoizedURLs.get(e);if(t)return t;"\\"===IP&&(e=e.replace(/\\/g,"/"));var r=encodeURI(e).replace(/[#?]/g,encodeURIComponent);return this.memoizedURLs.set(e,r),r},e}(),LP=jP,DP=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="comment",r}return i_(t,e),t}(QA),FP=DP;DP.default=DP;var $P,BP,zP,VP,UP=$A.isClean,qP=$A.my,WP=tP,HP=FP;function GP(e){return e.map(function(e){return e.nodes&&(e.nodes=GP(e.nodes)),delete e.source,e})}function KP(e){if(e[UP]=!1,e.proxyOf.nodes)for(var t,r=d_(e.proxyOf.nodes);!(t=r()).done;)KP(t.value)}var YP=function(e){function t(){return e.apply(this,arguments)||this}i_(t,e);var r=t.prototype;return r.append=function(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];for(var n,o=d_(t);!(n=o()).done;)for(var i,s=n.value,a=d_(this.normalize(s,this.last));!(i=a()).done;){var l=i.value;this.proxyOf.nodes.push(l)}return this.markDirty(),this},r.cleanRaws=function(t){if(e.prototype.cleanRaws.call(this,t),this.nodes)for(var r,n=d_(this.nodes);!(r=n()).done;)r.value.cleanRaws(t)},r.each=function(e){if(this.proxyOf.nodes){for(var t,r,n=this.getIterator();this.indexes[n]<this.proxyOf.nodes.length&&(t=this.indexes[n],!1!==(r=e(this.proxyOf.nodes[t],t)));)this.indexes[n]+=1;return delete this.indexes[n],r}},r.every=function(e){return this.nodes.every(e)},r.getIterator=function(){this.lastEach||(this.lastEach=0),this.indexes||(this.indexes={}),this.lastEach+=1;var e=this.lastEach;return this.indexes[e]=0,e},r.getProxyProcessor=function(){return{get:function(e,t){return"proxyOf"===t?e:e[t]?"each"===t||"string"==typeof t&&t.startsWith("walk")?function(){for(var r=arguments.length,n=new Array(r),o=0;o<r;o++)n[o]=arguments[o];var i;return(i=e)[t].apply(i,[].concat(n.map(function(e){return"function"==typeof e?function(t,r){return e(t.toProxy(),r)}:e})))}:"every"===t||"some"===t?function(r){return e[t](function(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),o=1;o<t;o++)n[o-1]=arguments[o];return r.apply(void 0,[].concat([e.toProxy()],n))})}:"root"===t?function(){return e.root().toProxy()}:"nodes"===t?e.nodes.map(function(e){return e.toProxy()}):"first"===t||"last"===t?e[t].toProxy():e[t]:e[t]},set:function(e,t,r){return e[t]===r||(e[t]=r,"name"!==t&&"params"!==t&&"selector"!==t||e.markDirty()),!0}}},r.index=function(e){return"number"==typeof e?e:(e.proxyOf&&(e=e.proxyOf),this.proxyOf.nodes.indexOf(e))},r.insertAfter=function(e,t){var r,n=this.index(e),o=this.normalize(t,this.proxyOf.nodes[n]).reverse();n=this.index(e);for(var i,s=d_(o);!(i=s()).done;){var a=i.value;this.proxyOf.nodes.splice(n+1,0,a)}for(var l in this.indexes)n<(r=this.indexes[l])&&(this.indexes[l]=r+o.length);return this.markDirty(),this},r.insertBefore=function(e,t){var r,n=this.index(e),o=0===n&&"prepend",i=this.normalize(t,this.proxyOf.nodes[n],o).reverse();n=this.index(e);for(var s,a=d_(i);!(s=a()).done;){var l=s.value;this.proxyOf.nodes.splice(n,0,l)}for(var c in this.indexes)n<=(r=this.indexes[c])&&(this.indexes[c]=r+i.length);return this.markDirty(),this},r.normalize=function(e,r){var n=this;if("string"==typeof e)e=GP($P(e).nodes);else if(void 0===e)e=[];else if(Array.isArray(e))for(var o,i=d_(e=e.slice(0));!(o=i()).done;){var s=o.value;s.parent&&s.parent.removeChild(s,"ignore")}else if("root"===e.type&&"document"!==this.type)for(var a,l=d_(e=e.nodes.slice(0));!(a=l()).done;){var c=a.value;c.parent&&c.parent.removeChild(c,"ignore")}else if(e.type)e=[e];else if(e.prop){if(void 0===e.value)throw new Error("Value field is missed in node creation");"string"!=typeof e.value&&(e.value=String(e.value)),e=[new WP(e)]}else if(e.selector)e=[new BP(e)];else if(e.name)e=[new zP(e)];else{if(!e.text)throw new Error("Unknown node type in node creation");e=[new HP(e)]}var u=e.map(function(e){return e[qP]||t.rebuild(e),(e=e.proxyOf).parent&&e.parent.removeChild(e),e[UP]&&KP(e),void 0===e.raws.before&&r&&void 0!==r.raws.before&&(e.raws.before=r.raws.before.replace(/\S/g,"")),e.parent=n.proxyOf,e});return u},r.prepend=function(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];for(var n,o=d_(t=t.reverse());!(n=o()).done;){for(var i,s=n.value,a=this.normalize(s,this.first,"prepend").reverse(),l=d_(a);!(i=l()).done;){var c=i.value;this.proxyOf.nodes.unshift(c)}for(var u in this.indexes)this.indexes[u]=this.indexes[u]+a.length}return this.markDirty(),this},r.push=function(e){return e.parent=this,this.proxyOf.nodes.push(e),this},r.removeAll=function(){for(var e,t=d_(this.proxyOf.nodes);!(e=t()).done;)e.value.parent=void 0;return this.proxyOf.nodes=[],this.markDirty(),this},r.removeChild=function(e){var t;for(var r in e=this.index(e),this.proxyOf.nodes[e].parent=void 0,this.proxyOf.nodes.splice(e,1),this.indexes)(t=this.indexes[r])>=e&&(this.indexes[r]=t-1);return this.markDirty(),this},r.replaceValues=function(e,t,r){return r||(r=t,t={}),this.walkDecls(function(n){t.props&&!t.props.includes(n.prop)||t.fast&&!n.value.includes(t.fast)||(n.value=n.value.replace(e,r))}),this.markDirty(),this},r.some=function(e){return this.nodes.some(e)},r.walk=function(e){return this.each(function(t,r){var n;try{n=e(t,r)}catch(e){throw t.addToError(e)}return!1!==n&&t.walk&&(n=t.walk(e)),n})},r.walkAtRules=function(e,t){return t?s_(e,RegExp)?this.walk(function(r,n){if("atrule"===r.type&&e.test(r.name))return t(r,n)}):this.walk(function(r,n){if("atrule"===r.type&&r.name===e)return t(r,n)}):(t=e,this.walk(function(e,r){if("atrule"===e.type)return t(e,r)}))},r.walkComments=function(e){return this.walk(function(t,r){if("comment"===t.type)return e(t,r)})},r.walkDecls=function(e,t){return t?s_(e,RegExp)?this.walk(function(r,n){if("decl"===r.type&&e.test(r.prop))return t(r,n)}):this.walk(function(r,n){if("decl"===r.type&&r.prop===e)return t(r,n)}):(t=e,this.walk(function(e,r){if("decl"===e.type)return t(e,r)}))},r.walkRules=function(e,t){return t?s_(e,RegExp)?this.walk(function(r,n){if("rule"===r.type&&e.test(r.selector))return t(r,n)}):this.walk(function(r,n){if("rule"===r.type&&r.selector===e)return t(r,n)}):(t=e,this.walk(function(e,r){if("rule"===e.type)return t(e,r)}))},r_(t,[{key:"first",get:function(){if(this.proxyOf.nodes)return this.proxyOf.nodes[0]}},{key:"last",get:function(){if(this.proxyOf.nodes)return this.proxyOf.nodes[this.proxyOf.nodes.length-1]}}]),t}(QA);YP.registerParse=function(e){$P=e},YP.registerRule=function(e){BP=e},YP.registerAtRule=function(e){zP=e},YP.registerRoot=function(e){VP=e};var ZP=YP;YP.default=YP,YP.rebuild=function(e){"atrule"===e.type?Object.setPrototypeOf(e,zP.prototype):"rule"===e.type?Object.setPrototypeOf(e,BP.prototype):"decl"===e.type?Object.setPrototypeOf(e,WP.prototype):"comment"===e.type?Object.setPrototypeOf(e,HP.prototype):"root"===e.type&&Object.setPrototypeOf(e,VP.prototype),e[qP]=!0,e.nodes&&e.nodes.forEach(function(e){YP.rebuild(e)})};var XP,JP,QP=function(e){function t(t){var r;return(r=e.call(this,n_({type:"document"},t))||this).nodes||(r.nodes=[]),r}return i_(t,e),t.prototype.toResult=function(e){return void 0===e&&(e={}),new XP(new JP,this,e).stringify()},t}(ZP);QP.registerLazyResult=function(e){XP=e},QP.registerProcessor=function(e){JP=e};var eN=QP;QP.default=QP;var tN={},rN=function(e){tN[e]||(tN[e]=!0,"undefined"!=typeof console&&console.warn&&console.warn(e))},nN=function(){function e(e,t){if(void 0===t&&(t={}),this.type="warning",this.text=e,t.node&&t.node.source){var r=t.node.rangeBy(t);this.line=r.start.line,this.column=r.start.column,this.endLine=r.end.line,this.endColumn=r.end.column}for(var n in t)this[n]=t[n]}return e.prototype.toString=function(){return this.node?this.node.error(this.text,{index:this.index,plugin:this.plugin,word:this.word}).message:this.plugin?this.plugin+": "+this.text:this.text},e}(),oN=nN;nN.default=nN;var iN=oN,sN=function(){function e(e,t,r){this.processor=e,this.messages=[],this.root=t,this.opts=r,this.css=void 0,this.map=void 0}var t=e.prototype;return t.toString=function(){return this.css},t.warn=function(e,t){void 0===t&&(t={}),t.plugin||this.lastPlugin&&this.lastPlugin.postcssPlugin&&(t.plugin=this.lastPlugin.postcssPlugin);var r=new iN(e,t);return this.messages.push(r),r},t.warnings=function(){return this.messages.filter(function(e){return"warning"===e.type})},r_(e,[{key:"content",get:function(){return this.css}}]),e}(),aN=sN;sN.default=sN;var lN="'".charCodeAt(0),cN='"'.charCodeAt(0),uN="\\".charCodeAt(0),pN="/".charCodeAt(0),dN="\n".charCodeAt(0),fN=" ".charCodeAt(0),hN="\f".charCodeAt(0),mN="\t".charCodeAt(0),gN="\r".charCodeAt(0),vN="[".charCodeAt(0),yN="]".charCodeAt(0),bN="(".charCodeAt(0),wN=")".charCodeAt(0),xN="{".charCodeAt(0),_N="}".charCodeAt(0),SN=";".charCodeAt(0),kN="*".charCodeAt(0),CN=":".charCodeAt(0),ON="@".charCodeAt(0),EN=/[\t\n\f\r "#'()/;[\\\]{}]/g,TN=/[\t\n\f\r !"#'():;@[\\\]{}]|\/(?=\*)/g,RN=/.[\r\n"'(/\\]/,IN=/[\da-f]/i,MN=ZP,AN=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="atrule",r}i_(t,e);var r=t.prototype;return r.append=function(){for(var t=arguments.length,r=new Array(t),n=0;n<t;n++)r[n]=arguments[n];var o;return this.proxyOf.nodes||(this.nodes=[]),(o=e.prototype.append).call.apply(o,[].concat([this],r))},r.prepend=function(){for(var t=arguments.length,r=new Array(t),n=0;n<t;n++)r[n]=arguments[n];var o;return this.proxyOf.nodes||(this.nodes=[]),(o=e.prototype.prepend).call.apply(o,[].concat([this],r))},t}(MN),PN=AN;AN.default=AN,MN.registerAtRule(AN);var NN,jN,LN=ZP,DN=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="root",r.nodes||(r.nodes=[]),r}i_(t,e);var r=t.prototype;return r.normalize=function(t,r,n){var o=e.prototype.normalize.call(this,t);if(r)if("prepend"===n)this.nodes.length>1?r.raws.before=this.nodes[1].raws.before:delete r.raws.before;else if(this.first!==r)for(var i,s=d_(o);!(i=s()).done;)i.value.raws.before=r.raws.before;return o},r.removeChild=function(t,r){var n=this.index(t);return!r&&0===n&&this.nodes.length>1&&(this.nodes[1].raws.before=this.nodes[n].raws.before),e.prototype.removeChild.call(this,t)},r.toResult=function(e){return void 0===e&&(e={}),new NN(new jN,this,e).stringify()},t}(LN);DN.registerLazyResult=function(e){NN=e},DN.registerProcessor=function(e){jN=e};var FN=DN;DN.default=DN,LN.registerRoot(DN);var $N={comma:function(e){return $N.split(e,[","],!0)},space:function(e){return $N.split(e,[" ","\n","\t"])},split:function(e,t,r){for(var n,o=[],i="",s=!1,a=0,l=!1,c="",u=!1,p=d_(e);!(n=p()).done;){var d=n.value;u?u=!1:"\\"===d?u=!0:l?d===c&&(l=!1):'"'===d||"'"===d?(l=!0,c=d):"("===d?a+=1:")"===d?a>0&&(a-=1):0===a&&t.includes(d)&&(s=!0),s?(""!==i&&o.push(i.trim()),i="",s=!1):i+=d}return(r||""!==i)&&o.push(i.trim()),o}},BN=$N;$N.default=$N;var zN=ZP,VN=BN,UN=function(e){function t(t){var r;return(r=e.call(this,t)||this).type="rule",r.nodes||(r.nodes=[]),r}return i_(t,e),r_(t,[{key:"selectors",get:function(){return VN.comma(this.selector)},set:function(e){var t=this.selector?this.selector.match(/,\s*/):null,r=t?t[0]:","+this.raw("between","beforeOpen");this.selector=e.join(r)}}]),t}(zN),qN=UN;UN.default=UN,zN.registerRule(UN);var WN=tP,HN=FP,GN=PN,KN=FN,YN=qN,ZN={empty:!0,space:!0},XN=function(){function e(e){this.input=e,this.root=new KN,this.current=this.root,this.spaces="",this.semicolon=!1,this.createTokenizer(),this.root.source={input:e,start:{column:1,line:1,offset:0}}}var t=e.prototype;return t.atrule=function(e){var t,r,n,o=new GN;o.name=e[1].slice(1),""===o.name&&this.unnamedAtrule(o,e),this.init(o,e[2]);for(var i=!1,s=!1,a=[],l=[];!this.tokenizer.endOfFile();){if("("===(t=(e=this.tokenizer.nextToken())[0])||"["===t?l.push("("===t?")":"]"):"{"===t&&l.length>0?l.push("}"):t===l[l.length-1]&&l.pop(),0===l.length){if(";"===t){o.source.end=this.getPosition(e[2]),o.source.end.offset++,this.semicolon=!0;break}if("{"===t){s=!0;break}if("}"===t){if(a.length>0){for(r=a[n=a.length-1];r&&"space"===r[0];)r=a[--n];r&&(o.source.end=this.getPosition(r[3]||r[2]),o.source.end.offset++)}this.end(e);break}a.push(e)}else a.push(e);if(this.tokenizer.endOfFile()){i=!0;break}}o.raws.between=this.spacesAndCommentsFromEnd(a),a.length?(o.raws.afterName=this.spacesAndCommentsFromStart(a),this.raw(o,"params",a),i&&(e=a[a.length-1],o.source.end=this.getPosition(e[3]||e[2]),o.source.end.offset++,this.spaces=o.raws.between,o.raws.between="")):(o.raws.afterName="",o.params=""),s&&(o.nodes=[],this.current=o)},t.checkMissedSemicolon=function(e){var t=this.colon(e);if(!1!==t){for(var r,n=0,o=t-1;o>=0&&("space"===(r=e[o])[0]||2!==(n+=1));o--);throw this.input.error("Missed semicolon","word"===r[0]?r[3]+1:r[2])}},t.colon=function(e){for(var t,r,n,o,i=0,s=d_(e.entries());!(o=s()).done;){var a=o.value,l=a[0];if("("===(r=(t=a[1])[0])&&(i+=1),")"===r&&(i-=1),0===i&&":"===r){if(n){if("word"===n[0]&&"progid"===n[1])continue;return l}this.doubleColon(t)}n=t}return!1},t.comment=function(e){var t=new HN;this.init(t,e[2]),t.source.end=this.getPosition(e[3]||e[2]),t.source.end.offset++;var r=e[1].slice(2,-2);if(/^\s*$/.test(r))t.text="",t.raws.left=r,t.raws.right="";else{var n=r.match(/^(\s*)([^]*\S)(\s*)$/);t.text=n[2],t.raws.left=n[1],t.raws.right=n[3]}},t.createTokenizer=function(){this.tokenizer=function(e,t){void 0===t&&(t={});var r,n,o,i,s,a,l,c,u,p,d=e.css.valueOf(),f=t.ignoreErrors,h=d.length,m=0,g=[],v=[];function y(t){throw e.error("Unclosed "+t,m)}return{back:function(e){v.push(e)},endOfFile:function(){return 0===v.length&&m>=h},nextToken:function(e){if(v.length)return v.pop();if(!(m>=h)){var t=!!e&&e.ignoreUnclosed;switch(r=d.charCodeAt(m)){case dN:case fN:case mN:case gN:case hN:n=m;do{n+=1,r=d.charCodeAt(n)}while(r===fN||r===dN||r===mN||r===gN||r===hN);p=["space",d.slice(m,n)],m=n-1;break;case vN:case yN:case xN:case _N:case CN:case SN:case wN:var b=String.fromCharCode(r);p=[b,b,m];break;case bN:if(c=g.length?g.pop()[1]:"",u=d.charCodeAt(m+1),"url"===c&&u!==lN&&u!==cN&&u!==fN&&u!==dN&&u!==mN&&u!==hN&&u!==gN){n=m;do{if(a=!1,-1===(n=d.indexOf(")",n+1))){if(f||t){n=m;break}y("bracket")}for(l=n;d.charCodeAt(l-1)===uN;)l-=1,a=!a}while(a);p=["brackets",d.slice(m,n+1),m,n],m=n}else n=d.indexOf(")",m+1),i=d.slice(m,n+1),-1===n||RN.test(i)?p=["(","(",m]:(p=["brackets",i,m,n],m=n);break;case lN:case cN:o=r===lN?"'":'"',n=m;do{if(a=!1,-1===(n=d.indexOf(o,n+1))){if(f||t){n=m+1;break}y("string")}for(l=n;d.charCodeAt(l-1)===uN;)l-=1,a=!a}while(a);p=["string",d.slice(m,n+1),m,n],m=n;break;case ON:EN.lastIndex=m+1,EN.test(d),n=0===EN.lastIndex?d.length-1:EN.lastIndex-2,p=["at-word",d.slice(m,n+1),m,n],m=n;break;case uN:for(n=m,s=!0;d.charCodeAt(n+1)===uN;)n+=1,s=!s;if(r=d.charCodeAt(n+1),s&&r!==pN&&r!==fN&&r!==dN&&r!==mN&&r!==gN&&r!==hN&&(n+=1,IN.test(d.charAt(n)))){for(;IN.test(d.charAt(n+1));)n+=1;d.charCodeAt(n+1)===fN&&(n+=1)}p=["word",d.slice(m,n+1),m,n],m=n;break;default:r===pN&&d.charCodeAt(m+1)===kN?(0===(n=d.indexOf("*/",m+2)+1)&&(f||t?n=d.length:y("comment")),p=["comment",d.slice(m,n+1),m,n],m=n):(TN.lastIndex=m+1,TN.test(d),n=0===TN.lastIndex?d.length-1:TN.lastIndex-2,p=["word",d.slice(m,n+1),m,n],g.push(p),m=n)}return m++,p}},position:function(){return m}}}(this.input)},t.decl=function(e,t){var r=new WN;this.init(r,e[0][2]);var n,o=e[e.length-1];for(";"===o[0]&&(this.semicolon=!0,e.pop()),r.source.end=this.getPosition(o[3]||o[2]||function(e){for(var t=e.length-1;t>=0;t--){var r=e[t],n=r[3]||r[2];if(n)return n}}(e)),r.source.end.offset++;"word"!==e[0][0];)1===e.length&&this.unknownWord(e),r.raws.before+=e.shift()[1];for(r.source.start=this.getPosition(e[0][2]),r.prop="";e.length;){var i=e[0][0];if(":"===i||"space"===i||"comment"===i)break;r.prop+=e.shift()[1]}for(r.raws.between="";e.length;){if(":"===(n=e.shift())[0]){r.raws.between+=n[1];break}"word"===n[0]&&/\w/.test(n[1])&&this.unknownWord([n]),r.raws.between+=n[1]}"_"!==r.prop[0]&&"*"!==r.prop[0]||(r.raws.before+=r.prop[0],r.prop=r.prop.slice(1));for(var s,a=[];e.length&&("space"===(s=e[0][0])||"comment"===s);)a.push(e.shift());this.precheckMissedSemicolon(e);for(var l=e.length-1;l>=0;l--){if("!important"===(n=e[l])[1].toLowerCase()){r.important=!0;var c=this.stringFrom(e,l);" !important"!==(c=this.spacesFromEnd(e)+c)&&(r.raws.important=c);break}if("important"===n[1].toLowerCase()){for(var u=e.slice(0),p="",d=l;d>0;d--){var f=u[d][0];if(0===p.trim().indexOf("!")&&"space"!==f)break;p=u.pop()[1]+p}0===p.trim().indexOf("!")&&(r.important=!0,r.raws.important=p,e=u)}if("space"!==n[0]&&"comment"!==n[0])break}var h=e.some(function(e){return"space"!==e[0]&&"comment"!==e[0]});h&&(r.raws.between+=a.map(function(e){return e[1]}).join(""),a=[]),this.raw(r,"value",a.concat(e),t),r.value.includes(":")&&!t&&this.checkMissedSemicolon(e)},t.doubleColon=function(e){throw this.input.error("Double colon",{offset:e[2]},{offset:e[2]+e[1].length})},t.emptyRule=function(e){var t=new YN;this.init(t,e[2]),t.selector="",t.raws.between="",this.current=t},t.end=function(e){this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.semicolon=!1,this.current.raws.after=(this.current.raws.after||"")+this.spaces,this.spaces="",this.current.parent?(this.current.source.end=this.getPosition(e[2]),this.current.source.end.offset++,this.current=this.current.parent):this.unexpectedClose(e)},t.endFile=function(){this.current.parent&&this.unclosedBlock(),this.current.nodes&&this.current.nodes.length&&(this.current.raws.semicolon=this.semicolon),this.current.raws.after=(this.current.raws.after||"")+this.spaces,this.root.source.end=this.getPosition(this.tokenizer.position())},t.freeSemicolon=function(e){if(this.spaces+=e[1],this.current.nodes){var t=this.current.nodes[this.current.nodes.length-1];t&&"rule"===t.type&&!t.raws.ownSemicolon&&(t.raws.ownSemicolon=this.spaces,this.spaces="")}},t.getPosition=function(e){var t=this.input.fromOffset(e);return{column:t.col,line:t.line,offset:e}},t.init=function(e,t){this.current.push(e),e.source={input:this.input,start:this.getPosition(t)},e.raws.before=this.spaces,this.spaces="","comment"!==e.type&&(this.semicolon=!1)},t.other=function(e){for(var t=!1,r=null,n=!1,o=null,i=[],s=e[1].startsWith("--"),a=[],l=e;l;){if(r=l[0],a.push(l),"("===r||"["===r)o||(o=l),i.push("("===r?")":"]");else if(s&&n&&"{"===r)o||(o=l),i.push("}");else if(0===i.length){if(";"===r){if(n)return void this.decl(a,s);break}if("{"===r)return void this.rule(a);if("}"===r){this.tokenizer.back(a.pop()),t=!0;break}":"===r&&(n=!0)}else r===i[i.length-1]&&(i.pop(),0===i.length&&(o=null));l=this.tokenizer.nextToken()}if(this.tokenizer.endOfFile()&&(t=!0),i.length>0&&this.unclosedBracket(o),t&&n){if(!s)for(;a.length&&("space"===(l=a[a.length-1][0])||"comment"===l);)this.tokenizer.back(a.pop());this.decl(a,s)}else this.unknownWord(a)},t.parse=function(){for(var e;!this.tokenizer.endOfFile();)switch((e=this.tokenizer.nextToken())[0]){case"space":this.spaces+=e[1];break;case";":this.freeSemicolon(e);break;case"}":this.end(e);break;case"comment":this.comment(e);break;case"at-word":this.atrule(e);break;case"{":this.emptyRule(e);break;default:this.other(e)}this.endFile()},t.precheckMissedSemicolon=function(){},t.raw=function(e,t,r,n){for(var o,i,s,a,l=r.length,c="",u=!0,p=0;p<l;p+=1)"space"!==(i=(o=r[p])[0])||p!==l-1||n?"comment"===i?(a=r[p-1]?r[p-1][0]:"empty",s=r[p+1]?r[p+1][0]:"empty",ZN[a]||ZN[s]||","===c.slice(-1)?u=!1:c+=o[1]):c+=o[1]:u=!1;if(!u){var d=r.reduce(function(e,t){return e+t[1]},"");e.raws[t]={raw:d,value:c}}e[t]=c},t.rule=function(e){e.pop();var t=new YN;this.init(t,e[0][2]),t.raws.between=this.spacesAndCommentsFromEnd(e),this.raw(t,"selector",e),this.current=t},t.spacesAndCommentsFromEnd=function(e){for(var t,r="";e.length&&("space"===(t=e[e.length-1][0])||"comment"===t);)r=e.pop()[1]+r;return r},t.spacesAndCommentsFromStart=function(e){for(var t,r="";e.length&&("space"===(t=e[0][0])||"comment"===t);)r+=e.shift()[1];return r},t.spacesFromEnd=function(e){for(var t="";e.length&&"space"===e[e.length-1][0];)t=e.pop()[1]+t;return t},t.stringFrom=function(e,t){for(var r="",n=t;n<e.length;n++)r+=e[n][1];return e.splice(t,e.length-t),r},t.unclosedBlock=function(){var e=this.current.source.start;throw this.input.error("Unclosed block",e.line,e.column)},t.unclosedBracket=function(e){throw this.input.error("Unclosed bracket",{offset:e[2]},{offset:e[2]+1})},t.unexpectedClose=function(e){throw this.input.error("Unexpected }",{offset:e[2]},{offset:e[2]+1})},t.unknownWord=function(e){throw this.input.error("Unknown word",{offset:e[0][2]},{offset:e[0][2]+e[0][1].length})},t.unnamedAtrule=function(e,t){throw this.input.error("At-rule without name",{offset:t[2]},{offset:t[2]+t[1].length})},e}(),JN=ZP,QN=XN,ej=kP;function tj(e,t){var r=new ej(e,t),n=new QN(r);try{n.parse()}catch(e){throw true&&"CssSyntaxError"===e.name&&t&&t.from&&(/\.scss$/i.test(t.from)?e.message+="\nYou tried to parse SCSS with the standard CSS parser; try again with the postcss-scss parser":/\.sass/i.test(t.from)?e.message+="\nYou tried to parse Sass with the standard CSS parser; try again with the postcss-sass parser":/\.less$/i.test(t.from)&&(e.message+="\nYou tried to parse Less with the standard CSS parser; try again with the postcss-less parser")),e}return n.root}var rj=tj;tj.default=tj,JN.registerParse(tj);var nj=$A.isClean,oj=$A.my,ij=LP,sj=WA,aj=ZP,lj=eN,cj=rN,uj=aN,pj=rj,dj=FN,fj={atrule:"AtRule",comment:"Comment",decl:"Declaration",document:"Document",root:"Root",rule:"Rule"},hj={AtRule:!0,AtRuleExit:!0,Comment:!0,CommentExit:!0,Declaration:!0,DeclarationExit:!0,Document:!0,DocumentExit:!0,Once:!0,OnceExit:!0,postcssPlugin:!0,prepare:!0,Root:!0,RootExit:!0,Rule:!0,RuleExit:!0},mj={Once:!0,postcssPlugin:!0,prepare:!0};function gj(e){return"object"===(void 0===e?"undefined":c_(e))&&"function"==typeof e.then}function vj(e){var t=!1,r=fj[e.type];return"decl"===e.type?t=e.prop.toLowerCase():"atrule"===e.type&&(t=e.name.toLowerCase()),t&&e.append?[r,r+"-"+t,0,r+"Exit",r+"Exit-"+t]:t?[r,r+"-"+t,r+"Exit",r+"Exit-"+t]:e.append?[r,0,r+"Exit"]:[r,r+"Exit"]}function yj(e){return{eventIndex:0,events:"document"===e.type?["Document",0,"DocumentExit"]:"root"===e.type?["Root",0,"RootExit"]:vj(e),iterator:0,node:e,visitorIndex:0,visitors:[]}}function bj(e){return e[nj]=!1,e.nodes&&e.nodes.forEach(function(e){return bj(e)}),e}var wj={},xj=function(){function e(t,r,n){var o,i=this;if(this.stringified=!1,this.processed=!1,"object"!==(void 0===r?"undefined":c_(r))||null===r||"root"!==r.type&&"document"!==r.type)if(s_(r,e)||s_(r,uj))o=bj(r.root),r.map&&(void 0===n.map&&(n.map={}),n.map.inline||(n.map.inline=!1),n.map.prev=r.map);else{var s=pj;n.syntax&&(s=n.syntax.parse),n.parser&&(s=n.parser),s.parse&&(s=s.parse);try{o=s(r,n)}catch(e){this.processed=!0,this.error=e}o&&!o[oj]&&aj.rebuild(o)}else o=bj(r);this.result=new uj(t,o,n),this.helpers=n_({},wj,{postcss:wj,result:this.result}),this.plugins=this.processor.plugins.map(function(e){return"object"===(void 0===e?"undefined":c_(e))&&e.prepare?n_({},e,e.prepare(i.result)):e})}var t=e.prototype;return t.async=function(){return this.error?Promise.reject(this.error):this.processed?Promise.resolve(this.result):(this.processing||(this.processing=this.runAsync()),this.processing)},t.catch=function(e){return this.async().catch(e)},t.finally=function(e){return this.async().then(e,e)},t.getAsyncError=function(){throw new Error("Use process(css).then(cb) to work with async plugins")},t.handleError=function(e,t){var r=this.result.lastPlugin;try{if(t&&t.addToError(e),this.error=e,"CssSyntaxError"!==e.name||e.plugin){if(r.postcssVersion&&"production"!=="development"){var n=r.postcssPlugin,o=r.postcssVersion,i=this.result.processor.version,s=o.split("."),a=i.split(".");(s[0]!==a[0]||parseInt(s[1])>parseInt(a[1]))&&console.error("Unknown error from PostCSS plugin. Your current PostCSS version is "+i+", but "+n+" uses "+o+". Perhaps this is the source of the error below.")}}else e.plugin=r.postcssPlugin,e.setMessage()}catch(e){console&&console.error&&console.error(e)}return e},t.prepareVisitors=function(){var e=this;this.listeners={};for(var t,r=function(t,r,n){e.listeners[r]||(e.listeners[r]=[]),e.listeners[r].push([t,n])},n=d_(this.plugins);!(t=n()).done;){var o=t.value;if("object"===(void 0===o?"undefined":c_(o)))for(var i in o){if(!hj[i]&&/^[A-Z]/.test(i))throw new Error("Unknown event "+i+" in "+o.postcssPlugin+". Try to update PostCSS ("+this.processor.version+" now).");if(!mj[i])if("object"===c_(o[i]))for(var s in o[i])r(o,"*"===s?i:i+"-"+s.toLowerCase(),o[i][s]);else"function"==typeof o[i]&&r(o,i,o[i])}}this.hasListener=Object.keys(this.listeners).length>0},t.runAsync=function(){var e=this;return e_(function(){var t,r,n,o,i,s,a,l,c,u,p,d;return f_(this,function(f){switch(f.label){case 0:e.plugin=0,t=0,f.label=1;case 1:if(!(t<e.plugins.length))return[3,6];if(r=e.plugins[t],!gj(n=e.runOnRoot(r)))return[3,5];f.label=2;case 2:return f.trys.push([2,4,,5]),[4,n];case 3:return f.sent(),[3,5];case 4:throw o=f.sent(),e.handleError(o);case 5:return t++,[3,1];case 6:if(e.prepareVisitors(),!e.hasListener)return[3,18];i=e.result.root,f.label=7;case 7:if(i[nj])return[3,14];i[nj]=!0,s=[yj(i)],f.label=8;case 8:if(!(s.length>0))return[3,13];if(!gj(a=e.visitTick(s)))return[3,12];f.label=9;case 9:return f.trys.push([9,11,,12]),[4,a];case 10:return f.sent(),[3,12];case 11:throw l=f.sent(),c=s[s.length-1].node,e.handleError(l,c);case 12:return[3,8];case 13:return[3,7];case 14:if(!e.listeners.OnceExit)return[3,18];u=function(){var t,r,n,o,s;return f_(this,function(a){switch(a.label){case 0:t=d.value,r=t[0],n=t[1],e.result.lastPlugin=r,a.label=1;case 1:return a.trys.push([1,6,,7]),"document"!==i.type?[3,3]:(o=i.nodes.map(function(t){return n(t,e.helpers)}),[4,Promise.all(o)]);case 2:return a.sent(),[3,5];case 3:return[4,n(i,e.helpers)];case 4:a.sent(),a.label=5;case 5:return[3,7];case 6:throw s=a.sent(),e.handleError(s);case 7:return[2]}})},p=d_(e.listeners.OnceExit),f.label=15;case 15:return(d=p()).done?[3,18]:[5,h_(u())];case 16:f.sent(),f.label=17;case 17:return[3,15];case 18:return e.processed=!0,[2,e.stringify()]}})})()},t.runOnRoot=function(e){var t=this;this.result.lastPlugin=e;try{if("object"===(void 0===e?"undefined":c_(e))&&e.Once){if("document"===this.result.root.type){var r=this.result.root.nodes.map(function(r){return e.Once(r,t.helpers)});return gj(r[0])?Promise.all(r):r}return e.Once(this.result.root,this.helpers)}if("function"==typeof e)return e(this.result.root,this.result)}catch(e){throw this.handleError(e)}},t.stringify=function(){if(this.error)throw this.error;if(this.stringified)return this.result;this.stringified=!0,this.sync();var e=this.result.opts,t=sj;e.syntax&&(t=e.syntax.stringify),e.stringifier&&(t=e.stringifier),t.stringify&&(t=t.stringify);var r=new ij(t,this.result.root,this.result.opts).generate();return this.result.css=r[0],this.result.map=r[1],this.result},t.sync=function(){if(this.error)throw this.error;if(this.processed)return this.result;if(this.processed=!0,this.processing)throw this.getAsyncError();for(var e,t=d_(this.plugins);!(e=t()).done;){var r=e.value;if(gj(this.runOnRoot(r)))throw this.getAsyncError()}if(this.prepareVisitors(),this.hasListener){for(var n=this.result.root;!n[nj];)n[nj]=!0,this.walkSync(n);if(this.listeners.OnceExit)if("document"===n.type)for(var o,i=d_(n.nodes);!(o=i()).done;){var s=o.value;this.visitSync(this.listeners.OnceExit,s)}else this.visitSync(this.listeners.OnceExit,n)}return this.result},t.then=function(e,t){return true&&("from"in this.opts||cj("Without `from` option PostCSS could generate wrong source map and will not find Browserslist config. Set it to CSS file path or to `undefined` to prevent this warning.")),this.async().then(e,t)},t.toString=function(){return this.css},t.visitSync=function(e,t){for(var r,n=d_(e);!(r=n()).done;){var o=r.value,i=o[0],s=o[1];this.result.lastPlugin=i;var a=void 0;try{a=s(t,this.helpers)}catch(e){throw this.handleError(e,t.proxyOf)}if("root"!==t.type&&"document"!==t.type&&!t.parent)return!0;if(gj(a))throw this.getAsyncError()}},t.visitTick=function(e){var t=e[e.length-1],r=t.node,n=t.visitors;if("root"===r.type||"document"===r.type||r.parent){if(n.length>0&&t.visitorIndex<n.length){var o=n[t.visitorIndex],i=o[0],s=o[1];t.visitorIndex+=1,t.visitorIndex===n.length&&(t.visitors=[],t.visitorIndex=0),this.result.lastPlugin=i;try{return s(r.toProxy(),this.helpers)}catch(e){throw this.handleError(e,r)}}if(0!==t.iterator){for(var a,l=t.iterator;a=r.nodes[r.indexes[l]];)if(r.indexes[l]+=1,!a[nj])return a[nj]=!0,void e.push(yj(a));t.iterator=0,delete r.indexes[l]}for(var c=t.events;t.eventIndex<c.length;){var u=c[t.eventIndex];if(t.eventIndex+=1,0===u)return void(r.nodes&&r.nodes.length&&(r[nj]=!0,t.iterator=r.getIterator()));if(this.listeners[u])return void(t.visitors=this.listeners[u])}e.pop()}else e.pop()},t.walkSync=function(e){var t=this;e[nj]=!0;for(var r,n=d_(vj(e));!(r=n()).done;){var o=r.value;if(0===o)e.nodes&&e.each(function(e){e[nj]||t.walkSync(e)});else{var i=this.listeners[o];if(i&&this.visitSync(i,e.toProxy()))return}}},t.warnings=function(){return this.sync().warnings()},r_(e,[{key:"content",get:function(){return this.stringify().content}},{key:"css",get:function(){return this.stringify().css}},{key:"map",get:function(){return this.stringify().map}},{key:"messages",get:function(){return this.sync().messages}},{key:"opts",get:function(){return this.result.opts}},{key:"processor",get:function(){return this.result.processor}},{key:"root",get:function(){return this.sync().root}},{key:Symbol.toStringTag,get:function(){return"LazyResult"}}]),e}();xj.registerPostcss=function(e){wj=e};var _j=xj;xj.default=xj,dj.registerLazyResult(xj),lj.registerLazyResult(xj);var Sj=LP,kj=WA,Cj=rN,Oj=rj,Ej=aN,Tj=function(){function e(e,t,r){var n;t=t.toString(),this.stringified=!1,this._processor=e,this._css=t,this._opts=r,this._map=void 0;var o=kj;this.result=new Ej(this._processor,n,this._opts),this.result.css=t;var i=this;Object.defineProperty(this.result,"root",{get:function(){return i.root}});var s=new Sj(o,n,this._opts,t);if(s.isMap()){var a=s.generate(),l=a[0],c=a[1];l&&(this.result.css=l),c&&(this.result.map=c)}else s.clearAnnotation(),this.result.css=s.css}var t=e.prototype;return t.async=function(){return this.error?Promise.reject(this.error):Promise.resolve(this.result)},t.catch=function(e){return this.async().catch(e)},t.finally=function(e){return this.async().then(e,e)},t.sync=function(){if(this.error)throw this.error;return this.result},t.then=function(e,t){return true&&("from"in this._opts||Cj("Without `from` option PostCSS could generate wrong source map and will not find Browserslist config. Set it to CSS file path or to `undefined` to prevent this warning.")),this.async().then(e,t)},t.toString=function(){return this._css},t.warnings=function(){return[]},r_(e,[{key:"content",get:function(){return this.result.css}},{key:"css",get:function(){return this.result.css}},{key:"map",get:function(){return this.result.map}},{key:"messages",get:function(){return[]}},{key:"opts",get:function(){return this.result.opts}},{key:"processor",get:function(){return this.result.processor}},{key:"root",get:function(){if(this._root)return this._root;var e,t=Oj;try{e=t(this._css,this._opts)}catch(e){this.error=e}if(this.error)throw this.error;return this._root=e,e}},{key:Symbol.toStringTag,get:function(){return"NoWorkResult"}}]),e}(),Rj=Tj;Tj.default=Tj;var Ij=Rj,Mj=_j,Aj=eN,Pj=FN,Nj=function(){function e(e){void 0===e&&(e=[]),this.version="8.4.38",this.plugins=this.normalize(e)}var t=e.prototype;return t.normalize=function(e){for(var t,r=[],n=d_(e);!(t=n()).done;){var o=t.value;if(!0===o.postcss?o=o():o.postcss&&(o=o.postcss),"object"===(void 0===o?"undefined":c_(o))&&Array.isArray(o.plugins))r=r.concat(o.plugins);else if("object"===(void 0===o?"undefined":c_(o))&&o.postcssPlugin)r.push(o);else if("function"==typeof o)r.push(o);else{if("object"!==(void 0===o?"undefined":c_(o))||!o.parse&&!o.stringify)throw new Error(o+" is not a PostCSS plugin");if(true)throw new Error("PostCSS syntaxes cannot be used as plugins. Instead, please use one of the syntax/parser/stringifier options as outlined in your PostCSS runner documentation.")}}return r},t.process=function(e,t){return void 0===t&&(t={}),this.plugins.length||t.parser||t.stringifier||t.syntax?new Mj(this,e,t):new Ij(this,e,t)},t.use=function(e){return this.plugins=this.plugins.concat(this.normalize([e])),this},e}(),jj=Nj;Nj.default=Nj,Pj.registerProcessor(Nj),Aj.registerProcessor(Nj);var Lj=tP,Dj=cP,Fj=FP,$j=PN,Bj=kP,zj=FN,Vj=qN;function Uj(e,t){if(Array.isArray(e))return e.map(function(e){return Uj(e)});var r=e.inputs,n=a_(e,["inputs"]);if(r){t=[];for(var o,i=d_(r);!(o=i()).done;){var s=n_({},o.value,{__proto__:Bj.prototype});s.map&&(s.map=n_({},s.map,{__proto__:Dj.prototype})),t.push(s)}}if(n.nodes&&(n.nodes=e.nodes.map(function(e){return Uj(e,t)})),n.source){var a=n.source,l=a.inputId,c=a_(a,["inputId"]);n.source=c,null!=l&&(n.source.input=t[l])}if("root"===n.type)return new zj(n);if("decl"===n.type)return new Lj(n);if("rule"===n.type)return new Vj(n);if("comment"===n.type)return new Fj(n);if("atrule"===n.type)return new $j(n);throw new Error("Unknown node type: "+e.type)}var qj=Uj;Uj.default=Uj;var Wj=FA,Hj=tP,Gj=_j,Kj=ZP,Yj=jj,Zj=WA,Xj=qj,Jj=eN,Qj=oN,eL=FP,tL=PN,rL=aN,nL=kP,oL=rj,iL=BN,sL=qN,aL=FN,lL=QA;function cL(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];return 1===t.length&&Array.isArray(t[0])&&(t=t[0]),new Yj(t)}cL.plugin=function(e,t){var r,n=!1;function o(){for(var r=arguments.length,o=new Array(r),i=0;i<r;i++)o[i]=arguments[i];console&&console.warn&&!n&&(n=!0,console.warn(e+": postcss.plugin was deprecated. Migration guide:\nhttps://evilmartians.com/chronicles/postcss-8-plugin-migration"),process.env.LANG&&process.env.LANG.startsWith("cn")&&console.warn(e+": 里面 postcss.plugin 被弃用. 迁移指南:\nhttps://www.w3ctech.com/topic/2226"));var s=t.apply(void 0,[].concat(o));return s.postcssPlugin=e,s.postcssVersion=(new Yj).version,s}return Object.defineProperty(o,"postcss",{get:function(){return r||(r=o()),r}}),o.process=function(e,t,r){return cL([o(r)]).process(e,t)},o},cL.stringify=Zj,cL.parse=oL,cL.fromJSON=Xj,cL.list=iL,cL.comment=function(e){return new eL(e)},cL.atRule=function(e){return new tL(e)},cL.decl=function(e){return new Hj(e)},cL.rule=function(e){return new sL(e)},cL.root=function(e){return new aL(e)},cL.document=function(e){return new Jj(e)},cL.CssSyntaxError=Wj,cL.Declaration=Hj,cL.Container=Kj,cL.Processor=Yj,cL.Document=Jj,cL.Comment=eL,cL.Warning=Qj,cL.AtRule=tL,cL.Result=rL,cL.Input=nL,cL.Rule=sL,cL.Root=aL,cL.Node=lL,Gj.registerPostcss(cL),cL.default=cL;var uL=Object.defineProperty,pL=function(e,t,r){return function(e,t,r){return t in e?uL(e,t,{enumerable:!0,configurable:!0,writable:!0,value:r}):e[t]=r}(e,"symbol"!==(void 0===t?"undefined":c_(t))?t+"":t,r)},dL=function(){function e(e){pL(this,"fileName"),pL(this,"functionName"),pL(this,"lineNumber"),pL(this,"columnNumber"),this.fileName=e.fileName||"",this.functionName=e.functionName||"",this.lineNumber=e.lineNumber,this.columnNumber=e.columnNumber}return e.prototype.toString=function(){var e=this.lineNumber||"",t=this.columnNumber||"";return this.functionName?this.functionName+" ("+this.fileName+":"+e+":"+t+")":this.fileName+":"+e+":"+t},e}(),fL=/(^|@)\S+:\d+/,hL=/^\s*at .*(\S+:\d+|\(native\))/m,mL=/^(eval@)?(\[native code])?$/,gL={parse:function(e){return e?void 0!==e.stacktrace||void 0!==e["opera#sourceloc"]?this.parseOpera(e):e.stack&&e.stack.match(hL)?this.parseV8OrIE(e):e.stack?this.parseFFOrSafari(e):(console.warn("[console-record-plugin]: Failed to parse error object:",e),[]):[]},extractLocation:function(e){if(-1===e.indexOf(":"))return[e];var t=/(.+?)(?::(\d+))?(?::(\d+))?$/.exec(e.replace(/[()]/g,""));if(!t)throw new Error("Cannot parse given url: "+e);return[t[1],t[2]||void 0,t[3]||void 0]},parseV8OrIE:function(e){var t=e.stack.split("\n").filter(function(e){return!!e.match(hL)},this);return t.map(function(e){e.indexOf("(eval ")>-1&&(e=e.replace(/eval code/g,"eval").replace(/(\(eval at [^()]*)|(\),.*$)/g,""));var t=e.replace(/^\s+/,"").replace(/\(eval code/g,"("),r=t.match(/ (\((.+):(\d+):(\d+)\)$)/),n=(t=r?t.replace(r[0],""):t).split(/\s+/).slice(1),o=this.extractLocation(r?r[1]:n.pop()),i=n.join(" ")||void 0,s=["eval","<anonymous>"].indexOf(o[0])>-1?void 0:o[0];return new dL({functionName:i,fileName:s,lineNumber:o[1],columnNumber:o[2]})},this)},parseFFOrSafari:function(e){var t=e.stack.split("\n").filter(function(e){return!e.match(mL)},this);return t.map(function(e){if(e.indexOf(" > eval")>-1&&(e=e.replace(/ line (\d+)(?: > eval line \d+)* > eval:\d+:\d+/g,":$1")),-1===e.indexOf("@")&&-1===e.indexOf(":"))return new dL({functionName:e});var t=/((.*".+"[^@]*)?[^@]*)(?:@)/,r=e.match(t),n=r&&r[1]?r[1]:void 0,o=this.extractLocation(e.replace(t,""));return new dL({functionName:n,fileName:o[0],lineNumber:o[1],columnNumber:o[2]})},this)},parseOpera:function(e){return!e.stacktrace||e.message.indexOf("\n")>-1&&e.message.split("\n").length>e.stacktrace.split("\n").length?this.parseOpera9(e):e.stack?this.parseOpera11(e):this.parseOpera10(e)},parseOpera9:function(e){for(var t=/Line (\d+).*script (?:in )?(\S+)/i,r=e.message.split("\n"),n=[],o=2,i=r.length;o<i;o+=2){var s=t.exec(r[o]);s&&n.push(new dL({fileName:s[2],lineNumber:parseFloat(s[1])}))}return n},parseOpera10:function(e){for(var t=/Line (\d+).*script (?:in )?(\S+)(?:: In function (\S+))?$/i,r=e.stacktrace.split("\n"),n=[],o=0,i=r.length;o<i;o+=2){var s=t.exec(r[o]);s&&n.push(new dL({functionName:s[3]||void 0,fileName:s[2],lineNumber:parseFloat(s[1])}))}return n},parseOpera11:function(e){var t=e.stack.split("\n").filter(function(e){return!!e.match(fL)&&!e.match(/^Error created at/)},this);return t.map(function(e){var t=e.split("@"),r=this.extractLocation(t.pop()),n=(t.shift()||"").replace(/<anonymous function(: (\w+))?>/,"$2").replace(/\([^)]*\)/g,"")||void 0;return new dL({functionName:n,fileName:r[0],lineNumber:r[1],columnNumber:r[2]})},this)}};function vL(e){if(!e||!e.outerHTML)return"";for(var t="";e.parentElement;){var r=e.localName;if(!r)break;r=r.toLowerCase();var n=e.parentElement,o=[];if(n.children&&n.children.length>0)for(var i=0;i<n.children.length;i++){var s=n.children[i];s.localName&&s.localName.toLowerCase&&s.localName.toLowerCase()===r&&o.push(s)}o.length>1&&(r+=":eq("+o.indexOf(e)+")"),t=r+(t?">"+t:""),e=n}return t}function yL(e){return"[object Object]"===Object.prototype.toString.call(e)}function bL(e,t){if(0===t)return!0;for(var r,n=d_(Object.keys(e));!(r=n()).done;){var o=r.value;if(yL(e[o])&&bL(e[o],t-1))return!0}return!1}function wL(e,t){var r={numOfKeysLimit:50,depthOfLimit:4};Object.assign(r,t);var n=[],o=[];return JSON.stringify(e,function(e,t){if(n.length>0){var i=n.indexOf(this);~i?n.splice(i+1):n.push(this),~i?o.splice(i,1/0,e):o.push(e),~n.indexOf(t)&&(t=n[0]===t?"[Circular ~]":"[Circular ~."+o.slice(0,n.indexOf(t)).join(".")+"]")}else n.push(t);if(null===t)return t;if(void 0===t)return"undefined";if(yL(s=t)&&Object.keys(s).length>r.numOfKeysLimit||"function"==typeof s||yL(s)&&bL(s,r.depthOfLimit))return function(e){var t=e.toString();return r.stringLengthLimit&&t.length>r.stringLengthLimit&&(t=t.slice(0,r.stringLengthLimit)+"..."),t}(t);var s;if("bigint"===(void 0===t?"undefined":c_(t)))return t.toString()+"n";if(s_(t,Event)){var a={};for(var l in t){var c=t[l];Array.isArray(c)?a[l]=vL(c.length?c[0]:null):a[l]=c}return a}return s_(t,Node)?s_(t,HTMLElement)?t?t.outerHTML:"":t.nodeName:s_(t,Error)?t.stack?t.stack+"\nEnd of stack for Error object":t.name+": "+t.message:t})}var xL={level:["assert","clear","count","countReset","debug","dir","dirxml","error","group","groupCollapsed","groupEnd","info","log","table","time","timeEnd","timeLog","trace","warn"],lengthThreshold:1e3,logger:"console"};function _L(e,t,r){var n,o=r?Object.assign({},xL,r):xL,i=o.logger;if(!i)return function(){};n="string"==typeof i?t[i]:i;var s=0,a=!1,l=[];if(o.level.includes("error")){var c=function(t){var r=t.message,n=t.error,i=gL.parse(n).map(function(e){return e.toString()}),s=[wL(r,o.stringifyOptions)];e({level:"error",trace:i,payload:s})};t.addEventListener("error",c),l.push(function(){t.removeEventListener("error",c)});var u=function(t){var r,n;s_(t.reason,Error)?n=[wL("Uncaught (in promise) "+(r=t.reason).name+": "+r.message,o.stringifyOptions)]:(r=new Error,n=[wL("Uncaught (in promise)",o.stringifyOptions),wL(t.reason,o.stringifyOptions)]);var i=gL.parse(r).map(function(e){return e.toString()});e({level:"error",trace:i,payload:n})};t.addEventListener("unhandledrejection",u),l.push(function(){t.removeEventListener("unhandledrejection",u)})}for(var p,d=d_(o.level);!(p=d()).done;){var f=p.value;l.push(h(n,f))}return function(){l.forEach(function(e){return e()})};function h(t,r){var n=this;return t[r]?function(t,i){try{if(!(i in t))return function(){};var l=t[i],c=function(t){var i=n;return function(){for(var n=arguments.length,l=new Array(n),c=0;c<n;c++)l[c]=arguments[c];if(t.apply(i,l),!("assert"===r&&l[0]||a)){a=!0;try{var u=gL.parse(new Error).map(function(e){return e.toString()}).splice(1),p=("assert"===r?l.slice(1):l).map(function(e){return wL(e,o.stringifyOptions)});++s<o.lengthThreshold?e({level:r,trace:u,payload:p}):s===o.lengthThreshold&&e({level:"warn",trace:[],payload:[wL("The number of log records reached the threshold.")]})}catch(e){t.apply(void 0,[].concat(["rrweb logger error:",e],l))}finally{a=!1}}}}(l);return"function"==typeof c&&(c.prototype=c.prototype||{},Object.defineProperties(c,{__rrweb_original__:{enumerable:!1,value:l}})),t[i]=c,function(){t[i]=l}}catch(e){return function(){}}}(t,r):function(){}}}var SL,kL,CL,OL=Hx.setImmediate,EL=Object.prototype.toString,TL=void 0!==OL?function(e){return OL(e)}:setTimeout;try{SL=function(e,t,r,n){return Object.defineProperty(e,t,{value:r,writable:!0,configurable:!1!==n})}}catch(e){SL=function(e,t,r){return e[t]=r,e}}function RL(e,t){CL.add(e,t),kL||(kL=TL(CL.drain))}function IL(e){var t,r=typeof e;return null===e||"object"!==r&&"function"!==r||(t=e.then),"function"==typeof t&&t}function ML(){for(var e=0;e<this.chain.length;e++)AL(this,1===this.state?this.chain[e].success:this.chain[e].failure,this.chain[e]);this.chain.length=0}function AL(e,t,r){var n,o;try{!1===t?r.reject(e.msg):(n=!0===t?e.msg:t.call(void 0,e.msg))===r.promise?r.reject(TypeError("Promise-chain cycle")):(o=IL(n))?o.call(n,r.resolve,r.reject):r.resolve(n)}catch(e){r.reject(e)}}function PL(e){var t,r=this;if(!r.triggered){r.triggered=!0,r.def&&(r=r.def);try{(t=IL(e))?RL(function(){var n=new LL(r);try{t.call(e,function(){PL.apply(n,arguments)},function(){NL.apply(n,arguments)})}catch(e){NL.call(n,e)}}):(r.msg=e,r.state=1,r.chain.length>0&&RL(ML,r))}catch(e){NL.call(new LL(r),e)}}}function NL(e){var t=this;t.triggered||(t.triggered=!0,t.def&&(t=t.def),t.msg=e,t.state=2,t.chain.length>0&&RL(ML,t))}function jL(e,t,r,n){for(var o=0;o<t.length;o++)(function(o){e.resolve(t[o]).then(function(e){r(o,e)},n)})(o)}function LL(e){this.def=e,this.triggered=!1}function DL(e){this.promise=e,this.state=0,this.triggered=!1,this.chain=[],this.msg=void 0}function FL(e){if("function"!=typeof e)throw TypeError("Not a function");if(0!==this.__NPO__)throw TypeError("Not a promise");this.__NPO__=1;var t=new DL(this);this.then=function(e,r){var n={success:"function"!=typeof e||e,failure:"function"==typeof r&&r};return n.promise=new this.constructor(function(e,t){if("function"!=typeof e||"function"!=typeof t)throw TypeError("Not a function");n.resolve=e,n.reject=t}),t.chain.push(n),0!==t.state&&RL(ML,t),n.promise},this.catch=function(e){return this.then(void 0,e)};try{e.call(void 0,function(e){PL.call(t,e)},function(e){NL.call(t,e)})}catch(e){NL.call(t,e)}}CL=function(){var e,t,r;function n(e,t){this.fn=e,this.self=t,this.next=void 0}return{add:function(o,i){r=new n(o,i),t?t.next=r:e=r,t=r,r=void 0},drain:function(){var r=e;for(e=t=kL=void 0;r;)r.fn.call(r.self),r=r.next}}}();var $L,BL=SL({},"constructor",FL,!1);FL.prototype=BL,SL(BL,"__NPO__",0,!1),SL(FL,"resolve",function(e){return e&&"object"==typeof e&&1===e.__NPO__?e:new this(function(t,r){if("function"!=typeof t||"function"!=typeof r)throw TypeError("Not a function");t(e)})}),SL(FL,"reject",function(e){return new this(function(t,r){if("function"!=typeof t||"function"!=typeof r)throw TypeError("Not a function");r(e)})}),SL(FL,"all",function(e){var t=this;return"[object Array]"!==EL.call(e)?t.reject(TypeError("Not an array")):0===e.length?t.resolve([]):new t(function(r,n){if("function"!=typeof r||"function"!=typeof n)throw TypeError("Not a function");var o=e.length,i=Array(o),s=0;jL(t,e,function(e,t){i[e]=t,++s===o&&r(i)},n)})}),SL(FL,"race",function(e){var t=this;return"[object Array]"!==EL.call(e)?t.reject(TypeError("Not an array")):new t(function(r,n){if("function"!=typeof r||"function"!=typeof n)throw TypeError("Not a function");jL(t,e,function(e,t){r(t)},n)})}),$L="undefined"!=typeof Promise&&-1!==Promise.toString().indexOf("[native code]")?Promise:FL;var zL=864e5,VL=Array.prototype,UL=Function.prototype,qL=Object.prototype,WL=VL.slice,HL=qL.toString,GL=qL.hasOwnProperty,KL=Hx.console,YL=Hx.navigator,ZL=Hx.document,XL=Hx.opera,JL=Hx.screen,QL=YL.userAgent,eD=UL.bind,tD=VL.forEach,rD=VL.indexOf,nD=VL.map,oD=Array.isArray,iD={},sD={trim:function(e){return e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")}},aD={log:function(){if(Kx.DEBUG&&!sD.isUndefined(KL)&&KL)try{KL.log.apply(KL,arguments)}catch(e){sD.each(arguments,function(e){KL.log(e)})}},warn:function(){if(Kx.DEBUG&&!sD.isUndefined(KL)&&KL){var e=["Mixpanel warning:"].concat(sD.toArray(arguments));try{KL.warn.apply(KL,e)}catch(t){sD.each(e,function(e){KL.warn(e)})}}},error:function(){if(Kx.DEBUG&&!sD.isUndefined(KL)&&KL){var e=["Mixpanel error:"].concat(sD.toArray(arguments));try{KL.error.apply(KL,e)}catch(t){sD.each(e,function(e){KL.error(e)})}}},critical:function(){if(!sD.isUndefined(KL)&&KL){var e=["Mixpanel error:"].concat(sD.toArray(arguments));try{KL.error.apply(KL,e)}catch(t){sD.each(e,function(e){KL.error(e)})}}}},lD=function(e,t){return function(){return arguments[0]="["+t+"] "+arguments[0],e.apply(aD,arguments)}},cD=function(e){return{log:lD(aD.log,e),error:lD(aD.error,e),critical:lD(aD.critical,e)}},uD=function(e){return function(){try{return e.apply(this,arguments)}catch(e){aD.critical("Implementation error. Please turn on debug and contact support@mixpanel.com."),Kx.DEBUG&&aD.critical(e)}}},pD=function(e){var t=e.prototype;for(var r in t)"function"==typeof t[r]&&(t[r]=uD(t[r]))};sD.bind=function(e,t){var r,n;if(eD&&e.bind===eD)return eD.apply(e,WL.call(arguments,1));if(!sD.isFunction(e))throw new TypeError;return r=WL.call(arguments,2),n=function(){if(!(this instanceof n))return e.apply(t,r.concat(WL.call(arguments)));var o={};o.prototype=e.prototype;var i=new o;o.prototype=null;var s=e.apply(i,r.concat(WL.call(arguments)));return Object(s)===s?s:i},n},sD.each=function(e,t,r){if(null!=e)if(tD&&e.forEach===tD)e.forEach(t,r);else if(e.length===+e.length){for(var n=0,o=e.length;n<o;n++)if(n in e&&t.call(r,e[n],n,e)===iD)return}else for(var i in e)if(GL.call(e,i)&&t.call(r,e[i],i,e)===iD)return},sD.extend=function(e){return sD.each(WL.call(arguments,1),function(t){for(var r in t)void 0!==t[r]&&(e[r]=t[r])}),e},sD.isArray=oD||function(e){return"[object Array]"===HL.call(e)},sD.isFunction=function(e){return"function"==typeof e},sD.isArguments=function(e){return!(!e||!GL.call(e,"callee"))},sD.toArray=function(e){return e?e.toArray?e.toArray():sD.isArray(e)||sD.isArguments(e)?WL.call(e):sD.values(e):[]},sD.map=function(e,t,r){if(nD&&e.map===nD)return e.map(t,r);var n=[];return sD.each(e,function(e){n.push(t.call(r,e))}),n},sD.keys=function(e){var t=[];return null===e||sD.each(e,function(e,r){t[t.length]=r}),t},sD.values=function(e){var t=[];return null===e||sD.each(e,function(e){t[t.length]=e}),t},sD.include=function(e,t){var r=!1;return null===e?r:rD&&e.indexOf===rD?-1!=e.indexOf(t):(sD.each(e,function(e){if(r||(r=e===t))return iD}),r)},sD.includes=function(e,t){return-1!==e.indexOf(t)},sD.inherit=function(e,t){return e.prototype=new t,e.prototype.constructor=e,e.superclass=t.prototype,e},sD.isObject=function(e){return e===Object(e)&&!sD.isArray(e)},sD.isEmptyObject=function(e){if(sD.isObject(e)){for(var t in e)if(GL.call(e,t))return!1;return!0}return!1},sD.isUndefined=function(e){return void 0===e},sD.isString=function(e){return"[object String]"==HL.call(e)},sD.isDate=function(e){return"[object Date]"==HL.call(e)},sD.isNumber=function(e){return"[object Number]"==HL.call(e)},sD.isElement=function(e){return!(!e||1!==e.nodeType)},sD.encodeDates=function(e){return sD.each(e,function(t,r){sD.isDate(t)?e[r]=sD.formatDate(t):sD.isObject(t)&&(e[r]=sD.encodeDates(t))}),e},sD.timestamp=function(){return Date.now=Date.now||function(){return+new Date},Date.now()},sD.formatDate=function(e){function t(e){return e<10?"0"+e:e}return e.getUTCFullYear()+"-"+t(e.getUTCMonth()+1)+"-"+t(e.getUTCDate())+"T"+t(e.getUTCHours())+":"+t(e.getUTCMinutes())+":"+t(e.getUTCSeconds())},sD.strip_empty_properties=function(e){var t={};return sD.each(e,function(e,r){sD.isString(e)&&e.length>0&&(t[r]=e)}),t},sD.truncate=function(e,t){var r;return"string"==typeof e?r=e.slice(0,t):sD.isArray(e)?(r=[],sD.each(e,function(e){r.push(sD.truncate(e,t))})):sD.isObject(e)?(r={},sD.each(e,function(e,n){r[n]=sD.truncate(e,t)})):r=e,r},sD.JSONEncode=function(e){var t=function(e){var t=/[\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,r={"\b":"\\b","\t":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"};return t.lastIndex=0,t.test(e)?'"'+e.replace(t,function(e){var t=r[e];return"string"==typeof t?t:"\\u"+("0000"+e.charCodeAt(0).toString(16)).slice(-4)})+'"':'"'+e+'"'},r=function(e,n){var o="",i=0,s="",a="",l=0,c=o,u=[],p=n[e];switch(p&&"object"==typeof p&&"function"==typeof p.toJSON&&(p=p.toJSON(e)),typeof p){case"string":return t(p);case"number":return isFinite(p)?String(p):"null";case"boolean":case"null":return String(p);case"object":if(!p)return"null";if(o+="    ",u=[],"[object Array]"===HL.apply(p)){for(l=p.length,i=0;i<l;i+=1)u[i]=r(i,p)||"null";return a=0===u.length?"[]":o?"[\n"+o+u.join(",\n"+o)+"\n"+c+"]":"["+u.join(",")+"]",o=c,a}for(s in p)GL.call(p,s)&&(a=r(s,p))&&u.push(t(s)+(o?": ":":")+a);return a=0===u.length?"{}":o?"{"+u.join(",")+c+"}":"{"+u.join(",")+"}",o=c,a}};return r("",{"":e})},sD.JSONDecode=function(){var e,t,r,n,o={'"':'"',"\\":"\\","/":"/",b:"\b",f:"\f",n:"\n",r:"\r",t:"\t"},i=function(t){var n=new SyntaxError(t);throw n.at=e,n.text=r,n},s=function(n){return n&&n!==t&&i("Expected '"+n+"' instead of '"+t+"'"),t=r.charAt(e),e+=1,t},a=function(){var e,r="";for("-"===t&&(r="-",s("-"));t>="0"&&t<="9";)r+=t,s();if("."===t)for(r+=".";s()&&t>="0"&&t<="9";)r+=t;if("e"===t||"E"===t)for(r+=t,s(),"-"!==t&&"+"!==t||(r+=t,s());t>="0"&&t<="9";)r+=t,s();if(e=+r,isFinite(e))return e;i("Bad number")},l=function(){var e,r,n,a="";if('"'===t)for(;s();){if('"'===t)return s(),a;if("\\"===t)if(s(),"u"===t){for(n=0,r=0;r<4&&(e=parseInt(s(),16),isFinite(e));r+=1)n=16*n+e;a+=String.fromCharCode(n)}else{if("string"!=typeof o[t])break;a+=o[t]}else a+=t}i("Bad string")},c=function(){for(;t&&t<=" ";)s()};return n=function(){switch(c(),t){case"{":return function(){var e,r={};if("{"===t){if(s("{"),c(),"}"===t)return s("}"),r;for(;t;){if(e=l(),c(),s(":"),Object.hasOwnProperty.call(r,e)&&i('Duplicate key "'+e+'"'),r[e]=n(),c(),"}"===t)return s("}"),r;s(","),c()}}i("Bad object")}();case"[":return function(){var e=[];if("["===t){if(s("["),c(),"]"===t)return s("]"),e;for(;t;){if(e.push(n()),c(),"]"===t)return s("]"),e;s(","),c()}}i("Bad array")}();case'"':return l();case"-":return a();default:return t>="0"&&t<="9"?a():function(){switch(t){case"t":return s("t"),s("r"),s("u"),s("e"),!0;case"f":return s("f"),s("a"),s("l"),s("s"),s("e"),!1;case"n":return s("n"),s("u"),s("l"),s("l"),null}i('Unexpected "'+t+'"')}()}},function(o){var s;return r=o,e=0,t=" ",s=n(),c(),t&&i("Syntax error"),s}}(),sD.base64Encode=function(e){var t,r,n,o,i,s="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=",a=0,l=0,c="",u=[];if(!e)return e;e=sD.utf8Encode(e);do{t=(i=e.charCodeAt(a++)<<16|e.charCodeAt(a++)<<8|e.charCodeAt(a++))>>18&63,r=i>>12&63,n=i>>6&63,o=63&i,u[l++]=s.charAt(t)+s.charAt(r)+s.charAt(n)+s.charAt(o)}while(a<e.length);switch(c=u.join(""),e.length%3){case 1:c=c.slice(0,-2)+"==";break;case 2:c=c.slice(0,-1)+"="}return c},sD.utf8Encode=function(e){var t,r,n,o,i="";for(t=r=0,n=(e=(e+"").replace(/\r\n/g,"\n").replace(/\r/g,"\n")).length,o=0;o<n;o++){var s=e.charCodeAt(o),a=null;s<128?r++:a=s>127&&s<2048?String.fromCharCode(s>>6|192,63&s|128):String.fromCharCode(s>>12|224,s>>6&63|128,63&s|128),null!==a&&(r>t&&(i+=e.substring(t,r)),i+=a,t=r=o+1)}return r>t&&(i+=e.substring(t,e.length)),i},sD.UUID=function(){try{return Hx.crypto.randomUUID()}catch(r){for(var e=new Array(36),t=0;t<36;t++)e[t]=Math.floor(16*Math.random());return e[14]=4,e[19]=e[19]&=-5,e[19]=e[19]|=8,e[8]=e[13]=e[18]=e[23]="-",sD.map(e,function(e){return e.toString(16)}).join("")}};var dD=["ahrefsbot","ahrefssiteaudit","amazonbot","baiduspider","bingbot","bingpreview","chrome-lighthouse","facebookexternal","petalbot","pinterest","screaming frog","yahoo! slurp","yandex","adsbot-google","apis-google","duplexweb-google","feedfetcher-google","google favicon","google web preview","google-read-aloud","googlebot","googleweblight","mediapartners-google","storebot-google"];sD.isBlockedUA=function(e){var t;for(e=e.toLowerCase(),t=0;t<dD.length;t++)if(-1!==e.indexOf(dD[t]))return!0;return!1},sD.HTTPBuildQuery=function(e,t){var r,n,o=[];return sD.isUndefined(t)&&(t="&"),sD.each(e,function(e,t){r=encodeURIComponent(e.toString()),n=encodeURIComponent(t),o[o.length]=n+"="+r}),o.join(t)},sD.getQueryParam=function(e,t){t=t.replace(/[[]/g,"\\[").replace(/[\]]/g,"\\]");var r=new RegExp("[\\?&]"+t+"=([^&#]*)").exec(e);if(null===r||r&&"string"!=typeof r[1]&&r[1].length)return"";var n=r[1];try{n=decodeURIComponent(n)}catch(e){aD.error("Skipping decoding for malformed query param: "+n)}return n.replace(/\+/g," ")},sD.cookie={get:function(e){for(var t=e+"=",r=ZL.cookie.split(";"),n=0;n<r.length;n++){for(var o=r[n];" "==o.charAt(0);)o=o.substring(1,o.length);if(0===o.indexOf(t))return decodeURIComponent(o.substring(t.length,o.length))}return null},parse:function(e){var t;try{t=sD.JSONDecode(sD.cookie.get(e))||{}}catch(e){}return t},set_seconds:function(e,t,r,n,o,i,s){var a="",l="",c="";if(s)a="; domain="+s;else if(n){var u=ED(ZL.location.hostname);a=u?"; domain=."+u:""}if(r){var p=new Date;p.setTime(p.getTime()+1e3*r),l="; expires="+p.toGMTString()}i&&(o=!0,c="; SameSite=None"),o&&(c+="; secure"),ZL.cookie=e+"="+encodeURIComponent(t)+l+"; path=/"+a+c},set:function(e,t,r,n,o,i,s){var a="",l="",c="";if(s)a="; domain="+s;else if(n){var u=ED(ZL.location.hostname);a=u?"; domain=."+u:""}if(r){var p=new Date;p.setTime(p.getTime()+24*r*60*60*1e3),l="; expires="+p.toGMTString()}i&&(o=!0,c="; SameSite=None"),o&&(c+="; secure");var d=e+"="+encodeURIComponent(t)+l+"; path=/"+a+c;return ZL.cookie=d,d},remove:function(e,t,r){sD.cookie.set(e,"",-1,t,!1,!1,r)}};var fD=function(e){var t=!0;try{var r="__mplss_"+SD(8);e.setItem(r,"xyz"),"xyz"!==e.getItem(r)&&(t=!1),e.removeItem(r)}catch(e){t=!1}return t},hD=null,mD=function(e,t){return null===hD||t?hD=fD(e||Hx.localStorage):hD},gD=null;function vD(e,t,r){var n=function(e){aD.error(t+" error: "+e)};return{is_supported:function(n){var o=r(e,n);return o||aD.error(t+" unsupported"),o},error:n,get:function(t){try{return e.getItem(t)}catch(e){n(e)}return null},parse:function(t){try{return sD.JSONDecode(e.getItem(t))||{}}catch(e){}return null},set:function(t,r){try{e.setItem(t,r)}catch(e){n(e)}},remove:function(t){try{e.removeItem(t)}catch(e){n(e)}}}}var yD=null,bD=null;try{yD=Hx.localStorage,bD=Hx.sessionStorage}catch(e){}sD.localStorage=vD(yD,"localStorage",mD),sD.sessionStorage=vD(bD,"sessionStorage",function(e,t){return null===gD||t?gD=fD(e||Hx.sessionStorage):gD}),sD.register_event=function(){function e(t){return t&&(t.preventDefault=e.preventDefault,t.stopPropagation=e.stopPropagation),t}return e.preventDefault=function(){this.returnValue=!1},e.stopPropagation=function(){this.cancelBubble=!0},function(t,r,n,o,i){if(t)if(t.addEventListener&&!o)t.addEventListener(r,n,!!i);else{var s="on"+r,a=t[s];t[s]=function(t,r,n){return function(o){if(o=o||e(Hx.event)){var i,s,a=!0;return sD.isFunction(n)&&(i=n(o)),s=r.call(t,o),!1!==i&&!1!==s||(a=!1),a}}}(t,n,a)}else aD.error("No valid element provided to register_event")}}();var wD=new RegExp('^(\\w*)\\[(\\w+)([=~\\|\\^\\$\\*]?)=?"?([^\\]"]*)"?\\]$');sD.dom_query=function(){function e(e){return e.all?e.all:e.getElementsByTagName("*")}var t=/[\t\r\n]/g;function r(e,r){var n=" "+r+" ";return(" "+e.className+" ").replace(t," ").indexOf(n)>=0}function n(t){if(!ZL.getElementsByTagName)return[];var n,o,i,s,a,l,c,u,p,d,f=t.split(" "),h=[ZL];for(l=0;l<f.length;l++)if((n=f[l].replace(/^\s+/,"").replace(/\s+$/,"")).indexOf("#")>-1){i=(o=n.split("#"))[0];var m=o[1],g=ZL.getElementById(m);if(!g||i&&g.nodeName.toLowerCase()!=i)return[];h=[g]}else if(n.indexOf(".")>-1){i=(o=n.split("."))[0];var v=o[1];for(i||(i="*"),s=[],a=0,c=0;c<h.length;c++)for(p="*"==i?e(h[c]):h[c].getElementsByTagName(i),u=0;u<p.length;u++)s[a++]=p[u];for(h=[],d=0,c=0;c<s.length;c++)s[c].className&&sD.isString(s[c].className)&&r(s[c],v)&&(h[d++]=s[c])}else{var y=n.match(wD);if(y){i=y[1];var b,w=y[2],x=y[3],_=y[4];for(i||(i="*"),s=[],a=0,c=0;c<h.length;c++)for(p="*"==i?e(h[c]):h[c].getElementsByTagName(i),u=0;u<p.length;u++)s[a++]=p[u];switch(h=[],d=0,x){case"=":b=function(e){return e.getAttribute(w)==_};break;case"~":b=function(e){return e.getAttribute(w).match(new RegExp("\\b"+_+"\\b"))};break;case"|":b=function(e){return e.getAttribute(w).match(new RegExp("^"+_+"-?"))};break;case"^":b=function(e){return 0===e.getAttribute(w).indexOf(_)};break;case"$":b=function(e){return e.getAttribute(w).lastIndexOf(_)==e.getAttribute(w).length-_.length};break;case"*":b=function(e){return e.getAttribute(w).indexOf(_)>-1};break;default:b=function(e){return e.getAttribute(w)}}for(h=[],d=0,c=0;c<s.length;c++)b(s[c])&&(h[d++]=s[c])}else{for(i=n,s=[],a=0,c=0;c<h.length;c++)for(p=h[c].getElementsByTagName(i),u=0;u<p.length;u++)s[a++]=p[u];h=s}}return h}return function(e){return sD.isElement(e)?[e]:sD.isObject(e)&&!sD.isUndefined(e.length)?e:n.call(this,e)}}();var xD=["utm_source","utm_medium","utm_campaign","utm_content","utm_term","utm_id","utm_source_platform","utm_campaign_id","utm_creative_format","utm_marketing_tactic"],_D=["dclid","fbclid","gclid","ko_click_id","li_fat_id","msclkid","sccid","ttclid","twclid","wbraid"];sD.info={campaignParams:function(e){var t="",r={};return sD.each(xD,function(n){(t=sD.getQueryParam(ZL.URL,n)).length?r[n]=t:void 0!==e&&(r[n]=e)}),r},clickParams:function(){var e="",t={};return sD.each(_D,function(r){(e=sD.getQueryParam(ZL.URL,r)).length&&(t[r]=e)}),t},marketingParams:function(){return sD.extend(sD.info.campaignParams(),sD.info.clickParams())},searchEngine:function(e){return 0===e.search("https?://(.*)google.([^/?]*)")?"google":0===e.search("https?://(.*)bing.com")?"bing":0===e.search("https?://(.*)yahoo.com")?"yahoo":0===e.search("https?://(.*)duckduckgo.com")?"duckduckgo":null},searchInfo:function(e){var t=sD.info.searchEngine(e),r="yahoo"!=t?"q":"p",n={};if(null!==t){n.$search_engine=t;var o=sD.getQueryParam(e,r);o.length&&(n.mp_keyword=o)}return n},browser:function(e,t,r){return t=t||"",r||sD.includes(e," OPR/")?sD.includes(e,"Mini")?"Opera Mini":"Opera":/(BlackBerry|PlayBook|BB10)/i.test(e)?"BlackBerry":sD.includes(e,"IEMobile")||sD.includes(e,"WPDesktop")?"Internet Explorer Mobile":sD.includes(e,"SamsungBrowser/")?"Samsung Internet":sD.includes(e,"Edge")||sD.includes(e,"Edg/")?"Microsoft Edge":sD.includes(e,"FBIOS")?"Facebook Mobile":sD.includes(e,"Whale/")?"Whale Browser":sD.includes(e,"Chrome")?"Chrome":sD.includes(e,"CriOS")?"Chrome iOS":sD.includes(e,"UCWEB")||sD.includes(e,"UCBrowser")?"UC Browser":sD.includes(e,"FxiOS")?"Firefox iOS":sD.includes(t,"Apple")?sD.includes(e,"Mobile")?"Mobile Safari":"Safari":sD.includes(e,"Android")?"Android Mobile":sD.includes(e,"Konqueror")?"Konqueror":sD.includes(e,"Firefox")?"Firefox":sD.includes(e,"MSIE")||sD.includes(e,"Trident/")?"Internet Explorer":sD.includes(e,"Gecko")?"Mozilla":""},browserVersion:function(e,t,r){var n={"Internet Explorer Mobile":/rv:(\d+(\.\d+)?)/,"Microsoft Edge":/Edge?\/(\d+(\.\d+)?)/,Chrome:/Chrome\/(\d+(\.\d+)?)/,"Chrome iOS":/CriOS\/(\d+(\.\d+)?)/,"UC Browser":/(UCBrowser|UCWEB)\/(\d+(\.\d+)?)/,Safari:/Version\/(\d+(\.\d+)?)/,"Mobile Safari":/Version\/(\d+(\.\d+)?)/,Opera:/(Opera|OPR)\/(\d+(\.\d+)?)/,Firefox:/Firefox\/(\d+(\.\d+)?)/,"Firefox iOS":/FxiOS\/(\d+(\.\d+)?)/,Konqueror:/Konqueror:(\d+(\.\d+)?)/,BlackBerry:/BlackBerry (\d+(\.\d+)?)/,"Android Mobile":/android\s(\d+(\.\d+)?)/,"Samsung Internet":/SamsungBrowser\/(\d+(\.\d+)?)/,"Internet Explorer":/(rv:|MSIE )(\d+(\.\d+)?)/,Mozilla:/rv:(\d+(\.\d+)?)/,"Whale Browser":/Whale\/(\d+(\.\d+)?)/}[sD.info.browser(e,t,r)];if(void 0===n)return null;var o=e.match(n);return o?parseFloat(o[o.length-2]):null},os:function(){var e=QL;return/Windows/i.test(e)?/Phone/.test(e)||/WPDesktop/.test(e)?"Windows Phone":"Windows":/(iPhone|iPad|iPod)/.test(e)?"iOS":/Android/.test(e)?"Android":/(BlackBerry|PlayBook|BB10)/i.test(e)?"BlackBerry":/Mac/i.test(e)?"Mac OS X":/Linux/.test(e)?"Linux":/CrOS/.test(e)?"Chrome OS":""},device:function(e){return/Windows Phone/i.test(e)||/WPDesktop/.test(e)?"Windows Phone":/iPad/.test(e)?"iPad":/iPod/.test(e)?"iPod Touch":/iPhone/.test(e)?"iPhone":/(BlackBerry|PlayBook|BB10)/i.test(e)?"BlackBerry":/Android/.test(e)?"Android":""},referringDomain:function(e){var t=e.split("/");return t.length>=3?t[2]:""},currentUrl:function(){return Hx.location.href},properties:function(e){return"object"!=typeof e&&(e={}),sD.extend(sD.strip_empty_properties({$os:sD.info.os(),$browser:sD.info.browser(QL,YL.vendor,XL),$referrer:ZL.referrer,$referring_domain:sD.info.referringDomain(ZL.referrer),$device:sD.info.device(QL)}),{$current_url:sD.info.currentUrl(),$browser_version:sD.info.browserVersion(QL,YL.vendor,XL),$screen_height:JL.height,$screen_width:JL.width,mp_lib:"web",$lib_version:Kx.LIB_VERSION,$insert_id:SD(),time:sD.timestamp()/1e3},sD.strip_empty_properties(e))},people_properties:function(){return sD.extend(sD.strip_empty_properties({$os:sD.info.os(),$browser:sD.info.browser(QL,YL.vendor,XL)}),{$browser_version:sD.info.browserVersion(QL,YL.vendor,XL)})},mpPageViewProperties:function(){return sD.strip_empty_properties({current_page_title:ZL.title,current_domain:Hx.location.hostname,current_url_path:Hx.location.pathname,current_url_protocol:Hx.location.protocol,current_url_search:Hx.location.search})}};var SD=function(e){var t=Math.random().toString(36).substring(2,10)+Math.random().toString(36).substring(2,10);return e?t.substring(0,e):t},kD=function(){return"00-"+sD.UUID().replace(/-/g,"")+"-"+sD.UUID().replace(/-/g,"").substring(0,16)+"-01"},CD=/[a-z0-9][a-z0-9-]*\.[a-z]+$/i,OD=/[a-z0-9][a-z0-9-]+\.[a-z.]{2,6}$/i,ED=function(e){var t=OD,r=e.split("."),n=r[r.length-1];(n.length>4||"com"===n||"org"===n)&&(t=CD);var o=e.match(t);return o?o[0]:""},TD=function(){},RD=function(e,t){for(var r=!1,n=0;n<t.length;n++)if(e.match(t[n])){r=!0;break}return r},ID=null,MD=null;"undefined"!=typeof JSON&&(ID=JSON.stringify,MD=JSON.parse),ID=ID||sD.JSONEncode,MD=MD||sD.JSONDecode,sD.info=sD.info,sD.info.browser=sD.info.browser,sD.info.browserVersion=sD.info.browserVersion,sD.info.device=sD.info.device,sD.info.properties=sD.info.properties,sD.isBlockedUA=sD.isBlockedUA,sD.isEmptyObject=sD.isEmptyObject,sD.isObject=sD.isObject,sD.JSONDecode=sD.JSONDecode,sD.JSONEncode=sD.JSONEncode,sD.toArray=sD.toArray,sD.NPO=FL;var AD="mixpanelRecordingEvents",PD="mixpanelRecordingRegistry",ND=[AD,PD],jD=function(e){this.dbPromise=null,this.storeName=e};function LD(e,t){GD(!0,e,t)}function DD(e,t){GD(!1,e,t)}function FD(e,t){return"1"===HD(e,t)}function $D(e,t){if(function(e){if(e&&e.ignoreDnt)return!1;var t=e&&e.window||Hx,r=t.navigator||{},n=!1;return sD.each([r.doNotTrack,r.msDoNotTrack,t.doNotTrack],function(e){sD.includes([!0,1,"1","yes"],e)&&(n=!0)}),n}(t))return aD.warn('This browser has "Do Not Track" enabled. This will prevent the Mixpanel SDK from sending any data. To ignore the "Do Not Track" browser setting, initialize the Mixpanel instance with the config "ignore_dnt: true"'),!0;var r="0"===HD(e,t);return r&&aD.warn("You are opted out of Mixpanel tracking. This will prevent the Mixpanel SDK from sending any data."),r}function BD(e){return KD(e,function(e){return this.get_config(e)})}function zD(e){return KD(e,function(e){return this._get_config(e)})}function VD(e){return KD(e,function(e){return this._get_config(e)})}function UD(e,t){qD(t=t||{}).remove(WD(e,t),!!t.crossSubdomainCookie,t.cookieDomain)}function qD(e){return"localStorage"===(e=e||{}).persistenceType?sD.localStorage:sD.cookie}function WD(e,t){return((t=t||{}).persistencePrefix||"__mp_opt_in_out_")+e}function HD(e,t){return qD(t).get(WD(e,t))}function GD(e,t,r){sD.isString(t)&&t.length?(qD(r=r||{}).set(WD(t,r),e?1:0,sD.isNumber(r.cookieExpiration)?r.cookieExpiration:null,!!r.crossSubdomainCookie,!!r.secureCookie,!!r.crossSiteCookie,r.cookieDomain),r.track&&e&&r.track(r.trackEventName||"$opt_in",r.trackProperties,{send_immediately:!0})):aD.error("gdpr."+(e?"optIn":"optOut")+" called with an invalid token")}function KD(e,t){return function(){var r=!1;try{var n=t.call(this,"token"),o=t.call(this,"ignore_dnt"),i=t.call(this,"opt_out_tracking_persistence_type"),s=t.call(this,"opt_out_tracking_cookie_prefix"),a=t.call(this,"window");n&&(r=$D(n,{ignoreDnt:o,persistenceType:i,persistencePrefix:s,window:a}))}catch(e){aD.error("Unexpected error when checking tracking opt-out status: "+e)}if(!r)return e.apply(this,arguments);var l=arguments[arguments.length-1];"function"==typeof l&&l(0)}}jD.prototype._openDb=function(){return new $L(function(e,t){var r=Hx.indexedDB.open("mixpanelBrowserDb",1);r.onerror=function(){t(r.error)},r.onsuccess=function(){e(r.result)},r.onupgradeneeded=function(e){var t=e.target.result;ND.forEach(function(e){t.createObjectStore(e)})}})},jD.prototype.init=function(){return Hx.indexedDB?(this.dbPromise||(this.dbPromise=this._openDb()),this.dbPromise.then(function(e){return e instanceof Hx.IDBDatabase?$L.resolve():$L.reject(e)})):$L.reject("indexedDB is not supported in this browser")},jD.prototype.isInitialized=function(){return!!this.dbPromise},jD.prototype.makeTransaction=function(e,t){var r=this.storeName,n=function(n){return new $L(function(o,i){var s=n.transaction(r,e);s.oncomplete=function(){o(s)},s.onabort=s.onerror=function(){i(s.error)},t(s.objectStore(r))})};return this.dbPromise.then(n).catch(function(e){return e&&"InvalidStateError"===e.name?(this.dbPromise=this._openDb(),this.dbPromise.then(n)):$L.reject(e)}.bind(this))},jD.prototype.setItem=function(e,t){return this.makeTransaction("readwrite",function(r){r.put(t,e)})},jD.prototype.getItem=function(e){var t;return this.makeTransaction("readonly",function(r){t=r.get(e)}).then(function(){return t.result})},jD.prototype.removeItem=function(e){return this.makeTransaction("readwrite",function(t){t.delete(e)})},jD.prototype.getAll=function(){var e;return this.makeTransaction("readonly",function(t){e=t.getAll()}).then(function(){return e.result})};var YD=cD("lock"),ZD=function(e,t){t=t||{},this.storageKey=e,this.storage=t.storage||Hx.localStorage,this.pollIntervalMS=t.pollIntervalMS||100,this.timeoutMS=t.timeoutMS||2e3,this.promiseImpl=t.promiseImpl||$L};ZD.prototype.withLock=function(e,t){return new(0,this.promiseImpl)(sD.bind(function(r,n){var o=t||(new Date).getTime()+"|"+Math.random(),i=(new Date).getTime(),s=this.storageKey,a=this.pollIntervalMS,l=this.timeoutMS,c=this.storage,u=s+":X",p=s+":Y",d=s+":Z",f=function(e){if((new Date).getTime()-i>l)return YD.error("Timeout waiting for mutex on "+s+"; clearing lock. ["+o+"]"),c.removeItem(d),c.removeItem(p),void g();setTimeout(function(){try{e()}catch(e){n(e)}},a*(Math.random()+.1))},h=function(e,t){e()?t():f(function(){h(e,t)})},m=function(){var e=c.getItem(p);return!(e&&e!==o||(c.setItem(p,o),c.getItem(p)!==o&&(mD(c,!0)||n(new Error("localStorage support dropped while acquiring lock")),1)))},g=function(){c.setItem(u,o),h(m,function(){c.getItem(u)!==o?f(function(){c.getItem(p)===o?h(function(){return!c.getItem(d)},v):g()}):v()})},v=function(){c.setItem(d,"1");var t=function(){c.removeItem(d),c.getItem(p)===o&&c.removeItem(p),c.getItem(u)===o&&c.removeItem(u)};e().then(function(e){t(),r(e)}).catch(function(e){t(),n(e)})};try{if(!mD(c,!0))throw new Error("localStorage support check failed");g()}catch(e){n(e)}},this))};var XD=function(e){this.storage=e||Hx.localStorage};XD.prototype.init=function(){return $L.resolve()},XD.prototype.isInitialized=function(){return!0},XD.prototype.setItem=function(e,t){return new $L(sD.bind(function(r,n){try{this.storage.setItem(e,ID(t))}catch(e){n(e)}r()},this))},XD.prototype.getItem=function(e){return new $L(sD.bind(function(t,r){var n;try{n=MD(this.storage.getItem(e))}catch(e){r(e)}t(n)},this))},XD.prototype.removeItem=function(e){return new $L(sD.bind(function(t,r){try{this.storage.removeItem(e)}catch(e){r(e)}t()},this))};var JD=cD("batch"),QD=function(e,t){var r,n,o,i;t=t||{},this.storageKey=e,this.usePersistence=t.usePersistence,this.usePersistence&&(this.queueStorage=t.queueStorage||new XD,this.lock=new ZD(e,{storage:t.sharedLockStorage||Hx.localStorage,timeoutMS:t.sharedLockTimeoutMS})),this.reportError=t.errorReporter||sD.bind(JD.error,JD),this.pid=t.pid||null,this.memQueue=[],this.initialized=!1,t.enqueueThrottleMs?this.enqueuePersisted=(r=sD.bind(this._enqueuePersisted,this),n=t.enqueueThrottleMs,o=null,i=[],function(e){var t=this;return i.push(e),o||(o=new $L(function(e){setTimeout(function(){var n=r.apply(t,[i]);o=null,i=[],e(n)},n)})),o}):this.enqueuePersisted=sD.bind(function(e){return this._enqueuePersisted([e])},this)};QD.prototype.ensureInit=function(){return this.initialized||!this.usePersistence?$L.resolve():this.queueStorage.init().then(sD.bind(function(){this.initialized=!0},this)).catch(sD.bind(function(e){this.reportError("Error initializing queue persistence. Disabling persistence",e),this.initialized=!0,this.usePersistence=!1},this))},QD.prototype.enqueue=function(e,t){var r={id:SD(),flushAfter:(new Date).getTime()+2*t,payload:e};return this.usePersistence?this.enqueuePersisted(r):(this.memQueue.push(r),$L.resolve(!0))},QD.prototype._enqueuePersisted=function(e){var t=sD.bind(function(){return this.ensureInit().then(sD.bind(function(){return this.readFromStorage()},this)).then(sD.bind(function(t){return this.saveToStorage(t.concat(e))},this)).then(sD.bind(function(t){return t&&(this.memQueue=this.memQueue.concat(e)),t},this)).catch(sD.bind(function(t){return this.reportError("Error enqueueing items",t,e),!1},this))},this);return this.lock.withLock(t,this.pid).catch(sD.bind(function(e){return this.reportError("Error acquiring storage lock",e),!1},this))},QD.prototype.fillBatch=function(e){var t=this.memQueue.slice(0,e);return this.usePersistence&&t.length<e?this.ensureInit().then(sD.bind(function(){return this.readFromStorage()},this)).then(sD.bind(function(r){if(r.length){var n={};sD.each(t,function(e){n[e.id]=!0});for(var o=0;o<r.length;o++){var i=r[o];if((new Date).getTime()>i.flushAfter&&!n[i.id]&&(i.orphaned=!0,t.push(i),t.length>=e))break}}return t},this)):$L.resolve(t)};var eF=function(e,t){var r=[];return sD.each(e,function(e){e.id&&!t[e.id]&&r.push(e)}),r};QD.prototype.removeItemsByID=function(e){var t={};if(sD.each(e,function(e){t[e]=!0}),this.memQueue=eF(this.memQueue,t),this.usePersistence){var r=sD.bind(function(){return this.ensureInit().then(sD.bind(function(){return this.readFromStorage()},this)).then(sD.bind(function(e){return e=eF(e,t),this.saveToStorage(e)},this)).then(sD.bind(function(){return this.readFromStorage()},this)).then(sD.bind(function(e){for(var r=0;r<e.length;r++){var n=e[r];if(n.id&&t[n.id])throw new Error("Item not removed from storage")}return!0},this)).catch(sD.bind(function(t){return this.reportError("Error removing items",t,e),!1},this))},this);return this.lock.withLock(r,this.pid).catch(sD.bind(function(e){return this.reportError("Error acquiring storage lock",e),!mD(this.lock.storage,!0)&&r().then(sD.bind(function(e){return e||this.queueStorage.removeItem(this.storageKey).then(function(){return e})},this)).catch(sD.bind(function(e){return this.reportError("Error clearing queue",e),!1},this))},this))}return $L.resolve(!0)};var tF=function(e,t){var r=[];return sD.each(e,function(e){var n=e.id;if(n in t){var o=t[n];null!==o&&(e.payload=o,r.push(e))}else r.push(e)}),r};QD.prototype.updatePayloads=function(e){return this.memQueue=tF(this.memQueue,e),this.usePersistence?this.lock.withLock(sD.bind(function(){return this.ensureInit().then(sD.bind(function(){return this.readFromStorage()},this)).then(sD.bind(function(t){return t=tF(t,e),this.saveToStorage(t)},this)).catch(sD.bind(function(t){return this.reportError("Error updating items",e,t),!1},this))},this),this.pid).catch(sD.bind(function(e){return this.reportError("Error acquiring storage lock",e),!1},this)):$L.resolve(!0)},QD.prototype.readFromStorage=function(){return this.ensureInit().then(sD.bind(function(){return this.queueStorage.getItem(this.storageKey)},this)).then(sD.bind(function(e){return e&&(sD.isArray(e)||(this.reportError("Invalid storage entry:",e),e=null)),e||[]},this)).catch(sD.bind(function(e){return this.reportError("Error retrieving queue",e),[]},this))},QD.prototype.saveToStorage=function(e){return this.ensureInit().then(sD.bind(function(){return this.queueStorage.setItem(this.storageKey,e)},this)).then(function(){return!0}).catch(sD.bind(function(e){return this.reportError("Error saving queue",e),!1},this))},QD.prototype.clear=function(){return this.memQueue=[],this.usePersistence?this.ensureInit().then(sD.bind(function(){return this.queueStorage.removeItem(this.storageKey)},this)):$L.resolve()};var rF=cD("batch"),nF=function(e,t){this.errorReporter=t.errorReporter,this.queue=new QD(e,{errorReporter:sD.bind(this.reportError,this),queueStorage:t.queueStorage,sharedLockStorage:t.sharedLockStorage,sharedLockTimeoutMS:t.sharedLockTimeoutMS,usePersistence:t.usePersistence,enqueueThrottleMs:t.enqueueThrottleMs}),this.libConfig=t.libConfig,this.sendRequest=t.sendRequestFunc,this.beforeSendHook=t.beforeSendHook,this.stopAllBatching=t.stopAllBatchingFunc,this.batchSize=this.libConfig.batch_size,this.flushInterval=this.libConfig.batch_flush_interval_ms,this.stopped=!this.libConfig.batch_autostart,this.consecutiveRemovalFailures=0,this.itemIdsSentSuccessfully={},this.flushOnlyOnInterval=t.flushOnlyOnInterval||!1,this._flushPromise=null};nF.prototype.enqueue=function(e){return this.queue.enqueue(e,this.flushInterval)},nF.prototype.start=function(){return this.stopped=!1,this.consecutiveRemovalFailures=0,this.flush()},nF.prototype.stop=function(){this.stopped=!0,this.timeoutID&&(clearTimeout(this.timeoutID),this.timeoutID=null)},nF.prototype.clear=function(){return this.queue.clear()},nF.prototype.resetBatchSize=function(){this.batchSize=this.libConfig.batch_size},nF.prototype.resetFlush=function(){this.scheduleFlush(this.libConfig.batch_flush_interval_ms)},nF.prototype.scheduleFlush=function(e){this.flushInterval=e,this.stopped||(this.timeoutID=setTimeout(sD.bind(function(){this.stopped||(this._flushPromise=this.flush())},this),this.flushInterval))},nF.prototype.sendRequestPromise=function(e,t){return new $L(sD.bind(function(r){this.sendRequest(e,t,r)},this))},nF.prototype.flush=function(e){if(this.requestInProgress)return rF.log("Flush: Request already in progress"),$L.resolve();this.requestInProgress=!0,e=e||{};var t=this.libConfig.batch_request_timeout_ms,r=(new Date).getTime(),n=this.batchSize;return this.queue.fillBatch(n).then(sD.bind(function(o){var i=o.length===n,s=[],a={};if(sD.each(o,function(e){var t=e.payload;if(this.beforeSendHook&&!e.orphaned&&(t=this.beforeSendHook(t)),t){t.event&&t.properties&&(t.properties=sD.extend({},t.properties,{mp_sent_by_lib_version:Kx.LIB_VERSION}));var r=!0,n=e.id;n?(this.itemIdsSentSuccessfully[n]||0)>5&&(this.reportError("[dupe] item ID sent too many times, not sending",{item:e,batchSize:o.length,timesSent:this.itemIdsSentSuccessfully[n]}),r=!1):this.reportError("[dupe] found item with no ID",{item:e}),r&&s.push(t)}a[e.id]=t},this),s.length<1)return this.requestInProgress=!1,this.resetFlush(),$L.resolve();var l=sD.bind(function(){return this.queue.removeItemsByID(sD.map(o,function(e){return e.id})).then(sD.bind(function(e){return sD.each(o,sD.bind(function(e){var t=e.id;t?(this.itemIdsSentSuccessfully[t]=this.itemIdsSentSuccessfully[t]||0,this.itemIdsSentSuccessfully[t]++,this.itemIdsSentSuccessfully[t]>5&&this.reportError("[dupe] item ID sent too many times",{item:e,batchSize:o.length,timesSent:this.itemIdsSentSuccessfully[t]})):this.reportError("[dupe] found item with no ID while removing",{item:e})},this)),e?(this.consecutiveRemovalFailures=0,this.flushOnlyOnInterval&&!i?(this.resetFlush(),$L.resolve()):this.flush()):(++this.consecutiveRemovalFailures>5?(this.reportError("Too many queue failures; disabling batching system."),this.stopAllBatching()):this.resetFlush(),$L.resolve())},this))},this),c=sD.bind(function(i){this.requestInProgress=!1;try{if(e.unloading)return this.queue.updatePayloads(a);if(sD.isObject(i)&&"timeout"===i.error&&(new Date).getTime()-r>=t)return this.reportError("Network timeout; retrying"),this.flush();if(sD.isObject(i)&&(i.httpStatusCode>=500||429===i.httpStatusCode||i.httpStatusCode<=0&&(u=Hx.navigator.onLine,!sD.isUndefined(u)&&!u)||"timeout"===i.error)){var s=2*this.flushInterval;return i.retryAfter&&(s=1e3*parseInt(i.retryAfter,10)||s),s=Math.min(6e5,s),this.reportError("Error; retry in "+s+" ms"),this.scheduleFlush(s),$L.resolve()}if(sD.isObject(i)&&413===i.httpStatusCode){if(o.length>1){var c=Math.max(1,Math.floor(n/2));return this.batchSize=Math.min(this.batchSize,c,o.length-1),this.reportError("413 response; reducing batch size to "+this.batchSize),this.resetFlush(),$L.resolve()}return this.reportError("Single-event request too large; dropping",o),this.resetBatchSize(),l()}return l()}catch(e){this.reportError("Error handling API response",e),this.resetFlush()}var u},this),u={method:"POST",verbose:!0,ignore_json_errors:!0,timeout_ms:t};return e.unloading&&(u.transport="sendBeacon"),rF.log("MIXPANEL REQUEST:",s),this.sendRequestPromise(s,u).then(c)},this)).catch(sD.bind(function(e){this.reportError("Error flushing request queue",e),this.resetFlush()},this))},nF.prototype.reportError=function(e,t){if(rF.error.apply(rF.error,arguments),this.errorReporter)try{t instanceof Error||(t=new Error(e)),this.errorReporter(e,t)}catch(t){rF.error(t)}};var oF=function(e){var t=Date.now();return!e||t>e.maxExpires||t>e.idleExpires},iF=function(e,t){if(!sD.isArray(e))return e&&t.critical("record_allowed_iframe_origins must be an array of origin strings, cross-origin recording will be disabled."),[];for(var r=[],n=0;n<e.length;n++)try{var o=new URL(e[n]).origin;if("null"===o){t.critical(e[n]+" has an opaque origin. Skipping this entry.");continue}r.push(o)}catch(r){t.critical(e[n]+" is not a valid origin URL. Skipping this entry.")}return r},sF="change",aF="click",lF="hashchange",cF="load",uF="mp_locationchange",pF="popstate",dF="scrollend",fF="scroll",hF="submit",mF="visibilitychange",gF=["clientX","clientY","offsetX","offsetY","pageX","pageY","screenX","screenY","x","y"],vF=["mp-include"],yF=["mp-no-track"],bF=yF.concat(["mp-sensitive"]),wF=["aria-label","aria-labelledby","aria-describedby","href","name","role","title","type"],xF={button:!0,checkbox:!0,combobox:!0,grid:!0,link:!0,listbox:!0,menu:!0,menubar:!0,menuitem:!0,menuitemcheckbox:!0,menuitemradio:!0,navigation:!0,option:!0,radio:!0,radiogroup:!0,searchbox:!0,slider:!0,spinbutton:!0,switch:!0,tab:!0,tablist:!0,textbox:!0,tree:!0,treegrid:!0,treeitem:!0},_F={base:!0,head:!0,html:!0,link:!0,meta:!0,script:!0,style:!0,title:!0,br:!0,hr:!0,wbr:!0,noscript:!0,picture:!0,source:!0,template:!0,track:!0},SF={article:!0,div:!0,h1:!0,h2:!0,h3:!0,h4:!0,h5:!0,h6:!0,p:!0,section:!0,span:!0},kF=["onclick","onmousedown","onmouseup","onpointerdown","onpointerup","ontouchend","ontouchstart"],CF=cD("autocapture");function OF(e){for(var t={},r=EF(e).split(" "),n=0;n<r.length;n++){var o=r[n];o&&(t[o]=!0)}return t}function EF(e){switch(typeof e.className){case"string":return e.className;case"object":return e.className.baseVal||e.getAttribute("class")||"";default:return""}}function TF(e){if(e.previousElementSibling)return e.previousElementSibling;do{e=e.previousSibling}while(e&&!PF(e));return e}function RF(e,t,r,n,o,i){var s={$classes:EF(e).split(" "),$tag_name:e.tagName.toLowerCase()},a=e.id;a&&(s.$id=a),DF(e,t,o,i)&&sD.each(wF.concat(n),function(t){if(e.hasAttribute(t)&&!r[t]){var n=e.getAttribute(t);FF(n)&&(s["$attr-"+t]=n)}});for(var l=1,c=1,u=e;u=TF(u);)l++,u.tagName===e.tagName&&c++;return s.$nth_child=l,s.$nth_of_type=c,s}function IF(e,t,r,n){var o="";return DF(e,t,r,n)&&e.childNodes&&e.childNodes.length&&sD.each(e.childNodes,function(e){jF(e)&&e.textContent&&(o+=sD.trim(e.textContent).split(/(\s+)/).filter(FF).join("").replace(/[\r\n]/g," ").replace(/[ ]+/g," ").substring(0,255))}),sD.trim(o)}function MF(e,t,r,n){if(r)try{if(!r(e,t))return!1}catch(e){return CF.critical("Error while checking element in allowElementCallback",e),!1}if(!n.length)return!0;for(var o=0;o<n.length;o++){var i=n[o];try{if(e.matches(i))return!0}catch(e){CF.critical("Error while checking selector: "+i,e)}}return!1}function AF(e,t,r,n){var o;if(r)try{if(r(e,t))return!0}catch(e){return CF.critical("Error while checking element in blockElementCallback",e),!0}if(n&&n.length)for(o=0;o<n.length;o++){var i=n[o];try{if(e.matches(i))return!0}catch(e){CF.critical("Error while checking selector: "+i,e)}}var s=OF(e);for(o=0;o<yF.length;o++)if(s[yF[o]])return!0;return!1}function PF(e){return e&&1===e.nodeType}function NF(e,t){return e&&e.tagName&&e.tagName.toLowerCase()===t.toLowerCase()}function jF(e){return e&&3===e.nodeType}function LF(e){var t=(e.name||e.id||"").toString().toLowerCase();return!("string"!=typeof t||!/^cc|cardnum|ccnum|creditcard|csc|cvc|cvv|exp|pass|pwd|routing|seccode|securitycode|securitynum|socialsec|socsec|ssn/i.test(t.replace(/[^a-zA-Z0-9]/g,"")))}function DF(e,t,r,n){var o;if(!MF(e,t,r,n))return!1;for(var i=e;i.parentNode&&!NF(i,"body");i=i.parentNode){var s=OF(i);for(o=0;o<bF.length;o++)if(s[bF[o]])return!1}var a=OF(e);for(o=0;o<vF.length;o++)if(a[vF[o]])return!0;if(NF(e,"input")||NF(e,"select")||NF(e,"textarea")||"true"===e.getAttribute("contenteditable"))return!1;var l=e.type||"";if("string"==typeof l)switch(l.toLowerCase()){case"hidden":case"password":return!1}return!LF(e)}function FF(e){if(null===e||sD.isUndefined(e))return!1;if("string"==typeof e){if(e=sD.trim(e),/^(?:(4[0-9]{12}(?:[0-9]{3})?)|(5[1-5][0-9]{14})|(6(?:011|5[0-9]{2})[0-9]{12})|(3[47][0-9]{13})|(3(?:0[0-5]|[68][0-9])[0-9]{11})|((?:2131|1800|35[0-9]{3})[0-9]{11}))$/.test((e||"").replace(/[- ]/g,"")))return!1;if(/(^\d{3}-?\d{2}-?\d{4}$)/.test(e))return!1}return!0}function $F(e){var t="onscrollend"in Hx,r=uD(e),n=dF;if(!t){var o=null;r=uD(function(){clearTimeout(o),o=setTimeout(e,100)}),n=fF}return{listener:r,eventType:n}}function BF(e){var t=e.tagName.toLowerCase();return!!("button"===t||"input"===t||"select"===t||"textarea"===t||"details"===t||"dialog"===t||e.isContentEditable||e.onclick||e.onmousedown||e.onmouseup||e.ontouchstart||e.ontouchend||function(e){for(var t=0;t<kF.length;t++)if(e.hasAttribute(kF[t]))return!0;return!1}(e)||function(e){var t=e.getAttribute("role");if(!t)return!1;var r=t.trim().split(/\s+/)[0].toLowerCase();return xF[r]}(e)||"a"===t&&e.hasAttribute("href")||e.hasAttribute("tabindex"))}function zF(e){if(!e||!e.tagName)return!0;var t=e.tagName.toLowerCase();if(_F[t])return!0;if(BF(e))return!1;for(var r=e.parentElement,n=0;r&&n<5;){if(BF(r))return!1;if(r.getRootNode&&r.getRootNode()!==ZL){var o=r.getRootNode();if(o.host&&BF(o.host))return!1}r=r.parentElement,n++}return!!SF[t]}function VF(e){return"composedPath"in e?e.composedPath():[]}function UF(e){var t=VF(e);return t&&t.length>0?t[0]:e.target||e.srcElement}var qF=".mp-mask, .fs-mask, .amp-mask, .rr-mask, .ph-mask",WF=["password","email","tel","hidden"];function HF(e){return e?Array.isArray(e)?e:[e]:[]}function GF(e,t){return!!t&&!!e.closest(t)}function KF(e,t){var r=(e.getAttribute("type")||"").toLowerCase();if(-1!==WF.indexOf(r))return!0;var n=(e.getAttribute("autocomplete")||"").toLowerCase();return!((!n||""===n||"off"===n)&&!e.hasAttribute("data-rr-is-password")&&!LF(e)&&(t.input.maskAll?GF(e,t.input.unmaskingSelector):!GF(e,t.input.maskingSelector)&&!GF(e,qF)))}function YF(e,t){return!(!e||(!t.text._legacyClassRegex||!TA(e,t.text._legacyClassRegex))&&(t.text.maskAll?GF(e,t.text.unmaskingSelector):!GF(e,t.text.maskingSelector)&&!GF(e,qF)))}var ZF=cD("network-plugin");function XF(e){return Math.round(Date.now()-e.performance.now())}var JF={initiatorTypes:["audio","beacon","body","css","early-hint","embed","fetch","frame","iframe","icon","image","img","input","link","navigation","object","ping","script","track","video","xmlhttprequest"],ignoreRequestFn:function(){return!1},recordHeaders:{request:[],response:[]},recordBodyUrls:{request:[],response:[]},recordInitialRequests:!1};function QF(e){return"resource"===e.entryType}function e$(e,t,r){if(!(t in e)||"function"!=typeof e[t])return function(){};var n=e[t],o=r(n);return e[t]=o,function(){e[t]=n}}var t$=1048576;function r$(e){return e&&"string"==typeof e&&e.length>t$?(ZF.error("Body truncated from "+e.length+" to "+t$+" characters"),e.substring(0,t$)+"... [truncated]"):e}function n$(e,t,r){return!(!t[e]||0===t[e].length)&&t[e].includes(r.toLowerCase())}function o$(e,t,r){return!(!t[e]||0===t[e].length)&&RD(r,t[e])}function i$(e){if(null==e)return null;var t;if("string"==typeof e)t=e;else if(e instanceof Document)t=e.textContent;else if(e instanceof FormData)t=sD.HTTPBuildQuery(e);else{if(!sD.isObject(e))return"Cannot read body of type "+typeof e;try{t=JSON.stringify(e)}catch(e){return"Failed to stringify response object"}}return r$(t)}function s$(e){return new Promise(function(t){var r=setTimeout(function(){t("Timeout while trying to read body")},500);try{e.clone().text().then(function(e){clearTimeout(r),t(r$(e))},function(e){clearTimeout(r),t("Failed to read body: "+String(e))})}catch(e){clearTimeout(r),t("Failed to read body: "+String(e))}})}function a$(e,t,r,n,o,i){if(void 0===i&&(i=0),i>10)return ZF.error("Cannot find performance entry"),Promise.resolve(null);var s=function(e,t){for(var r=e.length-1;r>=0;r-=1)if(t(e[r]))return e[r]}(e.performance.getEntriesByName(r),function(e){return QF(e)&&e.initiatorType===t&&(!n||e.startTime>=n)&&(!o||e.startTime<=o)});return s?Promise.resolve(s):new Promise(function(e){setTimeout(e,50*i)}).then(function(){return a$(e,t,r,n,o,i+1)})}function l$(e,t,r){if(!("performance"in t))return function(){};var n=Object.assign({},JF.recordHeaders,r.recordHeaders||{}),o=Object.assign({},JF.recordBodyUrls,r.recordBodyUrls||{});r=Object.assign({},r,{recordHeaders:n,recordBodyUrls:o});var i=Object.assign({},JF,r),s=function(t){var r=t.requests.filter(function(e){return!RD(e.url,i.ignoreRequestUrls||[])&&!i.ignoreRequestFn(e)});(r.length>0||t.isInitial)&&e(Object.assign({},t,{requests:r}))},a=function(e,t,r){if(!t.PerformanceObserver)return ZF.error("PerformanceObserver not supported"),function(){};if(r.recordInitialRequests){var n=t.performance.getEntries().filter(function(e){return function(e){return"navigation"===e.entryType}(e)||QF(e)&&r.initiatorTypes.includes(e.initiatorType)});e({requests:n.map(function(e){return{url:e.name,initiatorType:e.initiatorType,status:"responseStatus"in e?e.responseStatus:void 0,startTime:Math.round(e.startTime),endTime:Math.round(e.responseEnd),timeOrigin:XF(t)}}),isInitial:!0})}var o=new t.PerformanceObserver(function(n){var o=n.getEntries().filter(function(e){return QF(e)&&r.initiatorTypes.includes(e.initiatorType)&&"xmlhttprequest"!==e.initiatorType&&"fetch"!==e.initiatorType});e({requests:o.map(function(e){return{url:e.name,initiatorType:e.initiatorType,status:"responseStatus"in e?e.responseStatus:void 0,startTime:Math.round(e.startTime),endTime:Math.round(e.responseEnd),timeOrigin:XF(t)}})})});return o.observe({entryTypes:["navigation","resource"]}),function(){o.disconnect()}}(s,t,i),l=function(e,t,r){if(!r.initiatorTypes.includes("xmlhttprequest"))return function(){};var n=e$(t.XMLHttpRequest.prototype,"open",function(n){return function(o,i,s,a,l){void 0===s&&(s=!0);var c,u,p=this,d=new Request(i,{method:o}),f={},h={},m=p.setRequestHeader.bind(p);p.setRequestHeader=function(e,t){return n$("request",r.recordHeaders,e)&&(h[e]=t),m(e,t)},f.requestHeaders=h;var g=p.send.bind(p);p.send=function(e){return o$("request",r.recordBodyUrls,d.url)&&(f.requestBody=i$(e)),c=t.performance.now(),g(e)},p.addEventListener("readystatechange",function(){if(p.readyState===p.DONE){u=t.performance.now();var n={},o=p.getAllResponseHeaders();o&&o.trim().split(/[\r\n]+/).forEach(function(e){if(e){var t=e.indexOf(": ");if(-1!==t){var o=e.substring(0,t),i=e.substring(t+2);o&&n$("response",r.recordHeaders,o)&&(n[o]=i)}}}),f.responseHeaders=n,o$("response",r.recordBodyUrls,d.url)&&(f.responseBody=i$(p.response)),a$(t,"xmlhttprequest",d.url,c,u).then(function(r){if(r){var n={url:r.name,method:d.method,initiatorType:r.initiatorType,status:p.status,startTime:Math.round(r.startTime),endTime:Math.round(r.responseEnd),timeOrigin:XF(t),requestHeaders:f.requestHeaders,requestBody:f.requestBody,responseHeaders:f.responseHeaders,responseBody:f.responseBody};e({requests:[n]})}else ZF.error("Failed to get performance entry for XHR request to "+d.url)}).catch(function(e){ZF.error("Error recording XHR request to "+d.url+": "+String(e))})}}),n.call(p,o,i,s,a,l)}});return function(){n()}}(s,t,i),c=function(e,t,r){if(!r.initiatorTypes.includes("fetch"))return function(){};var n=e$(t,"fetch",function(n){return function(){var o,i,s,a,l=new Request(arguments[0],arguments[1]),c={},u=Promise.resolve(void 0),p=Promise.resolve(void 0);try{var d={};l.headers.forEach(function(e,t){n$("request",r.recordHeaders,t)&&(d[t]=e)}),c.requestHeaders=d,o$("request",r.recordBodyUrls,l.url)&&(u=s$(l).then(function(e){c.requestBody=e})),i=t.performance.now(),a=n.apply(t,arguments).then(function(e){o=e,s=t.performance.now();var n={};return o.headers.forEach(function(e,t){n$("response",r.recordHeaders,t)&&(n[t]=e)}),c.responseHeaders=n,o$("response",r.recordBodyUrls,l.url)&&(p=s$(o).then(function(e){c.responseBody=e})),o})}catch(e){a=Promise.reject(e)}return Promise.all([u,p,a]).then(function(){return a$(t,"fetch",l.url,i,s)}).then(function(r){if(r){var n={url:r.name,method:l.method,initiatorType:r.initiatorType,status:o?o.status:void 0,startTime:Math.round(r.startTime),endTime:Math.round(r.responseEnd),timeOrigin:XF(t),requestHeaders:c.requestHeaders,requestBody:c.requestBody,responseHeaders:c.responseHeaders,responseBody:c.responseBody};e({requests:[n]})}else ZF.error("Failed to get performance entry for fetch request to "+l.url)}).catch(function(e){ZF.error("Error recording fetch request to "+l.url+": "+String(e))}),a}});return function(){n()}}(s,t,i);return function(){a(),l(),c()}}var c$=cD("recorder"),u$=Hx.CompressionStream,p$={batch_size:1e3,batch_flush_interval_ms:1e4,batch_request_timeout_ms:9e4,batch_autostart:!0},d$=new Set([vM.MouseMove,vM.MouseInteraction,vM.Scroll,vM.ViewportResize,vM.Input,vM.TouchMove,vM.MediaInteraction,vM.Drag,vM.Selection]),f$=function(e){this._mixpanel=e.mixpanelInstance,this._onIdleTimeout=e.onIdleTimeout||TD,this._onMaxLengthReached=e.onMaxLengthReached||TD,this._onBatchSent=e.onBatchSent||TD,this._rrwebRecord=e.rrwebRecord||null,this._stopRecording=null,this.replayId=e.replayId,this.batchStartUrl=e.batchStartUrl||null,this.replayStartUrl=e.replayStartUrl||null,this.idleExpires=e.idleExpires||null,this.maxExpires=e.maxExpires||null,this.replayStartTime=e.replayStartTime||null,this.lastEventTimestamp=e.lastEventTimestamp||null,this.seqNo=e.seqNo||0,this.idleTimeoutId=null,this.maxTimeoutId=null,this.recordMaxMs=zL,this.recordMinMs=0;var t=mD(e.sharedLockStorage,!0)&&!this.getConfig("disable_persistence");this.batcherKey="__mprec_"+this.getConfig("name")+"_"+this.getConfig("token")+"_"+this.replayId,this.queueStorage=new jD(AD),this.batcher=new nF(this.batcherKey,{errorReporter:this.reportError.bind(this),flushOnlyOnInterval:!0,libConfig:p$,sendRequestFunc:this.flushEventsWithOptOut.bind(this),queueStorage:this.queueStorage,sharedLockStorage:e.sharedLockStorage,usePersistence:t,stopAllBatchingFunc:this.stopRecording.bind(this),enqueueThrottleMs:250,sharedLockTimeoutMS:1e4})};f$.prototype.getUserIdInfo=function(){if(this.finalFlushUserIdInfo)return this.finalFlushUserIdInfo;var e={distinct_id:String(this._mixpanel.get_distinct_id())},t=this._mixpanel.get_property("$device_id");t&&(e.$device_id=t);var r=this._mixpanel.get_property("$user_id");return r&&(e.$user_id=r),e},f$.prototype.unloadPersistedData=function(){return this.batcher.stop(),this.queueStorage.init().catch(function(){this.reportError("Error initializing IndexedDB storage for unloading persisted data.")}.bind(this)).then(function(){return this.getDurationMs()<this._getRecordMinMs()?this.queueStorage.removeItem(this.batcherKey):this.batcher.flush().then(function(){return this.queueStorage.removeItem(this.batcherKey)}.bind(this))}.bind(this))},f$.prototype.getConfig=function(e){return this._mixpanel.get_config(e)},f$.prototype.get_config=function(e){return this.getConfig(e)},f$.prototype.startRecording=function(e){if(null!==this._rrwebRecord)if(null===this._stopRecording){this.recordMaxMs=this.getConfig("record_max_ms"),this.recordMaxMs>zL&&(this.recordMaxMs=zL,c$.critical("record_max_ms cannot be greater than "+zL+"ms. Capping value.")),this.maxExpires||(this.maxExpires=(new Date).getTime()+this.recordMaxMs),this.recordMinMs=this._getRecordMinMs(),this.replayStartTime||(this.replayStartTime=(new Date).getTime(),this.batchStartUrl=sD.info.currentUrl(),this.replayStartUrl=sD.info.currentUrl()),e||this.recordMinMs>0?this.batcher.stop():this.batcher.start();var t=function(){clearTimeout(this.idleTimeoutId);var e=this.getConfig("record_idle_timeout_ms");this.idleTimeoutId=setTimeout(this._onIdleTimeout,e),this.idleExpires=(new Date).getTime()+e}.bind(this);t();var r=this.getConfig("record_block_selector");""!==r&&null!==r||(r=void 0);var n=function(e){var t={input:{maskingSelector:"",unmaskingSelector:"",maskAll:!0},text:{maskingSelector:"",unmaskingSelector:"",maskAll:!0}},r=e.get_config("record_mask_input_selector"),n=e.get_config("record_unmask_input_selector"),o=e.get_config("record_mask_all_inputs");t.input.maskingSelector=HF(r).join(","),t.input.unmaskingSelector=HF(n).join(","),void 0!==o&&(t.input.maskAll=o);var i=e.get_config("record_mask_text_selector"),s=e.get_config("record_unmask_text_selector"),a=e.get_config("record_mask_all_text"),l=e.get_config("record_mask_text_class"),c=HF(i);if(l)if(l instanceof RegExp)t.text._legacyClassRegex=l;else{var u="."+l;-1===c.indexOf(u)&&c.push(u)}return t.text.maskingSelector=c.join(","),t.text.unmaskingSelector=HF(s).join(","),void 0===a&&void 0!==i?t.text.maskAll=!1:void 0!==a&&(t.text.maskAll=a),t}(this._mixpanel),o=[];if(this.getConfig("record_network")){var i=this.getConfig("record_network_options")||{},s=(i.ignoreRequestUrls||[]).slice();s.push(this._getApiRoute()),i.ignoreRequestUrls=s,o.push(function(e){return{name:"rrweb/network@1.mp",observer:l$,options:e}}(i))}this.getConfig("record_console")&&o.push({name:"rrweb/console@1",observer:_L,options:{stringifyOptions:{stringLengthLimit:1e3,numOfKeysLimit:50,depthOfLimit:2}}});var a=iF(this.getConfig("record_allowed_iframe_origins"),c$);try{this._stopRecording=this._rrwebRecord({emit:function(e){this.idleExpires&&this.idleExpires<e.timestamp?this._onIdleTimeout():(function(e){return e.type===gM.IncrementalSnapshot&&d$.has(e.data.source)}(e)&&(this.batcher.stopped&&(new Date).getTime()-this.replayStartTime>=this.recordMinMs&&this.batcher.start(),t()),this.__enqueuePromise=this.batcher.enqueue(e),(null===this.lastEventTimestamp||e.timestamp>this.lastEventTimestamp)&&(this.lastEventTimestamp=e.timestamp))}.bind(this),blockClass:this.getConfig("record_block_class"),blockSelector:r,collectFonts:this.getConfig("record_collect_fonts"),dataURLOptions:{type:"image/webp",quality:.6},maskAllInputs:!0,maskTextSelector:"*",maskInputFn:this._getMaskFn(KF,n),maskTextFn:this._getMaskFn(YF,n),recordCrossOriginIframes:a.length>0,allowedIframeOrigins:a,recordCanvas:this.getConfig("record_canvas"),sampling:{canvas:15},plugins:o})}catch(e){this.reportError("Unexpected error when starting rrweb recording.",e)}if("function"!=typeof this._stopRecording)return this.reportError("rrweb failed to start, skipping this recording."),this._stopRecording=null,void this.stopRecording();var l=this.maxExpires-(new Date).getTime();this.maxTimeoutId=setTimeout(this._onMaxLengthReached.bind(this),l)}else c$.log("Recording already in progress, skipping startRecording.");else this.reportError("rrweb record function not provided. ")},f$.prototype.stopRecording=function(e){if(this.finalFlushUserIdInfo=this.getUserIdInfo(),!this.isRrwebStopped()){try{this._stopRecording()}catch(e){this.reportError("Error with rrweb stopRecording",e)}this._stopRecording=null}var t;return this.batcher.stopped?t=this.batcher.clear():e||(t=this.batcher.flush()),this.batcher.stop(),clearTimeout(this.idleTimeoutId),clearTimeout(this.maxTimeoutId),t},f$.prototype.isRrwebStopped=function(){return null===this._stopRecording},f$.prototype.flushEventsWithOptOut=function(e,t,r){var n=function(e){0===e&&(this.stopRecording(),r({error:"Tracking has been opted out, stopping recording."}))}.bind(this);this._flushEvents(e,t,r,n)},f$.prototype.serialize=function(){var e;try{e=this._mixpanel.get_tab_id()}catch(t){this.reportError("Error getting tab ID for serialization ",t),e=null}return{replayId:this.replayId,seqNo:this.seqNo,replayStartTime:this.replayStartTime,batchStartUrl:this.batchStartUrl,replayStartUrl:this.replayStartUrl,lastEventTimestamp:this.lastEventTimestamp,idleExpires:this.idleExpires,maxExpires:this.maxExpires,tabId:e}},f$.deserialize=function(e,t){return new f$(sD.extend({},t,{replayId:e.replayId,batchStartUrl:e.batchStartUrl,replayStartUrl:e.replayStartUrl,idleExpires:e.idleExpires,maxExpires:e.maxExpires,replayStartTime:e.replayStartTime,lastEventTimestamp:e.lastEventTimestamp,seqNo:e.seqNo,sharedLockStorage:t.sharedLockStorage}))},f$.prototype._getApiRoute=function(){return this.getConfig("api_routes").record},f$.prototype._sendRequest=function(e,t,r,n){var o=function(t,r){200===t.status&&this.replayId===e&&(this.seqNo++,this.batchStartUrl=sD.info.currentUrl()),this._onBatchSent(),n({status:0,httpStatusCode:t.status,responseBody:r,retryAfter:t.headers.get("Retry-After")})}.bind(this),i=this._mixpanel.get_api_host&&this._mixpanel.get_api_host("record")||this.getConfig("api_host");Hx.fetch(i+"/"+this._getApiRoute()+"?"+new URLSearchParams(t),{method:"POST",headers:{Authorization:"Basic "+btoa(this.getConfig("token")+":"),"Content-Type":"application/octet-stream"},body:r}).then(function(e){e.json().then(function(t){o(e,t)}).catch(function(e){n({error:e})})}).catch(function(e){n({error:e,httpStatusCode:0})})},f$.prototype._flushEvents=BD(function(e,t,r){var n=e.length;if(n>0){for(var o=this.replayId,i=1/0,s=-1/0,a=!1,l=0;l<n;l++)i=Math.min(i,e[l].timestamp),s=Math.max(s,e[l].timestamp),e[l].type===gM.FullSnapshot&&(a=!0);if(0===this.seqNo){if(!a)return r({error:"First batch does not contain a full snapshot. Aborting recording."}),void this.stopRecording(!0);this.replayStartTime=i}else this.replayStartTime||(this.reportError("Replay start time not set but seqNo is not 0. Using current batch start time as a fallback."),this.replayStartTime=i);var c=s-this.replayStartTime,u={$current_url:this.batchStartUrl,$lib_version:Kx.LIB_VERSION,batch_start_time:i/1e3,mp_lib:"web",replay_id:o,replay_length_ms:c,replay_start_time:this.replayStartTime/1e3,replay_start_url:this.replayStartUrl,seq:this.seqNo},p=JSON.stringify(e);if(Object.assign(u,this.getUserIdInfo()),function(e,t,r){if(!Hx.CompressionStream)return!1;var n=sD.info.browser(e,t,r),o=sD.info.browserVersion(e,t,r);return!(("Safari"===n||"Mobile Safari"===n)&&o>=16.4&&o<16.6)}(QL,YL.vendor,XL)){var d=new Blob([p],{type:"application/json"}).stream().pipeThrough(new u$("gzip"));new Response(d).blob().then(function(e){u.format="gzip",this._sendRequest(o,u,e,r)}.bind(this))}else u.format="body",this._sendRequest(o,u,p,r)}}),f$.prototype.reportError=function(e,t){c$.error.apply(c$.error,arguments);try{t||e instanceof Error||(e=new Error(e)),this.getConfig("error_reporter")(e,t)}catch(t){c$.error(t)}},f$.prototype.getDurationMs=function(){return null===this.replayStartTime?0:null===this.lastEventTimestamp?(new Date).getTime()-this.replayStartTime:this.lastEventTimestamp-this.replayStartTime},f$.prototype._getRecordMinMs=function(){var e=this.getConfig("record_min_ms");return e>8e3?(c$.critical("record_min_ms cannot be greater than 8000ms. Capping value."),8e3):e},f$.prototype._getMaskFn=function(e,t){return function(r,n){if(!r.trim().length)return"";var o=!0;try{o=e(n,t)}catch(e){this.reportError("Error checking if text should be masked, defaulting to masked",e)}if(o){var i=Math.min(r.length,1e4);return"*".repeat(i)}return r}.bind(this)};var h$=function(e){this.idb=new jD(PD),this.errorReporter=e.errorReporter,this.mixpanelInstance=e.mixpanelInstance,this.sharedLockStorage=e.sharedLockStorage};h$.prototype.isPersistenceEnabled=function(){return!this.mixpanelInstance.get_config("disable_persistence")},h$.prototype.handleError=function(e){this.errorReporter("IndexedDB error: ",e)},h$.prototype.setActiveRecording=function(e){if(!this.isPersistenceEnabled())return $L.resolve();var t=e.tabId;return t?this.idb.init().then(function(){return this.idb.setItem(t,e)}.bind(this)).catch(this.handleError.bind(this)):(console.warn("No tab ID is set, cannot persist recording metadata."),$L.resolve())},h$.prototype.getActiveRecording=function(){return this.isPersistenceEnabled()?this.idb.init().then(function(){return this.idb.getItem(this.mixpanelInstance.get_tab_id())}.bind(this)).then(function(e){return oF(e)?null:e}.bind(this)).catch(this.handleError.bind(this)):$L.resolve(null)},h$.prototype.clearActiveRecording=function(){return this.isPersistenceEnabled()?this.markActiveRecordingExpired():this.deleteActiveRecording()},h$.prototype.markActiveRecordingExpired=function(){return this.getActiveRecording().then(function(e){if(e)return e.maxExpires=0,this.setActiveRecording(e)}.bind(this)).catch(this.handleError.bind(this))},h$.prototype.deleteActiveRecording=function(){return this.idb.isInitialized()?this.idb.removeItem(this.mixpanelInstance.get_tab_id()).catch(this.handleError.bind(this)):$L.resolve()},h$.prototype.flushInactiveRecordings=function(){return this.isPersistenceEnabled()?this.idb.init().then(function(){return this.idb.getAll()}.bind(this)).then(function(e){var t=e.filter(function(e){return oF(e)}).map(function(e){return f$.deserialize(e,{mixpanelInstance:this.mixpanelInstance,sharedLockStorage:this.sharedLockStorage}).unloadPersistedData().then(function(){return this.idb.removeItem(e.tabId)}.bind(this)).catch(this.handleError.bind(this))}.bind(this));return $L.all(t)}.bind(this)).catch(this.handleError.bind(this)):$L.resolve([])};var m$=cD("recorder"),g$=function(e,t,r){this.mixpanelInstance=e,this.rrwebRecord=t||wA,this.sharedLockStorage=r,this.recordingRegistry=new h$({mixpanelInstance:this.mixpanelInstance,errorReporter:m$.error,sharedLockStorage:r}),this._flushInactivePromise=this.recordingRegistry.flushInactiveRecordings(),this.activeRecording=null,this.stopRecordingInProgress=!1};function v$(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}g$.prototype.startRecording=function(e){if(e=e||{},!this.activeRecording||this.activeRecording.isRrwebStopped()){var t=function(){m$.log("Idle timeout reached, restarting recording."),this.resetRecording()}.bind(this),r=function(){m$.log("Max recording length reached, stopping recording."),this.resetRecording()}.bind(this),n=function(){this.recordingRegistry.setActiveRecording(this.activeRecording.serialize()),this.__flushPromise=this.activeRecording.batcher._flushPromise}.bind(this),o={mixpanelInstance:this.mixpanelInstance,onBatchSent:n,onIdleTimeout:t,onMaxLengthReached:r,replayId:sD.UUID(),rrwebRecord:this.rrwebRecord,sharedLockStorage:this.sharedLockStorage};return e.activeSerializedRecording?this.activeRecording=f$.deserialize(e.activeSerializedRecording,o):this.activeRecording=new f$(o),this.activeRecording.startRecording(e.shouldStopBatcher),this.recordingRegistry.setActiveRecording(this.activeRecording.serialize())}m$.log("Recording already in progress, skipping startRecording.")},g$.prototype.stopRecording=function(){return this.stopRecordingInProgress=!0,this._stopCurrentRecording(!1,!0).then(function(){return this.recordingRegistry.clearActiveRecording()}.bind(this)).then(function(){this.stopRecordingInProgress=!1}.bind(this))},g$.prototype.pauseRecording=function(){return this._stopCurrentRecording(!1)},g$.prototype._stopCurrentRecording=function(e,t){if(this.activeRecording){var r=this.activeRecording.stopRecording(e);return t&&(this.activeRecording=null),r}return $L.resolve()},g$.prototype.resumeRecording=function(e){return this.activeRecording&&this.activeRecording.isRrwebStopped()?(this.activeRecording.startRecording(!1),$L.resolve(null)):this.recordingRegistry.getActiveRecording().then(function(t){return t&&!this.stopRecordingInProgress?this.startRecording({activeSerializedRecording:t}):e?this.startRecording({shouldStopBatcher:!1}):(m$.log("No resumable recording found."),null)}.bind(this))},g$.prototype.resetRecording=function(){this.stopRecording(),this.startRecording({shouldStopBatcher:!0})},g$.prototype.isRecording=function(){return this.activeRecording&&!this.activeRecording.isRrwebStopped()},g$.prototype.getActiveReplayId=function(){return this.isRecording()?this.activeRecording.replayId:null},Object.defineProperty(g$.prototype,"replayId",{get:function(){return this.getActiveReplayId()}}),Hx[Zx]=g$;var y$,b$={exports:{}},w$=(y$||(y$=1,b$.exports=function(){Array.isArray||(Array.isArray=function(e){return"[object Array]"===Object.prototype.toString.call(e)});var e={},t={"==":function(e,t){return e==t},"===":function(e,t){return e===t},"!=":function(e,t){return e!=t},"!==":function(e,t){return e!==t},">":function(e,t){return e>t},">=":function(e,t){return e>=t},"<":function(e,t,r){return void 0===r?e<t:e<t&&t<r},"<=":function(e,t,r){return void 0===r?e<=t:e<=t&&t<=r},"!!":function(t){return e.truthy(t)},"!":function(t){return!e.truthy(t)},"%":function(e,t){return e%t},log:function(e){return console.log(e),e},in:function(e,t){return!(!t||void 0===t.indexOf)&&-1!==t.indexOf(e)},cat:function(){return Array.prototype.join.call(arguments,"")},substr:function(e,t,r){if(r<0){var n=String(e).substr(t);return n.substr(0,n.length+r)}return String(e).substr(t,r)},"+":function(){return Array.prototype.reduce.call(arguments,function(e,t){return parseFloat(e,10)+parseFloat(t,10)},0)},"*":function(){return Array.prototype.reduce.call(arguments,function(e,t){return parseFloat(e,10)*parseFloat(t,10)})},"-":function(e,t){return void 0===t?-e:e-t},"/":function(e,t){return e/t},min:function(){return Math.min.apply(this,arguments)},max:function(){return Math.max.apply(this,arguments)},merge:function(){return Array.prototype.reduce.call(arguments,function(e,t){return e.concat(t)},[])},var:function(e,t){var r=void 0===t?null:t,n=this;if(void 0===e||""===e||null===e)return n;for(var o=String(e).split("."),i=0;i<o.length;i++){if(null==n)return r;if(void 0===(n=n[o[i]]))return r}return n},missing:function(){for(var t=[],r=Array.isArray(arguments[0])?arguments[0]:arguments,n=0;n<r.length;n++){var o=r[n],i=e.apply({var:o},this);null!==i&&""!==i||t.push(o)}return t},missing_some:function(t,r){var n=e.apply({missing:r},this);return r.length-n.length>=t?[]:n}};return e.is_logic=function(e){return"object"==typeof e&&null!==e&&!Array.isArray(e)&&1===Object.keys(e).length},e.truthy=function(e){return!(Array.isArray(e)&&0===e.length||!e)},e.get_operator=function(e){return Object.keys(e)[0]},e.get_values=function(t){return t[e.get_operator(t)]},e.apply=function(r,n){if(Array.isArray(r))return r.map(function(t){return e.apply(t,n)});if(!e.is_logic(r))return r;var o,i,s,a,l,c=e.get_operator(r),u=r[c];if(Array.isArray(u)||(u=[u]),"if"===c||"?:"==c){for(o=0;o<u.length-1;o+=2)if(e.truthy(e.apply(u[o],n)))return e.apply(u[o+1],n);return u.length===o+1?e.apply(u[o],n):null}if("and"===c){for(o=0;o<u.length;o+=1)if(i=e.apply(u[o],n),!e.truthy(i))return i;return i}if("or"===c){for(o=0;o<u.length;o+=1)if(i=e.apply(u[o],n),e.truthy(i))return i;return i}if("filter"===c)return a=e.apply(u[0],n),s=u[1],Array.isArray(a)?a.filter(function(t){return e.truthy(e.apply(s,t))}):[];if("map"===c)return a=e.apply(u[0],n),s=u[1],Array.isArray(a)?a.map(function(t){return e.apply(s,t)}):[];if("reduce"===c)return a=e.apply(u[0],n),s=u[1],l=void 0!==u[2]?e.apply(u[2],n):null,Array.isArray(a)?a.reduce(function(t,r){return e.apply(s,{current:r,accumulator:t})},l):l;if("all"===c){if(a=e.apply(u[0],n),s=u[1],!Array.isArray(a)||!a.length)return!1;for(o=0;o<a.length;o+=1)if(!e.truthy(e.apply(s,a[o])))return!1;return!0}if("none"===c){if(a=e.apply(u[0],n),s=u[1],!Array.isArray(a)||!a.length)return!0;for(o=0;o<a.length;o+=1)if(e.truthy(e.apply(s,a[o])))return!1;return!0}if("some"===c){if(a=e.apply(u[0],n),s=u[1],!Array.isArray(a)||!a.length)return!1;for(o=0;o<a.length;o+=1)if(e.truthy(e.apply(s,a[o])))return!0;return!1}if(u=u.map(function(t){return e.apply(t,n)}),t.hasOwnProperty(c)&&"function"==typeof t[c])return t[c].apply(n,u);if(c.indexOf(".")>0){var p=String(c).split("."),d=t;for(o=0;o<p.length;o++){if(!d.hasOwnProperty(p[o]))throw new Error("Unrecognized operation "+c+" (failed at "+p.slice(0,o+1).join(".")+")");d=d[p[o]]}return d.apply(n,u)}throw new Error("Unrecognized operation "+c)},e.uses_data=function(t){var r=[];if(e.is_logic(t)){var n=e.get_operator(t),o=t[n];Array.isArray(o)||(o=[o]),"var"===n?r.push(o[0]):o.forEach(function(t){r.push.apply(r,e.uses_data(t))})}return function(e){for(var t=[],r=0,n=e.length;r<n;r++)-1===t.indexOf(e[r])&&t.push(e[r]);return t}(r)},e.add_operation=function(e,r){t[e]=r},e.rm_operation=function(e){delete t[e]},e.rule_like=function(t,r){if(r===t)return!0;if("@"===r)return!0;if("number"===r)return"number"==typeof t;if("string"===r)return"string"==typeof t;if("array"===r)return Array.isArray(t)&&!e.is_logic(t);if(e.is_logic(r)){if(e.is_logic(t)){var n=e.get_operator(r),o=e.get_operator(t);if("@"===n||n===o)return e.rule_like(e.get_values(t,!1),e.get_values(r,!1))}return!1}if(Array.isArray(r)){if(Array.isArray(t)){if(r.length!==t.length)return!1;for(var i=0;i<r.length;i+=1)if(!e.rule_like(t[i],r[i]))return!1;return!0}return!1}return!1},e}()),b$.exports),x$=v$(w$),_$={eventMatchesCriteria:function(e,t,r){if(e!==r.event_name)return{matches:!1};var n=r.property_filters,o=!0;if(n&&!sD.isEmptyObject(n))try{o=x$.apply(n,t||{})}catch(e){return{matches:!1,error:e.toString()}}return{matches:o}}};function S$(){this.clicks=[]}function k$(e,t){this.changeCallback=e||function(){},this.observerConfig=t,this.observedShadowRoots=null,this.shadowObservers=[]}Hx[Yx]=Promise.resolve(_$),S$.prototype.isRageClick=function(e,t){var r=(t=t||{}).threshold_px||30,n=t.timeout_ms||1e3,o=t.click_count||4;if(t.interactive_elements_only){var i=UF(e);if(!i||zF(i))return!1}var s=Date.now(),a=e.pageX,l=e.pageY,c=this.clicks[this.clicks.length-1];if(c&&s-c.timestamp<n&&Math.sqrt(Math.pow(a-c.x,2)+Math.pow(l-c.y,2))<r){if(this.clicks.push({x:a,y:l,timestamp:s}),this.clicks.length>=o)return this.clicks=[],!0}else this.clicks=[{x:a,y:l,timestamp:s}];return!1},k$.prototype.getEventTarget=function(e){if(this.observedShadowRoots)return UF(e)},k$.prototype.observeFromEvent=function(e){if(this.observedShadowRoots)for(var t=VF(e),r=0;r<t.length;r++){var n=t[r];n&&n.shadowRoot&&this.observeShadowRoot(n.shadowRoot)}},k$.prototype.observeShadowRoot=function(e){if(this.observedShadowRoots&&!this.observedShadowRoots.has(e)){var t=this;try{this.observedShadowRoots.add(e);var r=new window.MutationObserver(function(){t.changeCallback()});r.observe(e,this.observerConfig),this.shadowObservers.push(r)}catch(e){CF.critical("Error while observing shadow root",e)}}},k$.prototype.start=function(){this.observedShadowRoots||("undefined"!=typeof WeakSet?this.observedShadowRoots=new WeakSet:CF.critical("Shadow DOM observation unavailable: WeakSet not supported"))},k$.prototype.stop=function(){if(this.observedShadowRoots){for(var e=0;e<this.shadowObservers.length;e++)try{this.shadowObservers[e].disconnect()}catch(e){CF.critical("Error while disconnecting shadow DOM observer",e)}this.shadowObservers=[],this.observedShadowRoots=null}};var C$=[sF,"input",hF,"select","toggle"],O$=[dF],E$=[lF],T$={characterData:!0,childList:!0,subtree:!0,attributes:!0,attributeFilter:["style","class","hidden","checked","selected","value","display","visibility"]};function R$(e){this.eventListeners=[],this.mutationObserver=null,this.shadowDOMObserver=null,this.isTracking=!1,this.lastChangeEventTimestamp=0,this.pendingClicks=[],this.onDeadClickCallback=e,this.processingActive=!1,this.processingTimeout=null}R$.prototype.addClick=function(e){var t=this.shadowDOMObserver&&this.shadowDOMObserver.getEventTarget(e);return t||(t=e.target||e.srcElement),!(!t||zF(t)||(this.shadowDOMObserver&&this.shadowDOMObserver.observeFromEvent(e),this.pendingClicks.push({element:t,event:e,timestamp:Date.now()}),0))},R$.prototype.trackClick=function(e,t){if(!this.isTracking)return!1;var r=this.addClick(e);return r&&this.triggerProcessing(t),r},R$.prototype.getDeadClicks=function(e){if(0===this.pendingClicks.length)return[];var t=e.timeout_ms,r=Date.now(),n=this.pendingClicks.slice();this.pendingClicks=[];for(var o=[],i=0;i<n.length;i++){var s=n[i];r-s.timestamp>=t?this.hasChangesAfter(s.timestamp)||o.push(s):this.pendingClicks.push(s)}return o},R$.prototype.hasChangesAfter=function(e){return this.lastChangeEventTimestamp>=e-100},R$.prototype.recordChangeEvent=function(){this.lastChangeEventTimestamp=Date.now()},R$.prototype.triggerProcessing=function(e){this.processingActive||(this.processingActive=!0,this.processRecursively(e))},R$.prototype.processRecursively=function(e){if(this.isTracking&&this.onDeadClickCallback){var t=e.timeout_ms,r=this;this.processingTimeout=setTimeout(function(){if(r.processingActive){for(var t=r.getDeadClicks(e),n=0;n<t.length;n++)r.onDeadClickCallback(t[n].event);r.pendingClicks.length>0?r.processRecursively(e):r.processingActive=!1}},t)}else this.processingActive=!1},R$.prototype.startTracking=function(){if(!this.isTracking){this.isTracking=!0;var e=this;C$.forEach(function(t){var r=function(){e.recordChangeEvent()};document.addEventListener(t,r,{capture:!0,passive:!0}),e.eventListeners.push({target:document,event:t,handler:r,options:{capture:!0,passive:!0}})}),E$.forEach(function(t){var r=function(){e.recordChangeEvent()};window.addEventListener(t,r),e.eventListeners.push({target:window,event:t,handler:r})}),O$.forEach(function(t){var r=function(){e.recordChangeEvent()};window.addEventListener(t,r,{passive:!0}),e.eventListeners.push({target:window,event:t,handler:r,options:{passive:!0}})});var t=function(){e.recordChangeEvent()};if(document.addEventListener("selectionchange",t),e.eventListeners.push({target:document,event:"selectionchange",handler:t}),window.MutationObserver)try{this.mutationObserver=new window.MutationObserver(function(){e.recordChangeEvent()}),this.mutationObserver.observe(document.body||document.documentElement,T$)}catch(e){CF.critical("Error while setting up mutation observer",e)}if(window.customElements)try{this.shadowDOMObserver=new k$(function(){e.recordChangeEvent()},T$),this.shadowDOMObserver.start()}catch(e){CF.critical("Error while setting up shadow DOM observer",e),this.shadowDOMObserver=null}}},R$.prototype.stopTracking=function(){if(this.isTracking){this.isTracking=!1,this.pendingClicks=[],this.lastChangeEventTimestamp=0,this.processingActive=!1,this.processingTimeout&&(clearTimeout(this.processingTimeout),this.processingTimeout=null);for(var e=0;e<this.eventListeners.length;e++){var t=this.eventListeners[e];try{t.target.removeEventListener(t.event,t.handler,t.options)}catch(e){CF.critical("Error while removing event listener",e)}}if(this.eventListeners=[],this.mutationObserver){try{this.mutationObserver.disconnect()}catch(e){CF.critical("Error while disconnecting mutation observer",e)}this.mutationObserver=null}if(this.shadowDOMObserver){try{this.shadowDOMObserver.stop()}catch(e){CF.critical("Error while stopping shadow DOM observer",e)}this.shadowDOMObserver=null}}};var I$="autocapture",M$="full-url",A$="allow_selectors",P$="allow_url_regexes",N$="block_attrs",j$="block_element_callback",L$="block_selectors",D$="block_url_regexes",F$="capture_extra_attrs",$$="capture_text_content",B$="scroll_capture_all",z$="scroll_depth_percent_checkpoints",V$="click",U$="dead_click",q$="input",W$="pageview",H$="rage_click",G$="scroll",K$="page_leave",Y$="submit",Z$={};Z$[A$]=[],Z$[P$]=[],Z$[N$]=[],Z$[j$]=null,Z$[L$]=[],Z$[D$]=[],Z$[F$]=[],Z$[$$]=!1,Z$[B$]=!1,Z$[z$]=[25,50,75,100],Z$[V$]=!0,Z$[U$]=!0,Z$[q$]=!0,Z$[W$]=M$,Z$[H$]=!0,Z$[G$]=!0,Z$[K$]=!1,Z$[Y$]=!0;var X$={$mp_autocapture:!0},J$="$mp_click",Q$="$mp_dead_click",eB="$mp_rage_click",tB=function(e){this.mp=e,this.maxScrollViewDepth=0,this.hasTrackedScrollSession=!1,this.previousScrollHeight=0};tB.prototype.init=function(){!function(){try{return!!ZL.createElement("div").matches}catch(e){return!1}}()?CF.critical("Autocapture unavailable: missing required DOM APIs"):(this.initPageListeners(),this.initPageviewTracking(),this.initClickTracking(),this.initDeadClickTracking(),this.initInputTracking(),this.initScrollTracking(),this.initSubmitTracking(),this.initRageClickTracking(),this.initPageLeaveTracking())},tB.prototype.getFullConfig=function(){var e=this.mp.get_config(I$);return e?sD.isObject(e)?sD.extend({},Z$,e):Z$:{}},tB.prototype.getConfig=function(e){return this.getFullConfig()[e]},tB.prototype.currentUrlBlocked=function(){var e=sD.info.currentUrl(),t=this.getConfig(P$)||[];if(t.length)try{return!RD(e,t)}catch(e){return CF.critical("Error while checking block URL regexes: ",e),!0}var r=this.getConfig(D$)||[];if(!r||!r.length)return!1;try{return RD(e,r)}catch(e){return CF.critical("Error while checking block URL regexes: ",e),!0}},tB.prototype.pageviewTrackingConfig=function(){return this.mp.get_config(I$)?this.getConfig(W$):this.mp.get_config("track_pageview")},tB.prototype.trackDomEvent=function(e,t){if(!this.currentUrlBlocked()){var r=this.mp.is_recording_heatmap_data()&&(t===J$&&!this.getConfig(V$)||t===eB&&!this._getClickTrackingConfig(H$)||t===Q$&&!this._getClickTrackingConfig(U$)),n=function(e,t){var r=t.allowElementCallback,n=t.allowSelectors||[],o=t.blockAttrs||[],i=t.blockElementCallback,s=t.blockSelectors||[],a=t.captureTextContent||!1,l=t.captureExtraAttrs||[],c=t.capturedForHeatMap||!1,u={};sD.each(o,function(e){u[e]=!0});var p=null,d=void 0===e.target?e.srcElement:e.target;if(jF(d)&&(d=d.parentNode),function(e,t){if(!e||NF(e,"html")||!PF(e))return!1;switch(e.tagName.toLowerCase()){case"form":return t.type===hF;case"input":return-1===["button","submit"].indexOf(e.getAttribute("type"))?t.type===sF:t.type===aF;case"select":case"textarea":return t.type===sF;default:return t.type===aF}}(d,e)&&MF(d,e,r,n)&&!AF(d,e,i,s)){for(var f=[d],h=d;h.parentNode&&!NF(h,"body");)f.push(h.parentNode),h=h.parentNode;var m,g=[],v=!1;if(sD.each(f,function(t){var o=DF(t,e,r,n);u.href||"a"!==t.tagName.toLowerCase()||(m=t.getAttribute("href"),m=o&&FF(m)&&m),AF(t,e,i,s)&&(v=!0),g.push(RF(t,e,u,l,r,n))},this),!v){var y=ZL.documentElement;if(p={$event_type:e.type,$host:Hx.location.host,$pathname:Hx.location.pathname,$elements:g,$el_attr__href:m,$viewportHeight:Math.max(y.clientHeight,Hx.innerHeight||0),$viewportWidth:Math.max(y.clientWidth,Hx.innerWidth||0),$pageHeight:ZL.body.offsetHeight||0,$pageWidth:ZL.body.offsetWidth||0},sD.each(l,function(e){if(!u[e]&&d.hasAttribute(e)){var t=d.getAttribute(e);FF(t)&&(p["$el_attr__"+e]=t)}}),a&&(b=IF(d,e,r,n))&&b.length&&(p.$el_text=b),e.type===aF&&(sD.each(gF,function(t){t in e&&(p["$"+t]=e[t])}),c&&(p.$captured_for_heatmap=!0),d=function(e){for(var t=e.target,r=e.composedPath(),n=0;n<r.length;n++){var o=r[n];if(NF(o,"a")||NF(o,"button")||NF(o,"input")||NF(o,"select")||o.getAttribute&&"button"===o.getAttribute("role")){t=o;break}if(o===t)break}return t}(e)),a){var b=IF(d,e,r,n);b&&b.length&&(p.$el_text=b)}if(d){if(!MF(d,e,r,n)||AF(d,e,i,s))return null;var w=RF(d,e,u,l,r,n);p.$target=w,p.$el_classes=w.$classes,sD.extend(p,sD.strip_empty_properties({$el_id:w.$id,$el_tag_name:w.$tag_name}))}}}return p}(e,{allowElementCallback:this.getConfig("allow_element_callback"),allowSelectors:this.getConfig(A$),blockAttrs:this.getConfig(N$),blockElementCallback:this.getConfig(j$),blockSelectors:this.getConfig(L$),captureExtraAttrs:this.getConfig(F$),captureTextContent:this.getConfig($$),capturedForHeatMap:r});n&&(sD.extend(n,X$),this.mp.track(t,n))}},tB.prototype.initPageListeners=function(){if(Hx.removeEventListener(pF,this.listenerPopstate),Hx.removeEventListener(lF,this.listenerHashchange),this.pageviewTrackingConfig()||this.getConfig(K$)||this.mp.get_config("record_heatmap_data")){this.listenerPopstate=function(){Hx.dispatchEvent(new Event(uF))},this.listenerHashchange=function(){Hx.dispatchEvent(new Event(uF))},Hx.addEventListener(pF,this.listenerPopstate),Hx.addEventListener(lF,this.listenerHashchange);var e=Hx.history.pushState;"function"==typeof e&&(Hx.history.pushState=function(t,r,n){e.call(Hx.history,t,r,n),Hx.dispatchEvent(new Event(uF))});var t=Hx.history.replaceState;"function"==typeof t&&(Hx.history.replaceState=function(e,r,n){t.call(Hx.history,e,r,n),Hx.dispatchEvent(new Event(uF))})}},tB.prototype._getClickTrackingConfig=function(e){var t=this.getConfig(e);return t?!0===t?{}:"object"==typeof t?t:{}:null},tB.prototype._trackPageLeave=function(e,t,r){if(!this.hasTrackedScrollSession&&(this.getConfig(K$)||this.mp.is_recording_heatmap_data())){this.hasTrackedScrollSession=!0;var n=Math.max(ZL.documentElement.clientHeight,Hx.innerHeight||0),o=Math.round(Math.max(this.maxScrollViewDepth-n,0)/(r-n)*100),i=Math.round(n/r*100);r<=n&&(o=100,i=100);var s=sD.extend({$max_scroll_view_depth:this.maxScrollViewDepth,$max_scroll_percentage:o,$fold_line_percentage:i,$scroll_height:r,$event_type:e.type,$current_url:t||sD.info.currentUrl(),$viewportHeight:n,$viewportWidth:Math.max(ZL.documentElement.clientWidth,Hx.innerWidth||0),$captured_for_heatmap:this.mp.is_recording_heatmap_data()},X$);this.mp.track("$mp_page_leave",s,{transport:"sendBeacon"})}},tB.prototype._initScrollDepthTracking=function(){if(Hx.removeEventListener(fF,this.listenerScrollDepth),Hx.removeEventListener(dF,this.listenerScrollDepth),this.mp.get_config("record_heatmap_data")){CF.log("Initializing scroll depth tracking"),this.maxScrollViewDepth=Math.max(ZL.documentElement.clientHeight,Hx.innerHeight||0);var e=$F(function(){if(!this.currentUrlBlocked()){var e=Math.max(ZL.documentElement.clientHeight,Hx.innerHeight||0)+Hx.scrollY;e>this.maxScrollViewDepth&&(this.maxScrollViewDepth=e),this.previousScrollHeight=ZL.body.scrollHeight}}.bind(this));this.listenerScrollDepth=e.listener,Hx.addEventListener(e.eventType,this.listenerScrollDepth)}},tB.prototype.initClickTracking=function(){Hx.removeEventListener(aF,this.listenerClick),(this.getConfig(V$)||this.mp.get_config("record_heatmap_data"))&&(CF.log("Initializing click tracking"),this.listenerClick=function(e){(this.getConfig(V$)||this.mp.is_recording_heatmap_data())&&this.trackDomEvent(e,J$)}.bind(this),Hx.addEventListener(aF,this.listenerClick))},tB.prototype.initDeadClickTracking=function(){this._getClickTrackingConfig(U$)||this.mp.get_config("record_heatmap_data")?(CF.log("Initializing dead click tracking"),this._deadClickTracker||(this._deadClickTracker=new R$(function(e){this.trackDomEvent(e,Q$)}.bind(this)),this._deadClickTracker.startTracking()),this.listenerDeadClick||(this.listenerDeadClick=function(e){var t=this._getClickTrackingConfig(U$);if((t||this.mp.is_recording_heatmap_data())&&!this.currentUrlBlocked()){var r=t||{};r.timeout_ms||(r.timeout_ms=500),this._deadClickTracker.trackClick(e,r)}}.bind(this),Hx.addEventListener(aF,this.listenerDeadClick))):this.stopDeadClickTracking()},tB.prototype.initInputTracking=function(){Hx.removeEventListener(sF,this.listenerChange),this.getConfig(q$)&&(CF.log("Initializing input tracking"),this.listenerChange=function(e){this.getConfig(q$)&&this.trackDomEvent(e,"$mp_input_change")}.bind(this),Hx.addEventListener(sF,this.listenerChange))},tB.prototype.initPageviewTracking=function(){if(Hx.removeEventListener(uF,this.listenerLocationchange),this.pageviewTrackingConfig()){CF.log("Initializing pageview tracking");var e="",t=!1;this.currentUrlBlocked()||(t=this.mp.track_pageview(X$)),t&&(e=sD.info.currentUrl()),this.listenerLocationchange=uD(function(){if(!this.currentUrlBlocked()){var t=sD.info.currentUrl(),r=!1,n=t.split("#")[0].split("?")[0]!==e.split("#")[0].split("?")[0],o=this.pageviewTrackingConfig();o===M$?r=t!==e:"url-with-path-and-query-string"===o?r=t.split("#")[0]!==e.split("#")[0]:"url-with-path"===o&&(r=n),r&&(this.mp.track_pageview(X$)&&(e=t),n&&(this.lastScrollCheckpoint=0,CF.log("Path change: re-initializing scroll depth checkpoints")))}}.bind(this)),Hx.addEventListener(uF,this.listenerLocationchange)}},tB.prototype.initRageClickTracking=function(){Hx.removeEventListener(aF,this.listenerRageClick),(this._getClickTrackingConfig(H$)||this.mp.get_config("record_heatmap_data"))&&(CF.log("Initializing rage click tracking"),this._rageClickTracker||(this._rageClickTracker=new S$),this.listenerRageClick=function(e){var t=this._getClickTrackingConfig(H$);(t||this.mp.is_recording_heatmap_data())&&(this.currentUrlBlocked()||this._rageClickTracker.isRageClick(e,t)&&this.trackDomEvent(e,eB))}.bind(this),Hx.addEventListener(aF,this.listenerRageClick))},tB.prototype.initScrollTracking=function(){if(Hx.removeEventListener(dF,this.listenerScroll),Hx.removeEventListener(fF,this.listenerScroll),this.getConfig(G$)){CF.log("Initializing scroll tracking"),this.lastScrollCheckpoint=0;var e=$F(function(){if(this.getConfig(G$)&&!this.currentUrlBlocked()){var e=this.getConfig(B$),t=(this.getConfig(z$)||[]).slice().sort(function(e,t){return e-t}),r=Hx.scrollY,n=sD.extend({$scroll_top:r},X$);try{var o=ZL.body.scrollHeight,i=Math.round(r/(o-Hx.innerHeight)*100);if(n.$scroll_height=o,n.$scroll_percentage=i,i>this.lastScrollCheckpoint)for(var s=0;s<t.length;s++){var a=t[s];i>=a&&this.lastScrollCheckpoint<a&&(n.$scroll_checkpoint=a,this.lastScrollCheckpoint=a,e=!0)}}catch(e){CF.critical("Error while calculating scroll percentage",e)}e&&this.mp.track("$mp_scroll",n)}}.bind(this));this.listenerScroll=e.listener,Hx.addEventListener(e.eventType,this.listenerScroll)}},tB.prototype.initSubmitTracking=function(){Hx.removeEventListener(hF,this.listenerSubmit),this.getConfig(Y$)&&(CF.log("Initializing submit tracking"),this.listenerSubmit=function(e){this.getConfig(Y$)&&this.trackDomEvent(e,"$mp_submit")}.bind(this),Hx.addEventListener(hF,this.listenerSubmit))},tB.prototype.initPageLeaveTracking=function(){if(ZL.removeEventListener(mF,this.listenerPageLeaveVisibilitychange),Hx.removeEventListener(uF,this.listenerPageLeaveLocationchange),Hx.removeEventListener(cF,this.listenerPageLoad),this.getConfig(K$)||this.mp.get_config("record_heatmap_data")){CF.log("Initializing page visibility tracking."),this._initScrollDepthTracking();var e=sD.info.currentUrl();this.listenerPageLoad=function(){this.previousScrollHeight=ZL.body.scrollHeight}.bind(this),Hx.addEventListener(cF,this.listenerPageLoad),this.listenerPageLeaveLocationchange=uD(function(t){if(!this.currentUrlBlocked()){var r=sD.info.currentUrl();r!==e&&(this._trackPageLeave(t,e,this.previousScrollHeight),e=r,this.maxScrollViewDepth=Math.max(ZL.documentElement.clientHeight,Hx.innerHeight||0),this.previousScrollHeight=ZL.body.scrollHeight,this.hasTrackedScrollSession=!1)}}.bind(this)),Hx.addEventListener(uF,this.listenerPageLeaveLocationchange),this.listenerPageLeaveVisibilitychange=function(t){ZL.hidden&&this._trackPageLeave(t,e,this.previousScrollHeight)}.bind(this),ZL.addEventListener(mF,this.listenerPageLeaveVisibilitychange)}},tB.prototype.stopDeadClickTracking=function(){this.listenerDeadClick&&(Hx.removeEventListener(aF,this.listenerDeadClick),this.listenerDeadClick=null),this._deadClickTracker&&(this._deadClickTracker.stopTracking(),this._deadClickTracker=null)},pD(tB);var rB=function(e,t){return Hx[Yx]&&"function"==typeof Hx[Yx].then||(Hx[Yx]=new Promise(function(r){e(t,r)}).then(function(){var e=Hx[Yx];if(e&&"function"==typeof e.then)return e;throw new Error("targeting failed to load")}).catch(function(e){throw delete Hx[Yx],e})),Hx[Yx]},nB=cD("flags"),oB="flags",iB="context",sB={};sB[iB]={};var aB=function(e){this.fetch=Hx.fetch,this.getFullApiRoute=e.getFullApiRoute,this.getMpConfig=e.getConfigFunc,this.setMpConfig=e.setConfigFunc,this.getMpProperty=e.getPropertyFunc,this.track=e.trackingFunc,this.loadExtraBundle=e.loadExtraBundle||function(){},this.targetingSrc=e.targetingSrc||""};aB.prototype.init=function(){this.minApisSupported()?(this.flags=null,this.fetchFlags(),this.trackedFeatures=new Set,this.pendingFirstTimeEvents={},this.activatedFirstTimeEvents={}):nB.critical("Feature Flags unavailable: missing minimum required APIs")},aB.prototype.getFullConfig=function(){var e=this.getMpConfig(oB);return e?sD.isObject(e)?sD.extend({},sB,e):sB:{}},aB.prototype.getConfig=function(e){return this.getFullConfig()[e]},aB.prototype.isSystemEnabled=function(){return!!this.getMpConfig(oB)},aB.prototype.updateContext=function(e,t){if(!this.isSystemEnabled())return nB.critical("Feature Flags not enabled, cannot update context"),Promise.resolve();var r=this.getMpConfig(oB);sD.isObject(r)||(r={});var n=t&&t.replace?{}:this.getConfig(iB);return r[iB]=sD.extend({},n,e),this.setMpConfig(oB,r),this.fetchFlags()},aB.prototype.areFlagsReady=function(){return this.isSystemEnabled()||nB.error("Feature Flags not enabled"),!!this.flags},aB.prototype.fetchFlags=function(){if(!this.isSystemEnabled())return Promise.resolve();var e=this.getMpProperty("distinct_id"),t=this.getMpProperty("$device_id"),r=kD();nB.log("Fetching flags for distinct ID: "+e);var n=sD.extend({distinct_id:e,device_id:t},this.getConfig(iB)),o=new URLSearchParams;o.set("context",JSON.stringify(n)),o.set("token",this.getMpConfig("token")),o.set("mp_lib","web"),o.set("$lib_version",Kx.LIB_VERSION);var i=this.getFullApiRoute()+"?"+o.toString();return this._fetchInProgressStartTime=Date.now(),this.fetchPromise=this.fetch.call(Hx,i,{method:"GET",headers:{Authorization:"Basic "+btoa(this.getMpConfig("token")+":"),traceparent:r}}).then(function(e){return this.markFetchComplete(),e.json().then(function(e){var t=e.flags;if(!t)throw new Error("No flags in API response");var n=new Map,o={};sD.each(t,function(e,t){var r=!1,o=t+":";if(sD.each(this.activatedFirstTimeEvents,function(e,t){t.startsWith(o)&&(r=!0)}),r){var i=this.flags&&this.flags.get(t);i&&n.set(t,i)}else n.set(t,{key:e.variant_key,value:e.variant_value,experiment_id:e.experiment_id,is_experiment_active:e.is_experiment_active,is_qa_tester:e.is_qa_tester})},this);var i=e.pending_first_time_events;i&&i.length>0&&sD.each(i,function(e){var t=e.flag_key,r=function(e,t){return e+":"+t}(t,e.first_time_event_hash);this.activatedFirstTimeEvents[r]||(o[r]={flag_key:t,flag_id:e.flag_id,project_id:e.project_id,first_time_event_hash:e.first_time_event_hash,event_name:e.event_name,property_filters:e.property_filters,pending_variant:e.pending_variant})},this),this.activatedFirstTimeEvents&&sD.each(this.activatedFirstTimeEvents,function(e,t){var r=function(e){return e.split(":")[0]}(t);e&&!n.has(r)&&this.flags&&this.flags.has(r)&&n.set(r,this.flags.get(r))},this),this.flags=n,this.pendingFirstTimeEvents=o,this._traceparent=r,this._loadTargetingIfNeeded()}.bind(this)).catch(function(e){this.markFetchComplete(),nB.error(e)}.bind(this))}.bind(this)).catch(function(e){this.markFetchComplete(),nB.error(e)}.bind(this)),this.fetchPromise},aB.prototype.markFetchComplete=function(){this._fetchInProgressStartTime?(this._fetchStartTime=this._fetchInProgressStartTime,this._fetchCompleteTime=Date.now(),this._fetchLatency=this._fetchCompleteTime-this._fetchStartTime,this._fetchInProgressStartTime=null):nB.error("Fetch in progress started time not set, cannot mark fetch complete")},aB.prototype._loadTargetingIfNeeded=function(){var e=!1;sD.each(this.pendingFirstTimeEvents,function(t){t.property_filters&&!sD.isEmptyObject(t.property_filters)&&(e=!0)}),e&&this.getTargeting().then(function(){nB.log("targeting loaded for property filter evaluation")})},aB.prototype.getTargeting=function(){return rB(this.loadExtraBundle.bind(this),this.targetingSrc).catch(function(e){nB.error("Failed to load targeting: "+e)}.bind(this))},aB.prototype.checkFirstTimeEvents=function(e,t){this.pendingFirstTimeEvents&&!sD.isEmptyObject(this.pendingFirstTimeEvents)&&(Hx[Yx]&&sD.isFunction(Hx[Yx].then)?Hx[Yx].then(function(r){this._processFirstTimeEventCheck(e,t,r)}.bind(this)).catch(function(){this._processFirstTimeEventCheck(e,t,null)}.bind(this)):this._processFirstTimeEventCheck(e,t,null))},aB.prototype._processFirstTimeEventCheck=function(e,t,r){sD.each(this.pendingFirstTimeEvents,function(n,o){if(!this.activatedFirstTimeEvents[o]){var i,s=n.flag_key;if(r||!n.property_filters||sD.isEmptyObject(n.property_filters)){if(r){var a={event_name:n.event_name,property_filters:n.property_filters};i=r.eventMatchesCriteria(e,t,a)}else i={matches:e===n.event_name,error:null};if(i.error)nB.error('Error checking first-time event for flag "'+s+'": '+i.error);else if(i.matches){nB.log('First-time event matched for flag "'+s+'": '+e);var l={key:n.pending_variant.variant_key,value:n.pending_variant.variant_value,experiment_id:n.pending_variant.experiment_id,is_experiment_active:n.pending_variant.is_experiment_active};this.flags.set(s,l),this.activatedFirstTimeEvents[o]=!0,this.recordFirstTimeEvent(n.flag_id,n.project_id,n.first_time_event_hash)}}else nB.warn('Skipping event check for "'+s+'" - property filters require targeting library')}},this)},aB.prototype.getFirstTimeEventApiRoute=function(e){return this.getFullApiRoute()+"/"+e+"/first-time-events"},aB.prototype.recordFirstTimeEvent=function(e,t,r){var n=this.getMpProperty("distinct_id"),o=kD(),i=new URLSearchParams;i.set("mp_lib","web"),i.set("$lib_version",Kx.LIB_VERSION);var s=this.getFirstTimeEventApiRoute(e)+"?"+i.toString(),a={distinct_id:n,project_id:t,first_time_event_hash:r};nB.log("Recording first-time event for flag: "+e),this.fetch.call(Hx,s,{method:"POST",headers:{"Content-Type":"application/json",Authorization:"Basic "+btoa(this.getMpConfig("token")+":"),traceparent:o},body:JSON.stringify(a)}).catch(function(t){nB.error("Failed to record first-time event for flag "+e+": "+t)})},aB.prototype.getVariant=function(e,t){return this.fetchPromise?this.fetchPromise.then(function(){return this.getVariantSync(e,t)}.bind(this)).catch(function(e){return nB.error(e),t}):new Promise(function(e){nB.critical("Feature Flags not initialized"),e(t)})},aB.prototype.getVariantSync=function(e,t){if(!this.areFlagsReady())return nB.log("Flags not loaded yet"),t;var r=this.flags.get(e);return r?(this.trackFeatureCheck(e,r),r):(nB.log('No flag found: "'+e+'"'),t)},aB.prototype.getVariantValue=function(e,t){return this.getVariant(e,{value:t}).then(function(e){return e.value}).catch(function(e){return nB.error(e),t})},aB.prototype.getFeatureData=function(e,t){return nB.critical("mixpanel.flags.get_feature_data() is deprecated and will be removed in a future release. Use mixpanel.flags.get_variant_value() instead."),this.getVariantValue(e,t)},aB.prototype.getVariantValueSync=function(e,t){return this.getVariantSync(e,{value:t}).value},aB.prototype.isEnabled=function(e,t){return this.getVariantValue(e).then(function(){return this.isEnabledSync(e,t)}.bind(this)).catch(function(e){return nB.error(e),t})},aB.prototype.isEnabledSync=function(e,t){t=t||!1;var r=this.getVariantValueSync(e,t);return!0!==r&&!1!==r&&(nB.error('Feature flag "'+e+'" value: '+r+" is not a boolean; returning fallback value: "+t),r=t),r},aB.prototype.trackFeatureCheck=function(e,t){if(!this.trackedFeatures.has(e)){this.trackedFeatures.add(e);var r={"Experiment name":e,"Variant name":t.key,$experiment_type:"feature_flag","Variant fetch start time":new Date(this._fetchStartTime).toISOString(),"Variant fetch complete time":new Date(this._fetchCompleteTime).toISOString(),"Variant fetch latency (ms)":this._fetchLatency,"Variant fetch traceparent":this._traceparent};"undefined"!==t.experiment_id&&(r.$experiment_id=t.experiment_id),"undefined"!==t.is_experiment_active&&(r.$is_experiment_active=t.is_experiment_active),"undefined"!==t.is_qa_tester&&(r.$is_qa_tester=t.is_qa_tester),this.track("$experiment_started",r)}},aB.prototype.minApisSupported=function(){return!!this.fetch&&"undefined"!=typeof Promise&&"undefined"!=typeof Map&&"undefined"!=typeof Set},pD(aB),aB.prototype.are_flags_ready=aB.prototype.areFlagsReady,aB.prototype.get_variant=aB.prototype.getVariant,aB.prototype.get_variant_sync=aB.prototype.getVariantSync,aB.prototype.get_variant_value=aB.prototype.getVariantValue,aB.prototype.get_variant_value_sync=aB.prototype.getVariantValueSync,aB.prototype.is_enabled=aB.prototype.isEnabled,aB.prototype.is_enabled_sync=aB.prototype.isEnabledSync,aB.prototype.update_context=aB.prototype.updateContext,aB.prototype.get_feature_data=aB.prototype.getFeatureData,aB.prototype.getTargeting=aB.prototype.getTargeting;var lB=cD("recorder"),cB="mp_iframe_handshake_request",uB="mp_iframe_handshake_response",pB=function(e){this.mixpanelInstance=e.mixpanelInstance,this.getMpConfig=e.getConfigFunc,this.getTabId=e.getTabIdFunc,this.reportError=e.reportErrorFunc,this.getDistinctId=e.getDistinctIdFunc,this.loadExtraBundle=e.loadExtraBundle,this.recorderSrc=e.recorderSrc,this.targetingSrc=e.targetingSrc,this.libBasePath=e.libBasePath,this._recorder=null,this._parentReplayId=null,this._parentFrameRetryInterval=null};pB.prototype.shouldLoadRecorder=function(){if(this.getMpConfig("disable_persistence"))return aD.log("Load recorder check skipped due to disable_persistence config"),$L.resolve(!1);var e=new jD(PD),t=this.getTabId();return e.init().then(function(){return e.getAll()}).then(function(e){for(var r=0;r<e.length;r++)if(oF(e[r])||e[r].tabId===t)return!0;return!1}).catch(sD.bind(function(e){return this.reportError("Error checking recording registry",e),!1},this))},pB.prototype.checkAndStartSessionRecording=function(e,t){if(!Hx.MutationObserver)return aD.critical("Browser does not support MutationObserver; skipping session recording"),$L.resolve();var r=sD.bind(function(e){return new $L(sD.bind(function(t){var r=uD(sD.bind(function(){this._recorder=this._recorder||new Hx[Zx](this.mixpanelInstance),this._recorder.resumeRecording(e),t()},this));if(sD.isUndefined(Hx[Zx])){var n=this.recorderSrc||this.libBasePath+"__MP_RECORDER_FILENAME__";this.loadExtraBundle(n,r)}else r()},this))},this),n=iF(this.getMpConfig("record_allowed_iframe_origins"),lB);if(n.length>0&&(this._setupParentFrameListener(n),Hx.parent!==Hx))return this._setupChildFrameListener(n,r),this._sendParentFrameRequestWithRetry(n),$L.resolve();var o=sD.isUndefined(t)?this.getMpConfig("record_sessions_percent"):t,i=o>0&&100*Math.random()<=o;return e||i?r(!0):this.shouldLoadRecorder().then(sD.bind(function(e){return e?r(!1):$L.resolve()},this))},pB.prototype.isRecording=function(){if(!this._recorder||!sD.isFunction(this._recorder.isRecording))return!1;try{return this._recorder.isRecording()}catch(e){return this.reportError("Error checking if recording is active",e),!1}},pB.prototype.startRecordingOnEvent=function(e,t){var r=this.isRecording(),n=this.getMpConfig("recording_event_triggers");if(!r&&n){var o=n[e];if(o&&"number"==typeof o.percentage){var i=o.percentage,s=o.property_filters;if(s&&!sD.isEmptyObject(s)){var a=this.targetingSrc||this.libBasePath+Xx;rB(this.loadExtraBundle,a).then(function(r){try{r.eventMatchesCriteria(e,t,{event_name:e,property_filters:s}).matches&&this.checkAndStartSessionRecording(!1,i)}catch(e){aD.critical("Could not parse recording event trigger properties logic:",e)}}.bind(this)).catch(function(e){aD.critical("Failed to load targeting library:",e)})}else this.checkAndStartSessionRecording(!1,i)}}},pB.prototype.stopSessionRecording=function(){return this._recorder?this._recorder.stopRecording():$L.resolve()},pB.prototype.pauseSessionRecording=function(){return this._recorder?this._recorder.pauseRecording():$L.resolve()},pB.prototype.resumeSessionRecording=function(){return this._recorder?this._recorder.resumeRecording():$L.resolve()},pB.prototype.isRecordingHeatmapData=function(){return this.getSessionReplayId()&&this.getMpConfig("record_heatmap_data")},pB.prototype.getSessionRecordingProperties=function(){var e={},t=this.getSessionReplayId();return t&&(e.$mp_replay_id=t),e},pB.prototype.getSessionReplayUrl=function(){var e=null,t=this.getSessionReplayId();return t&&(e="https://mixpanel.com/projects/replay-redirect?"+sD.HTTPBuildQuery({replay_id:t,distinct_id:this.getDistinctId(),token:this.getMpConfig("token")})),e},pB.prototype.getSessionReplayId=function(){if(this._parentReplayId)return this._parentReplayId;var e=null;return this._recorder&&(e=this._recorder.replayId),e||null},pB.prototype.getRecorder=function(){return this._recorder},pB.prototype._setupChildFrameListener=function(e,t){if(!this._childFrameMessageHandler){var r=this;this._childFrameMessageHandler=function(n){if(-1!==e.indexOf(n.origin)){var o=n.data;o&&o.type===uB&&o.token===r.getMpConfig("token")&&o.replayId&&(r._parentReplayId=o.replayId,o.distinctId&&r.mixpanelInstance.identify(o.distinctId),r._parentFrameRetryActive=!1,Hx.removeEventListener("message",r._childFrameMessageHandler),r._childFrameMessageHandler=null,t(!0))}},Hx.addEventListener("message",this._childFrameMessageHandler)}},pB.prototype._sendParentFrameRequest=function(e){var t={};t.type=cB,t.token=this.getMpConfig("token");for(var r=0;r<e.length;r++)try{Hx.parent.postMessage(t,e[r])}catch(e){}},pB.prototype._sendParentFrameRequestWithRetry=function(e){var t=this,r=0,n=50;this._parentFrameRetryActive=!0,this._sendParentFrameRequest(e),function o(){setTimeout(function(){!t._parentFrameRetryActive||t._parentReplayId||++r>=10||(t._sendParentFrameRequest(e),n*=2,o())},n)}()},pB.prototype._setupParentFrameListener=function(e){if(!this._parentFrameMessageHandler){var t=this;this._parentFrameMessageHandler=function(r){if(-1!==e.indexOf(r.origin)){var n=r.data;if(n&&n.type===cB&&n.token===t.getMpConfig("token")){var o=t.getSessionReplayId();if(o){var i={};i.type=uB,i.token=t.getMpConfig("token"),i.replayId=o,i.distinctId=t.getDistinctId(),r.source.postMessage(i,r.origin)}}}},Hx.addEventListener("message",this._parentFrameMessageHandler)}},pD(pB);var dB=function(){};dB.prototype.create_properties=function(){},dB.prototype.event_handler=function(){},dB.prototype.after_track_handler=function(){},dB.prototype.init=function(e){return this.mp=e,this},dB.prototype.track=function(e,t,r,n){var o=this,i=sD.dom_query(e);if(0!==i.length)return sD.each(i,function(e){sD.register_event(e,this.override_event,function(e){var i={},s=o.create_properties(r,this),a=o.mp.get_config("track_links_timeout");o.event_handler(e,this,i),window.setTimeout(o.track_callback(n,s,i,!0),a),o.mp.track(t,s,o.track_callback(n,s,i))})},this),!0;aD.error("The DOM query ("+e+") returned 0 elements")},dB.prototype.track_callback=function(e,t,r,n){n=n||!1;var o=this;return function(){r.callback_fired||(r.callback_fired=!0,e&&!1===e(n,t)||o.after_track_handler(t,r,n))}},dB.prototype.create_properties=function(e,t){return"function"==typeof e?e(t):sD.extend({},e)};var fB=function(){this.override_event="click"};sD.inherit(fB,dB),fB.prototype.create_properties=function(e,t){var r=fB.superclass.create_properties.apply(this,arguments);return t.href&&(r.url=t.href),r},fB.prototype.event_handler=function(e,t,r){r.new_tab=2===e.which||e.metaKey||e.ctrlKey||"_blank"===t.target,r.href=t.href,r.new_tab||e.preventDefault()},fB.prototype.after_track_handler=function(e,t){t.new_tab||setTimeout(function(){window.location=t.href},0)};var hB=function(){this.override_event="submit"};sD.inherit(hB,dB),hB.prototype.event_handler=function(e,t,r){r.element=t,e.preventDefault()},hB.prototype.after_track_handler=function(e,t){setTimeout(function(){t.element.submit()},0)};var mB="$set",gB="$set_once",vB="$unset",yB="$add",bB="$append",wB="$union",xB="$remove",_B={set_action:function(e,t){var r={},n={};return sD.isObject(e)?sD.each(e,function(e,t){this._is_reserved_property(t)||(n[t]=e)},this):n[e]=t,r[mB]=n,r},unset_action:function(e){var t={},r=[];return sD.isArray(e)||(e=[e]),sD.each(e,function(e){this._is_reserved_property(e)||r.push(e)},this),t[vB]=r,t},set_once_action:function(e,t){var r={},n={};return sD.isObject(e)?sD.each(e,function(e,t){this._is_reserved_property(t)||(n[t]=e)},this):n[e]=t,r[gB]=n,r},union_action:function(e,t){var r={},n={};return sD.isObject(e)?sD.each(e,function(e,t){this._is_reserved_property(t)||(n[t]=sD.isArray(e)?e:[e])},this):n[e]=sD.isArray(t)?t:[t],r[wB]=n,r},append_action:function(e,t){var r={},n={};return sD.isObject(e)?sD.each(e,function(e,t){this._is_reserved_property(t)||(n[t]=e)},this):n[e]=t,r[bB]=n,r},remove_action:function(e,t){var r={},n={};return sD.isObject(e)?sD.each(e,function(e,t){this._is_reserved_property(t)||(n[t]=e)},this):n[e]=t,r[xB]=n,r},delete_action:function(){return{$delete:""}}},SB=function(){};sD.extend(SB.prototype,_B),SB.prototype._init=function(e,t,r){this._mixpanel=e,this._group_key=t,this._group_id=r},SB.prototype.set=VD(function(e,t,r){var n=this.set_action(e,t);return sD.isObject(e)&&(r=t),this._send_request(n,r)}),SB.prototype.set_once=VD(function(e,t,r){var n=this.set_once_action(e,t);return sD.isObject(e)&&(r=t),this._send_request(n,r)}),SB.prototype.unset=VD(function(e,t){var r=this.unset_action(e);return this._send_request(r,t)}),SB.prototype.union=VD(function(e,t,r){sD.isObject(e)&&(r=t);var n=this.union_action(e,t);return this._send_request(n,r)}),SB.prototype.delete=VD(function(e){var t=this.delete_action();return this._send_request(t,e)}),SB.prototype.remove=VD(function(e,t,r){var n=this.remove_action(e,t);return this._send_request(n,r)}),SB.prototype._send_request=function(e,t){e.$group_key=this._group_key,e.$group_id=this._group_id,e.$token=this._get_config("token");var r=sD.encodeDates(e);return this._mixpanel._track_or_batch({type:"groups",data:r,endpoint:this._mixpanel.get_api_host("groups")+"/"+this._get_config("api_routes").groups,batcher:this._mixpanel.request_batchers.groups},t)},SB.prototype._is_reserved_property=function(e){return"$group_key"===e||"$group_id"===e},SB.prototype._get_config=function(e){return this._mixpanel.get_config(e)},SB.prototype.toString=function(){return this._mixpanel.toString()+".group."+this._group_key+"."+this._group_id},SB.prototype.remove=SB.prototype.remove,SB.prototype.set=SB.prototype.set,SB.prototype.set_once=SB.prototype.set_once,SB.prototype.union=SB.prototype.union,SB.prototype.unset=SB.prototype.unset,SB.prototype.toString=SB.prototype.toString;var kB=function(){};sD.extend(kB.prototype,_B),kB.prototype._init=function(e){this._mixpanel=e},kB.prototype.set=zD(function(e,t,r){var n=this.set_action(e,t);return sD.isObject(e)&&(r=t),this._get_config("save_referrer")&&this._mixpanel.persistence.update_referrer_info(document.referrer),n[mB]=sD.extend({},sD.info.people_properties(),n[mB]),this._send_request(n,r)}),kB.prototype.set_once=zD(function(e,t,r){var n=this.set_once_action(e,t);return sD.isObject(e)&&(r=t),this._send_request(n,r)}),kB.prototype.unset=zD(function(e,t){var r=this.unset_action(e);return this._send_request(r,t)}),kB.prototype.increment=zD(function(e,t,r){var n={},o={};return sD.isObject(e)?(sD.each(e,function(e,t){if(!this._is_reserved_property(t)){if(isNaN(parseFloat(e)))return void aD.error("Invalid increment value passed to mixpanel.people.increment - must be a number");o[t]=e}},this),r=t):(sD.isUndefined(t)&&(t=1),o[e]=t),n[yB]=o,this._send_request(n,r)}),kB.prototype.append=zD(function(e,t,r){sD.isObject(e)&&(r=t);var n=this.append_action(e,t);return this._send_request(n,r)}),kB.prototype.remove=zD(function(e,t,r){sD.isObject(e)&&(r=t);var n=this.remove_action(e,t);return this._send_request(n,r)}),kB.prototype.union=zD(function(e,t,r){sD.isObject(e)&&(r=t);var n=this.union_action(e,t);return this._send_request(n,r)}),kB.prototype.track_charge=zD(function(){aD.error("mixpanel.people.track_charge() is deprecated and no longer has any effect.")}),kB.prototype.clear_charges=function(e){return this.set("$transactions",[],e)},kB.prototype.delete_user=function(){if(this._identify_called()){var e={$delete:this._mixpanel.get_distinct_id()};return this._send_request(e)}aD.error("mixpanel.people.delete_user() requires you to call identify() first")},kB.prototype.toString=function(){return this._mixpanel.toString()+".people"},kB.prototype._send_request=function(e,t){e.$token=this._get_config("token"),e.$distinct_id=this._mixpanel.get_distinct_id();var r=this._mixpanel.get_property("$device_id"),n=this._mixpanel.get_property("$user_id"),o=this._mixpanel.get_property("$had_persisted_distinct_id");r&&(e.$device_id=r),n&&(e.$user_id=n),o&&(e.$had_persisted_distinct_id=o);var i=sD.encodeDates(e);return this._identify_called()?this._mixpanel._track_or_batch({type:"people",data:i,endpoint:this._mixpanel.get_api_host("people")+"/"+this._get_config("api_routes").engage,batcher:this._mixpanel.request_batchers.people},t):(this._enqueue(e),sD.isUndefined(t)||(this._get_config("verbose")?t({status:-1,error:null}):t(-1)),sD.truncate(i,255))},kB.prototype._get_config=function(e){return this._mixpanel.get_config(e)},kB.prototype._identify_called=function(){return!0===this._mixpanel._flags.identify_called},kB.prototype._enqueue=function(e){mB in e?this._mixpanel.persistence._add_to_people_queue(mB,e):gB in e?this._mixpanel.persistence._add_to_people_queue(gB,e):vB in e?this._mixpanel.persistence._add_to_people_queue(vB,e):yB in e?this._mixpanel.persistence._add_to_people_queue(yB,e):bB in e?this._mixpanel.persistence._add_to_people_queue(bB,e):xB in e?this._mixpanel.persistence._add_to_people_queue(xB,e):wB in e?this._mixpanel.persistence._add_to_people_queue(wB,e):aD.error("Invalid call to _enqueue():",e)},kB.prototype._flush_one_queue=function(e,t,r,n){var o=this,i=sD.extend({},this._mixpanel.persistence.load_queue(e)),s=i;sD.isUndefined(i)||!sD.isObject(i)||sD.isEmptyObject(i)||(o._mixpanel.persistence._pop_from_people_queue(e,i),o._mixpanel.persistence.save(),n&&(s=n(i)),t.call(o,s,function(t,n){0===t&&o._mixpanel.persistence._add_to_people_queue(e,i),sD.isUndefined(r)||r(t,n)}))},kB.prototype._flush=function(e,t,r,n,o,i,s){var a=this;this._flush_one_queue(mB,this.set,e),this._flush_one_queue(gB,this.set_once,n),this._flush_one_queue(vB,this.unset,i,function(e){return sD.keys(e)}),this._flush_one_queue(yB,this.increment,t),this._flush_one_queue(wB,this.union,o);var l=this._mixpanel.persistence.load_queue(bB);if(!sD.isUndefined(l)&&sD.isArray(l)&&l.length)for(var c,u=function(e,t){0===e&&a._mixpanel.persistence._add_to_people_queue(bB,c),sD.isUndefined(r)||r(e,t)},p=l.length-1;p>=0;p--)l=this._mixpanel.persistence.load_queue(bB),c=l.pop(),a._mixpanel.persistence.save(),sD.isEmptyObject(c)||a.append(c,u);var d=this._mixpanel.persistence.load_queue(xB);if(!sD.isUndefined(d)&&sD.isArray(d)&&d.length)for(var f,h=function(e,t){0===e&&a._mixpanel.persistence._add_to_people_queue(xB,f),sD.isUndefined(s)||s(e,t)},m=d.length-1;m>=0;m--)d=this._mixpanel.persistence.load_queue(xB),f=d.pop(),a._mixpanel.persistence.save(),sD.isEmptyObject(f)||a.remove(f,h)},kB.prototype._is_reserved_property=function(e){return"$distinct_id"===e||"$token"===e||"$device_id"===e||"$user_id"===e||"$had_persisted_distinct_id"===e},kB.prototype.set=kB.prototype.set,kB.prototype.set_once=kB.prototype.set_once,kB.prototype.unset=kB.prototype.unset,kB.prototype.increment=kB.prototype.increment,kB.prototype.append=kB.prototype.append,kB.prototype.remove=kB.prototype.remove,kB.prototype.union=kB.prototype.union,kB.prototype.track_charge=kB.prototype.track_charge,kB.prototype.clear_charges=kB.prototype.clear_charges,kB.prototype.delete_user=kB.prototype.delete_user,kB.prototype.toString=kB.prototype.toString;var CB,OB="__mps",EB="__mpso",TB="__mpus",RB="__mpa",IB="__mpap",MB="__mpr",AB="__mpu",PB="$people_distinct_id",NB="__alias",jB="__timers",LB=[OB,EB,TB,RB,IB,MB,AB,PB,NB,jB],DB=function(e){this.props={},this.campaign_params_saved=!1,e.persistence_name?this.name="mp_"+e.persistence_name:this.name="mp_"+e.token+"_mixpanel";var t=e.persistence;"cookie"!==t&&"localStorage"!==t&&(aD.critical("Unknown persistence type "+t+"; falling back to cookie"),t=e.persistence="cookie"),"localStorage"===t&&sD.localStorage.is_supported()?this.storage=sD.localStorage:this.storage=sD.cookie,this.load(),this.update_config(e),this.upgrade(),this.save()};DB.prototype.properties=function(){var e={};return this.load(),sD.each(this.props,function(t,r){sD.include(LB,r)||(e[r]=t)}),e},DB.prototype.load=function(){if(!this.disabled){var e=this.storage.parse(this.name);e&&(this.props=sD.extend({},e))}},DB.prototype.upgrade=function(){var e,t;this.storage===sD.localStorage?(e=sD.cookie.parse(this.name),sD.cookie.remove(this.name),sD.cookie.remove(this.name,!0),e&&this.register_once(e)):this.storage===sD.cookie&&(t=sD.localStorage.parse(this.name),sD.localStorage.remove(this.name),t&&this.register_once(t))},DB.prototype.save=function(){this.disabled||this.storage.set(this.name,ID(this.props),this.expire_days,this.cross_subdomain,this.secure,this.cross_site,this.cookie_domain)},DB.prototype.load_prop=function(e){return this.load(),this.props[e]},DB.prototype.remove=function(){this.storage.remove(this.name,!1,this.cookie_domain),this.storage.remove(this.name,!0,this.cookie_domain)},DB.prototype.clear=function(){this.remove(),this.props={}},DB.prototype.register_once=function(e,t,r){return!!sD.isObject(e)&&(void 0===t&&(t="None"),this.expire_days=void 0===r?this.default_expiry:r,this.load(),sD.each(e,function(e,r){this.props.hasOwnProperty(r)&&this.props[r]!==t||(this.props[r]=e)},this),this.save(),!0)},DB.prototype.register=function(e,t){return!!sD.isObject(e)&&(this.expire_days=void 0===t?this.default_expiry:t,this.load(),sD.extend(this.props,e),this.save(),!0)},DB.prototype.unregister=function(e){this.load(),e in this.props&&(delete this.props[e],this.save())},DB.prototype.update_search_keyword=function(e){this.register(sD.info.searchInfo(e))},DB.prototype.update_referrer_info=function(e){this.register_once({$initial_referrer:e||"$direct",$initial_referring_domain:sD.info.referringDomain(e)||"$direct"},"")},DB.prototype.get_referrer_info=function(){return sD.strip_empty_properties({$initial_referrer:this.props.$initial_referrer,$initial_referring_domain:this.props.$initial_referring_domain})},DB.prototype.update_config=function(e){this.default_expiry=this.expire_days=e.cookie_expiration,this.set_disabled(e.disable_persistence),this.set_cookie_domain(e.cookie_domain),this.set_cross_site(e.cross_site_cookie),this.set_cross_subdomain(e.cross_subdomain_cookie),this.set_secure(e.secure_cookie)},DB.prototype.set_disabled=function(e){this.disabled=e,this.disabled?this.remove():this.save()},DB.prototype.set_cookie_domain=function(e){e!==this.cookie_domain&&(this.remove(),this.cookie_domain=e,this.save())},DB.prototype.set_cross_site=function(e){e!==this.cross_site&&(this.cross_site=e,this.remove(),this.save())},DB.prototype.set_cross_subdomain=function(e){e!==this.cross_subdomain&&(this.cross_subdomain=e,this.remove(),this.save())},DB.prototype.get_cross_subdomain=function(){return this.cross_subdomain},DB.prototype.set_secure=function(e){e!==this.secure&&(this.secure=!!e,this.remove(),this.save())},DB.prototype._add_to_people_queue=function(e,t){var r=this._get_queue_key(e),n=t[e],o=this._get_or_create_queue(mB),i=this._get_or_create_queue(gB),s=this._get_or_create_queue(vB),a=this._get_or_create_queue(yB),l=this._get_or_create_queue(wB),c=this._get_or_create_queue(xB,[]),u=this._get_or_create_queue(bB,[]);r===OB?(sD.extend(o,n),this._pop_from_people_queue(yB,n),this._pop_from_people_queue(wB,n),this._pop_from_people_queue(vB,n)):r===EB?(sD.each(n,function(e,t){t in i||(i[t]=e)}),this._pop_from_people_queue(vB,n)):r===TB?sD.each(n,function(e){sD.each([o,i,a,l],function(t){e in t&&delete t[e]}),sD.each(u,function(t){e in t&&delete t[e]}),s[e]=!0}):r===RB?(sD.each(n,function(e,t){t in o?o[t]+=e:(t in a||(a[t]=0),a[t]+=e)},this),this._pop_from_people_queue(vB,n)):r===AB?(sD.each(n,function(e,t){sD.isArray(e)&&(t in l||(l[t]=[]),sD.each(e,function(e){sD.include(l[t],e)||l[t].push(e)}))}),this._pop_from_people_queue(vB,n)):r===MB?(c.push(n),this._pop_from_people_queue(bB,n)):r===IB&&(u.push(n),this._pop_from_people_queue(vB,n)),aD.log("MIXPANEL PEOPLE REQUEST (QUEUED, PENDING IDENTIFY):"),aD.log(t),this.save()},DB.prototype._pop_from_people_queue=function(e,t){var r=this.props[this._get_queue_key(e)];sD.isUndefined(r)||sD.each(t,function(t,n){e===bB||e===xB?sD.each(r,function(e){e[n]===t&&delete e[n]}):delete r[n]},this)},DB.prototype.load_queue=function(e){return this.load_prop(this._get_queue_key(e))},DB.prototype._get_queue_key=function(e){return e===mB?OB:e===gB?EB:e===vB?TB:e===yB?RB:e===bB?IB:e===xB?MB:e===wB?AB:void aD.error("Invalid queue:",e)},DB.prototype._get_or_create_queue=function(e,t){var r=this._get_queue_key(e);return t=sD.isUndefined(t)?{}:t,this.props[r]||(this.props[r]=t)},DB.prototype.set_event_timer=function(e,t){var r=this.load_prop(jB)||{};r[e]=t,this.props[jB]=r,this.save()},DB.prototype.remove_event_timer=function(e){var t=(this.load_prop(jB)||{})[e];return sD.isUndefined(t)||(delete this.props[jB][e],this.save()),t};var FB,$B=function(e,t){throw new Error(e+" not available in this build.")},BB="mixpanel",zB="base64",VB="$device:",UB=Hx.XMLHttpRequest&&"withCredentials"in new XMLHttpRequest,qB=!UB&&-1===QL.indexOf("MSIE")&&-1===QL.indexOf("Mozilla"),WB=null;YL.sendBeacon&&(WB=function(){return YL.sendBeacon.apply(YL,arguments)});var HB={track:"track/",engage:"engage/",groups:"groups/",record:"record/",flags:"flags/",settings:"settings/"},GB={api_host:"https://api-js.mixpanel.com",api_hosts:{},api_routes:HB,api_extra_query_params:{},api_method:"POST",api_transport:"XHR",api_payload_format:zB,app_host:"https://mixpanel.com",autocapture:!1,cdn:"https://cdn.mxpnl.com",cross_site_cookie:!1,cross_subdomain_cookie:!0,error_reporter:TD,flags:!1,persistence:"cookie",persistence_name:"",cookie_domain:"",cookie_name:"",loaded:TD,mp_loader:null,track_marketing:!0,track_pageview:!1,skip_first_touch_marketing:!1,store_google:!0,stop_utm_persistence:!1,save_referrer:!0,test:!1,verbose:!1,img:!1,debug:!1,track_links_timeout:300,cookie_expiration:365,upgrade:!1,disable_persistence:!1,disable_cookie:!1,secure_cookie:!1,ip:!0,opt_out_tracking_by_default:!1,opt_out_persistence_by_default:!1,opt_out_tracking_persistence_type:"localStorage",opt_out_tracking_cookie_prefix:null,property_blacklist:[],xhr_headers:{},ignore_dnt:!1,batch_requests:!0,batch_size:50,batch_flush_interval_ms:5e3,batch_request_timeout_ms:9e4,batch_autostart:!0,hooks:{},record_allowed_iframe_origins:[],record_block_class:new RegExp("^(mp-block|fs-exclude|amp-block|rr-block|ph-no-capture)$"),record_block_selector:"img, video, audio",record_canvas:!1,record_collect_fonts:!1,record_console:!0,record_heatmap_data:!1,recording_event_triggers:{},record_idle_timeout_ms:18e5,record_mask_inputs:!0,record_max_ms:zL,record_min_ms:0,record_network:!1,record_network_options:{},record_sessions_percent:0,recorder_src:null,targeting_src:null,lib_base_path:"https://cdn.mxpnl.com/libs/",remote_settings_mode:"disabled"},KB=!1,YB=function(){},ZB=function(e,t,r){var n,o=r===BB?FB:FB[r];if(o&&0===CB)n=o;else{if(o&&!sD.isArray(o))return void aD.error("You have already initialized "+r);n=new YB}if(n._cached_groups={},n._init(e,t,r),n.people=new kB,n.people._init(n),!n.get_config("skip_first_touch_marketing")){var i=sD.info.campaignParams(null),s={},a=!1;sD.each(i,function(e,t){s["initial_"+t]=e,e&&(a=!0)}),a&&n.people.set_once(s)}Kx.DEBUG=Kx.DEBUG||n.get_config("debug");var l=0===CB?"module":"snippet";return Hx.dispatchEvent(new Hx.CustomEvent("$mp_sdk_to_extension_event",{detail:{instance:n,source:l,token:e,name:r,info:sD.info}})),!sD.isUndefined(o)&&sD.isArray(o)&&(n._execute_array.call(n.people,o.people),n._execute_array(o)),n};YB.prototype.init=function(e,t,r){if(sD.isUndefined(r))this.report_error("You must name your new library: init(token, config, name)");else{if(r!==BB){var n=ZB(e,t,r);return FB[r]=n,n._loaded(),n}this.report_error("You must initialize the main mixpanel object right after you include the Mixpanel js snippet")}},YB.prototype._init=function(e,t,r){t=t||{},this.__loaded=!0,this.config={};var n={};if("api_payload_format"in t||(t.api_host||GB.api_host).match(/\.mixpanel\.com/)&&(n.api_payload_format="json"),this.hooks={},this.set_config(sD.extend({},GB,n,t,{name:r,token:e,callback_fn:(r===BB?r:BB+"."+r)+"._jsc"})),this.recorderManager=new pB({mixpanelInstance:this,getConfigFunc:sD.bind(this.get_config,this),setConfigFunc:sD.bind(this.set_config,this),getTabIdFunc:sD.bind(this.get_tab_id,this),reportErrorFunc:sD.bind(this.report_error,this),getDistinctIdFunc:sD.bind(this.get_distinct_id,this),recorderSrc:this.get_config("recorder_src"),targetingSrc:this.get_config("targeting_src"),libBasePath:this.get_config("lib_base_path"),loadExtraBundle:$B}),this._jsc=TD,this.__dom_loaded_queue=[],this.__request_queue=[],this.__disabled_events=[],this._flags={disable_all_events:!1,identify_called:!1},this.request_batchers={},this._batch_requests=this.get_config("batch_requests"),this._batch_requests)if(sD.localStorage.is_supported(!0)&&UB){if(this.init_batchers(),WB&&Hx.addEventListener){var o=sD.bind(function(){this.request_batchers.events.stopped||this.request_batchers.events.flush({unloading:!0})},this);Hx.addEventListener("pagehide",function(e){e.persisted&&o()}),Hx.addEventListener("visibilitychange",function(){"hidden"===ZL.visibilityState&&o()})}}else this._batch_requests=!1,aD.log("Turning off Mixpanel request-queueing; needs XHR and localStorage support"),sD.each(this.get_batcher_configs(),function(e){aD.log("Clearing batch queue "+e.queue_key),sD.localStorage.remove(e.queue_key)});this.persistence=this.cookie=new DB(this.config),this.unpersisted_superprops={},this._gdpr_init();var i=sD.UUID();this.get_distinct_id()||this.register_once({distinct_id:VB+i,$device_id:i},""),this.flags=new aB({getFullApiRoute:sD.bind(function(){return this.get_api_host("flags")+"/"+this.get_config("api_routes").flags},this),getConfigFunc:sD.bind(this.get_config,this),setConfigFunc:sD.bind(this.set_config,this),getPropertyFunc:sD.bind(this.get_property,this),trackingFunc:sD.bind(this.track,this),loadExtraBundle:$B,targetingSrc:this.get_config("targeting_src")||this.get_config("lib_base_path")+Xx}),this.flags.init(),this.flags=this.flags,this.autocapture=new tB(this),this.autocapture.init(),this._init_tab_id();var s=this.get_config("remote_settings_mode");this.__session_recording_init_promise="strict"===s||"fallback"===s?this._fetch_remote_settings(s).then(sD.bind(function(){return this._check_and_start_session_recording()},this)):this._check_and_start_session_recording()},YB.prototype._init_tab_id=function(){if(this.get_config("disable_persistence"))aD.log("Tab ID initialization skipped due to disable_persistence config");else if(sD.sessionStorage.is_supported())try{var e=this.get_config("name")+"_"+this.get_config("token"),t="mp_tab_id_"+e,r="mp_gen_new_tab_id_"+e;!sD.sessionStorage.get(r)&&sD.sessionStorage.get(t)||sD.sessionStorage.set(t,"$tab-"+sD.UUID()),sD.sessionStorage.set(r,"1"),this.tab_id=sD.sessionStorage.get(t),Hx.addEventListener("beforeunload",function(){sD.sessionStorage.remove(r)})}catch(e){this.report_error("Error initializing tab id",e)}else this.report_error("Session storage is not supported, cannot keep track of unique tab ID.")},YB.prototype.get_tab_id=function(){return this.tab_id||null},YB.prototype._check_and_start_session_recording=BD(function(e){return this.recorderManager.checkAndStartSessionRecording(e)}),YB.prototype._start_recording_on_event=function(e,t){return this.recorderManager.startRecordingOnEvent(e,t)},YB.prototype.start_session_recording=function(){return this._check_and_start_session_recording(!0)},YB.prototype.stop_session_recording=function(){return this.recorderManager.stopSessionRecording()},YB.prototype.pause_session_recording=function(){return this.recorderManager.pauseSessionRecording()},YB.prototype.resume_session_recording=function(){return this.recorderManager.resumeSessionRecording()},YB.prototype.is_recording_heatmap_data=function(){return this.recorderManager.isRecordingHeatmapData()},YB.prototype.get_session_recording_properties=function(){return this.recorderManager.getSessionRecordingProperties()},YB.prototype.get_session_replay_url=function(){return this.recorderManager.getSessionReplayUrl()},YB.prototype.__get_recorder=function(){return this.recorderManager.getRecorder()},YB.prototype.__get_recording_init_promise=function(){return this.__session_recording_init_promise},YB.prototype._loaded=function(){if(this.get_config("loaded")(this),this._set_default_superprops(),this.people.set_once(this.persistence.get_referrer_info()),this.get_config("store_google")&&this.get_config("stop_utm_persistence")){var e=sD.info.campaignParams(null);sD.each(e,function(e,t){this.unregister(t)}.bind(this))}},YB.prototype._set_default_superprops=function(){this.persistence.update_search_keyword(ZL.referrer),this.get_config("store_google")&&!this.get_config("stop_utm_persistence")&&this.register(sD.info.campaignParams()),this.get_config("save_referrer")&&this.persistence.update_referrer_info(ZL.referrer)},YB.prototype._dom_loaded=function(){sD.each(this.__dom_loaded_queue,function(e){this._track_dom.apply(this,e)},this),this.has_opted_out_tracking()||sD.each(this.__request_queue,function(e){this._send_request.apply(this,e)},this),delete this.__dom_loaded_queue,delete this.__request_queue},YB.prototype._track_dom=function(e,t){if(this.get_config("img"))return this.report_error("You can't use DOM tracking functions with img = true."),!1;if(!KB)return this.__dom_loaded_queue.push([e,t]),!1;var r=(new e).init(this);return r.track.apply(r,t)},YB.prototype._prepare_callback=function(e,t){if(sD.isUndefined(e))return null;if(UB)return function(r){e(r,t)};var r=this._jsc,n=""+Math.floor(1e8*Math.random()),o=this.get_config("callback_fn")+"["+n+"]";return r[n]=function(o){delete r[n],e(o,t)},o},YB.prototype._send_request=function(e,t,r,n){var o=!0;if(qB)return this.__request_queue.push(arguments),o;var i={method:this.get_config("api_method"),transport:this.get_config("api_transport"),verbose:this.get_config("verbose")},s=null;n||!sD.isFunction(r)&&"string"!=typeof r||(n=r,r=null),r=sD.extend(i,r||{}),UB||(r.method="GET");var a="POST"===r.method,l=WB&&a&&"sendbeacon"===r.transport.toLowerCase(),c=r.verbose;t.verbose&&(c=!0),this.get_config("test")&&(t.test=1),c&&(t.verbose=1),this.get_config("img")&&(t.img=1),UB||(n?t.callback=n:(c||this.get_config("test"))&&(t.callback="(function(){})")),t.ip=this.get_config("ip")?1:0,t._=(new Date).getTime().toString(),a&&(s="data="+encodeURIComponent(t.data),delete t.data),sD.extend(t,this.get_config("api_extra_query_params")),e+="?"+sD.HTTPBuildQuery(t);var u=this;if("img"in t){var p=ZL.createElement("img");p.src=e,ZL.body.appendChild(p)}else if(l){try{o=WB(e,s)}catch(e){u.report_error(e),o=!1}try{n&&n(o?1:0)}catch(e){u.report_error(e)}}else if(UB)try{var d=new XMLHttpRequest;d.open(r.method,e,!0);var f=this.get_config("xhr_headers");if(a&&(f["Content-Type"]="application/x-www-form-urlencoded"),sD.each(f,function(e,t){d.setRequestHeader(t,e)}),r.timeout_ms&&void 0!==d.timeout){d.timeout=r.timeout_ms;var h=(new Date).getTime()}d.withCredentials=!0,d.onreadystatechange=function(){var e;if(4===d.readyState)if(200===d.status){if(n)if(c){var t;try{t=sD.JSONDecode(d.responseText)}catch(e){if(u.report_error(e),!r.ignore_json_errors)return;t=d.responseText}n(t)}else n(Number(d.responseText))}else if(e=d.timeout&&!d.status&&(new Date).getTime()-h>=d.timeout?"timeout":"Bad HTTP status: "+d.status+" "+d.statusText,u.report_error(e),n)if(c){var o=d.responseHeaders||{};n({status:0,httpStatusCode:d.status,error:e,retryAfter:o["Retry-After"]})}else n(0)},d.send(s)}catch(e){u.report_error(e),o=!1}else{var m=ZL.createElement("script");m.type="text/javascript",m.async=!0,m.defer=!0,m.src=e;var g=ZL.getElementsByTagName("script")[0];g.parentNode.insertBefore(m,g)}return o},YB.prototype._fetch_remote_settings=function(e){var t=this,r=function(){"strict"===e&&t.set_config({record_sessions_percent:0})};if(!Hx.AbortController)return aD.critical("Remote settings unavailable: missing minimum required APIs"),r(),Promise.resolve();var n=this.get_api_host("settings")+"/"+this.get_config("api_routes").settings,o={$lib_version:Kx.LIB_VERSION,mp_lib:"web",sdk_config:"1"},i=n+"?"+sD.HTTPBuildQuery(o),s=new AbortController,a=setTimeout(function(){s.abort()},500),l={method:"GET",headers:{Authorization:"Basic "+btoa(t.get_config("token")+":")},signal:s.signal};return Hx.fetch(i,l).then(function(e){return clearTimeout(a),e.ok?e.json():(aD.critical("Network response was not ok"),void r())}).then(function(e){if(e&&e.sdk_config&&e.sdk_config.config){var n=e.sdk_config.config,o={};sD.each(n,function(e,t){GB.hasOwnProperty(t)&&(o[t]=e)}),sD.isEmptyObject(o)?(aD.critical("No valid config keys found in remote settings."),r()):t.set_config(o)}else r()}).catch(function(e){clearTimeout(a),aD.critical("Failed to fetch remote settings",e),r()})},YB.prototype._execute_array=function(e){var t,r=[],n=[],o=[];sD.each(e,function(e){e&&(t=e[0],sD.isArray(t)?o.push(e):"function"==typeof e?e.call(this):sD.isArray(e)&&"alias"===t?r.push(e):sD.isArray(e)&&-1!==t.indexOf("track")&&"function"==typeof this[t]?o.push(e):n.push(e))},this);var i=function(e,t){sD.each(e,function(e){if(sD.isArray(e[0])){var r=t;sD.each(e,function(e){r=r[e[0]].apply(r,e.slice(1))})}else this[e[0]].apply(this,e.slice(1))},t)};i(r,this),i(n,this),i(o,this)},YB.prototype.are_batchers_initialized=function(){return!!this.request_batchers.events},YB.prototype.get_batcher_configs=function(){var e="__mpq_"+this.get_config("token");return this._batcher_configs=this._batcher_configs||{events:{type:"events",api_name:"track",queue_key:e+"_ev"},people:{type:"people",api_name:"engage",queue_key:e+"_pp"},groups:{type:"groups",api_name:"groups",queue_key:e+"_gr"}},this._batcher_configs},YB.prototype.init_batchers=function(){if(!this.are_batchers_initialized()){var e=sD.bind(function(e){return new nF(e.queue_key,{libConfig:this.config,errorReporter:this.get_config("error_reporter"),sendRequestFunc:sD.bind(function(t,r,n){var o=this.get_config("api_routes");this._send_request(this.get_api_host(e.api_name)+"/"+o[e.api_name],this._encode_data_for_request(t),r,this._prepare_callback(n,t))},this),beforeSendHook:sD.bind(function(t){var r=this._run_hook("before_send_"+e.type,t);return r?r[0]:null},this),stopAllBatchingFunc:sD.bind(this.stop_batch_senders,this),usePersistence:!0})},this),t=this.get_batcher_configs();this.request_batchers={events:e(t.events),people:e(t.people),groups:e(t.groups)}}this.get_config("batch_autostart")&&this.start_batch_senders()},YB.prototype.start_batch_senders=function(){this._batchers_were_started=!0,this.are_batchers_initialized()&&(this._batch_requests=!0,sD.each(this.request_batchers,function(e){e.start()}))},YB.prototype.stop_batch_senders=function(){this._batch_requests=!1,sD.each(this.request_batchers,function(e){e.stop(),e.clear()})},YB.prototype.push=function(e){this._execute_array([e])},YB.prototype.enable=function(e){var t,r,n,o;if(void 0===e)this._flags.disable_all_events=!1;else{for(t={},r=[],n=0;n<e.length;n++)t[e[n]]=!0;for(o=0;o<this.__disabled_events.length;o++)t[this.__disabled_events[o]]||r.push(this.__disabled_events[o]);this.__disabled_events=r}},YB.prototype.disable=function(e){void 0===e?this._flags.disable_all_events=!0:this.__disabled_events=this.__disabled_events.concat(e)},YB.prototype._encode_data_for_request=function(e){var t=ID(e);return this.get_config("api_payload_format")===zB&&(t=sD.base64Encode(t)),{data:t}},YB.prototype._track_or_batch=function(e,t){var r=sD.truncate(e.data,255),n=e.endpoint,o=e.batcher,i=e.should_send_immediately,s=e.send_request_options||{};t=t||TD;var a=!0,l=sD.bind(function(){return s.skip_hooks||(r=this._run_hook("before_send_"+e.type,r))&&(r=r[0]),r?(aD.log("MIXPANEL REQUEST:"),aD.log(r),this._send_request(n,this._encode_data_for_request(r),s,this._prepare_callback(t,r))):null},this);return this._batch_requests&&!i?o.enqueue(r).then(function(e){e?t(1,r):l()}):a=l(),a&&r},YB.prototype.track=BD(function(e,t,r,n){var o;if(!r||!r.skip_hooks){if(null===(o=this._run_hook("before_track",e,t)))return;e=o[0],t=o[1]}n||"function"!=typeof r||(n=r,r=null);var i=(r=r||{}).transport;i&&(r.transport=i);var s=r.send_immediately;if("function"!=typeof n&&(n=TD),sD.isUndefined(e))this.report_error("No event name provided to mixpanel.track");else{if(!this._event_is_disabled(e)){(t=sD.extend({},t)).token=this.get_config("token");var a=this.persistence.remove_event_timer(e);if(!sD.isUndefined(a)){var l=(new Date).getTime()-a;t.$duration=parseFloat((l/1e3).toFixed(3))}this._set_default_superprops();var c=this.get_config("track_marketing")?sD.info.marketingParams():{};t=sD.extend({},sD.info.properties({mp_loader:this.get_config("mp_loader")}),c,this.persistence.properties(),this.unpersisted_superprops,this.get_session_recording_properties(),t);var u=this.get_config("property_blacklist");sD.isArray(u)?sD.each(u,function(e){delete t[e]}):this.report_error("Invalid value for property_blacklist config: "+u),this._start_recording_on_event(e,t);var p={event:e,properties:t};return o=this._track_or_batch({type:"events",data:p,endpoint:this.get_api_host("events")+"/"+this.get_config("api_routes").track,batcher:this.request_batchers.events,should_send_immediately:s,send_request_options:r},n),this.flags&&this.flags.checkFirstTimeEvents&&this.flags.checkFirstTimeEvents(e,t),o}n(0)}}),YB.prototype.set_group=BD(function(e,t,r){sD.isArray(t)||(t=[t]);var n={};return n[e]=t,this.register(n),this.people.set(e,t,r)}),YB.prototype.add_group=BD(function(e,t,r){var n=this.get_property(e),o={};return void 0===n?(o[e]=[t],this.register(o)):-1===n.indexOf(t)&&(n.push(t),o[e]=n,this.register(o)),this.people.union(e,t,r)}),YB.prototype.remove_group=BD(function(e,t,r){var n=this.get_property(e);if(void 0!==n){var o=n.indexOf(t);o>-1&&(n.splice(o,1),this.register({group_key:n})),0===n.length&&this.unregister(e)}return this.people.remove(e,t,r)}),YB.prototype.track_with_groups=BD(function(e,t,r,n){var o=sD.extend({},t||{});return sD.each(r,function(e,t){null!=e&&(o[t]=e)}),this.track(e,o,n)}),YB.prototype._create_map_key=function(e,t){return e+"_"+JSON.stringify(t)},YB.prototype._remove_group_from_cache=function(e,t){delete this._cached_groups[this._create_map_key(e,t)]},YB.prototype.get_group=function(e,t){var r=this._create_map_key(e,t),n=this._cached_groups[r];return void 0!==n&&n._group_key===e&&n._group_id===t||((n=new SB)._init(this,e,t),this._cached_groups[r]=n),n},YB.prototype.track_pageview=BD(function(e,t){"object"!=typeof e&&(e={});var r=(t=t||{}).event_name||"$mp_web_page_view",n=sD.extend(sD.info.mpPageViewProperties(),sD.info.campaignParams(),sD.info.clickParams()),o=sD.extend({},n,e);return this.track(r,o)}),YB.prototype.track_links=function(){return this._track_dom.call(this,fB,arguments)},YB.prototype.track_forms=function(){return this._track_dom.call(this,hB,arguments)},YB.prototype.time_event=function(e){sD.isUndefined(e)?this.report_error("No event name provided to mixpanel.time_event"):this._event_is_disabled(e)||this.persistence.set_event_timer(e,(new Date).getTime())};var XB={persistent:!0},JB=function(e){var t;return t=sD.isObject(e)?e:sD.isUndefined(e)?{}:{days:e},sD.extend({},XB,t)};YB.prototype.register=function(e,t){var r=this._run_hook("before_register",e,t);if(null!==r){e=r[0],t=r[1];var n=JB(t);n.persistent?this.persistence.register(e,n.days):sD.extend(this.unpersisted_superprops,e)}},YB.prototype.register_once=function(e,t,r){var n=this._run_hook("before_register_once",e,t,r);if(null!==n){e=n[0],t=n[1],r=n[2];var o=JB(r);o.persistent?this.persistence.register_once(e,t,o.days):(void 0===t&&(t="None"),sD.each(e,function(e,r){this.unpersisted_superprops.hasOwnProperty(r)&&this.unpersisted_superprops[r]!==t||(this.unpersisted_superprops[r]=e)},this))}},YB.prototype.unregister=function(e,t){var r=this._run_hook("before_unregister",e,t);null!==r&&(e=r[0],t=r[1],(t=JB(t)).persistent?this.persistence.unregister(e):delete this.unpersisted_superprops[e])},YB.prototype._register_single=function(e,t){var r={};r[e]=t,this.register(r)},YB.prototype.identify=function(e,t,r,n,o,i,s,a){var l=this._run_hook("before_identify",e);if(null===l)return-1;e=l[0];var c=this.get_distinct_id();if(e&&c!==e){if("string"==typeof e&&0===e.indexOf(VB))return this.report_error("distinct_id cannot have $device: prefix"),-1;this.register({$user_id:e})}if(!this.get_property("$device_id")){var u=c;this.register_once({$had_persisted_distinct_id:!0,$device_id:u},"")}e!==c&&e!==this.get_property(NB)&&(this.unregister(NB),this.register({distinct_id:e})),this._flags.identify_called=!0,this.people._flush(t,r,n,o,i,s,a),e!==c&&this.track("$identify",{distinct_id:e,$anon_distinct_id:c},{skip_hooks:!0}),e!==c&&this.flags.fetchFlags()},YB.prototype.reset=function(){this.stop_session_recording(),this.persistence.clear(),this._flags.identify_called=!1;var e=sD.UUID();this.register_once({distinct_id:VB+e,$device_id:e},""),this._check_and_start_session_recording()},YB.prototype.get_distinct_id=function(){return this.get_property("distinct_id")},YB.prototype.alias=function(e,t){if(e===this.get_property(PB))return this.report_error("Attempting to create alias for existing People user - aborting."),-2;var r=this;return sD.isUndefined(t)&&(t=this.get_distinct_id()),e!==t?(this._register_single(NB,e),this.track("$create_alias",{alias:e,distinct_id:t},{skip_hooks:!0},function(){r.identify(e)})):(this.report_error("alias matches current distinct_id - skipping api call."),this.identify(e),-1)},YB.prototype.name_tag=function(e){this._register_single("mp_name_tag",e)},YB.prototype.set_config=function(e){sD.isObject(e)&&(sD.extend(this.config,e),e.batch_size&&sD.each(this.request_batchers,function(e){e.resetBatchSize()}),this.get_config("persistence_name")||(this.config.persistence_name=this.config.cookie_name),this.get_config("disable_persistence")||(this.config.disable_persistence=this.config.disable_cookie),this.persistence&&this.persistence.update_config(this.config),Kx.DEBUG=Kx.DEBUG||this.get_config("debug"),("autocapture"in e||"record_heatmap_data"in e)&&this.autocapture&&this.autocapture.init(),sD.isObject(e.hooks)&&(this.hooks={},sD.each(e.hooks,function(e,t){if(sD.isFunction(e))this.hooks[t]=[e];else if(sD.isArray(e)){this.hooks[t]=[];for(var r=0;r<e.length;r++)sD.isFunction(e[r])||aD.critical("Invalid hook added. Hook is not a function"),this.hooks[t].push(e[r])}else aD.critical("Invalid hooks added. Ensure that the hook values passed into config.hooks are functions or arrays of functions.")},this)))},YB.prototype.get_config=function(e){return this.config[e]},YB.prototype._run_hook=function(e){var t=WL.call(arguments,1);return sD.each(this.hooks[e],function(r){if(null===t)return null;var n=r.apply(this,t);void 0===n?(this.report_error(e+" hook did not return a valid value"),t=null):(sD.isArray(n)||(n=[n]),t.splice.apply(t,[0,n.length].concat(n)))},this),t},YB.prototype.get_property=function(e){return this.persistence.load_prop([e])},YB.prototype.get_api_host=function(e){return this.get_config("api_hosts")[e]||this.get_config("api_host")},YB.prototype.toString=function(){var e=this.get_config("name");return e!==BB&&(e=BB+"."+e),e},YB.prototype._event_is_disabled=function(e){return sD.isBlockedUA(QL)||this._flags.disable_all_events||sD.include(this.__disabled_events,e)},YB.prototype._gdpr_init=function(){"localStorage"===this.get_config("opt_out_tracking_persistence_type")&&sD.localStorage.is_supported()&&(!this.has_opted_in_tracking()&&this.has_opted_in_tracking({persistence_type:"cookie"})&&this.opt_in_tracking({enable_persistence:!1}),!this.has_opted_out_tracking()&&this.has_opted_out_tracking({persistence_type:"cookie"})&&this.opt_out_tracking({clear_persistence:!1}),this.clear_opt_in_out_tracking({persistence_type:"cookie",enable_persistence:!1})),this.has_opted_out_tracking()?this._gdpr_update_persistence({clear_persistence:!0}):this.has_opted_in_tracking()||!this.get_config("opt_out_tracking_by_default")&&!sD.cookie.get("mp_optout")||(sD.cookie.remove("mp_optout"),this.opt_out_tracking({clear_persistence:this.get_config("opt_out_persistence_by_default")}))},YB.prototype._gdpr_update_persistence=function(e){var t;if(e&&e.clear_persistence)t=!0;else{if(!e||!e.enable_persistence)return;t=!1}this.get_config("disable_persistence")||this.persistence.disabled===t||this.persistence.set_disabled(t),t?(this.stop_batch_senders(),this.stop_session_recording()):this._batchers_were_started&&this.start_batch_senders()},YB.prototype._gdpr_call_func=function(e,t){return t=sD.extend({track:sD.bind(this.track,this),persistence_type:this.get_config("opt_out_tracking_persistence_type"),cookie_prefix:this.get_config("opt_out_tracking_cookie_prefix"),cookie_expiration:this.get_config("cookie_expiration"),cross_site_cookie:this.get_config("cross_site_cookie"),cross_subdomain_cookie:this.get_config("cross_subdomain_cookie"),cookie_domain:this.get_config("cookie_domain"),secure_cookie:this.get_config("secure_cookie"),ignore_dnt:this.get_config("ignore_dnt")},t),sD.localStorage.is_supported()||(t.persistence_type="cookie"),e(this.get_config("token"),{track:t.track,trackEventName:t.track_event_name,trackProperties:t.track_properties,persistenceType:t.persistence_type,persistencePrefix:t.cookie_prefix,cookieDomain:t.cookie_domain,cookieExpiration:t.cookie_expiration,crossSiteCookie:t.cross_site_cookie,crossSubdomainCookie:t.cross_subdomain_cookie,secureCookie:t.secure_cookie,ignoreDnt:t.ignore_dnt})},YB.prototype.opt_in_tracking=function(e){e=sD.extend({enable_persistence:!0},e),this._gdpr_call_func(LD,e),this._gdpr_update_persistence(e)},YB.prototype.opt_out_tracking=function(e){(e=sD.extend({clear_persistence:!0,delete_user:!0},e)).delete_user&&this.people&&this.people._identify_called()&&(this.people.delete_user(),this.people.clear_charges()),this._gdpr_call_func(DD,e),this._gdpr_update_persistence(e)},YB.prototype.has_opted_in_tracking=function(e){return this._gdpr_call_func(FD,e)},YB.prototype.has_opted_out_tracking=function(e){return this._gdpr_call_func($D,e)},YB.prototype.clear_opt_in_out_tracking=function(e){e=sD.extend({enable_persistence:!0},e),this._gdpr_call_func(UD,e),this._gdpr_update_persistence(e)},YB.prototype.report_error=function(e,t){aD.error.apply(aD.error,arguments);try{t||e instanceof Error||(e=new Error(e)),this.get_config("error_reporter")(e,t)}catch(t){aD.error(t)}},YB.prototype.add_hook=function(e,t){this.hooks[e]||(this.hooks[e]=[]),this.hooks[e].push(t)},YB.prototype.remove_hook=function(e,t){var r;this.hooks[e]&&(-1!==(r=this.hooks[e].indexOf(t))?this.hooks[e].splice(r,1):aD.log("remove_hook failed. Matching hook was not found"))},YB.prototype.init=YB.prototype.init,YB.prototype.reset=YB.prototype.reset,YB.prototype.enable=YB.prototype.enable,YB.prototype.disable=YB.prototype.disable,YB.prototype.time_event=YB.prototype.time_event,YB.prototype.track=YB.prototype.track,YB.prototype.track_links=YB.prototype.track_links,YB.prototype.track_forms=YB.prototype.track_forms,YB.prototype.track_pageview=YB.prototype.track_pageview,YB.prototype.register=YB.prototype.register,YB.prototype.register_once=YB.prototype.register_once,YB.prototype.unregister=YB.prototype.unregister,YB.prototype.identify=YB.prototype.identify,YB.prototype.alias=YB.prototype.alias,YB.prototype.name_tag=YB.prototype.name_tag,YB.prototype.set_config=YB.prototype.set_config,YB.prototype.get_config=YB.prototype.get_config,YB.prototype.get_api_host=YB.prototype.get_api_host,YB.prototype.get_property=YB.prototype.get_property,YB.prototype.get_distinct_id=YB.prototype.get_distinct_id,YB.prototype.toString=YB.prototype.toString,YB.prototype.opt_out_tracking=YB.prototype.opt_out_tracking,YB.prototype.opt_in_tracking=YB.prototype.opt_in_tracking,YB.prototype.has_opted_out_tracking=YB.prototype.has_opted_out_tracking,YB.prototype.has_opted_in_tracking=YB.prototype.has_opted_in_tracking,YB.prototype.clear_opt_in_out_tracking=YB.prototype.clear_opt_in_out_tracking,YB.prototype.get_group=YB.prototype.get_group,YB.prototype.set_group=YB.prototype.set_group,YB.prototype.add_group=YB.prototype.add_group,YB.prototype.remove_group=YB.prototype.remove_group,YB.prototype.add_hook=YB.prototype.add_hook,YB.prototype.remove_hook=YB.prototype.remove_hook,YB.prototype.track_with_groups=YB.prototype.track_with_groups,YB.prototype.start_batch_senders=YB.prototype.start_batch_senders,YB.prototype.stop_batch_senders=YB.prototype.stop_batch_senders,YB.prototype.start_session_recording=YB.prototype.start_session_recording,YB.prototype.stop_session_recording=YB.prototype.stop_session_recording,YB.prototype.pause_session_recording=YB.prototype.pause_session_recording,YB.prototype.resume_session_recording=YB.prototype.resume_session_recording,YB.prototype.get_session_recording_properties=YB.prototype.get_session_recording_properties,YB.prototype.get_session_replay_url=YB.prototype.get_session_replay_url,YB.prototype.get_tab_id=YB.prototype.get_tab_id,YB.prototype.DEFAULT_API_ROUTES=HB,YB.prototype.__get_recorder=YB.prototype.__get_recorder,YB.prototype.__get_recording_init_promise=YB.prototype.__get_recording_init_promise,DB.prototype.properties=DB.prototype.properties,DB.prototype.update_search_keyword=DB.prototype.update_search_keyword,DB.prototype.update_referrer_info=DB.prototype.update_referrer_info,DB.prototype.get_cross_subdomain=DB.prototype.get_cross_subdomain,DB.prototype.clear=DB.prototype.clear;var QB={},ez=($B=function(e,t){t()},CB=0,(FB=new YB).init=function(e,t,r){if(r)return FB[r]||(FB[r]=QB[r]=ZB(e,t,r),FB[r]._loaded()),FB[r];var n=FB;QB[BB]?n=QB[BB]:e&&((n=ZB(e,t,BB))._loaded(),QB[BB]=n),FB=n,1===CB&&(Hx[BB]=FB),sD.each(QB,function(e,t){t!==BB&&(FB[t]=e)}),FB._=sD},FB.init(),function(){function e(){e.done||(e.done=!0,KB=!0,qB=!1,sD.each(QB,function(e){e._dom_loaded()}))}if(ZL.addEventListener)"complete"===ZL.readyState?e():ZL.addEventListener("DOMContentLoaded",e,!1);else if(ZL.attachEvent){ZL.attachEvent("onreadystatechange",e);var t=!1;try{t=null===Hx.frameElement}catch(e){}ZL.documentElement.doScroll&&t&&function t(){try{ZL.documentElement.doScroll("left")}catch(e){return void setTimeout(t,1)}e()}()}sD.register_event(Hx,"load",e,!0)}(),FB);const tz="elementor-one-assets";let rz=null;function nz(){return rz}const oz={initialize(e,t){if(!rz)try{ez.init(e,{debug:"production"!==t,track_pageview:!1,persistence:"localStorage"},tz),rz=ez[tz],rz.opt_in_tracking()}catch(e){console.warn("[elementor-one-assets] Failed to initialize tracking:",e)}},registerOnce(e){const t=nz();t?.register_once(e)},track(e,t){const r=nz();r?.track(e,t)},isInitialized:()=>null!==rz},iz="plugin-settings",sz=e=>{const{enabled:t=!0}=e||{};return Ay({queryKey:[iz],queryFn:()=>Ux.getPluginSettings(),enabled:t})},az=new Cy({defaultOptions:{queries:{refetchOnWindowFocus:!1,refetchOnMount:!1,retryOnMount:!1,retry:!1}}}),lz=t.createContext(null),cz=()=>{const e=t.useContext(lz);if(!e)throw new Error("Wrap your component in <ElementorOneAssetsProvider> to access the env config");return e.config};var uz=Cs;const pz=()=>{const e=ea();return uz(e.breakpoints.down("sm"))};function dz(e){return Mo("MuiSkeleton",e)}ta("MuiSkeleton",["root","text","rectangular","rounded","circular","pulse","wave","withChildren","fitContent","heightAuto"]);const fz=["animation","className","component","height","style","variant","width"];let hz,mz,gz,vz,yz=e=>e;const bz=Ot(hz||(hz=yz`
  0% {
    opacity: 1;
  }

  50% {
    opacity: 0.4;
  }

  100% {
    opacity: 1;
  }
`)),wz=Ot(mz||(mz=yz`
  0% {
    transform: translateX(-100%);
  }

  50% {
    /* +0.5s of delay between each loop */
    transform: translateX(100%);
  }

  100% {
    transform: translateX(100%);
  }
`)),xz=Vi("span",{name:"MuiSkeleton",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,t[r.variant],!1!==r.animation&&t[r.animation],r.hasChildren&&t.withChildren,r.hasChildren&&!r.width&&t.fitContent,r.hasChildren&&!r.height&&t.heightAuto]}})(({theme:e,ownerState:t})=>{const r=function(e){return String(e).match(/[\d.\-+]*\s*(.*)/)[1]||""}(e.shape.borderRadius)||"px",n=function(e){return parseFloat(e)}(e.shape.borderRadius);return a({display:"block",backgroundColor:e.vars?e.vars.palette.Skeleton.bg:Rs(e.palette.text.primary,"light"===e.palette.mode?.11:.13),height:"1.2em"},"text"===t.variant&&{marginTop:0,marginBottom:0,height:"auto",transformOrigin:"0 55%",transform:"scale(1, 0.60)",borderRadius:`${n}${r}/${Math.round(n/.6*10)/10}${r}`,"&:empty:before":{content:'"\\00a0"'}},"circular"===t.variant&&{borderRadius:"50%"},"rounded"===t.variant&&{borderRadius:(e.vars||e).shape.borderRadius},t.hasChildren&&{"& > *":{visibility:"hidden"}},t.hasChildren&&!t.width&&{maxWidth:"fit-content"},t.hasChildren&&!t.height&&{height:"auto"})},({ownerState:e})=>"pulse"===e.animation&&Ct(gz||(gz=yz`
      animation: ${0} 2s ease-in-out 0.5s infinite;
    `),bz),({ownerState:e,theme:t})=>"wave"===e.animation&&Ct(vz||(vz=yz`
      position: relative;
      overflow: hidden;

      /* Fix bug in Safari https://bugs.webkit.org/show_bug.cgi?id=68196 */
      -webkit-mask-image: -webkit-radial-gradient(white, black);

      &::after {
        animation: ${0} 2s linear 0.5s infinite;
        background: linear-gradient(
          90deg,
          transparent,
          ${0},
          transparent
        );
        content: '';
        position: absolute;
        transform: translateX(-100%); /* Avoid flash during server-side hydration */
        bottom: 0;
        left: 0;
        right: 0;
        top: 0;
      }
    `),wz,(t.vars||t).palette.action.hover)),_z=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiSkeleton"}),{animation:o="pulse",className:i,component:l="span",height:c,style:u,variant:p="text",width:d}=n,f=s(n,fz),h=a({},n,{animation:o,component:l,variant:p,hasChildren:Boolean(f.children)}),m=(e=>{const{classes:t,variant:r,animation:n,hasChildren:o,width:i,height:s}=e;return U({root:["root",r,n,o&&"withChildren",o&&!i&&"fitContent",o&&!s&&"heightAuto"]},dz,t)})(h);return e.jsx(xz,a({as:l,ref:r,className:V(m.root,i),ownerState:h},f,{style:a({width:d,height:c},u)}))}); true&&(_z.propTypes={animation:B.oneOf(["pulse","wave",!1]),children:B.node,classes:B.object,className:B.string,component:B.elementType,height:B.oneOfType([B.number,B.string]),style:B.object,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),variant:B.oneOfType([B.oneOf(["circular","rectangular","rounded","text"]),B.string]),width:B.oneOfType([B.number,B.string])});const Sz=_z;var kz=t.forwardRef((e,r)=>t.createElement(Sz,{...e,ref:r}));function Cz(t,r){function n(n,o){return e.jsx(ku,a({"data-testid":`${r}Icon`,ref:o},n,{children:t}))}return true&&(n.displayName=`${r}Icon`),n.muiName=ku.muiName,o.memo(o.forwardRef(n))}const Oz=Cz(e.jsx("path",{d:"M12 2C6.47 2 2 6.47 2 12s4.47 10 10 10 10-4.47 10-10S17.53 2 12 2zm5 13.59L15.59 17 12 13.41 8.41 17 7 15.59 10.59 12 7 8.41 8.41 7 12 10.59 15.59 7 17 8.41 13.41 12 17 15.59z"}),"Cancel");function Ez(e){return Mo("MuiChip",e)}const Tz=ta("MuiChip",["root","sizeSmall","sizeMedium","colorError","colorInfo","colorPrimary","colorSecondary","colorSuccess","colorWarning","disabled","clickable","clickableColorPrimary","clickableColorSecondary","deletable","deletableColorPrimary","deletableColorSecondary","outlined","filled","outlinedPrimary","outlinedSecondary","filledPrimary","filledSecondary","avatar","avatarSmall","avatarMedium","avatarColorPrimary","avatarColorSecondary","icon","iconSmall","iconMedium","iconColorPrimary","iconColorSecondary","label","labelSmall","labelMedium","deleteIcon","deleteIconSmall","deleteIconMedium","deleteIconColorPrimary","deleteIconColorSecondary","deleteIconOutlinedColorPrimary","deleteIconOutlinedColorSecondary","deleteIconFilledColorPrimary","deleteIconFilledColorSecondary","focusVisible"]),Rz=["avatar","className","clickable","color","component","deleteIcon","disabled","icon","label","onClick","onDelete","onKeyDown","onKeyUp","size","variant","tabIndex","skipFocusWhenDisabled"],Iz=Vi("div",{name:"MuiChip",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e,{color:n,iconColor:o,clickable:i,onDelete:s,size:a,variant:l}=r;return[{[`& .${Tz.avatar}`]:t.avatar},{[`& .${Tz.avatar}`]:t[`avatar${Zi(a)}`]},{[`& .${Tz.avatar}`]:t[`avatarColor${Zi(n)}`]},{[`& .${Tz.icon}`]:t.icon},{[`& .${Tz.icon}`]:t[`icon${Zi(a)}`]},{[`& .${Tz.icon}`]:t[`iconColor${Zi(o)}`]},{[`& .${Tz.deleteIcon}`]:t.deleteIcon},{[`& .${Tz.deleteIcon}`]:t[`deleteIcon${Zi(a)}`]},{[`& .${Tz.deleteIcon}`]:t[`deleteIconColor${Zi(n)}`]},{[`& .${Tz.deleteIcon}`]:t[`deleteIcon${Zi(l)}Color${Zi(n)}`]},t.root,t[`size${Zi(a)}`],t[`color${Zi(n)}`],i&&t.clickable,i&&"default"!==n&&t[`clickableColor${Zi(n)})`],s&&t.deletable,s&&"default"!==n&&t[`deletableColor${Zi(n)}`],t[l],t[`${l}${Zi(n)}`]]}})(({theme:e,ownerState:t})=>{const r="light"===e.palette.mode?e.palette.grey[700]:e.palette.grey[300];return a({maxWidth:"100%",fontFamily:e.typography.fontFamily,fontSize:e.typography.pxToRem(13),display:"inline-flex",alignItems:"center",justifyContent:"center",height:32,color:(e.vars||e).palette.text.primary,backgroundColor:(e.vars||e).palette.action.selected,borderRadius:16,whiteSpace:"nowrap",transition:e.transitions.create(["background-color","box-shadow"]),cursor:"unset",outline:0,textDecoration:"none",border:0,padding:0,verticalAlign:"middle",boxSizing:"border-box",[`&.${Tz.disabled}`]:{opacity:(e.vars||e).palette.action.disabledOpacity,pointerEvents:"none"},[`& .${Tz.avatar}`]:{marginLeft:5,marginRight:-6,width:24,height:24,color:e.vars?e.vars.palette.Chip.defaultAvatarColor:r,fontSize:e.typography.pxToRem(12)},[`& .${Tz.avatarColorPrimary}`]:{color:(e.vars||e).palette.primary.contrastText,backgroundColor:(e.vars||e).palette.primary.dark},[`& .${Tz.avatarColorSecondary}`]:{color:(e.vars||e).palette.secondary.contrastText,backgroundColor:(e.vars||e).palette.secondary.dark},[`& .${Tz.avatarSmall}`]:{marginLeft:4,marginRight:-4,width:18,height:18,fontSize:e.typography.pxToRem(10)},[`& .${Tz.icon}`]:a({marginLeft:5,marginRight:-6},"small"===t.size&&{fontSize:18,marginLeft:4,marginRight:-4},t.iconColor===t.color&&a({color:e.vars?e.vars.palette.Chip.defaultIconColor:r},"default"!==t.color&&{color:"inherit"})),[`& .${Tz.deleteIcon}`]:a({WebkitTapHighlightColor:"transparent",color:e.vars?`rgba(${e.vars.palette.text.primaryChannel} / 0.26)`:Fo.alpha(e.palette.text.primary,.26),fontSize:22,cursor:"pointer",margin:"0 5px 0 -6px","&:hover":{color:e.vars?`rgba(${e.vars.palette.text.primaryChannel} / 0.4)`:Fo.alpha(e.palette.text.primary,.4)}},"small"===t.size&&{fontSize:16,marginRight:4,marginLeft:-4},"default"!==t.color&&{color:e.vars?`rgba(${e.vars.palette[t.color].contrastTextChannel} / 0.7)`:Fo.alpha(e.palette[t.color].contrastText,.7),"&:hover, &:active":{color:(e.vars||e).palette[t.color].contrastText}})},"small"===t.size&&{height:24},"default"!==t.color&&{backgroundColor:(e.vars||e).palette[t.color].main,color:(e.vars||e).palette[t.color].contrastText},t.onDelete&&{[`&.${Tz.focusVisible}`]:{backgroundColor:e.vars?`rgba(${e.vars.palette.action.selectedChannel} / calc(${e.vars.palette.action.selectedOpacity} + ${e.vars.palette.action.focusOpacity}))`:Fo.alpha(e.palette.action.selected,e.palette.action.selectedOpacity+e.palette.action.focusOpacity)}},t.onDelete&&"default"!==t.color&&{[`&.${Tz.focusVisible}`]:{backgroundColor:(e.vars||e).palette[t.color].dark}})},({theme:e,ownerState:t})=>a({},t.clickable&&{userSelect:"none",WebkitTapHighlightColor:"transparent",cursor:"pointer","&:hover":{backgroundColor:e.vars?`rgba(${e.vars.palette.action.selectedChannel} / calc(${e.vars.palette.action.selectedOpacity} + ${e.vars.palette.action.hoverOpacity}))`:Fo.alpha(e.palette.action.selected,e.palette.action.selectedOpacity+e.palette.action.hoverOpacity)},[`&.${Tz.focusVisible}`]:{backgroundColor:e.vars?`rgba(${e.vars.palette.action.selectedChannel} / calc(${e.vars.palette.action.selectedOpacity} + ${e.vars.palette.action.focusOpacity}))`:Fo.alpha(e.palette.action.selected,e.palette.action.selectedOpacity+e.palette.action.focusOpacity)},"&:active":{boxShadow:(e.vars||e).shadows[1]}},t.clickable&&"default"!==t.color&&{[`&:hover, &.${Tz.focusVisible}`]:{backgroundColor:(e.vars||e).palette[t.color].dark}}),({theme:e,ownerState:t})=>a({},"outlined"===t.variant&&{backgroundColor:"transparent",border:e.vars?`1px solid ${e.vars.palette.Chip.defaultBorder}`:`1px solid ${"light"===e.palette.mode?e.palette.grey[400]:e.palette.grey[700]}`,[`&.${Tz.clickable}:hover`]:{backgroundColor:(e.vars||e).palette.action.hover},[`&.${Tz.focusVisible}`]:{backgroundColor:(e.vars||e).palette.action.focus},[`& .${Tz.avatar}`]:{marginLeft:4},[`& .${Tz.avatarSmall}`]:{marginLeft:2},[`& .${Tz.icon}`]:{marginLeft:4},[`& .${Tz.iconSmall}`]:{marginLeft:2},[`& .${Tz.deleteIcon}`]:{marginRight:5},[`& .${Tz.deleteIconSmall}`]:{marginRight:3}},"outlined"===t.variant&&"default"!==t.color&&{color:(e.vars||e).palette[t.color].main,border:`1px solid ${e.vars?`rgba(${e.vars.palette[t.color].mainChannel} / 0.7)`:Fo.alpha(e.palette[t.color].main,.7)}`,[`&.${Tz.clickable}:hover`]:{backgroundColor:e.vars?`rgba(${e.vars.palette[t.color].mainChannel} / ${e.vars.palette.action.hoverOpacity})`:Fo.alpha(e.palette[t.color].main,e.palette.action.hoverOpacity)},[`&.${Tz.focusVisible}`]:{backgroundColor:e.vars?`rgba(${e.vars.palette[t.color].mainChannel} / ${e.vars.palette.action.focusOpacity})`:Fo.alpha(e.palette[t.color].main,e.palette.action.focusOpacity)},[`& .${Tz.deleteIcon}`]:{color:e.vars?`rgba(${e.vars.palette[t.color].mainChannel} / 0.7)`:Fo.alpha(e.palette[t.color].main,.7),"&:hover, &:active":{color:(e.vars||e).palette[t.color].main}}})),Mz=Vi("span",{name:"MuiChip",slot:"Label",overridesResolver:(e,t)=>{const{ownerState:r}=e,{size:n}=r;return[t.label,t[`label${Zi(n)}`]]}})(({ownerState:e})=>a({overflow:"hidden",textOverflow:"ellipsis",paddingLeft:12,paddingRight:12,whiteSpace:"nowrap"},"outlined"===e.variant&&{paddingLeft:11,paddingRight:11},"small"===e.size&&{paddingLeft:8,paddingRight:8},"small"===e.size&&"outlined"===e.variant&&{paddingLeft:7,paddingRight:7}));function Az(e){return"Backspace"===e.key||"Delete"===e.key}const Pz=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiChip"}),{avatar:i,className:l,clickable:c,color:u="default",component:p,deleteIcon:d,disabled:f=!1,icon:h,label:m,onClick:g,onDelete:v,onKeyDown:y,onKeyUp:b,size:w="medium",variant:x="filled",tabIndex:_,skipFocusWhenDisabled:S=!1}=n,k=s(n,Rz),C=o.useRef(null),O=Fa(C,r),E=e=>{e.stopPropagation(),v&&v(e)},T=!(!1===c||!g)||c,R=T||v?Dl:p||"div",I=a({},n,{component:R,disabled:f,size:w,color:u,iconColor:o.isValidElement(h)&&h.props.color||u,onDelete:!!v,clickable:T,variant:x}),M=(e=>{const{classes:t,disabled:r,size:n,color:o,iconColor:i,onDelete:s,clickable:a,variant:l}=e;return U({root:["root",l,r&&"disabled",`size${Zi(n)}`,`color${Zi(o)}`,a&&"clickable",a&&`clickableColor${Zi(o)}`,s&&"deletable",s&&`deletableColor${Zi(o)}`,`${l}${Zi(o)}`],label:["label",`label${Zi(n)}`],avatar:["avatar",`avatar${Zi(n)}`,`avatarColor${Zi(o)}`],icon:["icon",`icon${Zi(n)}`,`iconColor${Zi(i)}`],deleteIcon:["deleteIcon",`deleteIcon${Zi(n)}`,`deleteIconColor${Zi(o)}`,`deleteIcon${Zi(l)}Color${Zi(o)}`]},Ez,t)})(I),A=R===Dl?a({component:p||"div",focusVisibleClassName:M.focusVisible},v&&{disableRipple:!0}):{};let P=null;v&&(P=d&&o.isValidElement(d)?o.cloneElement(d,{className:V(d.props.className,M.deleteIcon),onClick:E}):e.jsx(Oz,{className:V(M.deleteIcon),onClick:E}));let N=null;i&&o.isValidElement(i)&&(N=o.cloneElement(i,{className:V(M.avatar,i.props.className)}));let j=null;return h&&o.isValidElement(h)&&(j=o.cloneElement(h,{className:V(M.icon,h.props.className)})), true&&N&&j&&console.error("MUI: The Chip component can not handle the avatar and the icon prop at the same time. Pick one."),e.jsxs(Iz,a({as:R,className:V(M.root,l),disabled:!(!T||!f)||void 0,onClick:g,onKeyDown:e=>{e.currentTarget===e.target&&Az(e)&&e.preventDefault(),y&&y(e)},onKeyUp:e=>{e.currentTarget===e.target&&(v&&Az(e)?v(e):"Escape"===e.key&&C.current&&C.current.blur()),b&&b(e)},ref:O,tabIndex:S&&f?-1:_,ownerState:I},A,k,{children:[N||j,e.jsx(Mz,{className:V(M.label),ownerState:I,children:m}),P]}))}); true&&(Pz.propTypes={avatar:B.element,children:function(e,t,r,n,o){if(false)// removed by dead control flow
{}const i=o||t;return void 0!==e[t]?new Error(`The prop \`${i}\` is not supported. Please remove it.`):null},classes:B.object,className:B.string,clickable:B.bool,color:B.oneOfType([B.oneOf(["default","primary","secondary","error","info","success","warning"]),B.string]),component:B.elementType,deleteIcon:B.element,disabled:B.bool,icon:B.element,label:B.node,onClick:B.func,onDelete:B.func,onKeyDown:B.func,onKeyUp:B.func,size:B.oneOfType([B.oneOf(["medium","small"]),B.string]),skipFocusWhenDisabled:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),tabIndex:B.number,variant:B.oneOfType([B.oneOf(["filled","outlined"]),B.string])});const Nz=Pz,jz=sc(Nz)(({theme:e,ownerState:t})=>"rounded"!==t.shape?null:{borderRadius:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[1]}),Lz={shape:"pill"},Dz=t.forwardRef((e,r)=>{const{shape:n,...o}={...Lz,...e};return t.createElement(jz,{...o,ref:r,ownerState:{shape:n}})});Dz.defaultProps=Lz;var Fz=Dz;const $z=sc(ym)(({theme:e})=>({transform:"rtl"===e.direction?"scaleX(-1)":void 0})),Bz=({onDisconnect:t,onConnectClick:r,anchorElement:n,...o})=>{const{t:i}=Bd("common",{i18n:bm}),{MY_ELEMENTOR_URL:s}=cz(),a=window.elementorOneSettingsData?.canUserManageOptions??!1,{data:l,isLoading:c}=sz({enabled:a}),{mutate:u,isPending:p}=(()=>{const e=Ey();return Py({mutationFn:e=>Ux.initConnect(e&&"string"==typeof e?e:"new"),onSuccess:t=>{window.open(t,"_self")?.focus(),e.invalidateQueries({queryKey:[iz]})}})})(),{mutate:d,isPending:f}=(()=>{const e=Ey();return Py({mutationFn:()=>Ux.disconnect(),onSuccess:()=>{e.invalidateQueries({queryKey:[iz]})}})})();return e.jsx(vu,{colorScheme:"light",children:e.jsx(Zh,{...o,"data-test":"user-profile-menu",anchorEl:n,anchorOrigin:{vertical:"bottom",horizontal:"right"},transformOrigin:{vertical:"top",horizontal:"right"},PaperProps:{sx:{overflow:"visible !important",borderRadius:1,py:1,minWidth:300}},children:c?e.jsxs(ya,{alignItems:"center",gap:1,children:[e.jsx(kz,{variant:"text",width:"90%",height:30}),e.jsx(ju,{sx:{mx:2,width:"80%"}}),e.jsx(kz,{variant:"text",width:"90%",height:30})]}):[e.jsxs(mm,{dense:!0,onClick:async()=>{window.open(s,"_blank"),o.onClose?.({},"backdropClick")},"data-test":"user-menu-go-to-account",children:[e.jsx(vm,{children:i("header.userProfileMenu.goToMyAccount")}),e.jsx(gm,{children:e.jsx($z,{fontSize:"small"})})]},"go-to-account"),e.jsx(ju,{sx:{mx:2}},"divider"),l?.isUrlMismatch?e.jsxs(mm,{dense:!0,onClick:()=>{window.location.href=window.location.origin+window.location.pathname+"?page=elementor-home#/home/url-mismatch",o.onClose?.({},"backdropClick")},sx:{justifyContent:"space-between"},"data-test":"user-menu-fix-url-mismatch",children:[e.jsx(vm,{children:i("header.userProfileMenu.urlMismatch")}),e.jsx(Na,{sx:{color:"info.main"},variant:"caption",children:i("header.userProfileMenu.fixUrlMismatch")})]},"fix-url-mismatch"):l?.isConnected?e.jsxs(mm,{dense:!0,disabled:f,"data-test":"user-menu-disconnect",children:[e.jsxs(vm,{children:[i("header.userProfileMenu.elementorOneActive")," ",e.jsx(Fz,{variant:"standard",label:i("header.userProfileMenu.active"),color:"success",size:"small"})]}),e.jsx(vm,{onClick:()=>{f||d(void 0,{onSuccess:()=>{t?.(),o.onClose?.({},"backdropClick")}})},sx:{textAlign:"right",color:"info.main",cursor:"pointer"},children:i("header.userProfileMenu.disconnect")}),e.jsx(gm,{children:f?e.jsx(fp,{size:16,"data-test":"user-menu-disconnect-loader"}):e.jsx(e.Fragment,{})})]},"disconnect"):e.jsxs(mm,{dense:!0,onClick:()=>{p||(r?.(),u())},disabled:p,sx:{justifyContent:"space-between"},"data-test":"user-menu-connect",children:[e.jsx(vm,{children:i("header.userProfileMenu.connectPreText")}),p?e.jsx(fp,{size:16,"data-test":"user-menu-connect-loader"}):e.jsx(Na,{sx:{color:"info.main"},variant:"caption",children:i("header.userProfileMenu.connect")})]},"connect")]})})},zz=({onDisconnect:r,onClick:n,onConnectClick:o})=>{const{t:i}=Bd("common",{i18n:bm}),s=t.useRef(null),a=pz(),l=Yd({variant:"popover",popupId:"user-info-popover"}),c=()=>{n?.(),l.open()};return e.jsxs(e.Fragment,{children:[a?e.jsx(bu,{onClick:c,ref:s,"data-test":"header-user-button",children:e.jsx(Lu,{})}):e.jsx(wp,{startIcon:e.jsx(Lu,{}),color:"inherit",size:"small",onClick:c,ref:s,"data-test":"header-user-button",children:i("header.userInfo")}),e.jsx(Bz,{onDisconnect:r,onConnectClick:o,anchorElement:s.current,...qd(l)})]})};var Vz=o.forwardRef((e,t)=>o.createElement(Cu,{viewBox:"0 0 24 24",...e,ref:t},o.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M15.0221 2.2505C14.7086 2.2428 14.3993 2.32462 14.1306 2.48639C13.8619 2.64816 13.6449 2.88316 13.5049 3.16386L10.9999 8.19197L3.92384 11.2998C3.49889 11.4865 3.16549 11.8343 2.99698 12.2667C2.82848 12.6992 2.83867 13.1809 3.02531 13.6058L4.63384 17.2682C4.82048 17.6931 5.16829 18.0265 5.60074 18.195C6.0332 18.3635 6.51489 18.3533 6.93984 18.1667L8.9999 17.2619L10.709 21.1532C10.8956 21.5781 11.2434 21.9115 11.6759 22.08C12.1083 22.2485 12.59 22.2383 13.015 22.0517L13.9306 21.6496C14.3555 21.4629 14.6889 21.1151 14.8574 20.6827C15.0259 20.2502 15.0157 19.7685 14.8291 19.3436L13.12 15.4523L14.0159 15.0588L19.4131 16.616C19.7145 16.7029 20.0346 16.7021 20.3355 16.6137C20.6364 16.5253 20.9059 16.3529 21.1124 16.1168C21.3188 15.8807 21.4537 15.5907 21.5013 15.2806C21.5488 14.9707 21.507 14.6537 21.3808 14.3667M21.3808 14.3667L20.4142 12.1659C21.0102 11.7447 21.4752 11.1551 21.7441 10.4649C22.1052 9.53824 22.0834 8.50606 21.6834 7.59546C21.2835 6.68486 20.5382 5.97043 19.6115 5.60934C18.9213 5.3404 18.1726 5.28388 17.4591 5.43778L16.4927 3.23726C16.3667 2.95018 16.1613 2.70457 15.901 2.52988C15.6405 2.35511 15.3357 2.2582 15.0221 2.2505M18.0836 6.85961C18.4152 6.83504 18.7512 6.88399 19.0669 7.00698C19.6229 7.22364 20.0701 7.6523 20.3101 8.19866C20.55 8.74502 20.5631 9.36433 20.3465 9.92035C20.2235 10.236 20.0321 10.5166 19.7897 10.7441L18.0836 6.85961ZM15.1191 3.8401C15.1077 3.81399 15.0889 3.79133 15.0652 3.77544C15.0415 3.75956 15.0138 3.75075 14.9853 3.75005C14.9568 3.74935 14.9287 3.75678 14.9042 3.77149C14.8798 3.7862 14.8601 3.80756 14.8474 3.83308L12.2214 9.10391C12.1432 9.26095 12.0123 9.38559 11.8517 9.45615L10.7072 9.95881L12.5168 14.0789L13.6613 13.5763C13.8219 13.5057 14.0022 13.4937 14.1708 13.5423L19.8288 15.1748C19.8562 15.1827 19.8852 15.1826 19.9126 15.1746C19.9399 15.1665 19.9645 15.1509 19.9832 15.1294C20.002 15.1079 20.0143 15.0816 20.0186 15.0534C20.0229 15.0252 20.0191 14.9964 20.0076 14.9703L15.1191 3.8401ZM11.7466 16.0555L13.4557 19.9468C13.4824 20.0075 13.4838 20.0763 13.4598 20.1381C13.4357 20.1999 13.3881 20.2495 13.3274 20.2762L12.4118 20.6783C12.3511 20.705 12.2823 20.7064 12.2205 20.6824C12.1587 20.6583 12.109 20.6107 12.0824 20.55L10.3733 16.6587L11.7466 16.0555ZM11.1434 14.6821L9.33384 10.562L4.52704 12.6732C4.46633 12.6999 4.4187 12.7496 4.39463 12.8113C4.37056 12.8731 4.37201 12.9419 4.39868 13.0026L6.00721 16.665C6.03387 16.7257 6.08356 16.7733 6.14534 16.7974C6.20712 16.8214 6.27593 16.82 6.33664 16.7933L11.1434 14.6821Z"})));const Uz=["addEndListener","appear","children","container","direction","easing","in","onEnter","onEntered","onEntering","onExit","onExited","onExiting","style","timeout","TransitionComponent"];function qz(e){return"function"==typeof e?e():e}function Wz(e,t,r){const n=function(e,t,r){const n=t.getBoundingClientRect(),o=r&&r.getBoundingClientRect(),i=_f(t);let s;if(t.fakeTransform)s=t.fakeTransform;else{const e=i.getComputedStyle(t);s=e.getPropertyValue("-webkit-transform")||e.getPropertyValue("transform")}let a=0,l=0;if(s&&"none"!==s&&"string"==typeof s){const e=s.split("(")[1].split(")")[0].split(",");a=parseInt(e[4],10),l=parseInt(e[5],10)}return"left"===e?o?`translateX(${o.right+a-n.left}px)`:`translateX(${i.innerWidth+a-n.left}px)`:"right"===e?o?`translateX(-${n.right-o.left-a}px)`:`translateX(-${n.left+n.width-a}px)`:"up"===e?o?`translateY(${o.bottom+l-n.top}px)`:`translateY(${i.innerHeight+l-n.top}px)`:o?`translateY(-${n.top-o.top+n.height-l}px)`:`translateY(-${n.top+n.height-l}px)`}(e,t,qz(r));n&&(t.style.webkitTransform=n,t.style.transform=n)}const Hz=o.forwardRef(function(t,r){const n=ea(),i={enter:n.transitions.easing.easeOut,exit:n.transitions.easing.sharp},l={enter:n.transitions.duration.enteringScreen,exit:n.transitions.duration.leavingScreen},{addEndListener:c,appear:u=!0,children:p,container:d,direction:f="down",easing:h=i,in:m,onEnter:g,onEntered:v,onEntering:y,onExit:b,onExited:w,onExiting:x,style:_,timeout:S=l,TransitionComponent:k=ul}=t,C=s(t,Uz),O=o.useRef(null),E=Fa(p.ref,O,r),T=e=>t=>{e&&(void 0===t?e(O.current):e(O.current,t))},R=T((e,t)=>{Wz(f,e,d),g&&g(e,t)}),I=T((e,t)=>{const r=Gf({timeout:S,style:_,easing:h},{mode:"enter"});e.style.webkitTransition=n.transitions.create("-webkit-transform",a({},r)),e.style.transition=n.transitions.create("transform",a({},r)),e.style.webkitTransform="none",e.style.transform="none",y&&y(e,t)}),M=T(v),A=T(x),P=T(e=>{const t=Gf({timeout:S,style:_,easing:h},{mode:"exit"});e.style.webkitTransition=n.transitions.create("-webkit-transform",t),e.style.transition=n.transitions.create("transform",t),Wz(f,e,d),b&&b(e)}),N=T(e=>{e.style.webkitTransition="",e.style.transition="",w&&w(e)}),j=o.useCallback(()=>{O.current&&Wz(f,O.current,d)},[f,d]);return o.useEffect(()=>{if(m||"down"===f||"right"===f)return;const e=bf(()=>{O.current&&Wz(f,O.current,d)}),t=_f(O.current);return t.addEventListener("resize",e),()=>{e.clear(),t.removeEventListener("resize",e)}},[f,m,d]),o.useEffect(()=>{m||j()},[m,j]),e.jsx(k,a({nodeRef:O,onEnter:R,onEntered:M,onEntering:I,onExit:P,onExited:N,onExiting:A,addEndListener:e=>{c&&c(O.current,e)},appear:u,in:m,timeout:S},C,{children:(e,t)=>o.cloneElement(p,a({ref:E,style:a({visibility:"exited"!==e||m?void 0:"hidden"},_,p.props.style)},t))}))}); true&&(Hz.propTypes={addEndListener:B.func,appear:B.bool,children:hf.isRequired,container:rs(B.oneOfType([vf,B.func]),e=>{if(e.open){const t=qz(e.container);if(t&&1===t.nodeType){const e=t.getBoundingClientRect();if( true&&0===e.top&&0===e.left&&0===e.right&&0===e.bottom)return new Error(["MUI: The `container` prop provided to the component is invalid.","The anchor element should be part of the document layout.","Make sure the element is present in the document or that it's not display none."].join("\n"))}else if(!t||"function"!=typeof t.getBoundingClientRect||null!=t.contextElement&&1!==t.contextElement.nodeType)return new Error(["MUI: The `container` prop provided to the component is invalid.","It should be an HTML element instance."].join("\n"))}return null}),direction:B.oneOf(["down","left","right","up"]),easing:B.oneOfType([B.shape({enter:B.string,exit:B.string}),B.string]),in:B.bool,onEnter:B.func,onEntered:B.func,onEntering:B.func,onExit:B.func,onExited:B.func,onExiting:B.func,style:B.object,timeout:B.oneOfType([B.number,B.shape({appear:B.number,enter:B.number,exit:B.number})])});const Gz=Hz;function Kz(e){return Mo("MuiDrawer",e)}ta("MuiDrawer",["root","docked","paper","paperAnchorLeft","paperAnchorRight","paperAnchorTop","paperAnchorBottom","paperAnchorDockedLeft","paperAnchorDockedRight","paperAnchorDockedTop","paperAnchorDockedBottom","modal"]);const Yz=["BackdropProps"],Zz=["anchor","BackdropProps","children","className","elevation","hideBackdrop","ModalProps","onClose","open","PaperProps","SlideProps","TransitionComponent","transitionDuration","variant"],Xz=(e,t)=>{const{ownerState:r}=e;return[t.root,("permanent"===r.variant||"persistent"===r.variant)&&t.docked,t.modal]},Jz=Vi(kh,{name:"MuiDrawer",slot:"Root",overridesResolver:Xz})(({theme:e})=>({zIndex:(e.vars||e).zIndex.drawer})),Qz=Vi("div",{shouldForwardProp:zi,name:"MuiDrawer",slot:"Docked",skipVariantsResolver:!1,overridesResolver:Xz})({flex:"0 0 auto"}),eV=Vi(sa,{name:"MuiDrawer",slot:"Paper",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.paper,t[`paperAnchor${Zi(r.anchor)}`],"temporary"!==r.variant&&t[`paperAnchorDocked${Zi(r.anchor)}`]]}})(({theme:e,ownerState:t})=>a({overflowY:"auto",display:"flex",flexDirection:"column",height:"100%",flex:"1 0 auto",zIndex:(e.vars||e).zIndex.drawer,WebkitOverflowScrolling:"touch",position:"fixed",top:0,outline:0},"left"===t.anchor&&{left:0},"top"===t.anchor&&{top:0,left:0,right:0,height:"auto",maxHeight:"100%"},"right"===t.anchor&&{right:0},"bottom"===t.anchor&&{top:"auto",left:0,bottom:0,right:0,height:"auto",maxHeight:"100%"},"left"===t.anchor&&"temporary"!==t.variant&&{borderRight:`1px solid ${(e.vars||e).palette.divider}`},"top"===t.anchor&&"temporary"!==t.variant&&{borderBottom:`1px solid ${(e.vars||e).palette.divider}`},"right"===t.anchor&&"temporary"!==t.variant&&{borderLeft:`1px solid ${(e.vars||e).palette.divider}`},"bottom"===t.anchor&&"temporary"!==t.variant&&{borderTop:`1px solid ${(e.vars||e).palette.divider}`})),tV={left:"right",right:"left",top:"down",bottom:"up"},rV=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiDrawer"}),i=ea(),l=Vs(),c={enter:i.transitions.duration.enteringScreen,exit:i.transitions.duration.leavingScreen},{anchor:u="left",BackdropProps:p,children:d,className:f,elevation:h=16,hideBackdrop:m=!1,ModalProps:{BackdropProps:g}={},onClose:v,open:y=!1,PaperProps:b={},SlideProps:w,TransitionComponent:x=Gz,transitionDuration:_=c,variant:S="temporary"}=n,k=s(n.ModalProps,Yz),C=s(n,Zz),O=o.useRef(!1);o.useEffect(()=>{O.current=!0},[]);const E=function({direction:e},t){return"rtl"===e&&function(e){return-1!==["left","right"].indexOf(e)}(t)?tV[t]:t}({direction:l?"rtl":"ltr"},u),T=a({},n,{anchor:u,elevation:h,open:y,variant:S},C),R=(e=>{const{classes:t,anchor:r,variant:n}=e;return U({root:["root"],docked:[("permanent"===n||"persistent"===n)&&"docked"],modal:["modal"],paper:["paper",`paperAnchor${Zi(r)}`,"temporary"!==n&&`paperAnchorDocked${Zi(r)}`]},Kz,t)})(T),I=e.jsx(eV,a({elevation:"temporary"===S?h:0,square:!0},b,{className:V(R.paper,b.className),ownerState:T,children:d}));if("permanent"===S)return e.jsx(Qz,a({className:V(R.root,R.docked,f),ownerState:T,ref:r},C,{children:I}));const M=e.jsx(x,a({in:y,direction:tV[E],timeout:_,appear:O.current},w,{children:I}));return"persistent"===S?e.jsx(Qz,a({className:V(R.root,R.docked,f),ownerState:T,ref:r},C,{children:M})):e.jsx(Jz,a({BackdropProps:a({},p,g,{transitionDuration:_}),className:V(R.root,R.modal,f),open:y,ownerState:T,onClose:v,hideBackdrop:m,ref:r},C,k,{children:M}))}); true&&(rV.propTypes={anchor:B.oneOf(["bottom","left","right","top"]),BackdropProps:B.object,children:B.node,classes:B.object,className:B.string,elevation:ts,hideBackdrop:B.bool,ModalProps:B.object,onClose:B.func,open:B.bool,PaperProps:B.object,SlideProps:B.object,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),transitionDuration:B.oneOfType([B.number,B.shape({appear:B.number,enter:B.number,exit:B.number})]),variant:B.oneOf(["permanent","persistent","temporary"])});const nV=rV;var oV=t.forwardRef((e,r)=>t.createElement(nV,{...e,ref:r}));const iV=ta("MuiBox",["root"]),sV=Di(),aV=function(t={}){const{themeId:r,defaultTheme:n,defaultClassName:i="MuiBox-root",generateClassName:l}=t,c=jr("div",{shouldForwardProp:e=>"theme"!==e&&"sx"!==e&&"as"!==e})(fo);return o.forwardRef(function(t,o){const u=Gi(n),p=bo(t),{className:d,component:f="div"}=p,h=s(p,cs);return e.jsx(c,a({as:f,ref:o,className:ls(d,l?l(i):i),theme:r&&u[r]||u},h))})}({themeId:$i,defaultTheme:sV,defaultClassName:iV.root,generateClassName:Ro.generate}); true&&(aV.propTypes={children:B.node,component:B.elementType,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const lV=aV;var cV=t.forwardRef((e,r)=>t.createElement(lV,{...e,ref:r}));const uV=()=>e.jsx(ya,{children:new Array(3).fill(0).map((t,r)=>e.jsxs(cV,{children:[e.jsxs(ya,{gap:.5,sx:{mt:2},children:[e.jsx(kz,{variant:"text",width:50,height:24}),e.jsx(kz,{variant:"text",width:"100%",height:48}),e.jsx(kz,{variant:"rectangular",width:"100%",height:200,sx:{borderRadius:1}}),e.jsx(kz,{variant:"rounded",width:100,height:32,sx:{borderRadius:3,mt:1}}),e.jsx(kz,{variant:"text",width:200,height:24}),e.jsx(kz,{variant:"text",width:250,height:24}),e.jsx(kz,{variant:"text",width:170,height:24})]}),r<2&&e.jsx(ju,{sx:{mt:1.5}})]},r))});var pV,dV={},fV={},hV={},mV={},gV={},vV={};function yV(){return pV||(pV=1,function(e){var t;Object.defineProperty(e,"__esModule",{value:!0}),e.Doctype=e.CDATA=e.Tag=e.Style=e.Script=e.Comment=e.Directive=e.Text=e.Root=e.isTag=e.ElementType=void 0,function(e){e.Root="root",e.Text="text",e.Directive="directive",e.Comment="comment",e.Script="script",e.Style="style",e.Tag="tag",e.CDATA="cdata",e.Doctype="doctype"}(t=e.ElementType||(e.ElementType={})),e.isTag=function(e){return e.type===t.Tag||e.type===t.Script||e.type===t.Style},e.Root=t.Root,e.Text=t.Text,e.Directive=t.Directive,e.Comment=t.Comment,e.Script=t.Script,e.Style=t.Style,e.Tag=t.Tag,e.CDATA=t.CDATA,e.Doctype=t.Doctype}(vV)),vV}var bV,wV,xV={};function _V(){if(bV)return xV;bV=1;var e,t=xV&&xV.__extends||(e=function(t,r){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r])},e(t,r)},function(t,r){if("function"!=typeof r&&null!==r)throw new TypeError("Class extends value "+String(r)+" is not a constructor or null");function n(){this.constructor=t}e(t,r),t.prototype=null===r?Object.create(r):(n.prototype=r.prototype,new n)}),r=xV&&xV.__assign||function(){return r=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++)for(var o in t=arguments[r])Object.prototype.hasOwnProperty.call(t,o)&&(e[o]=t[o]);return e},r.apply(this,arguments)};Object.defineProperty(xV,"__esModule",{value:!0}),xV.cloneNode=xV.hasChildren=xV.isDocument=xV.isDirective=xV.isComment=xV.isText=xV.isCDATA=xV.isTag=xV.Element=xV.Document=xV.CDATA=xV.NodeWithChildren=xV.ProcessingInstruction=xV.Comment=xV.Text=xV.DataNode=xV.Node=void 0;var n=yV(),o=function(){function e(){this.parent=null,this.prev=null,this.next=null,this.startIndex=null,this.endIndex=null}return Object.defineProperty(e.prototype,"parentNode",{get:function(){return this.parent},set:function(e){this.parent=e},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"previousSibling",{get:function(){return this.prev},set:function(e){this.prev=e},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"nextSibling",{get:function(){return this.next},set:function(e){this.next=e},enumerable:!1,configurable:!0}),e.prototype.cloneNode=function(e){return void 0===e&&(e=!1),b(this,e)},e}();xV.Node=o;var i=function(e){function r(t){var r=e.call(this)||this;return r.data=t,r}return t(r,e),Object.defineProperty(r.prototype,"nodeValue",{get:function(){return this.data},set:function(e){this.data=e},enumerable:!1,configurable:!0}),r}(o);xV.DataNode=i;var s=function(e){function r(){var t=null!==e&&e.apply(this,arguments)||this;return t.type=n.ElementType.Text,t}return t(r,e),Object.defineProperty(r.prototype,"nodeType",{get:function(){return 3},enumerable:!1,configurable:!0}),r}(i);xV.Text=s;var a=function(e){function r(){var t=null!==e&&e.apply(this,arguments)||this;return t.type=n.ElementType.Comment,t}return t(r,e),Object.defineProperty(r.prototype,"nodeType",{get:function(){return 8},enumerable:!1,configurable:!0}),r}(i);xV.Comment=a;var l=function(e){function r(t,r){var o=e.call(this,r)||this;return o.name=t,o.type=n.ElementType.Directive,o}return t(r,e),Object.defineProperty(r.prototype,"nodeType",{get:function(){return 1},enumerable:!1,configurable:!0}),r}(i);xV.ProcessingInstruction=l;var c=function(e){function r(t){var r=e.call(this)||this;return r.children=t,r}return t(r,e),Object.defineProperty(r.prototype,"firstChild",{get:function(){var e;return null!==(e=this.children[0])&&void 0!==e?e:null},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"lastChild",{get:function(){return this.children.length>0?this.children[this.children.length-1]:null},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"childNodes",{get:function(){return this.children},set:function(e){this.children=e},enumerable:!1,configurable:!0}),r}(o);xV.NodeWithChildren=c;var u=function(e){function r(){var t=null!==e&&e.apply(this,arguments)||this;return t.type=n.ElementType.CDATA,t}return t(r,e),Object.defineProperty(r.prototype,"nodeType",{get:function(){return 4},enumerable:!1,configurable:!0}),r}(c);xV.CDATA=u;var p=function(e){function r(){var t=null!==e&&e.apply(this,arguments)||this;return t.type=n.ElementType.Root,t}return t(r,e),Object.defineProperty(r.prototype,"nodeType",{get:function(){return 9},enumerable:!1,configurable:!0}),r}(c);xV.Document=p;var d=function(e){function r(t,r,o,i){void 0===o&&(o=[]),void 0===i&&(i="script"===t?n.ElementType.Script:"style"===t?n.ElementType.Style:n.ElementType.Tag);var s=e.call(this,o)||this;return s.name=t,s.attribs=r,s.type=i,s}return t(r,e),Object.defineProperty(r.prototype,"nodeType",{get:function(){return 1},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"tagName",{get:function(){return this.name},set:function(e){this.name=e},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"attributes",{get:function(){var e=this;return Object.keys(this.attribs).map(function(t){var r,n;return{name:t,value:e.attribs[t],namespace:null===(r=e["x-attribsNamespace"])||void 0===r?void 0:r[t],prefix:null===(n=e["x-attribsPrefix"])||void 0===n?void 0:n[t]}})},enumerable:!1,configurable:!0}),r}(c);function f(e){return(0,n.isTag)(e)}function h(e){return e.type===n.ElementType.CDATA}function m(e){return e.type===n.ElementType.Text}function g(e){return e.type===n.ElementType.Comment}function v(e){return e.type===n.ElementType.Directive}function y(e){return e.type===n.ElementType.Root}function b(e,t){var n;if(void 0===t&&(t=!1),m(e))n=new s(e.data);else if(g(e))n=new a(e.data);else if(f(e)){var o=t?w(e.children):[],i=new d(e.name,r({},e.attribs),o);o.forEach(function(e){return e.parent=i}),null!=e.namespace&&(i.namespace=e.namespace),e["x-attribsNamespace"]&&(i["x-attribsNamespace"]=r({},e["x-attribsNamespace"])),e["x-attribsPrefix"]&&(i["x-attribsPrefix"]=r({},e["x-attribsPrefix"])),n=i}else if(h(e)){o=t?w(e.children):[];var c=new u(o);o.forEach(function(e){return e.parent=c}),n=c}else if(y(e)){o=t?w(e.children):[];var b=new p(o);o.forEach(function(e){return e.parent=b}),e["x-mode"]&&(b["x-mode"]=e["x-mode"]),n=b}else{if(!v(e))throw new Error("Not implemented yet: ".concat(e.type));var x=new l(e.name,e.data);null!=e["x-name"]&&(x["x-name"]=e["x-name"],x["x-publicId"]=e["x-publicId"],x["x-systemId"]=e["x-systemId"]),n=x}return n.startIndex=e.startIndex,n.endIndex=e.endIndex,null!=e.sourceCodeLocation&&(n.sourceCodeLocation=e.sourceCodeLocation),n}function w(e){for(var t=e.map(function(e){return b(e,!0)}),r=1;r<t.length;r++)t[r].prev=t[r-1],t[r-1].next=t[r];return t}return xV.Element=d,xV.isTag=f,xV.isCDATA=h,xV.isText=m,xV.isComment=g,xV.isDirective=v,xV.isDocument=y,xV.hasChildren=function(e){return Object.prototype.hasOwnProperty.call(e,"children")},xV.cloneNode=b,xV}function SV(){return wV||(wV=1,function(e){var t=gV&&gV.__createBinding||(Object.create?function(e,t,r,n){void 0===n&&(n=r);var o=Object.getOwnPropertyDescriptor(t,r);o&&!("get"in o?!t.__esModule:o.writable||o.configurable)||(o={enumerable:!0,get:function(){return t[r]}}),Object.defineProperty(e,n,o)}:function(e,t,r,n){void 0===n&&(n=r),e[n]=t[r]}),r=gV&&gV.__exportStar||function(e,r){for(var n in e)"default"===n||Object.prototype.hasOwnProperty.call(r,n)||t(r,e,n)};Object.defineProperty(e,"__esModule",{value:!0}),e.DomHandler=void 0;var n=yV(),o=_V();r(_V(),e);var i={withStartIndices:!1,withEndIndices:!1,xmlMode:!1},s=function(){function e(e,t,r){this.dom=[],this.root=new o.Document(this.dom),this.done=!1,this.tagStack=[this.root],this.lastNode=null,this.parser=null,"function"==typeof t&&(r=t,t=i),"object"==typeof e&&(t=e,e=void 0),this.callback=null!=e?e:null,this.options=null!=t?t:i,this.elementCB=null!=r?r:null}return e.prototype.onparserinit=function(e){this.parser=e},e.prototype.onreset=function(){this.dom=[],this.root=new o.Document(this.dom),this.done=!1,this.tagStack=[this.root],this.lastNode=null,this.parser=null},e.prototype.onend=function(){this.done||(this.done=!0,this.parser=null,this.handleCallback(null))},e.prototype.onerror=function(e){this.handleCallback(e)},e.prototype.onclosetag=function(){this.lastNode=null;var e=this.tagStack.pop();this.options.withEndIndices&&(e.endIndex=this.parser.endIndex),this.elementCB&&this.elementCB(e)},e.prototype.onopentag=function(e,t){var r=this.options.xmlMode?n.ElementType.Tag:void 0,i=new o.Element(e,t,void 0,r);this.addNode(i),this.tagStack.push(i)},e.prototype.ontext=function(e){var t=this.lastNode;if(t&&t.type===n.ElementType.Text)t.data+=e,this.options.withEndIndices&&(t.endIndex=this.parser.endIndex);else{var r=new o.Text(e);this.addNode(r),this.lastNode=r}},e.prototype.oncomment=function(e){if(this.lastNode&&this.lastNode.type===n.ElementType.Comment)this.lastNode.data+=e;else{var t=new o.Comment(e);this.addNode(t),this.lastNode=t}},e.prototype.oncommentend=function(){this.lastNode=null},e.prototype.oncdatastart=function(){var e=new o.Text(""),t=new o.CDATA([e]);this.addNode(t),e.parent=t,this.lastNode=e},e.prototype.oncdataend=function(){this.lastNode=null},e.prototype.onprocessinginstruction=function(e,t){var r=new o.ProcessingInstruction(e,t);this.addNode(r)},e.prototype.handleCallback=function(e){if("function"==typeof this.callback)this.callback(e,this.dom);else if(e)throw e},e.prototype.addNode=function(e){var t=this.tagStack[this.tagStack.length-1],r=t.children[t.children.length-1];this.options.withStartIndices&&(e.startIndex=this.parser.startIndex),this.options.withEndIndices&&(e.endIndex=this.parser.endIndex),t.children.push(e),r&&(e.prev=r,r.next=e),e.parent=t,this.lastNode=null},e}();e.DomHandler=s,e.default=s}(gV)),gV}var kV,CV,OV,EV,TV={};function RV(){return kV||(kV=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.CARRIAGE_RETURN_PLACEHOLDER_REGEX=e.CARRIAGE_RETURN_PLACEHOLDER=e.CARRIAGE_RETURN_REGEX=e.CARRIAGE_RETURN=e.CASE_SENSITIVE_TAG_NAMES_MAP=e.CASE_SENSITIVE_TAG_NAMES=void 0,e.CASE_SENSITIVE_TAG_NAMES=["animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","linearGradient","radialGradient","textPath"],e.CASE_SENSITIVE_TAG_NAMES_MAP=e.CASE_SENSITIVE_TAG_NAMES.reduce(function(e,t){return e[t.toLowerCase()]=t,e},{}),e.CARRIAGE_RETURN="\r",e.CARRIAGE_RETURN_REGEX=new RegExp(e.CARRIAGE_RETURN,"g"),e.CARRIAGE_RETURN_PLACEHOLDER="__HTML_DOM_PARSER_CARRIAGE_RETURN_PLACEHOLDER_".concat(Date.now(),"__"),e.CARRIAGE_RETURN_PLACEHOLDER_REGEX=new RegExp(e.CARRIAGE_RETURN_PLACEHOLDER,"g")}(TV)),TV}function IV(){if(CV)return mV;CV=1,Object.defineProperty(mV,"__esModule",{value:!0}),mV.formatAttributes=r,mV.escapeSpecialCharacters=function(e){return e.replace(t.CARRIAGE_RETURN_REGEX,t.CARRIAGE_RETURN_PLACEHOLDER)},mV.revertEscapedCharacters=o,mV.formatDOM=function t(i,s,a){void 0===s&&(s=null);for(var l,c=[],u=0,p=i.length;u<p;u++){var d=i[u];switch(d.nodeType){case 1:var f=n(d.nodeName);(l=new e.Element(f,r(d.attributes))).children=t("template"===f?d.content.childNodes:d.childNodes,l);break;case 3:l=new e.Text(o(d.nodeValue));break;case 8:l=new e.Comment(d.nodeValue);break;default:continue}var h=c[u-1]||null;h&&(h.next=l),l.parent=s,l.prev=h,l.next=null,c.push(l)}return a&&((l=new e.ProcessingInstruction(a.substring(0,a.indexOf(" ")).toLowerCase(),a)).next=c[0]||null,l.parent=s,c.unshift(l),c[1]&&(c[1].prev=c[0])),c};var e=SV(),t=RV();function r(e){for(var t={},r=0,n=e.length;r<n;r++){var o=e[r];t[o.name]=o.value}return t}function n(e){return function(e){return t.CASE_SENSITIVE_TAG_NAMES_MAP[e]}(e=e.toLowerCase())||e}function o(e){return e.replace(t.CARRIAGE_RETURN_PLACEHOLDER_REGEX,t.CARRIAGE_RETURN)}return mV}function MV(){if(OV)return hV;OV=1,Object.defineProperty(hV,"__esModule",{value:!0}),hV.default=function(c){var u,p,f=(c=(0,e.escapeSpecialCharacters)(c)).match(o),h=f&&f[1]?f[1].toLowerCase():"";switch(h){case t:var m=l(c);return i.test(c)||null===(u=null==(v=m.querySelector(r))?void 0:v.parentNode)||void 0===u||u.removeChild(v),s.test(c)||null===(p=null==(v=m.querySelector(n))?void 0:v.parentNode)||void 0===p||p.removeChild(v),m.querySelectorAll(t);case r:case n:var g=a(c).querySelectorAll(h);return s.test(c)&&i.test(c)?g[0].parentNode.childNodes:g;default:return d?d(c):(v=a(c,n).querySelector(n)).childNodes;// removed by dead control flow
 var v; }};var e=IV(),t="html",r="head",n="body",o=/<([a-zA-Z]+[0-9]?)/,i=/<head[^]*>/i,s=/<body[^]*>/i,a=function(e,t){throw new Error("This browser does not support `document.implementation.createHTMLDocument`")},l=function(e,t){throw new Error("This browser does not support `DOMParser.prototype.parseFromString`")},c="object"==typeof window&&window.DOMParser;if("function"==typeof c){var u=new c;a=l=function(e,t){return t&&(e="<".concat(t,">").concat(e,"</").concat(t,">")),u.parseFromString(e,"text/html")}}if("object"==typeof document&&document.implementation){var p=document.implementation.createHTMLDocument();a=function(e,t){if(t){var r=p.documentElement.querySelector(t);return r&&(r.innerHTML=e),p}return p.documentElement.innerHTML=e,p}}var d,f="object"==typeof document&&document.createElement("template");return f&&f.content&&(d=function(e){return f.innerHTML=e,f.content.childNodes}),hV}function AV(){if(EV)return fV;EV=1;var e=fV&&fV.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(fV,"__esModule",{value:!0}),fV.default=function(e){if("string"!=typeof e)throw new TypeError("First argument must be a string");if(!e)return[];var o=e.match(n),i=o?o[1]:void 0;return(0,r.formatDOM)((0,t.default)(e),null,i)};var t=e(MV()),r=IV(),n=/<(![a-zA-Z\s]+)>/;return fV}var PV,NV,jV={},LV={},DV={};function FV(){return PV||(PV=1,DV.SAME=0,DV.CAMELCASE=1,DV.possibleStandardNames={accept:0,acceptCharset:1,"accept-charset":"acceptCharset",accessKey:1,action:0,allowFullScreen:1,alt:0,as:0,async:0,autoCapitalize:1,autoComplete:1,autoCorrect:1,autoFocus:1,autoPlay:1,autoSave:1,capture:0,cellPadding:1,cellSpacing:1,challenge:0,charSet:1,checked:0,children:0,cite:0,class:"className",classID:1,className:1,cols:0,colSpan:1,content:0,contentEditable:1,contextMenu:1,controls:0,controlsList:1,coords:0,crossOrigin:1,dangerouslySetInnerHTML:1,data:0,dateTime:1,default:0,defaultChecked:1,defaultValue:1,defer:0,dir:0,disabled:0,disablePictureInPicture:1,disableRemotePlayback:1,download:0,draggable:0,encType:1,enterKeyHint:1,for:"htmlFor",form:0,formMethod:1,formAction:1,formEncType:1,formNoValidate:1,formTarget:1,frameBorder:1,headers:0,height:0,hidden:0,high:0,href:0,hrefLang:1,htmlFor:1,httpEquiv:1,"http-equiv":"httpEquiv",icon:0,id:0,innerHTML:1,inputMode:1,integrity:0,is:0,itemID:1,itemProp:1,itemRef:1,itemScope:1,itemType:1,keyParams:1,keyType:1,kind:0,label:0,lang:0,list:0,loop:0,low:0,manifest:0,marginWidth:1,marginHeight:1,max:0,maxLength:1,media:0,mediaGroup:1,method:0,min:0,minLength:1,multiple:0,muted:0,name:0,noModule:1,nonce:0,noValidate:1,open:0,optimum:0,pattern:0,placeholder:0,playsInline:1,poster:0,preload:0,profile:0,radioGroup:1,readOnly:1,referrerPolicy:1,rel:0,required:0,reversed:0,role:0,rows:0,rowSpan:1,sandbox:0,scope:0,scoped:0,scrolling:0,seamless:0,selected:0,shape:0,size:0,sizes:0,span:0,spellCheck:1,src:0,srcDoc:1,srcLang:1,srcSet:1,start:0,step:0,style:0,summary:0,tabIndex:1,target:0,title:0,type:0,useMap:1,value:0,width:0,wmode:0,wrap:0,about:0,accentHeight:1,"accent-height":"accentHeight",accumulate:0,additive:0,alignmentBaseline:1,"alignment-baseline":"alignmentBaseline",allowReorder:1,alphabetic:0,amplitude:0,arabicForm:1,"arabic-form":"arabicForm",ascent:0,attributeName:1,attributeType:1,autoReverse:1,azimuth:0,baseFrequency:1,baselineShift:1,"baseline-shift":"baselineShift",baseProfile:1,bbox:0,begin:0,bias:0,by:0,calcMode:1,capHeight:1,"cap-height":"capHeight",clip:0,clipPath:1,"clip-path":"clipPath",clipPathUnits:1,clipRule:1,"clip-rule":"clipRule",color:0,colorInterpolation:1,"color-interpolation":"colorInterpolation",colorInterpolationFilters:1,"color-interpolation-filters":"colorInterpolationFilters",colorProfile:1,"color-profile":"colorProfile",colorRendering:1,"color-rendering":"colorRendering",contentScriptType:1,contentStyleType:1,cursor:0,cx:0,cy:0,d:0,datatype:0,decelerate:0,descent:0,diffuseConstant:1,direction:0,display:0,divisor:0,dominantBaseline:1,"dominant-baseline":"dominantBaseline",dur:0,dx:0,dy:0,edgeMode:1,elevation:0,enableBackground:1,"enable-background":"enableBackground",end:0,exponent:0,externalResourcesRequired:1,fill:0,fillOpacity:1,"fill-opacity":"fillOpacity",fillRule:1,"fill-rule":"fillRule",filter:0,filterRes:1,filterUnits:1,floodOpacity:1,"flood-opacity":"floodOpacity",floodColor:1,"flood-color":"floodColor",focusable:0,fontFamily:1,"font-family":"fontFamily",fontSize:1,"font-size":"fontSize",fontSizeAdjust:1,"font-size-adjust":"fontSizeAdjust",fontStretch:1,"font-stretch":"fontStretch",fontStyle:1,"font-style":"fontStyle",fontVariant:1,"font-variant":"fontVariant",fontWeight:1,"font-weight":"fontWeight",format:0,from:0,fx:0,fy:0,g1:0,g2:0,glyphName:1,"glyph-name":"glyphName",glyphOrientationHorizontal:1,"glyph-orientation-horizontal":"glyphOrientationHorizontal",glyphOrientationVertical:1,"glyph-orientation-vertical":"glyphOrientationVertical",glyphRef:1,gradientTransform:1,gradientUnits:1,hanging:0,horizAdvX:1,"horiz-adv-x":"horizAdvX",horizOriginX:1,"horiz-origin-x":"horizOriginX",ideographic:0,imageRendering:1,"image-rendering":"imageRendering",in2:0,in:0,inlist:0,intercept:0,k1:0,k2:0,k3:0,k4:0,k:0,kernelMatrix:1,kernelUnitLength:1,kerning:0,keyPoints:1,keySplines:1,keyTimes:1,lengthAdjust:1,letterSpacing:1,"letter-spacing":"letterSpacing",lightingColor:1,"lighting-color":"lightingColor",limitingConeAngle:1,local:0,markerEnd:1,"marker-end":"markerEnd",markerHeight:1,markerMid:1,"marker-mid":"markerMid",markerStart:1,"marker-start":"markerStart",markerUnits:1,markerWidth:1,mask:0,maskContentUnits:1,maskUnits:1,mathematical:0,mode:0,numOctaves:1,offset:0,opacity:0,operator:0,order:0,orient:0,orientation:0,origin:0,overflow:0,overlinePosition:1,"overline-position":"overlinePosition",overlineThickness:1,"overline-thickness":"overlineThickness",paintOrder:1,"paint-order":"paintOrder",panose1:0,"panose-1":"panose1",pathLength:1,patternContentUnits:1,patternTransform:1,patternUnits:1,pointerEvents:1,"pointer-events":"pointerEvents",points:0,pointsAtX:1,pointsAtY:1,pointsAtZ:1,prefix:0,preserveAlpha:1,preserveAspectRatio:1,primitiveUnits:1,property:0,r:0,radius:0,refX:1,refY:1,renderingIntent:1,"rendering-intent":"renderingIntent",repeatCount:1,repeatDur:1,requiredExtensions:1,requiredFeatures:1,resource:0,restart:0,result:0,results:0,rotate:0,rx:0,ry:0,scale:0,security:0,seed:0,shapeRendering:1,"shape-rendering":"shapeRendering",slope:0,spacing:0,specularConstant:1,specularExponent:1,speed:0,spreadMethod:1,startOffset:1,stdDeviation:1,stemh:0,stemv:0,stitchTiles:1,stopColor:1,"stop-color":"stopColor",stopOpacity:1,"stop-opacity":"stopOpacity",strikethroughPosition:1,"strikethrough-position":"strikethroughPosition",strikethroughThickness:1,"strikethrough-thickness":"strikethroughThickness",string:0,stroke:0,strokeDasharray:1,"stroke-dasharray":"strokeDasharray",strokeDashoffset:1,"stroke-dashoffset":"strokeDashoffset",strokeLinecap:1,"stroke-linecap":"strokeLinecap",strokeLinejoin:1,"stroke-linejoin":"strokeLinejoin",strokeMiterlimit:1,"stroke-miterlimit":"strokeMiterlimit",strokeWidth:1,"stroke-width":"strokeWidth",strokeOpacity:1,"stroke-opacity":"strokeOpacity",suppressContentEditableWarning:1,suppressHydrationWarning:1,surfaceScale:1,systemLanguage:1,tableValues:1,targetX:1,targetY:1,textAnchor:1,"text-anchor":"textAnchor",textDecoration:1,"text-decoration":"textDecoration",textLength:1,textRendering:1,"text-rendering":"textRendering",to:0,transform:0,typeof:0,u1:0,u2:0,underlinePosition:1,"underline-position":"underlinePosition",underlineThickness:1,"underline-thickness":"underlineThickness",unicode:0,unicodeBidi:1,"unicode-bidi":"unicodeBidi",unicodeRange:1,"unicode-range":"unicodeRange",unitsPerEm:1,"units-per-em":"unitsPerEm",unselectable:0,vAlphabetic:1,"v-alphabetic":"vAlphabetic",values:0,vectorEffect:1,"vector-effect":"vectorEffect",version:0,vertAdvY:1,"vert-adv-y":"vertAdvY",vertOriginX:1,"vert-origin-x":"vertOriginX",vertOriginY:1,"vert-origin-y":"vertOriginY",vHanging:1,"v-hanging":"vHanging",vIdeographic:1,"v-ideographic":"vIdeographic",viewBox:1,viewTarget:1,visibility:0,vMathematical:1,"v-mathematical":"vMathematical",vocab:0,widths:0,wordSpacing:1,"word-spacing":"wordSpacing",writingMode:1,"writing-mode":"writingMode",x1:0,x2:0,x:0,xChannelSelector:1,xHeight:1,"x-height":"xHeight",xlinkActuate:1,"xlink:actuate":"xlinkActuate",xlinkArcrole:1,"xlink:arcrole":"xlinkArcrole",xlinkHref:1,"xlink:href":"xlinkHref",xlinkRole:1,"xlink:role":"xlinkRole",xlinkShow:1,"xlink:show":"xlinkShow",xlinkTitle:1,"xlink:title":"xlinkTitle",xlinkType:1,"xlink:type":"xlinkType",xmlBase:1,"xml:base":"xmlBase",xmlLang:1,"xml:lang":"xmlLang",xmlns:0,"xml:space":"xmlSpace",xmlnsXlink:1,"xmlns:xlink":"xmlnsXlink",xmlSpace:1,y1:0,y2:0,y:0,yChannelSelector:1,z:0,zoomAndPan:1}),DV}function $V(){if(NV)return LV;function e(e,t,r,n,o,i,s){this.acceptsBooleans=2===t||3===t||4===t,this.attributeName=n,this.attributeNamespace=o,this.mustUseProperty=r,this.propertyName=e,this.type=t,this.sanitizeURL=i,this.removeEmptyString=s}NV=1;const t={};["children","dangerouslySetInnerHTML","defaultValue","defaultChecked","innerHTML","suppressContentEditableWarning","suppressHydrationWarning","style"].forEach(r=>{t[r]=new e(r,0,!1,r,null,!1,!1)}),[["acceptCharset","accept-charset"],["className","class"],["htmlFor","for"],["httpEquiv","http-equiv"]].forEach(([r,n])=>{t[r]=new e(r,1,!1,n,null,!1,!1)}),["contentEditable","draggable","spellCheck","value"].forEach(r=>{t[r]=new e(r,2,!1,r.toLowerCase(),null,!1,!1)}),["autoReverse","externalResourcesRequired","focusable","preserveAlpha"].forEach(r=>{t[r]=new e(r,2,!1,r,null,!1,!1)}),["allowFullScreen","async","autoFocus","autoPlay","controls","default","defer","disabled","disablePictureInPicture","disableRemotePlayback","formNoValidate","hidden","loop","noModule","noValidate","open","playsInline","readOnly","required","reversed","scoped","seamless","itemScope"].forEach(r=>{t[r]=new e(r,3,!1,r.toLowerCase(),null,!1,!1)}),["checked","multiple","muted","selected"].forEach(r=>{t[r]=new e(r,3,!0,r,null,!1,!1)}),["capture","download"].forEach(r=>{t[r]=new e(r,4,!1,r,null,!1,!1)}),["cols","rows","size","span"].forEach(r=>{t[r]=new e(r,6,!1,r,null,!1,!1)}),["rowSpan","start"].forEach(r=>{t[r]=new e(r,5,!1,r.toLowerCase(),null,!1,!1)});const r=/[\-\:]([a-z])/g,n=e=>e[1].toUpperCase();["accent-height","alignment-baseline","arabic-form","baseline-shift","cap-height","clip-path","clip-rule","color-interpolation","color-interpolation-filters","color-profile","color-rendering","dominant-baseline","enable-background","fill-opacity","fill-rule","flood-color","flood-opacity","font-family","font-size","font-size-adjust","font-stretch","font-style","font-variant","font-weight","glyph-name","glyph-orientation-horizontal","glyph-orientation-vertical","horiz-adv-x","horiz-origin-x","image-rendering","letter-spacing","lighting-color","marker-end","marker-mid","marker-start","overline-position","overline-thickness","paint-order","panose-1","pointer-events","rendering-intent","shape-rendering","stop-color","stop-opacity","strikethrough-position","strikethrough-thickness","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","text-anchor","text-decoration","text-rendering","underline-position","underline-thickness","unicode-bidi","unicode-range","units-per-em","v-alphabetic","v-hanging","v-ideographic","v-mathematical","vector-effect","vert-adv-y","vert-origin-x","vert-origin-y","word-spacing","writing-mode","xmlns:xlink","x-height"].forEach(o=>{const i=o.replace(r,n);t[i]=new e(i,1,!1,o,null,!1,!1)}),["xlink:actuate","xlink:arcrole","xlink:role","xlink:show","xlink:title","xlink:type"].forEach(o=>{const i=o.replace(r,n);t[i]=new e(i,1,!1,o,"http://www.w3.org/1999/xlink",!1,!1)}),["xml:base","xml:lang","xml:space"].forEach(o=>{const i=o.replace(r,n);t[i]=new e(i,1,!1,o,"http://www.w3.org/XML/1998/namespace",!1,!1)}),["tabIndex","crossOrigin"].forEach(r=>{t[r]=new e(r,1,!1,r.toLowerCase(),null,!1,!1)}),t.xlinkHref=new e("xlinkHref",1,!1,"xlink:href","http://www.w3.org/1999/xlink",!0,!1),["src","href","action","formAction"].forEach(r=>{t[r]=new e(r,1,!1,r.toLowerCase(),null,!0,!0)});const{CAMELCASE:o,SAME:i,possibleStandardNames:s}=FV(),a=RegExp.prototype.test.bind(new RegExp("^(data|aria)-[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$")),l=Object.keys(s).reduce((e,t)=>{const r=s[t];return r===i?e[t]=t:r===o?e[t.toLowerCase()]=t:e[t]=r,e},{});return LV.BOOLEAN=3,LV.BOOLEANISH_STRING=2,LV.NUMERIC=5,LV.OVERLOADED_BOOLEAN=4,LV.POSITIVE_NUMERIC=6,LV.RESERVED=0,LV.STRING=1,LV.getPropertyInfo=function(e){return t.hasOwnProperty(e)?t[e]:null},LV.isCustomAttribute=a,LV.possibleStandardNames=l,LV}var BV,zV,VV,UV={},qV={};function WV(){if(zV)return BV;zV=1;var e=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,t=/\n/g,r=/^\s*/,n=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,o=/^:\s*/,i=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,s=/^[;\s]*/,a=/^\s+|\s+$/g,l="";function c(e){return e?e.replace(a,l):l}return BV=function(a,u){if("string"!=typeof a)throw new TypeError("First argument must be a string");if(!a)return[];u=u||{};var p=1,d=1;function f(e){var r=e.match(t);r&&(p+=r.length);var n=e.lastIndexOf("\n");d=~n?e.length-n:d+e.length}function h(){var e={line:p,column:d};return function(t){return t.position=new m(e),y(),t}}function m(e){this.start=e,this.end={line:p,column:d},this.source=u.source}function g(e){var t=new Error(u.source+":"+p+":"+d+": "+e);if(t.reason=e,t.filename=u.source,t.line=p,t.column=d,t.source=a,!u.silent)throw t}function v(e){var t=e.exec(a);if(t){var r=t[0];return f(r),a=a.slice(r.length),t}}function y(){v(r)}function b(e){var t;for(e=e||[];t=w();)!1!==t&&e.push(t);return e}function w(){var e=h();if("/"==a.charAt(0)&&"*"==a.charAt(1)){for(var t=2;l!=a.charAt(t)&&("*"!=a.charAt(t)||"/"!=a.charAt(t+1));)++t;if(t+=2,l===a.charAt(t-1))return g("End of comment missing");var r=a.slice(2,t-2);return d+=2,f(r),a=a.slice(t),d+=2,e({type:"comment",comment:r})}}function x(){var t=h(),r=v(n);if(r){if(w(),!v(o))return g("property missing ':'");var a=v(i),u=t({type:"declaration",property:c(r[0].replace(e,l)),value:a?c(a[0].replace(e,l)):l});return v(s),u}}return m.prototype.content=a,y(),function(){var e,t=[];for(b(t);e=x();)!1!==e&&(t.push(e),b(t));return t}()},BV}function HV(){if(VV)return qV;VV=1;var e=qV&&qV.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(qV,"__esModule",{value:!0}),qV.default=function(e,r){var n=null;if(!e||"string"!=typeof e)return n;var o=(0,t.default)(e),i="function"==typeof r;return o.forEach(function(e){if("declaration"===e.type){var t=e.property,o=e.value;i?r(t,o,e):o&&((n=n||{})[t]=o)}}),n};var t=e(WV());return qV}var GV,KV,YV,ZV,XV,JV={};function QV(){if(GV)return JV;GV=1,Object.defineProperty(JV,"__esModule",{value:!0}),JV.camelCase=void 0;var e=/^--[a-zA-Z0-9_-]+$/,t=/-([a-z])/g,r=/^[^-]+$/,n=/^-(webkit|moz|ms|o|khtml)-/,o=/^-(ms)-/,i=function(e,t){return t.toUpperCase()},s=function(e,t){return"".concat(t,"-")};return JV.camelCase=function(a,l){return void 0===l&&(l={}),function(t){return!t||r.test(t)||e.test(t)}(a)?a:(a=a.toLowerCase(),(a=l.reactCompat?a.replace(o,s):a.replace(n,s)).replace(t,i))},JV}function eU(){if(YV)return KV;YV=1;var e=(KV&&KV.__importDefault||function(e){return e&&e.__esModule?e:{default:e}})(HV()),t=QV();function r(r,n){var o={};return r&&"string"==typeof r?((0,e.default)(r,function(e,r){e&&r&&(o[(0,t.camelCase)(e,n)]=r)}),o):o}return r.default=r,KV=r}function tU(){return ZV||(ZV=1,function(e){var r=UV&&UV.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(e,"__esModule",{value:!0}),e.returnFirstArg=e.canTextBeChildOfNode=e.ELEMENTS_WITH_NO_TEXT_CHILDREN=e.PRESERVE_CUSTOM_ATTRIBUTES=void 0,e.isCustomComponent=function(e,t){return e.includes("-")?!i.has(e):Boolean(t&&"string"==typeof t.is)},e.setStyleProp=function(e,t){if("string"==typeof e)if(e.trim())try{t.style=(0,o.default)(e,s)}catch(e){t.style={}}else t.style={}};var n=t,o=r(eU()),i=new Set(["annotation-xml","color-profile","font-face","font-face-src","font-face-uri","font-face-format","font-face-name","missing-glyph"]),s={reactCompat:!0};e.PRESERVE_CUSTOM_ATTRIBUTES=Number(n.version.split(".")[0])>=16,e.ELEMENTS_WITH_NO_TEXT_CHILDREN=new Set(["tr","tbody","thead","tfoot","colgroup","table","head","html","frameset"]),e.canTextBeChildOfNode=function(t){return!e.ELEMENTS_WITH_NO_TEXT_CHILDREN.has(t.name)},e.returnFirstArg=function(e){return e}}(UV)),UV}function rU(){if(XV)return jV;XV=1,Object.defineProperty(jV,"__esModule",{value:!0}),jV.default=function(s,a){void 0===s&&(s={});var l={},c=Boolean(s.type&&o[s.type]);for(var u in s){var p=s[u];if((0,e.isCustomAttribute)(u))l[u]=p;else{var d=u.toLowerCase(),f=i(d);if(f){var h=(0,e.getPropertyInfo)(f);switch(r.includes(f)&&n.includes(a)&&!c&&(f=i("default"+d)),l[f]=p,h&&h.type){case e.BOOLEAN:l[f]=!0;break;case e.OVERLOADED_BOOLEAN:""===p&&(l[f]=!0)}}else t.PRESERVE_CUSTOM_ATTRIBUTES&&(l[u]=p)}}return(0,t.setStyleProp)(s.style,l),l};var e=$V(),t=tU(),r=["checked","value"],n=["input","select","textarea"],o={reset:!0,submit:!0};function i(t){return e.possibleStandardNames[t]}return jV}var nU,oU,iU={};function sU(){if(nU)return iU;nU=1;var e=iU&&iU.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(iU,"__esModule",{value:!0}),iU.default=function e(t,r){void 0===r&&(r={});for(var a=[],l="function"==typeof r.replace,c=r.transform||o.returnFirstArg,u=r.library||i,p=u.cloneElement,d=u.createElement,f=u.isValidElement,h=t.length,m=0;m<h;m++){var g=t[m];if(l){var v=r.replace(g,m);if(f(v)){h>1&&(v=p(v,{key:v.key||m})),a.push(c(v,g,m));continue}}if("text"!==g.type){var y=g,b={};s(y)?((0,o.setStyleProp)(y.attribs.style,y.attribs),b=y.attribs):y.attribs&&(b=(0,n.default)(y.attribs,y.name));var w=void 0;switch(g.type){case"script":case"style":g.children[0]&&(b.dangerouslySetInnerHTML={__html:g.children[0].data});break;case"tag":"textarea"===g.name&&g.children[0]?b.defaultValue=g.children[0].data:g.children&&g.children.length&&(w=e(g.children,r));break;default:continue}h>1&&(b.key=m),a.push(c(d(g.name,b,w),g,m))}else{var x=!g.data.trim().length;if(x&&g.parent&&!(0,o.canTextBeChildOfNode)(g.parent))continue;if(r.trim&&x)continue;a.push(c(g.data,g,m))}}return 1===a.length?a[0]:a};var r=t,n=e(rU()),o=tU(),i={cloneElement:r.cloneElement,createElement:r.createElement,isValidElement:r.isValidElement};function s(e){return o.PRESERVE_CUSTOM_ATTRIBUTES&&"tag"===e.type&&(0,o.isCustomComponent)(e.name,e.attribs)}return iU}function aU(){return oU||(oU=1,function(e){var t=dV&&dV.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(e,"__esModule",{value:!0}),e.htmlToDOM=e.domToReact=e.attributesToProps=e.Text=e.ProcessingInstruction=e.Element=e.Comment=void 0,e.default=function(e,t){if("string"!=typeof e)throw new TypeError("First argument must be a string");return e?(0,o.default)((0,r.default)(e,(null==t?void 0:t.htmlparser2)||s),t):[]};var r=t(AV());e.htmlToDOM=r.default;var n=t(rU());e.attributesToProps=n.default;var o=t(sU());e.domToReact=o.default;var i=SV();Object.defineProperty(e,"Comment",{enumerable:!0,get:function(){return i.Comment}}),Object.defineProperty(e,"Element",{enumerable:!0,get:function(){return i.Element}}),Object.defineProperty(e,"ProcessingInstruction",{enumerable:!0,get:function(){return i.ProcessingInstruction}}),Object.defineProperty(e,"Text",{enumerable:!0,get:function(){return i.Text}});var s={lowerCaseAttributeNames:!1}}(dV)),dV}const lU=l(aU()),cU=lU.default||lU,{slots:uU,classNames:pU}=tc("Image",["root"]),dU=sc("img",uU.root)(({theme:e,ownerState:t})=>{const{variant:r="square"}=t;return{borderRadius:{square:void 0,rounded:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[2],circle:"50%"}[r]}}),fU={variant:"square"},hU=t.forwardRef((e,r)=>{const n=Yi({props:{...fU,...e},name:uU.root.name});return t.createElement(dU,{...n,ref:r,className:V([[pU.root,n.className]]),ownerState:n})});hU.defaultProps=fU;var mU=hU;const gU=({id:r,title:n,description:o,topic:i,imageSrc:s,chipTags:a,link:l,readMoreText:c,cta:u,ctaLink:p,onItemClickedCallback:d})=>{const{t:f}=Bd("assets-whatsnew",{i18n:bm}),[h,m]=t.useState(!!s);t.useEffect(()=>{s&&m(!0)},[s]);const g=t.useMemo(()=>{const n=f(`${r}.description`,{defaultValue:o}),i=cU(n);return Array.isArray(i)?i.map((n,o)=>e.jsx(t.Fragment,{children:n},`${r}-description-${o}`)):i},[f,r,o]),v=t.useMemo(()=>{const e=`${r}.chipTags`;if(bm.exists(e,{ns:"assets-whatsnew"})){const t=f(e,{returnObjects:!0});if(Array.isArray(t)&&t.length>0)return t}return a},[f,r,a]),y=()=>{d?.()};return e.jsxs(cV,{marginTop:2,children:[i&&e.jsx(Na,{variant:"caption",color:"text.tertiary",children:f(`${r}.topic`,{defaultValue:i})}),e.jsx(Na,{variant:"subtitle1",color:"text.primary",children:f(`${r}.title`,{defaultValue:n})}),s&&e.jsxs(cV,{style:{marginBottom:16,position:"relative"},children:[h&&e.jsx(kz,{variant:"rectangular",width:"100%",height:200,sx:{borderRadius:1}}),e.jsx(mU,{src:s,alt:f(`${r}.title`,{defaultValue:n}),onLoad:()=>{m(!1)},onError:()=>{m(!1)},style:{width:"100%",height:"auto",display:h?"none":"block"}})]}),a&&v&&e.jsx(cV,{display:"flex",gap:1,flexWrap:"wrap",marginBottom:1,children:a.map((t,n)=>{const o=v[n]||t;return e.jsx(Fz,{variant:"outlined",label:o},`${r}-${t}`)})}),e.jsxs(Na,{variant:"body2",color:e=>e.palette.text.secondary,sx:{marginBottom:1},children:[g,c&&e.jsx("a",{href:l,target:"_blank",rel:"noreferrer",onClick:y,children:" "+f(`${r}.readMoreText`,{defaultValue:c})})]}),u&&e.jsx(wp,{variant:"contained",color:"promotion",href:p,target:"_blank",onClick:y,children:f(`${r}.cta`,{defaultValue:u})})]})};var vU=o.forwardRef((e,t)=>o.createElement(Cu,{viewBox:"0 0 24 24",...e,ref:t},o.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M11.9302 3.00684C12.3573 3.03542 12.7729 3.16362 13.1431 3.38184C13.5618 3.6287 13.9074 3.98244 14.1451 4.40625L21.2456 16.6562L21.2915 16.751C21.4597 17.1668 21.524 17.6183 21.4781 18.0645C21.432 18.5106 21.2773 18.9397 21.0279 19.3125C20.7784 19.685 20.4411 19.9915 20.0464 20.2041C19.6517 20.4166 19.2105 20.529 18.7622 20.5322L18.7564 20.5332H4.75638C4.73812 20.5332 4.71964 20.5316 4.7017 20.5303C4.69631 20.5307 4.69052 20.5319 4.6851 20.5322L4.60795 20.5312L4.44388 20.5186C4.06393 20.476 3.69614 20.3543 3.36478 20.1611C2.98591 19.9403 2.66472 19.6317 2.42924 19.2617C2.19395 18.8919 2.051 18.4707 2.01127 18.0342C1.97166 17.5975 2.03678 17.1563 2.2017 16.75L2.2476 16.6562L9.34721 4.40625C9.58473 3.98261 9.93165 3.62868 10.3501 3.38184C10.7731 3.13252 11.2556 3.00006 11.7466 3L11.9302 3.00684ZM11.7574 15.7822C11.2051 15.7822 10.7574 16.2299 10.7574 16.7822C10.7574 17.3345 11.2051 17.7822 11.7574 17.7822H11.7671L11.8697 17.7773C12.3737 17.7259 12.7671 17.2998 12.7671 16.7822C12.7671 16.2647 12.3737 15.8386 11.8697 15.7871L11.7671 15.7822H11.7574ZM11.7564 8.0332C11.3424 8.03352 11.0064 8.36919 11.0064 8.7832V13.7832C11.0069 14.1968 11.3428 14.5329 11.7564 14.5332C12.1702 14.5332 12.5059 14.1969 12.5064 13.7832V8.7832C12.5064 8.36902 12.1706 8.03325 11.7564 8.0332Z"})));const yU=({appSettings:t})=>{const{t:r}=Bd("common",{i18n:bm}),{data:n,isLoading:o,error:i}=(({appName:e,appVersion:t})=>Ay({queryKey:["notifications",e,t],queryFn:async()=>{const r=(await Ux.getNotifications(e,t)).filter((e,t,r)=>r.findIndex(t=>t.id===e.id)===t);return r},retry:!1}))({appName:t.slug,appVersion:t.version});return o?e.jsx(uV,{}):i?e.jsxs(ya,{sx:{height:"100%"},alignItems:"center",justifyContent:"center",children:[e.jsx(vU,{color:"error",fontSize:"large"}),e.jsx(Na,{variant:"subtitle2",color:"text.secondary",textAlign:"center",children:r("header.whatsNewError")})]}):n?.map((t,r)=>e.jsxs(cV,{"data-test":`whats-new-card-${r}`,children:[e.jsx(gU,{...t}),e.jsx(ju,{sx:{margin:"16px 0"}})]},t.id))};var bU=o.forwardRef((e,t)=>o.createElement(Cu,{viewBox:"0 0 24 24",...e,ref:t},o.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M18.5303 5.46967C18.8232 5.76256 18.8232 6.23744 18.5303 6.53033L6.53033 18.5303C6.23744 18.8232 5.76256 18.8232 5.46967 18.5303C5.17678 18.2374 5.17678 17.7626 5.46967 17.4697L17.4697 5.46967C17.7626 5.17678 18.2374 5.17678 18.5303 5.46967Z"}),o.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M5.46967 5.46967C5.76256 5.17678 6.23744 5.17678 6.53033 5.46967L18.5303 17.4697C18.8232 17.7626 18.8232 18.2374 18.5303 18.5303C18.2374 18.8232 17.7626 18.8232 17.4697 18.5303L5.46967 6.53033C5.17678 6.23744 5.17678 5.76256 5.46967 5.46967Z"})));const wU=({appSettings:t,onClose:r})=>{const{t:n}=Bd("common",{i18n:bm});return e.jsxs(e.Fragment,{children:[e.jsxs(cV,{sx:{display:"flex",alignItems:"center",justifyContent:"space-between"},children:[e.jsx(Na,{variant:"subtitle1",color:"primary.text",children:n("header.whatsNew")}),e.jsx(bu,{onClick:()=>{r()},"data-test":"service-banner-close",children:e.jsx(bU,{})})]}),e.jsx(yU,{appSettings:t})]})};function xU(e){return Yi}function _U(e){return Mo("MuiBadge",e)}const SU=ta("MuiBadge",["root","badge","dot","standard","anchorOriginTopRight","anchorOriginBottomRight","anchorOriginTopLeft","anchorOriginBottomLeft","invisible","colorError","colorInfo","colorPrimary","colorSecondary","colorSuccess","colorWarning","overlapRectangular","overlapCircular","anchorOriginTopLeftCircular","anchorOriginTopLeftRectangular","anchorOriginTopRightCircular","anchorOriginTopRightRectangular","anchorOriginBottomLeftCircular","anchorOriginBottomLeftRectangular","anchorOriginBottomRightCircular","anchorOriginBottomRightRectangular"]),kU=["anchorOrigin","className","classes","component","components","componentsProps","children","overlap","color","invisible","max","badgeContent","slots","slotProps","showZero","variant"],CU=xU(),OU=Vi("span",{name:"MuiBadge",slot:"Root",overridesResolver:(e,t)=>t.root})({position:"relative",display:"inline-flex",verticalAlign:"middle",flexShrink:0}),EU=Vi("span",{name:"MuiBadge",slot:"Badge",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.badge,t[r.variant],t[`anchorOrigin${Zi(r.anchorOrigin.vertical)}${Zi(r.anchorOrigin.horizontal)}${Zi(r.overlap)}`],"default"!==r.color&&t[`color${Zi(r.color)}`],r.invisible&&t.invisible]}})(({theme:e})=>{var t;return{display:"flex",flexDirection:"row",flexWrap:"wrap",justifyContent:"center",alignContent:"center",alignItems:"center",position:"absolute",boxSizing:"border-box",fontFamily:e.typography.fontFamily,fontWeight:e.typography.fontWeightMedium,fontSize:e.typography.pxToRem(12),minWidth:20,lineHeight:1,padding:"0 6px",height:20,borderRadius:10,zIndex:1,transition:e.transitions.create("transform",{easing:e.transitions.easing.easeInOut,duration:e.transitions.duration.enteringScreen}),variants:[...Object.keys((null!=(t=e.vars)?t:e).palette).filter(t=>{var r,n;return(null!=(r=e.vars)?r:e).palette[t].main&&(null!=(n=e.vars)?n:e).palette[t].contrastText}).map(t=>({props:{color:t},style:{backgroundColor:(e.vars||e).palette[t].main,color:(e.vars||e).palette[t].contrastText}})),{props:{variant:"dot"},style:{borderRadius:4,height:8,minWidth:8,padding:0}},{props:({ownerState:e})=>"top"===e.anchorOrigin.vertical&&"right"===e.anchorOrigin.horizontal&&"rectangular"===e.overlap,style:{top:0,right:0,transform:"scale(1) translate(50%, -50%)",transformOrigin:"100% 0%",[`&.${SU.invisible}`]:{transform:"scale(0) translate(50%, -50%)"}}},{props:({ownerState:e})=>"bottom"===e.anchorOrigin.vertical&&"right"===e.anchorOrigin.horizontal&&"rectangular"===e.overlap,style:{bottom:0,right:0,transform:"scale(1) translate(50%, 50%)",transformOrigin:"100% 100%",[`&.${SU.invisible}`]:{transform:"scale(0) translate(50%, 50%)"}}},{props:({ownerState:e})=>"top"===e.anchorOrigin.vertical&&"left"===e.anchorOrigin.horizontal&&"rectangular"===e.overlap,style:{top:0,left:0,transform:"scale(1) translate(-50%, -50%)",transformOrigin:"0% 0%",[`&.${SU.invisible}`]:{transform:"scale(0) translate(-50%, -50%)"}}},{props:({ownerState:e})=>"bottom"===e.anchorOrigin.vertical&&"left"===e.anchorOrigin.horizontal&&"rectangular"===e.overlap,style:{bottom:0,left:0,transform:"scale(1) translate(-50%, 50%)",transformOrigin:"0% 100%",[`&.${SU.invisible}`]:{transform:"scale(0) translate(-50%, 50%)"}}},{props:({ownerState:e})=>"top"===e.anchorOrigin.vertical&&"right"===e.anchorOrigin.horizontal&&"circular"===e.overlap,style:{top:"14%",right:"14%",transform:"scale(1) translate(50%, -50%)",transformOrigin:"100% 0%",[`&.${SU.invisible}`]:{transform:"scale(0) translate(50%, -50%)"}}},{props:({ownerState:e})=>"bottom"===e.anchorOrigin.vertical&&"right"===e.anchorOrigin.horizontal&&"circular"===e.overlap,style:{bottom:"14%",right:"14%",transform:"scale(1) translate(50%, 50%)",transformOrigin:"100% 100%",[`&.${SU.invisible}`]:{transform:"scale(0) translate(50%, 50%)"}}},{props:({ownerState:e})=>"top"===e.anchorOrigin.vertical&&"left"===e.anchorOrigin.horizontal&&"circular"===e.overlap,style:{top:"14%",left:"14%",transform:"scale(1) translate(-50%, -50%)",transformOrigin:"0% 0%",[`&.${SU.invisible}`]:{transform:"scale(0) translate(-50%, -50%)"}}},{props:({ownerState:e})=>"bottom"===e.anchorOrigin.vertical&&"left"===e.anchorOrigin.horizontal&&"circular"===e.overlap,style:{bottom:"14%",left:"14%",transform:"scale(1) translate(-50%, 50%)",transformOrigin:"0% 100%",[`&.${SU.invisible}`]:{transform:"scale(0) translate(-50%, 50%)"}}},{props:{invisible:!0},style:{transition:e.transitions.create("transform",{easing:e.transitions.easing.easeInOut,duration:e.transitions.duration.leavingScreen})}}]}}),TU=o.forwardRef(function(t,r){var n,o,i,l,c,u;const p=CU({props:t,name:"MuiBadge"}),{anchorOrigin:d={vertical:"top",horizontal:"right"},className:f,component:h,components:m={},componentsProps:g={},children:v,overlap:y="rectangular",color:b="default",invisible:w=!1,max:x=99,badgeContent:_,slots:S,slotProps:k,showZero:C=!1,variant:O="standard"}=p,E=s(p,kU),{badgeContent:T,invisible:R,max:I,displayValue:M}=function(e){const{badgeContent:t,invisible:r=!1,max:n=99,showZero:o=!1}=e,i=Tf({badgeContent:t,max:n});let s=r;!1!==r||0!==t||o||(s=!0);const{badgeContent:a,max:l=n}=s?i:e;return{badgeContent:a,invisible:s,max:l,displayValue:a&&Number(a)>l?`${l}+`:a}}({max:x,invisible:w,badgeContent:_,showZero:C}),A=Tf({anchorOrigin:d,color:b,overlap:y,variant:O,badgeContent:_}),P=R||null==T&&"dot"!==O,{color:N=b,overlap:j=y,anchorOrigin:L=d,variant:D=O}=P?A:p,F="dot"!==D?M:void 0,$=a({},p,{badgeContent:T,invisible:P,max:I,displayValue:F,showZero:C,anchorOrigin:L,color:N,overlap:j,variant:D}),B=(e=>{const{color:t,anchorOrigin:r,invisible:n,overlap:o,variant:i,classes:s={}}=e;return U({root:["root"],badge:["badge",i,n&&"invisible",`anchorOrigin${Zi(r.vertical)}${Zi(r.horizontal)}`,`anchorOrigin${Zi(r.vertical)}${Zi(r.horizontal)}${Zi(o)}`,`overlap${Zi(o)}`,"default"!==t&&`color${Zi(t)}`]},_U,s)})($),z=null!=(n=null!=(o=null==S?void 0:S.root)?o:m.Root)?n:OU,q=null!=(i=null!=(l=null==S?void 0:S.badge)?l:m.Badge)?i:EU,W=null!=(c=null==k?void 0:k.root)?c:g.root,H=null!=(u=null==k?void 0:k.badge)?u:g.badge,G=Af({elementType:z,externalSlotProps:W,externalForwardedProps:E,additionalProps:{ref:r,as:h},ownerState:$,className:V(null==W?void 0:W.className,B.root,f)}),K=Af({elementType:q,externalSlotProps:H,ownerState:$,className:V(B.badge,null==H?void 0:H.className)});return e.jsxs(z,a({},G,{children:[v,e.jsx(q,a({},K,{children:F}))]}))}); true&&(TU.propTypes={anchorOrigin:B.shape({horizontal:B.oneOf(["left","right"]).isRequired,vertical:B.oneOf(["bottom","top"]).isRequired}),badgeContent:B.node,children:B.node,classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["default","primary","secondary","error","info","success","warning"]),B.string]),component:B.elementType,components:B.shape({Badge:B.elementType,Root:B.elementType}),componentsProps:B.shape({badge:B.oneOfType([B.func,B.object]),root:B.oneOfType([B.func,B.object])}),invisible:B.bool,max:B.number,overlap:B.oneOf(["circular","rectangular"]),showZero:B.bool,slotProps:B.shape({badge:B.oneOfType([B.func,B.object]),root:B.oneOfType([B.func,B.object])}),slots:B.shape({badge:B.elementType,root:B.elementType}),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),variant:B.oneOfType([B.oneOf(["dot","standard"]),B.string])});const RU=TU;var IU=t.forwardRef((e,r)=>t.createElement(RU,{...e,ref:r}));const MU=({appSettings:r,containerSx:n={},notificationsApiUrl:o,onClick:i})=>{Bd("assets-whatsnew",{i18n:bm});const[s,a]=t.useState(!1),[l,c]=t.useState(!1),u=()=>{a(!1)};return e.jsxs(e.Fragment,{children:[e.jsx(IU,{color:"primary",overlap:"circular",badgeContent:"",invisible:l,variant:"dot",children:e.jsx(bu,{onClick:()=>{i(),s||l||c(!0),a(!s)},"data-test":"whats-new-button",size:"small",children:e.jsx(Vz,{fontSize:"small"})})}),e.jsx(vu,{colorScheme:"light",children:e.jsx(oV,{variant:"temporary",open:s,disableScrollLock:!0,anchor:"right",onClose:u,sx:n,disableEnforceFocus:!0,children:e.jsx(wU,{appSettings:r,onClose:u,notificationsApiUrl:o})})})]})};var AU=e=>"checkbox"===e.type,PU=e=>e instanceof Date,NU=e=>null==e;const jU=e=>"object"==typeof e;var LU=e=>!NU(e)&&!Array.isArray(e)&&jU(e)&&!PU(e),DU=e=>LU(e)&&e.target?AU(e.target)?e.target.checked:e.target.value:e,FU=(e,t)=>e.has((e=>e.substring(0,e.search(/\.\d+(\.|$)/))||e)(t)),$U="undefined"!=typeof window&&void 0!==window.HTMLElement&&"undefined"!=typeof document;function BU(e){let t;const r=Array.isArray(e),n="undefined"!=typeof FileList&&e instanceof FileList;if(e instanceof Date)t=new Date(e);else{if($U&&(e instanceof Blob||n)||!r&&!LU(e))return e;if(t=r?[]:Object.create(Object.getPrototypeOf(e)),r||(e=>{const t=e.constructor&&e.constructor.prototype;return LU(t)&&t.hasOwnProperty("isPrototypeOf")})(e))for(const r in e)e.hasOwnProperty(r)&&(t[r]=BU(e[r]));else t=e}return t}var zU=e=>/^\w*$/.test(e),VU=e=>void 0===e,UU=e=>Array.isArray(e)?e.filter(Boolean):[],qU=e=>UU(e.replace(/["|']|\]/g,"").split(/\.|\[/)),WU=(e,t,r)=>{if(!t||!LU(e))return r;const n=(zU(t)?[t]:qU(t)).reduce((e,t)=>NU(e)?e:e[t],e);return VU(n)||n===e?VU(e[t])?r:e[t]:n},HU=e=>"boolean"==typeof e,GU=(e,t,r)=>{let n=-1;const o=zU(t)?[t]:qU(t),i=o.length,s=i-1;for(;++n<i;){const t=o[n];let i=r;if(n!==s){const r=e[t];i=LU(r)||Array.isArray(r)?r:isNaN(+o[n+1])?{}:[]}if("__proto__"===t||"constructor"===t||"prototype"===t)return;e[t]=i,e=e[t]}};const KU="blur",YU="onChange",ZU="onSubmit",XU="all",JU="pattern",QU="required",eq=t.createContext(null);eq.displayName="HookFormContext";const tq=()=>t.useContext(eq);var rq=(e,t,r,n=!0)=>{const o={defaultValues:t._defaultValues};for(const i in e)Object.defineProperty(o,i,{get:()=>{const o=i;return t._proxyFormState[o]!==XU&&(t._proxyFormState[o]=!n||XU),r&&(r[o]=!0),e[o]}});return o};const nq="undefined"!=typeof window?t.useLayoutEffect:t.useEffect;var oq=e=>"string"==typeof e,iq=(e,t,r,n,o)=>oq(e)?(n&&t.watch.add(e),WU(r,e,o)):Array.isArray(e)?e.map(e=>(n&&t.watch.add(e),WU(r,e))):(n&&(t.watchAll=!0),r),sq=e=>NU(e)||!jU(e);function aq(e,t,r=new WeakSet){if(sq(e)||sq(t))return e===t;if(PU(e)&&PU(t))return e.getTime()===t.getTime();const n=Object.keys(e),o=Object.keys(t);if(n.length!==o.length)return!1;if(r.has(e)||r.has(t))return!0;r.add(e),r.add(t);for(const i of n){const n=e[i];if(!o.includes(i))return!1;if("ref"!==i){const e=t[i];if(PU(n)&&PU(e)||LU(n)&&LU(e)||Array.isArray(n)&&Array.isArray(e)?!aq(n,e,r):n!==e)return!1}}return!0}const lq=e=>e.render(function(e){const r=tq(),{name:n,disabled:o,control:i=r.control,shouldUnregister:s,defaultValue:a}=e,l=FU(i._names.array,n),c=t.useMemo(()=>WU(i._formValues,n,WU(i._defaultValues,n,a)),[i,n,a]),u=function(e){const r=tq(),{control:n=r.control,name:o,defaultValue:i,disabled:s,exact:a,compute:l}=e||{},c=t.useRef(i),u=t.useRef(l),p=t.useRef(void 0);u.current=l;const d=t.useMemo(()=>n._getWatch(o,c.current),[n,o]),[f,h]=t.useState(u.current?u.current(d):d);return nq(()=>n._subscribe({name:o,formState:{values:!0},exact:a,callback:e=>{if(!s){const t=iq(o,n._names,e.values||n._formValues,!1,c.current);if(u.current){const e=u.current(t);aq(e,p.current)||(h(e),p.current=e)}else h(t)}}}),[n,s,o,a]),t.useEffect(()=>n._removeUnmounted()),f}({control:i,name:n,defaultValue:c,exact:!0}),p=function(e){const r=tq(),{control:n=r.control,disabled:o,name:i,exact:s}=e||{},[a,l]=t.useState(n._formState),c=t.useRef({isDirty:!1,isLoading:!1,dirtyFields:!1,touchedFields:!1,validatingFields:!1,isValidating:!1,isValid:!1,errors:!1});return nq(()=>n._subscribe({name:i,formState:c.current,exact:s,callback:e=>{!o&&l({...n._formState,...e})}}),[i,o,s]),t.useEffect(()=>{c.current.isValid&&n._setValid(!0)},[n]),t.useMemo(()=>rq(a,n,c.current,!1),[a,n])}({control:i,name:n,exact:!0}),d=t.useRef(e),f=t.useRef(i.register(n,{...e.rules,value:u,...HU(e.disabled)?{disabled:e.disabled}:{}}));d.current=e;const h=t.useMemo(()=>Object.defineProperties({},{invalid:{enumerable:!0,get:()=>!!WU(p.errors,n)},isDirty:{enumerable:!0,get:()=>!!WU(p.dirtyFields,n)},isTouched:{enumerable:!0,get:()=>!!WU(p.touchedFields,n)},isValidating:{enumerable:!0,get:()=>!!WU(p.validatingFields,n)},error:{enumerable:!0,get:()=>WU(p.errors,n)}}),[p,n]),m=t.useCallback(e=>f.current.onChange({target:{value:DU(e),name:n},type:"change"}),[n]),g=t.useCallback(()=>f.current.onBlur({target:{value:WU(i._formValues,n),name:n},type:KU}),[n,i._formValues]),v=t.useCallback(e=>{const t=WU(i._fields,n);t&&e&&(t._f.ref={focus:()=>e.focus&&e.focus(),select:()=>e.select&&e.select(),setCustomValidity:t=>e.setCustomValidity(t),reportValidity:()=>e.reportValidity()})},[i._fields,n]),y=t.useMemo(()=>({name:n,value:u,...HU(o)||p.disabled?{disabled:p.disabled||o}:{},onChange:m,onBlur:g,ref:v}),[n,o,p.disabled,m,g,v,u]);return t.useEffect(()=>{const e=i._options.shouldUnregister||s;i.register(n,{...d.current.rules,...HU(d.current.disabled)?{disabled:d.current.disabled}:{}});const t=(e,t)=>{const r=WU(i._fields,e);r&&r._f&&(r._f.mount=t)};if(t(n,!0),e){const e=BU(WU(i._options.defaultValues,n));GU(i._defaultValues,n,e),VU(WU(i._formValues,n))&&GU(i._formValues,n,e)}return!l&&i.register(n),()=>{(l?e&&!i._state.action:e)?i.unregister(n):t(n,!1)}},[n,i,l,s]),t.useEffect(()=>{i._setDisabledField({disabled:o,name:n})},[o,n,i]),t.useMemo(()=>({field:y,formState:p,fieldState:h}),[y,p,h])}(e));var cq=(e,t,r,n,o)=>t?{...r[e],types:{...r[e]&&r[e].types?r[e].types:{},[n]:o||!0}}:{},uq=e=>Array.isArray(e)?e:[e],pq=()=>{let e=[];return{get observers(){return e},next:t=>{for(const r of e)r.next&&r.next(t)},subscribe:t=>(e.push(t),{unsubscribe:()=>{e=e.filter(e=>e!==t)}}),unsubscribe:()=>{e=[]}}},dq=e=>LU(e)&&!Object.keys(e).length,fq=e=>"file"===e.type,hq=e=>"function"==typeof e,mq=e=>{if(!$U)return!1;const t=e?e.ownerDocument:0;return e instanceof(t&&t.defaultView?t.defaultView.HTMLElement:HTMLElement)},gq=e=>"select-multiple"===e.type,vq=e=>"radio"===e.type,yq=e=>mq(e)&&e.isConnected;function bq(e,t){const r=Array.isArray(t)?t:zU(t)?[t]:qU(t),n=1===r.length?e:function(e,t){const r=t.slice(0,-1).length;let n=0;for(;n<r;)e=VU(e)?n++:e[t[n++]];return e}(e,r),o=r.length-1,i=r[o];return n&&delete n[i],0!==o&&(LU(n)&&dq(n)||Array.isArray(n)&&function(e){for(const t in e)if(e.hasOwnProperty(t)&&!VU(e[t]))return!1;return!0}(n))&&bq(e,r.slice(0,-1)),e}var wq=e=>{for(const t in e)if(hq(e[t]))return!0;return!1};function xq(e,t={}){const r=Array.isArray(e);if(LU(e)||r)for(const r in e)Array.isArray(e[r])||LU(e[r])&&!wq(e[r])?(t[r]=Array.isArray(e[r])?[]:{},xq(e[r],t[r])):NU(e[r])||(t[r]=!0);return t}function _q(e,t,r){const n=Array.isArray(e);if(LU(e)||n)for(const n in e)Array.isArray(e[n])||LU(e[n])&&!wq(e[n])?VU(t)||sq(r[n])?r[n]=Array.isArray(e[n])?xq(e[n],[]):{...xq(e[n])}:_q(e[n],NU(t)?{}:t[n],r[n]):r[n]=!aq(e[n],t[n]);return r}var Sq=(e,t)=>_q(e,t,xq(t));const kq={value:!1,isValid:!1},Cq={value:!0,isValid:!0};var Oq=e=>{if(Array.isArray(e)){if(e.length>1){const t=e.filter(e=>e&&e.checked&&!e.disabled).map(e=>e.value);return{value:t,isValid:!!t.length}}return e[0].checked&&!e[0].disabled?e[0].attributes&&!VU(e[0].attributes.value)?VU(e[0].value)||""===e[0].value?Cq:{value:e[0].value,isValid:!0}:Cq:kq}return kq},Eq=(e,{valueAsNumber:t,valueAsDate:r,setValueAs:n})=>VU(e)?e:t?""===e?NaN:e?+e:e:r&&oq(e)?new Date(e):n?n(e):e;const Tq={isValid:!1,value:null};var Rq=e=>Array.isArray(e)?e.reduce((e,t)=>t&&t.checked&&!t.disabled?{isValid:!0,value:t.value}:e,Tq):Tq;function Iq(e){const t=e.ref;return fq(t)?t.files:vq(t)?Rq(e.refs).value:gq(t)?[...t.selectedOptions].map(({value:e})=>e):AU(t)?Oq(e.refs).value:Eq(VU(t.value)?e.ref.value:t.value,e)}var Mq=e=>e instanceof RegExp,Aq=e=>VU(e)?e:Mq(e)?e.source:LU(e)?Mq(e.value)?e.value.source:e.value:e,Pq=e=>({isOnSubmit:!e||e===ZU,isOnBlur:"onBlur"===e,isOnChange:e===YU,isOnAll:e===XU,isOnTouch:"onTouched"===e});const Nq="AsyncFunction";var jq=e=>!!e&&!!e.validate&&!!(hq(e.validate)&&e.validate.constructor.name===Nq||LU(e.validate)&&Object.values(e.validate).find(e=>e.constructor.name===Nq)),Lq=(e,t,r)=>!r&&(t.watchAll||t.watch.has(e)||[...t.watch].some(t=>e.startsWith(t)&&/^\.\w+/.test(e.slice(t.length))));const Dq=(e,t,r,n)=>{for(const o of r||Object.keys(e)){const r=WU(e,o);if(r){const{_f:e,...i}=r;if(e){if(e.refs&&e.refs[0]&&t(e.refs[0],o)&&!n)return!0;if(e.ref&&t(e.ref,e.name)&&!n)return!0;if(Dq(i,t))break}else if(LU(i)&&Dq(i,t))break}}};function Fq(e,t,r){const n=WU(e,r);if(n||zU(r))return{error:n,name:r};const o=r.split(".");for(;o.length;){const n=o.join("."),i=WU(t,n),s=WU(e,n);if(i&&!Array.isArray(i)&&r!==n)return{name:r};if(s&&s.type)return{name:n,error:s};if(s&&s.root&&s.root.type)return{name:`${n}.root`,error:s.root};o.pop()}return{name:r}}var $q=(e,t,r)=>{const n=uq(WU(e,r));return GU(n,"root",t[r]),GU(e,r,n),e},Bq=e=>oq(e);function zq(e,t,r="validate"){if(Bq(e)||Array.isArray(e)&&e.every(Bq)||HU(e)&&!e)return{type:r,message:Bq(e)?e:"",ref:t}}var Vq=e=>LU(e)&&!Mq(e)?e:{value:e,message:""},Uq=async(e,t,r,n,o,i)=>{const{ref:s,refs:a,required:l,maxLength:c,minLength:u,min:p,max:d,pattern:f,validate:h,name:m,valueAsNumber:g,mount:v}=e._f,y=WU(r,m);if(!v||t.has(m))return{};const b=a?a[0]:s,w=e=>{o&&b.reportValidity&&(b.setCustomValidity(HU(e)?"":e||""),b.reportValidity())},x={},_=vq(s),S=AU(s),k=_||S,C=(g||fq(s))&&VU(s.value)&&VU(y)||mq(s)&&""===s.value||""===y||Array.isArray(y)&&!y.length,O=cq.bind(null,m,n,x),E=(e,t,r,n="maxLength",o="minLength")=>{const i=e?t:r;x[m]={type:e?n:o,message:i,ref:s,...O(e?n:o,i)}};if(i?!Array.isArray(y)||!y.length:l&&(!k&&(C||NU(y))||HU(y)&&!y||S&&!Oq(a).isValid||_&&!Rq(a).isValid)){const{value:e,message:t}=Bq(l)?{value:!!l,message:l}:Vq(l);if(e&&(x[m]={type:QU,message:t,ref:b,...O(QU,t)},!n))return w(t),x}if(!(C||NU(p)&&NU(d))){let e,t;const r=Vq(d),o=Vq(p);if(NU(y)||isNaN(y)){const n=s.valueAsDate||new Date(y),i=e=>new Date((new Date).toDateString()+" "+e),a="time"==s.type,l="week"==s.type;oq(r.value)&&y&&(e=a?i(y)>i(r.value):l?y>r.value:n>new Date(r.value)),oq(o.value)&&y&&(t=a?i(y)<i(o.value):l?y<o.value:n<new Date(o.value))}else{const n=s.valueAsNumber||(y?+y:y);NU(r.value)||(e=n>r.value),NU(o.value)||(t=n<o.value)}if((e||t)&&(E(!!e,r.message,o.message,"max","min"),!n))return w(x[m].message),x}if((c||u)&&!C&&(oq(y)||i&&Array.isArray(y))){const e=Vq(c),t=Vq(u),r=!NU(e.value)&&y.length>+e.value,o=!NU(t.value)&&y.length<+t.value;if((r||o)&&(E(r,e.message,t.message),!n))return w(x[m].message),x}if(f&&!C&&oq(y)){const{value:e,message:t}=Vq(f);if(Mq(e)&&!y.match(e)&&(x[m]={type:JU,message:t,ref:s,...O(JU,t)},!n))return w(t),x}if(h)if(hq(h)){const e=zq(await h(y,r),b);if(e&&(x[m]={...e,...O("validate",e.message)},!n))return w(e.message),x}else if(LU(h)){let e={};for(const t in h){if(!dq(e)&&!n)break;const o=zq(await h[t](y,r),b,t);o&&(e={...o,...O(t,o.message)},w(o.message),n&&(x[m]=e))}if(!dq(e)&&(x[m]={ref:b,...e},!n))return x}return w(!0),x};const qq={mode:ZU,reValidateMode:YU,shouldFocusError:!0};function Wq(e={}){let t,r={...qq,...e},n={submitCount:0,isDirty:!1,isReady:!1,isLoading:hq(r.defaultValues),isValidating:!1,isSubmitted:!1,isSubmitting:!1,isSubmitSuccessful:!1,isValid:!1,touchedFields:{},dirtyFields:{},validatingFields:{},errors:r.errors||{},disabled:r.disabled||!1},o={},i=(LU(r.defaultValues)||LU(r.values))&&BU(r.defaultValues||r.values)||{},s=r.shouldUnregister?{}:BU(i),a={action:!1,mount:!1,watch:!1},l={mount:new Set,disabled:new Set,unMount:new Set,array:new Set,watch:new Set},c=0;const u={isDirty:!1,dirtyFields:!1,validatingFields:!1,touchedFields:!1,isValidating:!1,isValid:!1,errors:!1};let p={...u};const d={array:pq(),state:pq()},f=r.criteriaMode===XU,h=async e=>{if(!r.disabled&&(u.isValid||p.isValid||e)){const e=r.resolver?dq((await y()).errors):await b(o,!0);e!==n.isValid&&d.state.next({isValid:e})}},m=(e,t)=>{!r.disabled&&(u.isValidating||u.validatingFields||p.isValidating||p.validatingFields)&&((e||Array.from(l.mount)).forEach(e=>{e&&(t?GU(n.validatingFields,e,t):bq(n.validatingFields,e))}),d.state.next({validatingFields:n.validatingFields,isValidating:!dq(n.validatingFields)}))},g=(e,t,r,n)=>{const l=WU(o,e);if(l){const o=WU(s,e,VU(r)?WU(i,e):r);VU(o)||n&&n.defaultChecked||t?GU(s,e,t?o:Iq(l._f)):_(e,o),a.mount&&h()}},v=(e,t,o,s,a)=>{let l=!1,c=!1;const f={name:e};if(!r.disabled){if(!o||s){(u.isDirty||p.isDirty)&&(c=n.isDirty,n.isDirty=f.isDirty=w(),l=c!==f.isDirty);const r=aq(WU(i,e),t);c=!!WU(n.dirtyFields,e),r?bq(n.dirtyFields,e):GU(n.dirtyFields,e,!0),f.dirtyFields=n.dirtyFields,l=l||(u.dirtyFields||p.dirtyFields)&&c!==!r}if(o){const t=WU(n.touchedFields,e);t||(GU(n.touchedFields,e,o),f.touchedFields=n.touchedFields,l=l||(u.touchedFields||p.touchedFields)&&t!==o)}l&&a&&d.state.next(f)}return l?f:{}},y=async e=>{m(e,!0);const t=await r.resolver(s,r.context,((e,t,r,n)=>{const o={};for(const r of e){const e=WU(t,r);e&&GU(o,r,e._f)}return{criteriaMode:r,names:[...e],fields:o,shouldUseNativeValidation:n}})(e||l.mount,o,r.criteriaMode,r.shouldUseNativeValidation));return m(e),t},b=async(e,t,o={valid:!0})=>{for(const i in e){const a=e[i];if(a){const{_f:e,...c}=a;if(e){const c=l.array.has(e.name),p=a._f&&jq(a._f);p&&u.validatingFields&&m([i],!0);const d=await Uq(a,l.disabled,s,f,r.shouldUseNativeValidation&&!t,c);if(p&&u.validatingFields&&m([i]),d[e.name]&&(o.valid=!1,t))break;!t&&(WU(d,e.name)?c?$q(n.errors,d,e.name):GU(n.errors,e.name,d[e.name]):bq(n.errors,e.name))}!dq(c)&&await b(c,t,o)}}return o.valid},w=(e,t)=>!r.disabled&&(e&&t&&GU(s,e,t),!aq(T(),i)),x=(e,t,r)=>iq(e,l,{...a.mount?s:VU(t)?i:oq(e)?{[e]:t}:t},r,t),_=(e,t,r={})=>{const n=WU(o,e);let i=t;if(n){const r=n._f;r&&(!r.disabled&&GU(s,e,Eq(t,r)),i=mq(r.ref)&&NU(t)?"":t,gq(r.ref)?[...r.ref.options].forEach(e=>e.selected=i.includes(e.value)):r.refs?AU(r.ref)?r.refs.forEach(e=>{e.defaultChecked&&e.disabled||(Array.isArray(i)?e.checked=!!i.find(t=>t===e.value):e.checked=i===e.value||!!i)}):r.refs.forEach(e=>e.checked=e.value===i):fq(r.ref)?r.ref.value="":(r.ref.value=i,r.ref.type||d.state.next({name:e,values:BU(s)})))}(r.shouldDirty||r.shouldTouch)&&v(e,i,r.shouldTouch,r.shouldDirty,!0),r.shouldValidate&&E(e)},S=(e,t,r)=>{for(const n in t){if(!t.hasOwnProperty(n))return;const i=t[n],s=e+"."+n,a=WU(o,s);(l.array.has(e)||LU(i)||a&&!a._f)&&!PU(i)?S(s,i,r):_(s,i,r)}},k=(e,t,r={})=>{const c=WU(o,e),f=l.array.has(e),h=BU(t);GU(s,e,h),f?(d.array.next({name:e,values:BU(s)}),(u.isDirty||u.dirtyFields||p.isDirty||p.dirtyFields)&&r.shouldDirty&&d.state.next({name:e,dirtyFields:Sq(i,s),isDirty:w(e,h)})):!c||c._f||NU(h)?_(e,h,r):S(e,h,r),Lq(e,l)&&d.state.next({...n,name:e}),d.state.next({name:a.mount?e:void 0,values:BU(s)})},C=async e=>{a.mount=!0;const i=e.target;let g=i.name,w=!0;const x=WU(o,g),_=e=>{w=Number.isNaN(e)||PU(e)&&isNaN(e.getTime())||aq(e,WU(s,g,e))},S=Pq(r.mode),k=Pq(r.reValidateMode);if(x){let a,O;const T=i.type?Iq(x._f):DU(e),R=e.type===KU||"focusout"===e.type,I=!((C=x._f).mount&&(C.required||C.min||C.max||C.maxLength||C.minLength||C.pattern||C.validate)||r.resolver||WU(n.errors,g)||x._f.deps)||((e,t,r,n,o)=>!o.isOnAll&&(!r&&o.isOnTouch?!(t||e):(r?n.isOnBlur:o.isOnBlur)?!e:!(r?n.isOnChange:o.isOnChange)||e))(R,WU(n.touchedFields,g),n.isSubmitted,k,S),M=Lq(g,l,R);GU(s,g,T),R?i&&i.readOnly||(x._f.onBlur&&x._f.onBlur(e),t&&t(0)):x._f.onChange&&x._f.onChange(e);const A=v(g,T,R),P=!dq(A)||M;if(!R&&d.state.next({name:g,type:e.type,values:BU(s)}),I)return(u.isValid||p.isValid)&&("onBlur"===r.mode?R&&h():R||h()),P&&d.state.next({name:g,...M?{}:A});if(!R&&M&&d.state.next({...n}),r.resolver){const{errors:e}=await y([g]);if(_(T),w){const t=Fq(n.errors,o,g),r=Fq(e,o,t.name||g);a=r.error,g=r.name,O=dq(e)}}else m([g],!0),a=(await Uq(x,l.disabled,s,f,r.shouldUseNativeValidation))[g],m([g]),_(T),w&&(a?O=!1:(u.isValid||p.isValid)&&(O=await b(o,!0)));w&&(x._f.deps&&E(x._f.deps),((e,o,i,s)=>{const a=WU(n.errors,e),l=(u.isValid||p.isValid)&&HU(o)&&n.isValid!==o;var f;if(r.delayError&&i?(f=()=>((e,t)=>{GU(n.errors,e,t),d.state.next({errors:n.errors})})(e,i),t=e=>{clearTimeout(c),c=setTimeout(f,e)},t(r.delayError)):(clearTimeout(c),t=null,i?GU(n.errors,e,i):bq(n.errors,e)),(i?!aq(a,i):a)||!dq(s)||l){const t={...s,...l&&HU(o)?{isValid:o}:{},errors:n.errors,name:e};n={...n,...t},d.state.next(t)}})(g,O,a,A))}var C},O=(e,t)=>{if(WU(n.errors,t)&&e.focus)return e.focus(),1},E=async(e,t={})=>{let i,s;const a=uq(e);if(r.resolver){const t=await(async e=>{const{errors:t}=await y(e);if(e)for(const r of e){const e=WU(t,r);e?GU(n.errors,r,e):bq(n.errors,r)}else n.errors=t;return t})(VU(e)?e:a);i=dq(t),s=e?!a.some(e=>WU(t,e)):i}else e?(s=(await Promise.all(a.map(async e=>{const t=WU(o,e);return await b(t&&t._f?{[e]:t}:t)}))).every(Boolean),(s||n.isValid)&&h()):s=i=await b(o);return d.state.next({...!oq(e)||(u.isValid||p.isValid)&&i!==n.isValid?{}:{name:e},...r.resolver||!e?{isValid:i}:{},errors:n.errors}),t.shouldFocus&&!s&&Dq(o,O,e?a:l.mount),s},T=e=>{const t={...a.mount?s:i};return VU(e)?t:oq(e)?WU(t,e):e.map(e=>WU(t,e))},R=(e,t)=>({invalid:!!WU((t||n).errors,e),isDirty:!!WU((t||n).dirtyFields,e),error:WU((t||n).errors,e),isValidating:!!WU(n.validatingFields,e),isTouched:!!WU((t||n).touchedFields,e)}),I=(e,t,r)=>{const i=(WU(o,e,{_f:{}})._f||{}).ref,s=WU(n.errors,e)||{},{ref:a,message:l,type:c,...u}=s;GU(n.errors,e,{...u,...t,ref:i}),d.state.next({name:e,errors:n.errors,isValid:!1}),r&&r.shouldFocus&&i&&i.focus&&i.focus()},M=e=>d.state.subscribe({next:t=>{var r,o,a;r=e.name,o=t.name,a=e.exact,r&&o&&r!==o&&!uq(r).some(e=>e&&(a?e===o:e.startsWith(o)||o.startsWith(e)))||!((e,t,r,n)=>{r(e);const{name:o,...i}=e;return dq(i)||Object.keys(i).length>=Object.keys(t).length||Object.keys(i).find(e=>t[e]===(!n||XU))})(t,e.formState||u,$,e.reRenderRoot)||e.callback({values:{...s},...n,...t,defaultValues:i})}}).unsubscribe,A=(e,t={})=>{for(const a of e?uq(e):l.mount)l.mount.delete(a),l.array.delete(a),t.keepValue||(bq(o,a),bq(s,a)),!t.keepError&&bq(n.errors,a),!t.keepDirty&&bq(n.dirtyFields,a),!t.keepTouched&&bq(n.touchedFields,a),!t.keepIsValidating&&bq(n.validatingFields,a),!r.shouldUnregister&&!t.keepDefaultValue&&bq(i,a);d.state.next({values:BU(s)}),d.state.next({...n,...t.keepDirty?{isDirty:w()}:{}}),!t.keepIsValid&&h()},P=({disabled:e,name:t})=>{(HU(e)&&a.mount||e||l.disabled.has(t))&&(e?l.disabled.add(t):l.disabled.delete(t))},N=(e,t={})=>{let n=WU(o,e);const s=HU(t.disabled)||HU(r.disabled);return GU(o,e,{...n||{},_f:{...n&&n._f?n._f:{ref:{name:e}},name:e,mount:!0,...t}}),l.mount.add(e),n?P({disabled:HU(t.disabled)?t.disabled:r.disabled,name:e}):g(e,!0,t.value),{...s?{disabled:t.disabled||r.disabled}:{},...r.progressive?{required:!!t.required,min:Aq(t.min),max:Aq(t.max),minLength:Aq(t.minLength),maxLength:Aq(t.maxLength),pattern:Aq(t.pattern)}:{},name:e,onChange:C,onBlur:C,ref:s=>{if(s){N(e,t),n=WU(o,e);const r=VU(s.value)&&s.querySelectorAll&&s.querySelectorAll("input,select,textarea")[0]||s,a=(e=>vq(e)||AU(e))(r),l=n._f.refs||[];if(a?l.find(e=>e===r):r===n._f.ref)return;GU(o,e,{_f:{...n._f,...a?{refs:[...l.filter(yq),r,...Array.isArray(WU(i,e))?[{}]:[]],ref:{type:r.type,name:e}}:{ref:r}}}),g(e,!1,void 0,r)}else n=WU(o,e,{}),n._f&&(n._f.mount=!1),(r.shouldUnregister||t.shouldUnregister)&&(!FU(l.array,e)||!a.action)&&l.unMount.add(e)}}},j=()=>r.shouldFocusError&&Dq(o,O,l.mount),L=(e,t)=>async i=>{let a;i&&(i.preventDefault&&i.preventDefault(),i.persist&&i.persist());let c=BU(s);if(d.state.next({isSubmitting:!0}),r.resolver){const{errors:e,values:t}=await y();n.errors=e,c=BU(t)}else await b(o);if(l.disabled.size)for(const e of l.disabled)bq(c,e);if(bq(n.errors,"root"),dq(n.errors)){d.state.next({errors:{}});try{await e(c,i)}catch(e){a=e}}else t&&await t({...n.errors},i),j(),setTimeout(j);if(d.state.next({isSubmitted:!0,isSubmitting:!1,isSubmitSuccessful:dq(n.errors)&&!a,submitCount:n.submitCount+1,errors:n.errors}),a)throw a},D=(e,t={})=>{const c=e?BU(e):i,p=BU(c),f=dq(e),h=f?i:p;if(t.keepDefaultValues||(i=c),!t.keepValues){if(t.keepDirtyValues){const e=new Set([...l.mount,...Object.keys(Sq(i,s))]);for(const t of Array.from(e))WU(n.dirtyFields,t)?GU(h,t,WU(s,t)):k(t,WU(h,t))}else{if($U&&VU(e))for(const e of l.mount){const t=WU(o,e);if(t&&t._f){const e=Array.isArray(t._f.refs)?t._f.refs[0]:t._f.ref;if(mq(e)){const t=e.closest("form");if(t){t.reset();break}}}}if(t.keepFieldsRef)for(const e of l.mount)k(e,WU(h,e));else o={}}s=r.shouldUnregister?t.keepDefaultValues?BU(i):{}:BU(h),d.array.next({values:{...h}}),d.state.next({values:{...h}})}l={mount:t.keepDirtyValues?l.mount:new Set,unMount:new Set,array:new Set,disabled:new Set,watch:new Set,watchAll:!1,focus:""},a.mount=!u.isValid||!!t.keepIsValid||!!t.keepDirtyValues,a.watch=!!r.shouldUnregister,d.state.next({submitCount:t.keepSubmitCount?n.submitCount:0,isDirty:!f&&(t.keepDirty?n.isDirty:!(!t.keepDefaultValues||aq(e,i))),isSubmitted:!!t.keepIsSubmitted&&n.isSubmitted,dirtyFields:f?{}:t.keepDirtyValues?t.keepDefaultValues&&s?Sq(i,s):n.dirtyFields:t.keepDefaultValues&&e?Sq(i,e):t.keepDirty?n.dirtyFields:{},touchedFields:t.keepTouched?n.touchedFields:{},errors:t.keepErrors?n.errors:{},isSubmitSuccessful:!!t.keepIsSubmitSuccessful&&n.isSubmitSuccessful,isSubmitting:!1,defaultValues:i})},F=(e,t)=>D(hq(e)?e(s):e,t),$=e=>{n={...n,...e}},B={control:{register:N,unregister:A,getFieldState:R,handleSubmit:L,setError:I,_subscribe:M,_runSchema:y,_focusError:j,_getWatch:x,_getDirty:w,_setValid:h,_setFieldArray:(e,t=[],l,c,f=!0,h=!0)=>{if(c&&l&&!r.disabled){if(a.action=!0,h&&Array.isArray(WU(o,e))){const t=l(WU(o,e),c.argA,c.argB);f&&GU(o,e,t)}if(h&&Array.isArray(WU(n.errors,e))){const t=l(WU(n.errors,e),c.argA,c.argB);f&&GU(n.errors,e,t),((e,t)=>{!UU(WU(e,t)).length&&bq(e,t)})(n.errors,e)}if((u.touchedFields||p.touchedFields)&&h&&Array.isArray(WU(n.touchedFields,e))){const t=l(WU(n.touchedFields,e),c.argA,c.argB);f&&GU(n.touchedFields,e,t)}(u.dirtyFields||p.dirtyFields)&&(n.dirtyFields=Sq(i,s)),d.state.next({name:e,isDirty:w(e,t),dirtyFields:n.dirtyFields,errors:n.errors,isValid:n.isValid})}else GU(s,e,t)},_setDisabledField:P,_setErrors:e=>{n.errors=e,d.state.next({errors:n.errors,isValid:!1})},_getFieldArray:e=>UU(WU(a.mount?s:i,e,r.shouldUnregister?WU(i,e,[]):[])),_reset:D,_resetDefaultValues:()=>hq(r.defaultValues)&&r.defaultValues().then(e=>{F(e,r.resetOptions),d.state.next({isLoading:!1})}),_removeUnmounted:()=>{for(const e of l.unMount){const t=WU(o,e);t&&(t._f.refs?t._f.refs.every(e=>!yq(e)):!yq(t._f.ref))&&A(e)}l.unMount=new Set},_disableForm:e=>{HU(e)&&(d.state.next({disabled:e}),Dq(o,(t,r)=>{const n=WU(o,r);n&&(t.disabled=n._f.disabled||e,Array.isArray(n._f.refs)&&n._f.refs.forEach(t=>{t.disabled=n._f.disabled||e}))},0,!1))},_subjects:d,_proxyFormState:u,get _fields(){return o},get _formValues(){return s},get _state(){return a},set _state(e){a=e},get _defaultValues(){return i},get _names(){return l},set _names(e){l=e},get _formState(){return n},get _options(){return r},set _options(e){r={...r,...e}}},subscribe:e=>(a.mount=!0,p={...p,...e.formState},M({...e,formState:p})),trigger:E,register:N,handleSubmit:L,watch:(e,t)=>hq(e)?d.state.subscribe({next:r=>"values"in r&&e(x(void 0,t),r)}):x(e,t,!0),setValue:k,getValues:T,reset:F,resetField:(e,t={})=>{WU(o,e)&&(VU(t.defaultValue)?k(e,BU(WU(i,e))):(k(e,t.defaultValue),GU(i,e,BU(t.defaultValue))),t.keepTouched||bq(n.touchedFields,e),t.keepDirty||(bq(n.dirtyFields,e),n.isDirty=t.defaultValue?w(e,BU(WU(i,e))):w()),t.keepError||(bq(n.errors,e),u.isValid&&h()),d.state.next({...n}))},clearErrors:e=>{e&&uq(e).forEach(e=>bq(n.errors,e)),d.state.next({errors:e?n.errors:{}})},unregister:A,setError:I,setFocus:(e,t={})=>{const r=WU(o,e),n=r&&r._f;if(n){const e=n.refs?n.refs[0]:n.ref;e.focus&&(e.focus(),t.shouldSelect&&hq(e.select)&&e.select())}},getFieldState:R};return{...B,formControl:B}}function Hq(e){return Mo("MuiDialog",e)}const Gq=ta("MuiDialog",["root","scrollPaper","scrollBody","container","paper","paperScrollPaper","paperScrollBody","paperWidthFalse","paperWidthXs","paperWidthSm","paperWidthMd","paperWidthLg","paperWidthXl","paperFullWidth","paperFullScreen"]),Kq=o.createContext({}); true&&(Kq.displayName="DialogContext");const Yq=Kq,Zq=["aria-describedby","aria-labelledby","BackdropComponent","BackdropProps","children","className","disableEscapeKeyDown","fullScreen","fullWidth","maxWidth","onBackdropClick","onClick","onClose","open","PaperComponent","PaperProps","scroll","TransitionComponent","transitionDuration","TransitionProps"],Xq=Vi(yh,{name:"MuiDialog",slot:"Backdrop",overrides:(e,t)=>t.backdrop})({zIndex:-1}),Jq=Vi(kh,{name:"MuiDialog",slot:"Root",overridesResolver:(e,t)=>t.root})({"@media print":{position:"absolute !important"}}),Qq=Vi("div",{name:"MuiDialog",slot:"Container",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.container,t[`scroll${Zi(r.scroll)}`]]}})(({ownerState:e})=>a({height:"100%","@media print":{height:"auto"},outline:0},"paper"===e.scroll&&{display:"flex",justifyContent:"center",alignItems:"center"},"body"===e.scroll&&{overflowY:"auto",overflowX:"hidden",textAlign:"center","&::after":{content:'""',display:"inline-block",verticalAlign:"middle",height:"100%",width:"0"}})),eW=Vi(sa,{name:"MuiDialog",slot:"Paper",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.paper,t[`scrollPaper${Zi(r.scroll)}`],t[`paperWidth${Zi(String(r.maxWidth))}`],r.fullWidth&&t.paperFullWidth,r.fullScreen&&t.paperFullScreen]}})(({theme:e,ownerState:t})=>a({margin:32,position:"relative",overflowY:"auto","@media print":{overflowY:"visible",boxShadow:"none"}},"paper"===t.scroll&&{display:"flex",flexDirection:"column",maxHeight:"calc(100% - 64px)"},"body"===t.scroll&&{display:"inline-block",verticalAlign:"middle",textAlign:"left"},!t.maxWidth&&{maxWidth:"calc(100% - 64px)"},"xs"===t.maxWidth&&{maxWidth:"px"===e.breakpoints.unit?Math.max(e.breakpoints.values.xs,444):`max(${e.breakpoints.values.xs}${e.breakpoints.unit}, 444px)`,[`&.${Gq.paperScrollBody}`]:{[e.breakpoints.down(Math.max(e.breakpoints.values.xs,444)+64)]:{maxWidth:"calc(100% - 64px)"}}},t.maxWidth&&"xs"!==t.maxWidth&&{maxWidth:`${e.breakpoints.values[t.maxWidth]}${e.breakpoints.unit}`,[`&.${Gq.paperScrollBody}`]:{[e.breakpoints.down(e.breakpoints.values[t.maxWidth]+64)]:{maxWidth:"calc(100% - 64px)"}}},t.fullWidth&&{width:"calc(100% - 64px)"},t.fullScreen&&{margin:0,width:"100%",maxWidth:"100%",height:"100%",maxHeight:"none",borderRadius:0,[`&.${Gq.paperScrollBody}`]:{margin:0,maxWidth:"100%"}})),tW=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiDialog"}),i=ea(),l={enter:i.transitions.duration.enteringScreen,exit:i.transitions.duration.leavingScreen},{"aria-describedby":c,"aria-labelledby":u,BackdropComponent:p,BackdropProps:d,children:f,className:h,disableEscapeKeyDown:m=!1,fullScreen:g=!1,fullWidth:v=!1,maxWidth:y="sm",onBackdropClick:b,onClick:w,onClose:x,open:_,PaperComponent:S=sa,PaperProps:k={},scroll:C="paper",TransitionComponent:O=fh,transitionDuration:E=l,TransitionProps:T}=n,R=s(n,Zq),I=a({},n,{disableEscapeKeyDown:m,fullScreen:g,fullWidth:v,maxWidth:y,scroll:C}),M=(e=>{const{classes:t,scroll:r,maxWidth:n,fullWidth:o,fullScreen:i}=e;return U({root:["root"],container:["container",`scroll${Zi(r)}`],paper:["paper",`paperScroll${Zi(r)}`,`paperWidth${Zi(String(n))}`,o&&"paperFullWidth",i&&"paperFullScreen"]},Hq,t)})(I),A=o.useRef(),P=Cf(u),N=o.useMemo(()=>({titleId:P}),[P]);return e.jsx(Jq,a({className:V(M.root,h),closeAfterTransition:!0,components:{Backdrop:Xq},componentsProps:{backdrop:a({transitionDuration:E,as:p},d)},disableEscapeKeyDown:m,onClose:x,open:_,ref:r,onClick:e=>{w&&w(e),A.current&&(A.current=null,b&&b(e),x&&x(e,"backdropClick"))},ownerState:I},R,{children:e.jsx(O,a({appear:!0,in:_,timeout:E,role:"presentation"},T,{children:e.jsx(Qq,{className:V(M.container),onMouseDown:e=>{A.current=e.target===e.currentTarget},ownerState:I,children:e.jsx(eW,a({as:S,elevation:24,role:"dialog","aria-describedby":c,"aria-labelledby":P},k,{className:V(M.paper,k.className),ownerState:I,children:e.jsx(Yq.Provider,{value:N,children:f})}))})}))}))}); true&&(tW.propTypes={"aria-describedby":B.string,"aria-labelledby":B.string,BackdropComponent:B.elementType,BackdropProps:B.object,children:B.node,classes:B.object,className:B.string,disableEscapeKeyDown:B.bool,fullScreen:B.bool,fullWidth:B.bool,maxWidth:B.oneOfType([B.oneOf(["xs","sm","md","lg","xl",!1]),B.string]),onBackdropClick:B.func,onClick:B.func,onClose:B.func,open:B.bool.isRequired,PaperComponent:B.elementType,PaperProps:B.object,scroll:B.oneOf(["body","paper"]),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),TransitionComponent:B.elementType,transitionDuration:B.oneOfType([B.number,B.shape({appear:B.number,enter:B.number,exit:B.number})]),TransitionProps:B.object});const rW=tW;var nW=t.forwardRef((e,r)=>t.createElement(rW,{...e,ref:r}));function oW(e){return Mo("MuiDialogContent",e)}function iW(e){return Mo("MuiDialogTitle",e)}ta("MuiDialogContent",["root","dividers"]);const sW=ta("MuiDialogTitle",["root"]),aW=["className","dividers"],lW=Vi("div",{name:"MuiDialogContent",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,r.dividers&&t.dividers]}})(({theme:e,ownerState:t})=>a({flex:"1 1 auto",WebkitOverflowScrolling:"touch",overflowY:"auto",padding:"20px 24px"},t.dividers?{padding:"16px 24px",borderTop:`1px solid ${(e.vars||e).palette.divider}`,borderBottom:`1px solid ${(e.vars||e).palette.divider}`}:{[`.${sW.root} + &`]:{paddingTop:0}})),cW=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiDialogContent"}),{className:o,dividers:i=!1}=n,l=s(n,aW),c=a({},n,{dividers:i}),u=(e=>{const{classes:t,dividers:r}=e;return U({root:["root",r&&"dividers"]},oW,t)})(c);return e.jsx(lW,a({className:V(u.root,o),ownerState:c,ref:r},l))}); true&&(cW.propTypes={children:B.node,classes:B.object,className:B.string,dividers:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const uW=cW;var pW=t.forwardRef((e,r)=>t.createElement(uW,{...e,ref:r}));function dW(e){return Mo("MuiDialogActions",e)}ta("MuiDialogActions",["root","spacing"]);const fW=["className","disableSpacing"],hW=Vi("div",{name:"MuiDialogActions",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,!r.disableSpacing&&t.spacing]}})(({ownerState:e})=>a({display:"flex",alignItems:"center",padding:8,justifyContent:"flex-end",flex:"0 0 auto"},!e.disableSpacing&&{"& > :not(style) ~ :not(style)":{marginLeft:8}})),mW=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiDialogActions"}),{className:o,disableSpacing:i=!1}=n,l=s(n,fW),c=a({},n,{disableSpacing:i}),u=(e=>{const{classes:t,disableSpacing:r}=e;return U({root:["root",!r&&"spacing"]},dW,t)})(c);return e.jsx(hW,a({className:V(u.root,o),ownerState:c,ref:r},l))}); true&&(mW.propTypes={children:B.node,classes:B.object,className:B.string,disableSpacing:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const gW=mW;var vW=t.forwardRef((e,r)=>t.createElement(gW,{...e,ref:r}));const yW=["className","id"],bW=Vi(Ma,{name:"MuiDialogTitle",slot:"Root",overridesResolver:(e,t)=>t.root})({padding:"16px 24px",flex:"0 0 auto"}),wW=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiDialogTitle"}),{className:i,id:l}=n,c=s(n,yW),u=n,p=(e=>{const{classes:t}=e;return U({root:["root"]},iW,t)})(u),{titleId:d=l}=o.useContext(Yq);return e.jsx(bW,a({component:"h2",className:V(p.root,i),ownerState:u,ref:r,variant:"h6",id:null!=l?l:d},c))}); true&&(wW.propTypes={children:B.node,classes:B.object,className:B.string,id:B.string,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const xW=wW,_W={variant:"subtitle1"},SW=t.forwardRef((e,r)=>t.createElement(xW,{..._W,...e,ref:r}));SW.defaultProps=_W;var kW=SW;function CW(e){return null!=e&&!(Array.isArray(e)&&0===e.length)}function OW(e,t=!1){return e&&(CW(e.value)&&""!==e.value||t&&CW(e.defaultValue)&&""!==e.defaultValue)}const EW=o.createContext(void 0); true&&(EW.displayName="FormControlContext");const TW=EW;function RW(e){return Mo("MuiFormControl",e)}ta("MuiFormControl",["root","marginNone","marginNormal","marginDense","fullWidth","disabled"]);const IW=["children","className","color","component","disabled","error","focused","fullWidth","hiddenLabel","margin","required","size","variant"],MW=Vi("div",{name:"MuiFormControl",slot:"Root",overridesResolver:({ownerState:e},t)=>a({},t.root,t[`margin${Zi(e.margin)}`],e.fullWidth&&t.fullWidth)})(({ownerState:e})=>a({display:"inline-flex",flexDirection:"column",position:"relative",minWidth:0,padding:0,margin:0,border:0,verticalAlign:"top"},"normal"===e.margin&&{marginTop:16,marginBottom:8},"dense"===e.margin&&{marginTop:8,marginBottom:4},e.fullWidth&&{width:"100%"})),AW=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiFormControl"}),{children:i,className:l,color:c="primary",component:u="div",disabled:p=!1,error:d=!1,focused:f,fullWidth:h=!1,hiddenLabel:m=!1,margin:g="none",required:v=!1,size:y="medium",variant:b="outlined"}=n,w=s(n,IW),x=a({},n,{color:c,component:u,disabled:p,error:d,fullWidth:h,hiddenLabel:m,margin:g,required:v,size:y,variant:b}),_=(e=>{const{classes:t,margin:r,fullWidth:n}=e;return U({root:["root","none"!==r&&`margin${Zi(r)}`,n&&"fullWidth"]},RW,t)})(x),[S,k]=o.useState(()=>{let e=!1;return i&&o.Children.forEach(i,t=>{if(!wf(t,["Input","Select"]))return;const r=wf(t,["Select"])?t.props.input:t;r&&r.props.startAdornment&&(e=!0)}),e}),[C,O]=o.useState(()=>{let e=!1;return i&&o.Children.forEach(i,t=>{wf(t,["Input","Select"])&&(OW(t.props,!0)||OW(t.props.inputProps,!0))&&(e=!0)}),e}),[E,T]=o.useState(!1);p&&E&&T(!1);const R=void 0===f||p?E:f;let I;if(true){const e=o.useRef(!1);I=()=>(e.current&&console.error(["MUI: There are multiple `InputBase` components inside a FormControl.","This creates visual inconsistencies, only use one `InputBase`."].join("\n")),e.current=!0,()=>{e.current=!1})}const M=o.useMemo(()=>({adornedStart:S,setAdornedStart:k,color:c,disabled:p,error:d,filled:C,focused:R,fullWidth:h,hiddenLabel:m,size:y,onBlur:()=>{T(!1)},onEmpty:()=>{O(!1)},onFilled:()=>{O(!0)},onFocus:()=>{T(!0)},registerEffect:I,required:v,variant:b}),[S,c,p,d,C,R,h,m,I,v,y,b]);return e.jsx(TW.Provider,{value:M,children:e.jsx(MW,a({as:u,ownerState:x,className:V(_.root,l),ref:r},w,{children:i}))})}); true&&(AW.propTypes={children:B.node,classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["primary","secondary","error","info","success","warning"]),B.string]),component:B.elementType,disabled:B.bool,error:B.bool,focused:B.bool,fullWidth:B.bool,hiddenLabel:B.bool,margin:B.oneOf(["dense","none","normal"]),required:B.bool,size:B.oneOfType([B.oneOf(["medium","small"]),B.string]),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),variant:B.oneOf(["filled","outlined","standard"])});const PW=AW;function NW(){return o.useContext(TW)}var jW=t.forwardRef((e,r)=>t.createElement(PW,{...e,ref:r}));const LW=t.forwardRef((e,r)=>t.createElement(Cu,{viewBox:"0 0 24 24",...e,ref:r},t.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M18.5303 5.46967C18.8232 5.76256 18.8232 6.23744 18.5303 6.53033L6.53033 18.5303C6.23744 18.8232 5.76256 18.8232 5.46967 18.5303C5.17678 18.2374 5.17678 17.7626 5.46967 17.4697L17.4697 5.46967C17.7626 5.17678 18.2374 5.17678 18.5303 5.46967Z"}),t.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M5.46967 5.46967C5.76256 5.17678 6.23744 5.17678 6.53033 5.46967L18.5303 17.4697C18.8232 17.7626 18.8232 18.2374 18.5303 18.5303C18.2374 18.8232 17.7626 18.8232 17.4697 18.5303L5.46967 6.53033C5.17678 6.23744 5.17678 5.76256 5.46967 5.46967Z"}))),{slots:DW,classNames:FW}=tc("CloseButton",["root","icon"]),$W=sc(bu,DW.root)({}),BW=sc(LW,DW.icon)({}),zW={"aria-label":"close",color:"default"},VW=t.forwardRef((e,r)=>{const n=Yi({props:{...zW,...e},name:DW.root.name}),{slotProps:o={},...i}=n;return t.createElement($W,{...i,size:"small",ref:r,className:V([[FW.root,i.className]]),ownerState:n},t.createElement(BW,{...o.icon,className:V([FW.icon,o.icon?.className]),ownerState:n}))});VW.defaultProps=zW;var UW=VW;const qW=sc(e=>t.createElement(Cu,{viewBox:"0 0 32 32",...e},t.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M2.69648 24.8891C0.938383 22.2579 0 19.1645 0 16C0 11.7566 1.68571 7.68687 4.68629 4.68629C7.68687 1.68571 11.7566 0 16 0C19.1645 0 22.2579 0.938383 24.8891 2.69648C27.5203 4.45459 29.5711 6.95344 30.7821 9.87706C31.9931 12.8007 32.3099 16.0177 31.6926 19.1214C31.0752 22.2251 29.5514 25.0761 27.3137 27.3137C25.0761 29.5514 22.2251 31.0752 19.1214 31.6926C16.0177 32.3099 12.8007 31.9931 9.87706 30.7821C6.95344 29.5711 4.45459 27.5203 2.69648 24.8891ZM12.0006 9.33281H9.33437V22.6665H12.0006V9.33281ZM22.6657 9.33281H14.6669V11.9991H22.6657V9.33281ZM22.6657 14.6654H14.6669V17.3316H22.6657V14.6654ZM22.6657 20.0003H14.6669V22.6665H22.6657V20.0003Z"})))(({theme:e})=>({width:e.spacing(3),height:e.spacing(3),"& path":{fill:e.palette.text.primary},marginRight:e.spacing(1)})),WW=sc("span")(({theme:e})=>({marginRight:e.spacing(1)})),HW=({logo:e,...r})=>!1===e?null:e?t.createElement(WW,null,e):t.createElement(qW,{...r}),{slots:GW,classNames:KW}=tc("DialogHeader",["root","logo","toolbar"]),YW=sc(ma,GW.root)({"& .MuiDialogTitle-root":{padding:0}}),ZW=sc(ka,GW.toolbar)({}),XW={color:"transparent",position:"relative"},JW=t.forwardRef((e,r)=>{const n=Yi({props:{...XW,...e},name:GW.root.name}),{slotProps:o={},logo:i,onClose:s,...a}=n;return t.createElement(YW,{...a,ref:r,className:V([[KW.root,a.className]]),ownerState:n},t.createElement(ZW,{variant:"dense",...o.toolbar,className:V([KW.toolbar,o.toolbar?.className]),ownerState:n},t.createElement(HW,{logo:i,className:V([KW.logo,o.logo?.className])}),t.createElement(ya,{direction:"row",alignItems:"center",flex:1},n.children),s&&t.createElement(UW,{edge:"end",onClick:s,sx:{"&.MuiButtonBase-root":{ml:.5}}})))});JW.defaultProps=XW;var QW=JW;const eH="base";function tH(e,t){const r=Io[t];return r?`${eH}--${r}`:function(e,t){return`${eH}-${e}-${t}`}(e,t)}function rH(e){return e.substring(2).toLowerCase()}function nH(t){const{children:r,disableReactTree:n=!1,mouseEvent:i="onClick",onClickAway:s,touchEvent:a="onTouchEnd"}=t,l=o.useRef(!1),c=o.useRef(null),u=o.useRef(!1),p=o.useRef(!1);o.useEffect(()=>(setTimeout(()=>{u.current=!0},0),()=>{u.current=!1}),[]);const d=Fa(r.ref,c),f=Ba(e=>{const t=p.current;p.current=!1;const r=xf(c.current);if(!u.current||!c.current||"clientX"in e&&function(e,t){return t.documentElement.clientWidth<e.clientX||t.documentElement.clientHeight<e.clientY}(e,r))return;if(l.current)return void(l.current=!1);let o;o=e.composedPath?e.composedPath().indexOf(c.current)>-1:!r.documentElement.contains(e.target)||c.current.contains(e.target),o||!n&&t||s(e)}),h=e=>t=>{p.current=!0;const n=r.props[e];n&&n(t)},m={ref:d};return!1!==a&&(m[a]=h(a)),o.useEffect(()=>{if(!1!==a){const e=rH(a),t=xf(c.current),r=()=>{l.current=!0};return t.addEventListener(e,f),t.addEventListener("touchmove",r),()=>{t.removeEventListener(e,f),t.removeEventListener("touchmove",r)}}},[f,a]),!1!==i&&(m[i]=h(i)),o.useEffect(()=>{if(!1!==i){const e=rH(i),t=xf(c.current);return t.addEventListener(e,f),()=>{t.removeEventListener(e,f)}}},[f,i]),e.jsx(o.Fragment,{children:o.cloneElement(r,m)})} true&&(nH.propTypes={children:hf.isRequired,disableReactTree:B.bool,mouseEvent:B.oneOf(["onClick","onMouseDown","onMouseUp","onPointerDown","onPointerUp",!1]),onClickAway:B.func.isRequired,touchEvent:B.oneOf(["onTouchEnd","onTouchStart",!1])}), true&&(nH.propTypes=gf(nH.propTypes));var oH="top",iH="bottom",sH="right",aH="left",lH="auto",cH=[oH,iH,sH,aH],uH="start",pH="end",dH="viewport",fH="popper",hH=cH.reduce(function(e,t){return e.concat([t+"-"+uH,t+"-"+pH])},[]),mH=[].concat(cH,[lH]).reduce(function(e,t){return e.concat([t,t+"-"+uH,t+"-"+pH])},[]),gH=["beforeRead","read","afterRead","beforeMain","main","afterMain","beforeWrite","write","afterWrite"];function vH(e){return e?(e.nodeName||"").toLowerCase():null}function yH(e){if(null==e)return window;if("[object Window]"!==e.toString()){var t=e.ownerDocument;return t&&t.defaultView||window}return e}function bH(e){return e instanceof yH(e).Element||e instanceof Element}function wH(e){return e instanceof yH(e).HTMLElement||e instanceof HTMLElement}function xH(e){return"undefined"!=typeof ShadowRoot&&(e instanceof yH(e).ShadowRoot||e instanceof ShadowRoot)}const _H={name:"applyStyles",enabled:!0,phase:"write",fn:function(e){var t=e.state;Object.keys(t.elements).forEach(function(e){var r=t.styles[e]||{},n=t.attributes[e]||{},o=t.elements[e];wH(o)&&vH(o)&&(Object.assign(o.style,r),Object.keys(n).forEach(function(e){var t=n[e];!1===t?o.removeAttribute(e):o.setAttribute(e,!0===t?"":t)}))})},effect:function(e){var t=e.state,r={popper:{position:t.options.strategy,left:"0",top:"0",margin:"0"},arrow:{position:"absolute"},reference:{}};return Object.assign(t.elements.popper.style,r.popper),t.styles=r,t.elements.arrow&&Object.assign(t.elements.arrow.style,r.arrow),function(){Object.keys(t.elements).forEach(function(e){var n=t.elements[e],o=t.attributes[e]||{},i=Object.keys(t.styles.hasOwnProperty(e)?t.styles[e]:r[e]).reduce(function(e,t){return e[t]="",e},{});wH(n)&&vH(n)&&(Object.assign(n.style,i),Object.keys(o).forEach(function(e){n.removeAttribute(e)}))})}},requires:["computeStyles"]};function SH(e){return e.split("-")[0]}var kH=Math.max,CH=Math.min,OH=Math.round;function EH(){var e=navigator.userAgentData;return null!=e&&e.brands&&Array.isArray(e.brands)?e.brands.map(function(e){return e.brand+"/"+e.version}).join(" "):navigator.userAgent}function TH(){return!/^((?!chrome|android).)*safari/i.test(EH())}function RH(e,t,r){void 0===t&&(t=!1),void 0===r&&(r=!1);var n=e.getBoundingClientRect(),o=1,i=1;t&&wH(e)&&(o=e.offsetWidth>0&&OH(n.width)/e.offsetWidth||1,i=e.offsetHeight>0&&OH(n.height)/e.offsetHeight||1);var s=(bH(e)?yH(e):window).visualViewport,a=!TH()&&r,l=(n.left+(a&&s?s.offsetLeft:0))/o,c=(n.top+(a&&s?s.offsetTop:0))/i,u=n.width/o,p=n.height/i;return{width:u,height:p,top:c,right:l+u,bottom:c+p,left:l,x:l,y:c}}function IH(e){var t=RH(e),r=e.offsetWidth,n=e.offsetHeight;return Math.abs(t.width-r)<=1&&(r=t.width),Math.abs(t.height-n)<=1&&(n=t.height),{x:e.offsetLeft,y:e.offsetTop,width:r,height:n}}function MH(e,t){var r=t.getRootNode&&t.getRootNode();if(e.contains(t))return!0;if(r&&xH(r)){var n=t;do{if(n&&e.isSameNode(n))return!0;n=n.parentNode||n.host}while(n)}return!1}function AH(e){return yH(e).getComputedStyle(e)}function PH(e){return["table","td","th"].indexOf(vH(e))>=0}function NH(e){return((bH(e)?e.ownerDocument:e.document)||window.document).documentElement}function jH(e){return"html"===vH(e)?e:e.assignedSlot||e.parentNode||(xH(e)?e.host:null)||NH(e)}function LH(e){return wH(e)&&"fixed"!==AH(e).position?e.offsetParent:null}function DH(e){for(var t=yH(e),r=LH(e);r&&PH(r)&&"static"===AH(r).position;)r=LH(r);return r&&("html"===vH(r)||"body"===vH(r)&&"static"===AH(r).position)?t:r||function(e){var t=/firefox/i.test(EH());if(/Trident/i.test(EH())&&wH(e)&&"fixed"===AH(e).position)return null;var r=jH(e);for(xH(r)&&(r=r.host);wH(r)&&["html","body"].indexOf(vH(r))<0;){var n=AH(r);if("none"!==n.transform||"none"!==n.perspective||"paint"===n.contain||-1!==["transform","perspective"].indexOf(n.willChange)||t&&"filter"===n.willChange||t&&n.filter&&"none"!==n.filter)return r;r=r.parentNode}return null}(e)||t}function FH(e){return["top","bottom"].indexOf(e)>=0?"x":"y"}function $H(e,t,r){return kH(e,CH(t,r))}function BH(e){return Object.assign({},{top:0,right:0,bottom:0,left:0},e)}function zH(e,t){return t.reduce(function(t,r){return t[r]=e,t},{})}const VH={name:"arrow",enabled:!0,phase:"main",fn:function(e){var t,r=e.state,n=e.name,o=e.options,i=r.elements.arrow,s=r.modifiersData.popperOffsets,a=SH(r.placement),l=FH(a),c=[aH,sH].indexOf(a)>=0?"height":"width";if(i&&s){var u=function(e,t){return BH("number"!=typeof(e="function"==typeof e?e(Object.assign({},t.rects,{placement:t.placement})):e)?e:zH(e,cH))}(o.padding,r),p=IH(i),d="y"===l?oH:aH,f="y"===l?iH:sH,h=r.rects.reference[c]+r.rects.reference[l]-s[l]-r.rects.popper[c],m=s[l]-r.rects.reference[l],g=DH(i),v=g?"y"===l?g.clientHeight||0:g.clientWidth||0:0,y=h/2-m/2,b=u[d],w=v-p[c]-u[f],x=v/2-p[c]/2+y,_=$H(b,x,w),S=l;r.modifiersData[n]=((t={})[S]=_,t.centerOffset=_-x,t)}},effect:function(e){var t=e.state,r=e.options.element,n=void 0===r?"[data-popper-arrow]":r;null!=n&&("string"!=typeof n||(n=t.elements.popper.querySelector(n)))&&MH(t.elements.popper,n)&&(t.elements.arrow=n)},requires:["popperOffsets"],requiresIfExists:["preventOverflow"]};function UH(e){return e.split("-")[1]}var qH={top:"auto",right:"auto",bottom:"auto",left:"auto"};function WH(e){var t,r=e.popper,n=e.popperRect,o=e.placement,i=e.variation,s=e.offsets,a=e.position,l=e.gpuAcceleration,c=e.adaptive,u=e.roundOffsets,p=e.isFixed,d=s.x,f=void 0===d?0:d,h=s.y,m=void 0===h?0:h,g="function"==typeof u?u({x:f,y:m}):{x:f,y:m};f=g.x,m=g.y;var v=s.hasOwnProperty("x"),y=s.hasOwnProperty("y"),b=aH,w=oH,x=window;if(c){var _=DH(r),S="clientHeight",k="clientWidth";_===yH(r)&&"static"!==AH(_=NH(r)).position&&"absolute"===a&&(S="scrollHeight",k="scrollWidth"),(o===oH||(o===aH||o===sH)&&i===pH)&&(w=iH,m-=(p&&_===x&&x.visualViewport?x.visualViewport.height:_[S])-n.height,m*=l?1:-1),o!==aH&&(o!==oH&&o!==iH||i!==pH)||(b=sH,f-=(p&&_===x&&x.visualViewport?x.visualViewport.width:_[k])-n.width,f*=l?1:-1)}var C,O=Object.assign({position:a},c&&qH),E=!0===u?function(e,t){var r=e.x,n=e.y,o=t.devicePixelRatio||1;return{x:OH(r*o)/o||0,y:OH(n*o)/o||0}}({x:f,y:m},yH(r)):{x:f,y:m};return f=E.x,m=E.y,l?Object.assign({},O,((C={})[w]=y?"0":"",C[b]=v?"0":"",C.transform=(x.devicePixelRatio||1)<=1?"translate("+f+"px, "+m+"px)":"translate3d("+f+"px, "+m+"px, 0)",C)):Object.assign({},O,((t={})[w]=y?m+"px":"",t[b]=v?f+"px":"",t.transform="",t))}var HH={passive:!0};const GH={name:"eventListeners",enabled:!0,phase:"write",fn:function(){},effect:function(e){var t=e.state,r=e.instance,n=e.options,o=n.scroll,i=void 0===o||o,s=n.resize,a=void 0===s||s,l=yH(t.elements.popper),c=[].concat(t.scrollParents.reference,t.scrollParents.popper);return i&&c.forEach(function(e){e.addEventListener("scroll",r.update,HH)}),a&&l.addEventListener("resize",r.update,HH),function(){i&&c.forEach(function(e){e.removeEventListener("scroll",r.update,HH)}),a&&l.removeEventListener("resize",r.update,HH)}},data:{}};var KH={left:"right",right:"left",bottom:"top",top:"bottom"};function YH(e){return e.replace(/left|right|bottom|top/g,function(e){return KH[e]})}var ZH={start:"end",end:"start"};function XH(e){return e.replace(/start|end/g,function(e){return ZH[e]})}function JH(e){var t=yH(e);return{scrollLeft:t.pageXOffset,scrollTop:t.pageYOffset}}function QH(e){return RH(NH(e)).left+JH(e).scrollLeft}function eG(e){var t=AH(e),r=t.overflow,n=t.overflowX,o=t.overflowY;return/auto|scroll|overlay|hidden/.test(r+o+n)}function tG(e){return["html","body","#document"].indexOf(vH(e))>=0?e.ownerDocument.body:wH(e)&&eG(e)?e:tG(jH(e))}function rG(e,t){var r;void 0===t&&(t=[]);var n=tG(e),o=n===(null==(r=e.ownerDocument)?void 0:r.body),i=yH(n),s=o?[i].concat(i.visualViewport||[],eG(n)?n:[]):n,a=t.concat(s);return o?a:a.concat(rG(jH(s)))}function nG(e){return Object.assign({},e,{left:e.x,top:e.y,right:e.x+e.width,bottom:e.y+e.height})}function oG(e,t,r){return t===dH?nG(function(e,t){var r=yH(e),n=NH(e),o=r.visualViewport,i=n.clientWidth,s=n.clientHeight,a=0,l=0;if(o){i=o.width,s=o.height;var c=TH();(c||!c&&"fixed"===t)&&(a=o.offsetLeft,l=o.offsetTop)}return{width:i,height:s,x:a+QH(e),y:l}}(e,r)):bH(t)?function(e,t){var r=RH(e,!1,"fixed"===t);return r.top=r.top+e.clientTop,r.left=r.left+e.clientLeft,r.bottom=r.top+e.clientHeight,r.right=r.left+e.clientWidth,r.width=e.clientWidth,r.height=e.clientHeight,r.x=r.left,r.y=r.top,r}(t,r):nG(function(e){var t,r=NH(e),n=JH(e),o=null==(t=e.ownerDocument)?void 0:t.body,i=kH(r.scrollWidth,r.clientWidth,o?o.scrollWidth:0,o?o.clientWidth:0),s=kH(r.scrollHeight,r.clientHeight,o?o.scrollHeight:0,o?o.clientHeight:0),a=-n.scrollLeft+QH(e),l=-n.scrollTop;return"rtl"===AH(o||r).direction&&(a+=kH(r.clientWidth,o?o.clientWidth:0)-i),{width:i,height:s,x:a,y:l}}(NH(e)))}function iG(e){var t,r=e.reference,n=e.element,o=e.placement,i=o?SH(o):null,s=o?UH(o):null,a=r.x+r.width/2-n.width/2,l=r.y+r.height/2-n.height/2;switch(i){case oH:t={x:a,y:r.y-n.height};break;case iH:t={x:a,y:r.y+r.height};break;case sH:t={x:r.x+r.width,y:l};break;case aH:t={x:r.x-n.width,y:l};break;default:t={x:r.x,y:r.y}}var c=i?FH(i):null;if(null!=c){var u="y"===c?"height":"width";switch(s){case uH:t[c]=t[c]-(r[u]/2-n[u]/2);break;case pH:t[c]=t[c]+(r[u]/2-n[u]/2)}}return t}function sG(e,t){void 0===t&&(t={});var r=t,n=r.placement,o=void 0===n?e.placement:n,i=r.strategy,s=void 0===i?e.strategy:i,a=r.boundary,l=void 0===a?"clippingParents":a,c=r.rootBoundary,u=void 0===c?dH:c,p=r.elementContext,d=void 0===p?fH:p,f=r.altBoundary,h=void 0!==f&&f,m=r.padding,g=void 0===m?0:m,v=BH("number"!=typeof g?g:zH(g,cH)),y=d===fH?"reference":fH,b=e.rects.popper,w=e.elements[h?y:d],x=function(e,t,r,n){var o="clippingParents"===t?function(e){var t=rG(jH(e)),r=["absolute","fixed"].indexOf(AH(e).position)>=0&&wH(e)?DH(e):e;return bH(r)?t.filter(function(e){return bH(e)&&MH(e,r)&&"body"!==vH(e)}):[]}(e):[].concat(t),i=[].concat(o,[r]),s=i[0],a=i.reduce(function(t,r){var o=oG(e,r,n);return t.top=kH(o.top,t.top),t.right=CH(o.right,t.right),t.bottom=CH(o.bottom,t.bottom),t.left=kH(o.left,t.left),t},oG(e,s,n));return a.width=a.right-a.left,a.height=a.bottom-a.top,a.x=a.left,a.y=a.top,a}(bH(w)?w:w.contextElement||NH(e.elements.popper),l,u,s),_=RH(e.elements.reference),S=iG({reference:_,element:b,strategy:"absolute",placement:o}),k=nG(Object.assign({},b,S)),C=d===fH?k:_,O={top:x.top-C.top+v.top,bottom:C.bottom-x.bottom+v.bottom,left:x.left-C.left+v.left,right:C.right-x.right+v.right},E=e.modifiersData.offset;if(d===fH&&E){var T=E[o];Object.keys(O).forEach(function(e){var t=[sH,iH].indexOf(e)>=0?1:-1,r=[oH,iH].indexOf(e)>=0?"y":"x";O[e]+=T[r]*t})}return O}function aG(e,t){void 0===t&&(t={});var r=t,n=r.placement,o=r.boundary,i=r.rootBoundary,s=r.padding,a=r.flipVariations,l=r.allowedAutoPlacements,c=void 0===l?mH:l,u=UH(n),p=u?a?hH:hH.filter(function(e){return UH(e)===u}):cH,d=p.filter(function(e){return c.indexOf(e)>=0});0===d.length&&(d=p);var f=d.reduce(function(t,r){return t[r]=sG(e,{placement:r,boundary:o,rootBoundary:i,padding:s})[SH(r)],t},{});return Object.keys(f).sort(function(e,t){return f[e]-f[t]})}const lG={name:"flip",enabled:!0,phase:"main",fn:function(e){var t=e.state,r=e.options,n=e.name;if(!t.modifiersData[n]._skip){for(var o=r.mainAxis,i=void 0===o||o,s=r.altAxis,a=void 0===s||s,l=r.fallbackPlacements,c=r.padding,u=r.boundary,p=r.rootBoundary,d=r.altBoundary,f=r.flipVariations,h=void 0===f||f,m=r.allowedAutoPlacements,g=t.options.placement,v=SH(g),y=l||(v!==g&&h?function(e){if(SH(e)===lH)return[];var t=YH(e);return[XH(e),t,XH(t)]}(g):[YH(g)]),b=[g].concat(y).reduce(function(e,r){return e.concat(SH(r)===lH?aG(t,{placement:r,boundary:u,rootBoundary:p,padding:c,flipVariations:h,allowedAutoPlacements:m}):r)},[]),w=t.rects.reference,x=t.rects.popper,_=new Map,S=!0,k=b[0],C=0;C<b.length;C++){var O=b[C],E=SH(O),T=UH(O)===uH,R=[oH,iH].indexOf(E)>=0,I=R?"width":"height",M=sG(t,{placement:O,boundary:u,rootBoundary:p,altBoundary:d,padding:c}),A=R?T?sH:aH:T?iH:oH;w[I]>x[I]&&(A=YH(A));var P=YH(A),N=[];if(i&&N.push(M[E]<=0),a&&N.push(M[A]<=0,M[P]<=0),N.every(function(e){return e})){k=O,S=!1;break}_.set(O,N)}if(S)for(var j=function(e){var t=b.find(function(t){var r=_.get(t);if(r)return r.slice(0,e).every(function(e){return e})});if(t)return k=t,"break"},L=h?3:1;L>0&&"break"!==j(L);L--);t.placement!==k&&(t.modifiersData[n]._skip=!0,t.placement=k,t.reset=!0)}},requiresIfExists:["offset"],data:{_skip:!1}};function cG(e,t,r){return void 0===r&&(r={x:0,y:0}),{top:e.top-t.height-r.y,right:e.right-t.width+r.x,bottom:e.bottom-t.height+r.y,left:e.left-t.width-r.x}}function uG(e){return[oH,sH,iH,aH].some(function(t){return e[t]>=0})}const pG={name:"offset",enabled:!0,phase:"main",requires:["popperOffsets"],fn:function(e){var t=e.state,r=e.options,n=e.name,o=r.offset,i=void 0===o?[0,0]:o,s=mH.reduce(function(e,r){return e[r]=function(e,t,r){var n=SH(e),o=[aH,oH].indexOf(n)>=0?-1:1,i="function"==typeof r?r(Object.assign({},t,{placement:e})):r,s=i[0],a=i[1];return s=s||0,a=(a||0)*o,[aH,sH].indexOf(n)>=0?{x:a,y:s}:{x:s,y:a}}(r,t.rects,i),e},{}),a=s[t.placement],l=a.x,c=a.y;null!=t.modifiersData.popperOffsets&&(t.modifiersData.popperOffsets.x+=l,t.modifiersData.popperOffsets.y+=c),t.modifiersData[n]=s}},dG={name:"preventOverflow",enabled:!0,phase:"main",fn:function(e){var t=e.state,r=e.options,n=e.name,o=r.mainAxis,i=void 0===o||o,s=r.altAxis,a=void 0!==s&&s,l=r.boundary,c=r.rootBoundary,u=r.altBoundary,p=r.padding,d=r.tether,f=void 0===d||d,h=r.tetherOffset,m=void 0===h?0:h,g=sG(t,{boundary:l,rootBoundary:c,padding:p,altBoundary:u}),v=SH(t.placement),y=UH(t.placement),b=!y,w=FH(v),x="x"===w?"y":"x",_=t.modifiersData.popperOffsets,S=t.rects.reference,k=t.rects.popper,C="function"==typeof m?m(Object.assign({},t.rects,{placement:t.placement})):m,O="number"==typeof C?{mainAxis:C,altAxis:C}:Object.assign({mainAxis:0,altAxis:0},C),E=t.modifiersData.offset?t.modifiersData.offset[t.placement]:null,T={x:0,y:0};if(_){if(i){var R,I="y"===w?oH:aH,M="y"===w?iH:sH,A="y"===w?"height":"width",P=_[w],N=P+g[I],j=P-g[M],L=f?-k[A]/2:0,D=y===uH?S[A]:k[A],F=y===uH?-k[A]:-S[A],$=t.elements.arrow,B=f&&$?IH($):{width:0,height:0},z=t.modifiersData["arrow#persistent"]?t.modifiersData["arrow#persistent"].padding:{top:0,right:0,bottom:0,left:0},V=z[I],U=z[M],q=$H(0,S[A],B[A]),W=b?S[A]/2-L-q-V-O.mainAxis:D-q-V-O.mainAxis,H=b?-S[A]/2+L+q+U+O.mainAxis:F+q+U+O.mainAxis,G=t.elements.arrow&&DH(t.elements.arrow),K=G?"y"===w?G.clientTop||0:G.clientLeft||0:0,Y=null!=(R=null==E?void 0:E[w])?R:0,Z=P+H-Y,X=$H(f?CH(N,P+W-Y-K):N,P,f?kH(j,Z):j);_[w]=X,T[w]=X-P}if(a){var J,Q="x"===w?oH:aH,ee="x"===w?iH:sH,te=_[x],re="y"===x?"height":"width",ne=te+g[Q],oe=te-g[ee],ie=-1!==[oH,aH].indexOf(v),se=null!=(J=null==E?void 0:E[x])?J:0,ae=ie?ne:te-S[re]-k[re]-se+O.altAxis,le=ie?te+S[re]+k[re]-se-O.altAxis:oe,ce=f&&ie?function(e,t,r){var n=$H(e,t,r);return n>r?r:n}(ae,te,le):$H(f?ae:ne,te,f?le:oe);_[x]=ce,T[x]=ce-te}t.modifiersData[n]=T}},requiresIfExists:["offset"]};function fG(e,t,r){void 0===r&&(r=!1);var n=wH(t),o=wH(t)&&function(e){var t=e.getBoundingClientRect(),r=OH(t.width)/e.offsetWidth||1,n=OH(t.height)/e.offsetHeight||1;return 1!==r||1!==n}(t),i=NH(t),s=RH(e,o,r),a={scrollLeft:0,scrollTop:0},l={x:0,y:0};return(n||!n&&!r)&&(("body"!==vH(t)||eG(i))&&(a=function(e){return e!==yH(e)&&wH(e)?{scrollLeft:(t=e).scrollLeft,scrollTop:t.scrollTop}:JH(e);// removed by dead control flow
 var t; }(t)),wH(t)?((l=RH(t,!0)).x+=t.clientLeft,l.y+=t.clientTop):i&&(l.x=QH(i))),{x:s.left+a.scrollLeft-l.x,y:s.top+a.scrollTop-l.y,width:s.width,height:s.height}}function hG(e){var t=new Map,r=new Set,n=[];function o(e){r.add(e.name),[].concat(e.requires||[],e.requiresIfExists||[]).forEach(function(e){if(!r.has(e)){var n=t.get(e);n&&o(n)}}),n.push(e)}return e.forEach(function(e){t.set(e.name,e)}),e.forEach(function(e){r.has(e.name)||o(e)}),n}var mG={placement:"bottom",modifiers:[],strategy:"absolute"};function gG(){for(var e=arguments.length,t=new Array(e),r=0;r<e;r++)t[r]=arguments[r];return!t.some(function(e){return!(e&&"function"==typeof e.getBoundingClientRect)})}function vG(e){void 0===e&&(e={});var t=e,r=t.defaultModifiers,n=void 0===r?[]:r,o=t.defaultOptions,i=void 0===o?mG:o;return function(e,t,r){void 0===r&&(r=i);var o,s,a={placement:"bottom",orderedModifiers:[],options:Object.assign({},mG,i),modifiersData:{},elements:{reference:e,popper:t},attributes:{},styles:{}},l=[],c=!1,u={state:a,setOptions:function(r){var o="function"==typeof r?r(a.options):r;p(),a.options=Object.assign({},i,a.options,o),a.scrollParents={reference:bH(e)?rG(e):e.contextElement?rG(e.contextElement):[],popper:rG(t)};var s,c,d=function(e){var t=hG(e);return gH.reduce(function(e,r){return e.concat(t.filter(function(e){return e.phase===r}))},[])}((s=[].concat(n,a.options.modifiers),c=s.reduce(function(e,t){var r=e[t.name];return e[t.name]=r?Object.assign({},r,t,{options:Object.assign({},r.options,t.options),data:Object.assign({},r.data,t.data)}):t,e},{}),Object.keys(c).map(function(e){return c[e]})));return a.orderedModifiers=d.filter(function(e){return e.enabled}),a.orderedModifiers.forEach(function(e){var t=e.name,r=e.options,n=void 0===r?{}:r,o=e.effect;if("function"==typeof o){var i=o({state:a,name:t,instance:u,options:n});l.push(i||function(){})}}),u.update()},forceUpdate:function(){if(!c){var e=a.elements,t=e.reference,r=e.popper;if(gG(t,r)){a.rects={reference:fG(t,DH(r),"fixed"===a.options.strategy),popper:IH(r)},a.reset=!1,a.placement=a.options.placement,a.orderedModifiers.forEach(function(e){return a.modifiersData[e.name]=Object.assign({},e.data)});for(var n=0;n<a.orderedModifiers.length;n++)if(!0!==a.reset){var o=a.orderedModifiers[n],i=o.fn,s=o.options,l=void 0===s?{}:s,p=o.name;"function"==typeof i&&(a=i({state:a,options:l,name:p,instance:u})||a)}else a.reset=!1,n=-1}}},update:(o=function(){return new Promise(function(e){u.forceUpdate(),e(a)})},function(){return s||(s=new Promise(function(e){Promise.resolve().then(function(){s=void 0,e(o())})})),s}),destroy:function(){p(),c=!0}};if(!gG(e,t))return u;function p(){l.forEach(function(e){return e()}),l=[]}return u.setOptions(r).then(function(e){!c&&r.onFirstUpdate&&r.onFirstUpdate(e)}),u}}var yG=vG({defaultModifiers:[GH,{name:"popperOffsets",enabled:!0,phase:"read",fn:function(e){var t=e.state,r=e.name;t.modifiersData[r]=iG({reference:t.rects.reference,element:t.rects.popper,strategy:"absolute",placement:t.placement})},data:{}},{name:"computeStyles",enabled:!0,phase:"beforeWrite",fn:function(e){var t=e.state,r=e.options,n=r.gpuAcceleration,o=void 0===n||n,i=r.adaptive,s=void 0===i||i,a=r.roundOffsets,l=void 0===a||a,c={placement:SH(t.placement),variation:UH(t.placement),popper:t.elements.popper,popperRect:t.rects.popper,gpuAcceleration:o,isFixed:"fixed"===t.options.strategy};null!=t.modifiersData.popperOffsets&&(t.styles.popper=Object.assign({},t.styles.popper,WH(Object.assign({},c,{offsets:t.modifiersData.popperOffsets,position:t.options.strategy,adaptive:s,roundOffsets:l})))),null!=t.modifiersData.arrow&&(t.styles.arrow=Object.assign({},t.styles.arrow,WH(Object.assign({},c,{offsets:t.modifiersData.arrow,position:"absolute",adaptive:!1,roundOffsets:l})))),t.attributes.popper=Object.assign({},t.attributes.popper,{"data-popper-placement":t.placement})},data:{}},_H,pG,lG,dG,VH,{name:"hide",enabled:!0,phase:"main",requiresIfExists:["preventOverflow"],fn:function(e){var t=e.state,r=e.name,n=t.rects.reference,o=t.rects.popper,i=t.modifiersData.preventOverflow,s=sG(t,{elementContext:"reference"}),a=sG(t,{altBoundary:!0}),l=cG(s,n),c=cG(a,o,i),u=uG(l),p=uG(c);t.modifiersData[r]={referenceClippingOffsets:l,popperEscapeOffsets:c,isReferenceHidden:u,hasPopperEscaped:p},t.attributes.popper=Object.assign({},t.attributes.popper,{"data-popper-reference-hidden":u,"data-popper-escaped":p})}}]});const bG="Popper";function wG(e){return tH(bG,e)}!function(e){const t={};["root"].forEach(r=>{t[r]=tH(e,r)})}(bG);const xG=["anchorEl","children","direction","disablePortal","modifiers","open","placement","popperOptions","popperRef","slotProps","slots","TransitionProps","ownerState"],_G=["anchorEl","children","container","direction","disablePortal","keepMounted","modifiers","open","placement","popperOptions","popperRef","style","transition","slotProps","slots"];function SG(e){return"function"==typeof e?e():e}function kG(e){return void 0!==e.nodeType}const CG={},OG=o.forwardRef(function(t,r){var n;const{anchorEl:i,children:l,direction:c,disablePortal:u,modifiers:p,open:d,placement:f,popperOptions:h,popperRef:m,slotProps:g={},slots:v={},TransitionProps:y}=t,b=s(t,xG),w=o.useRef(null),x=Fa(w,r),_=o.useRef(null),S=Fa(_,m),k=o.useRef(S);$a(()=>{k.current=S},[S]),o.useImperativeHandle(m,()=>_.current,[]);const C=function(e,t){if("ltr"===t)return e;switch(e){case"bottom-end":return"bottom-start";case"bottom-start":return"bottom-end";case"top-end":return"top-start";case"top-start":return"top-end";default:return e}}(f,c),[O,E]=o.useState(C),[T,R]=o.useState(SG(i));o.useEffect(()=>{_.current&&_.current.forceUpdate()}),o.useEffect(()=>{i&&R(SG(i))},[i]),$a(()=>{if(!T||!d)return;if( true&&T&&kG(T)&&1===T.nodeType){const e=T.getBoundingClientRect(); true&&0===e.top&&0===e.left&&0===e.right&&0===e.bottom&&console.warn(["MUI: The `anchorEl` prop provided to the component is invalid.","The anchor element should be part of the document layout.","Make sure the element is present in the document or that it's not display none."].join("\n"))}let e=[{name:"preventOverflow",options:{altBoundary:u}},{name:"flip",options:{altBoundary:u}},{name:"onUpdate",enabled:!0,phase:"afterWrite",fn:({state:e})=>{E(e.placement)}}];null!=p&&(e=e.concat(p)),h&&null!=h.modifiers&&(e=e.concat(h.modifiers));const t=yG(T,w.current,a({placement:C},h,{modifiers:e}));return k.current(t),()=>{t.destroy(),k.current(null)}},[T,u,p,d,h,C]);const I={placement:O};null!==y&&(I.TransitionProps=y);const M=U({root:["root"]},function(e){const{disableDefaultClasses:t}=o.useContext(cf);return r=>t?"":e(r)}(wG)),A=null!=(n=v.root)?n:"div",P=Af({elementType:A,externalSlotProps:g.root,externalForwardedProps:b,additionalProps:{role:"tooltip",ref:x},ownerState:t,className:M.root});return e.jsx(A,a({},P,{children:"function"==typeof l?l(I):l}))}),EG=o.forwardRef(function(t,r){const{anchorEl:n,children:i,container:l,direction:c="ltr",disablePortal:u=!1,keepMounted:p=!1,modifiers:d,open:f,placement:h="bottom",popperOptions:m=CG,popperRef:g,style:v,transition:y=!1,slotProps:b={},slots:w={}}=t,x=s(t,_G),[_,S]=o.useState(!0);if(!p&&!f&&(!y||_))return null;let k;if(l)k=l;else if(n){const e=SG(n);k=e&&kG(e)?xf(e).body:xf(null).body}const C=f||!p||y&&!_?void 0:"none",O=y?{in:f,onEnter:()=>{S(!1)},onExited:()=>{S(!0)}}:void 0;return e.jsx(ch,{disablePortal:u,container:k,children:e.jsx(OG,a({anchorEl:n,direction:c,disablePortal:u,modifiers:d,ref:r,open:y?!_:f,placement:h,popperOptions:m,popperRef:g,slotProps:b,slots:w},x,{style:a({position:"fixed",top:0,left:0,display:C},v),TransitionProps:O,children:i}))})}); true&&(EG.propTypes={anchorEl:rs(B.oneOfType([vf,B.object,B.func]),e=>{if(e.open){const t=SG(e.anchorEl);if(t&&kG(t)&&1===t.nodeType){const e=t.getBoundingClientRect();if( true&&0===e.top&&0===e.left&&0===e.right&&0===e.bottom)return new Error(["MUI: The `anchorEl` prop provided to the component is invalid.","The anchor element should be part of the document layout.","Make sure the element is present in the document or that it's not display none."].join("\n"))}else if(!t||"function"!=typeof t.getBoundingClientRect||!kG(t)&&null!=t.contextElement&&1!==t.contextElement.nodeType)return new Error(["MUI: The `anchorEl` prop provided to the component is invalid.","It should be an HTML element instance or a virtualElement ","(https://popper.js.org/docs/v2/virtual-elements/)."].join("\n"))}return null}),children:B.oneOfType([B.node,B.func]),container:B.oneOfType([vf,B.func]),direction:B.oneOf(["ltr","rtl"]),disablePortal:B.bool,keepMounted:B.bool,modifiers:B.arrayOf(B.shape({data:B.object,effect:B.func,enabled:B.bool,fn:B.func,name:B.any,options:B.object,phase:B.oneOf(["afterMain","afterRead","afterWrite","beforeMain","beforeRead","beforeWrite","main","read","write"]),requires:B.arrayOf(B.string),requiresIfExists:B.arrayOf(B.string)})),open:B.bool.isRequired,placement:B.oneOf(["auto-end","auto-start","auto","bottom-end","bottom-start","bottom","left-end","left-start","left","right-end","right-start","right","top-end","top-start","top"]),popperOptions:B.shape({modifiers:B.array,onFirstUpdate:B.func,placement:B.oneOf(["auto-end","auto-start","auto","bottom-end","bottom-start","bottom","left-end","left-start","left","right-end","right-start","right","top-end","top-start","top"]),strategy:B.oneOf(["absolute","fixed"])}),popperRef:ja,slotProps:B.shape({root:B.oneOfType([B.func,B.object])}),slots:B.shape({root:B.elementType}),transition:B.bool});const TG=["onChange","maxRows","minRows","style","value"];function RG(e){return parseInt(e,10)||0}const IG={visibility:"hidden",position:"absolute",overflow:"hidden",height:0,top:0,left:0,transform:"translateZ(0)"},MG=o.forwardRef(function(t,r){const{onChange:n,maxRows:i,minRows:l=1,style:c,value:u}=t,p=s(t,TG),{current:d}=o.useRef(null!=u),f=o.useRef(null),h=Fa(r,f),m=o.useRef(null),g=o.useCallback(()=>{const e=f.current,r=_f(e).getComputedStyle(e);if("0px"===r.width)return{outerHeightStyle:0,overflowing:!1};const n=m.current;n.style.width=r.width,n.value=e.value||t.placeholder||"x","\n"===n.value.slice(-1)&&(n.value+=" ");const o=r.boxSizing,s=RG(r.paddingBottom)+RG(r.paddingTop),a=RG(r.borderBottomWidth)+RG(r.borderTopWidth),c=n.scrollHeight;n.value="x";const u=n.scrollHeight;let p=c;return l&&(p=Math.max(Number(l)*u,p)),i&&(p=Math.min(Number(i)*u,p)),p=Math.max(p,u),{outerHeightStyle:p+("border-box"===o?s+a:0),overflowing:Math.abs(p-c)<=1}},[i,l,t.placeholder]),v=o.useCallback(()=>{const e=g();if(null==(t=e)||0===Object.keys(t).length||0===t.outerHeightStyle&&!t.overflowing)return;var t;const r=f.current;r.style.height=`${e.outerHeightStyle}px`,r.style.overflow=e.overflowing?"hidden":""},[g]);return $a(()=>{const e=()=>{v()};let t;const r=bf(e),n=f.current,o=_f(n);let i;return o.addEventListener("resize",r),"undefined"!=typeof ResizeObserver&&(i=new ResizeObserver( false?0:e),i.observe(n)),()=>{r.clear(),cancelAnimationFrame(t),o.removeEventListener("resize",r),i&&i.disconnect()}},[g,v]),$a(()=>{v()}),e.jsxs(o.Fragment,{children:[e.jsx("textarea",a({value:u,onChange:e=>{d||v(),n&&n(e)},ref:h,rows:l,style:c},p)),e.jsx("textarea",{"aria-hidden":!0,className:t.className,readOnly:!0,ref:m,tabIndex:-1,style:a({},IG,c,{paddingTop:0,paddingBottom:0})})]})});function AG(e){return void 0!==e.normalize?e.normalize("NFD").replace(/[\u0300-\u036f]/g,""):e}function PG(e,t){for(let r=0;r<e.length;r+=1)if(t(e[r]))return r;return-1} true&&(MG.propTypes={className:B.string,maxRows:B.oneOfType([B.number,B.string]),minRows:B.oneOfType([B.number,B.string]),onChange:B.func,placeholder:B.string,style:B.object,value:B.oneOfType([B.arrayOf(B.string),B.number,B.string])});const NG=function(e={}){const{ignoreAccents:t=!0,ignoreCase:r=!0,limit:n,matchFrom:o="any",stringify:i,trim:s=!1}=e;return(e,{inputValue:a,getOptionLabel:l})=>{let c=s?a.trim():a;r&&(c=c.toLowerCase()),t&&(c=AG(c));const u=c?e.filter(e=>{let n=(i||l)(e);return r&&(n=n.toLowerCase()),t&&(n=AG(n)),"start"===o?0===n.indexOf(c):n.indexOf(c)>-1}):e;return"number"==typeof n?u.slice(0,n):u}}(),jG=e=>{var t;return null!==e.current&&(null==(t=e.current.parentElement)?void 0:t.contains(document.activeElement))};var LG,DG={};function FG(){if(LG)return DG;LG=1,Object.defineProperty(DG,"__esModule",{value:!0}),DG.default=void 0;var e=function(e,t){if(e&&e.__esModule)return e;if(null===e||"object"!=typeof e&&"function"!=typeof e)return{default:e};var r=n(t);if(r&&r.has(e))return r.get(e);var o={__proto__:null},i=Object.defineProperty&&Object.getOwnPropertyDescriptor;for(var s in e)if("default"!==s&&Object.prototype.hasOwnProperty.call(e,s)){var a=i?Object.getOwnPropertyDescriptor(e,s):null;a&&(a.get||a.set)?Object.defineProperty(o,s,a):o[s]=e[s]}return o.default=e,r&&r.set(e,o),o}(t),r=Fr;function n(e){if("function"!=typeof WeakMap)return null;var t=new WeakMap,r=new WeakMap;return(n=function(e){return e?r:t})(e)}return DG.default=function(t=null){const n=e.useContext(r.ThemeContext);return n&&(o=n,0!==Object.keys(o).length)?n:t;// removed by dead control flow
 var o; },DG}const $G=l(FG()),BG=["anchorEl","component","components","componentsProps","container","disablePortal","keepMounted","modifiers","open","placement","popperOptions","popperRef","transition","slots","slotProps"],zG=Vi(EG,{name:"MuiPopper",slot:"Root",overridesResolver:(e,t)=>t.root})({}),VG=o.forwardRef(function(t,r){var n;const o=$G(),i=Yi({props:t,name:"MuiPopper"}),{anchorEl:l,component:c,components:u,componentsProps:p,container:d,disablePortal:f,keepMounted:h,modifiers:m,open:g,placement:v,popperOptions:y,popperRef:b,transition:w,slots:x,slotProps:_}=i,S=s(i,BG),k=null!=(n=null==x?void 0:x.root)?n:null==u?void 0:u.Root,C=a({anchorEl:l,container:d,disablePortal:f,keepMounted:h,modifiers:m,open:g,placement:v,popperOptions:y,popperRef:b,transition:w},S);return e.jsx(zG,a({as:c,direction:null==o?void 0:o.direction,slots:{root:k},slotProps:null!=_?_:p},C,{ref:r}))}); true&&(VG.propTypes={anchorEl:B.oneOfType([vf,B.object,B.func]),children:B.oneOfType([B.node,B.func]),component:B.elementType,components:B.shape({Root:B.elementType}),componentsProps:B.shape({root:B.oneOfType([B.func,B.object])}),container:B.oneOfType([vf,B.func]),disablePortal:B.bool,keepMounted:B.bool,modifiers:B.arrayOf(B.shape({data:B.object,effect:B.func,enabled:B.bool,fn:B.func,name:B.any,options:B.object,phase:B.oneOf(["afterMain","afterRead","afterWrite","beforeMain","beforeRead","beforeWrite","main","read","write"]),requires:B.arrayOf(B.string),requiresIfExists:B.arrayOf(B.string)})),open:B.bool.isRequired,placement:B.oneOf(["auto-end","auto-start","auto","bottom-end","bottom-start","bottom","left-end","left-start","left","right-end","right-start","right","top-end","top-start","top"]),popperOptions:B.shape({modifiers:B.array,onFirstUpdate:B.func,placement:B.oneOf(["auto-end","auto-start","auto","bottom-end","bottom-start","bottom","left-end","left-start","left","right-end","right-start","right","top-end","top-start","top"]),strategy:B.oneOf(["absolute","fixed"])}),popperRef:ja,slotProps:B.shape({root:B.oneOfType([B.func,B.object])}),slots:B.shape({root:B.elementType}),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),transition:B.bool});const UG=VG;function qG(e){return Mo("MuiListSubheader",e)}ta("MuiListSubheader",["root","colorPrimary","colorInherit","gutters","inset","sticky"]);const WG=["className","color","component","disableGutters","disableSticky","inset"],HG=Vi("li",{name:"MuiListSubheader",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,"default"!==r.color&&t[`color${Zi(r.color)}`],!r.disableGutters&&t.gutters,r.inset&&t.inset,!r.disableSticky&&t.sticky]}})(({theme:e,ownerState:t})=>a({boxSizing:"border-box",lineHeight:"48px",listStyle:"none",color:(e.vars||e).palette.text.secondary,fontFamily:e.typography.fontFamily,fontWeight:e.typography.fontWeightMedium,fontSize:e.typography.pxToRem(14)},"primary"===t.color&&{color:(e.vars||e).palette.primary.main},"inherit"===t.color&&{color:"inherit"},!t.disableGutters&&{paddingLeft:16,paddingRight:16},t.inset&&{paddingLeft:72},!t.disableSticky&&{position:"sticky",top:0,zIndex:1,backgroundColor:(e.vars||e).palette.background.paper})),GG=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiListSubheader"}),{className:o,color:i="default",component:l="li",disableGutters:c=!1,disableSticky:u=!1,inset:p=!1}=n,d=s(n,WG),f=a({},n,{color:i,component:l,disableGutters:c,disableSticky:u,inset:p}),h=(e=>{const{classes:t,color:r,disableGutters:n,inset:o,disableSticky:i}=e;return U({root:["root","default"!==r&&`color${Zi(r)}`,!n&&"gutters",o&&"inset",!i&&"sticky"]},qG,t)})(f);return e.jsx(HG,a({as:l,className:V(h.root,o),ref:r,ownerState:f},d))});GG.muiSkipListHighlight=!0, true&&(GG.propTypes={children:B.node,classes:B.object,className:B.string,color:B.oneOf(["default","inherit","primary"]),component:B.elementType,disableGutters:B.bool,disableSticky:B.bool,inset:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const KG=GG;function YG({props:e,states:t,muiFormControl:r}){return t.reduce((t,n)=>(t[n]=e[n],r&&void 0===e[n]&&(t[n]=r[n]),t),{})}function ZG(t){return e.jsx(os,a({},t,{defaultTheme:Fi,themeId:$i}))}function XG(e){return Mo("MuiInputBase",e)} true&&(ZG.propTypes={styles:B.oneOfType([B.array,B.func,B.number,B.object,B.string,B.bool])});const JG=ta("MuiInputBase",["root","formControl","focused","disabled","adornedStart","adornedEnd","error","sizeSmall","multiline","colorSecondary","fullWidth","hiddenLabel","readOnly","input","inputSizeSmall","inputMultiline","inputTypeSearch","inputAdornedStart","inputAdornedEnd","inputHiddenLabel"]),QG=["aria-describedby","autoComplete","autoFocus","className","color","components","componentsProps","defaultValue","disabled","disableInjectingGlobalStyles","endAdornment","error","fullWidth","id","inputComponent","inputProps","inputRef","margin","maxRows","minRows","multiline","name","onBlur","onChange","onClick","onFocus","onKeyDown","onKeyUp","placeholder","readOnly","renderSuffix","rows","size","slotProps","slots","startAdornment","type","value"],eK=(e,t)=>{const{ownerState:r}=e;return[t.root,r.formControl&&t.formControl,r.startAdornment&&t.adornedStart,r.endAdornment&&t.adornedEnd,r.error&&t.error,"small"===r.size&&t.sizeSmall,r.multiline&&t.multiline,r.color&&t[`color${Zi(r.color)}`],r.fullWidth&&t.fullWidth,r.hiddenLabel&&t.hiddenLabel]},tK=(e,t)=>{const{ownerState:r}=e;return[t.input,"small"===r.size&&t.inputSizeSmall,r.multiline&&t.inputMultiline,"search"===r.type&&t.inputTypeSearch,r.startAdornment&&t.inputAdornedStart,r.endAdornment&&t.inputAdornedEnd,r.hiddenLabel&&t.inputHiddenLabel]},rK=Vi("div",{name:"MuiInputBase",slot:"Root",overridesResolver:eK})(({theme:e,ownerState:t})=>a({},e.typography.body1,{color:(e.vars||e).palette.text.primary,lineHeight:"1.4375em",boxSizing:"border-box",position:"relative",cursor:"text",display:"inline-flex",alignItems:"center",[`&.${JG.disabled}`]:{color:(e.vars||e).palette.text.disabled,cursor:"default"}},t.multiline&&a({padding:"4px 0 5px"},"small"===t.size&&{paddingTop:1}),t.fullWidth&&{width:"100%"})),nK=Vi("input",{name:"MuiInputBase",slot:"Input",overridesResolver:tK})(({theme:e,ownerState:t})=>{const r="light"===e.palette.mode,n=a({color:"currentColor"},e.vars?{opacity:e.vars.opacity.inputPlaceholder}:{opacity:r?.42:.5},{transition:e.transitions.create("opacity",{duration:e.transitions.duration.shorter})}),o={opacity:"0 !important"},i=e.vars?{opacity:e.vars.opacity.inputPlaceholder}:{opacity:r?.42:.5};return a({font:"inherit",letterSpacing:"inherit",color:"currentColor",padding:"4px 0 5px",border:0,boxSizing:"content-box",background:"none",height:"1.4375em",margin:0,WebkitTapHighlightColor:"transparent",display:"block",minWidth:0,width:"100%",animationName:"mui-auto-fill-cancel",animationDuration:"10ms","&::-webkit-input-placeholder":n,"&::-moz-placeholder":n,"&:-ms-input-placeholder":n,"&::-ms-input-placeholder":n,"&:focus":{outline:0},"&:invalid":{boxShadow:"none"},"&::-webkit-search-decoration":{WebkitAppearance:"none"},[`label[data-shrink=false] + .${JG.formControl} &`]:{"&::-webkit-input-placeholder":o,"&::-moz-placeholder":o,"&:-ms-input-placeholder":o,"&::-ms-input-placeholder":o,"&:focus::-webkit-input-placeholder":i,"&:focus::-moz-placeholder":i,"&:focus:-ms-input-placeholder":i,"&:focus::-ms-input-placeholder":i},[`&.${JG.disabled}`]:{opacity:1,WebkitTextFillColor:(e.vars||e).palette.text.disabled},"&:-webkit-autofill":{animationDuration:"5000s",animationName:"mui-auto-fill"}},"small"===t.size&&{paddingTop:1},t.multiline&&{height:"auto",resize:"none",padding:0,paddingTop:0},"search"===t.type&&{MozAppearance:"textfield"})}),oK=e.jsx(ZG,{styles:{"@keyframes mui-auto-fill":{from:{display:"block"}},"@keyframes mui-auto-fill-cancel":{from:{display:"block"}}}}),iK=o.forwardRef(function(t,r){var n;const i=Yi({props:t,name:"MuiInputBase"}),{"aria-describedby":l,autoComplete:c,autoFocus:u,className:p,components:d={},componentsProps:f={},defaultValue:h,disabled:m,disableInjectingGlobalStyles:g,endAdornment:v,fullWidth:y=!1,id:b,inputComponent:w="input",inputProps:x={},inputRef:_,maxRows:S,minRows:k,multiline:C=!1,name:O,onBlur:E,onChange:T,onClick:R,onFocus:I,onKeyDown:M,onKeyUp:A,placeholder:P,readOnly:N,renderSuffix:j,rows:L,slotProps:D={},slots:F={},startAdornment:$,type:B="text",value:z}=i,q=s(i,QG),W=null!=x.value?x.value:z,{current:H}=o.useRef(null!=W),G=o.useRef(),K=o.useCallback(e=>{ true&&e&&"INPUT"!==e.nodeName&&!e.focus&&console.error(["MUI: You have provided a `inputComponent` to the input component","that does not correctly handle the `ref` prop.","Make sure the `ref` prop is called with a HTMLInputElement."].join("\n"))},[]),Y=Fa(G,_,x.ref,K),[Z,X]=o.useState(!1),J=NW(); true&&o.useEffect(()=>{if(J)return J.registerEffect()},[J]);const Q=YG({props:i,muiFormControl:J,states:["color","disabled","error","hiddenLabel","size","required","filled"]});Q.focused=J?J.focused:Z,o.useEffect(()=>{!J&&m&&Z&&(X(!1),E&&E())},[J,m,Z,E]);const ee=J&&J.onFilled,te=J&&J.onEmpty,re=o.useCallback(e=>{OW(e)?ee&&ee():te&&te()},[ee,te]);$a(()=>{H&&re({value:W})},[W,re,H]),o.useEffect(()=>{re(G.current)},[]);let ne=w,oe=x;C&&"input"===ne&&(L?( true&&(k||S)&&console.warn("MUI: You can not use the `minRows` or `maxRows` props when the input `rows` prop is set."),oe=a({type:void 0,minRows:L,maxRows:L},oe)):oe=a({type:void 0,maxRows:S,minRows:k},oe),ne=MG),o.useEffect(()=>{J&&J.setAdornedStart(Boolean($))},[J,$]);const ie=a({},i,{color:Q.color||"primary",disabled:Q.disabled,endAdornment:v,error:Q.error,focused:Q.focused,formControl:J,fullWidth:y,hiddenLabel:Q.hiddenLabel,multiline:C,size:Q.size,startAdornment:$,type:B}),se=(e=>{const{classes:t,color:r,disabled:n,error:o,endAdornment:i,focused:s,formControl:a,fullWidth:l,hiddenLabel:c,multiline:u,readOnly:p,size:d,startAdornment:f,type:h}=e;return U({root:["root",`color${Zi(r)}`,n&&"disabled",o&&"error",l&&"fullWidth",s&&"focused",a&&"formControl",d&&"medium"!==d&&`size${Zi(d)}`,u&&"multiline",f&&"adornedStart",i&&"adornedEnd",c&&"hiddenLabel",p&&"readOnly"],input:["input",n&&"disabled","search"===h&&"inputTypeSearch",u&&"inputMultiline","small"===d&&"inputSizeSmall",c&&"inputHiddenLabel",f&&"inputAdornedStart",i&&"inputAdornedEnd",p&&"readOnly"]},XG,t)})(ie),ae=F.root||d.Root||rK,le=D.root||f.root||{},ce=F.input||d.Input||nK;return oe=a({},oe,null!=(n=D.input)?n:f.input),e.jsxs(o.Fragment,{children:[!g&&oK,e.jsxs(ae,a({},le,!sf(ae)&&{ownerState:a({},ie,le.ownerState)},{ref:r,onClick:e=>{G.current&&e.currentTarget===e.target&&G.current.focus(),R&&R(e)}},q,{className:V(se.root,le.className,p,N&&"MuiInputBase-readOnly"),children:[$,e.jsx(TW.Provider,{value:null,children:e.jsx(ce,a({ownerState:ie,"aria-invalid":Q.error,"aria-describedby":l,autoComplete:c,autoFocus:u,defaultValue:h,disabled:Q.disabled,id:b,onAnimationStart:e=>{re("mui-auto-fill-cancel"===e.animationName?G.current:{value:"x"})},name:O,placeholder:P,readOnly:N,required:Q.required,rows:L,value:W,onKeyDown:M,onKeyUp:A,type:B},oe,!sf(ce)&&{as:ne,ownerState:a({},ie,oe.ownerState)},{ref:Y,className:V(se.input,oe.className,N&&"MuiInputBase-readOnly"),onBlur:e=>{E&&E(e),x.onBlur&&x.onBlur(e),J&&J.onBlur?J.onBlur(e):X(!1)},onChange:(e,...t)=>{if(!H){const t=e.target||G.current;if(null==t)throw new Error( true?"MUI: Expected valid input target. Did you use a custom `inputComponent` and forget to forward refs? See https://mui.com/r/input-component-ref-interface for more info.":0);re({value:t.value})}x.onChange&&x.onChange(e,...t),T&&T(e,...t)},onFocus:e=>{Q.disabled?e.stopPropagation():(I&&I(e),x.onFocus&&x.onFocus(e),J&&J.onFocus?J.onFocus(e):X(!0))}}))}),v,j?j(a({},Q,{startAdornment:$})):null]}))]})}); true&&(iK.propTypes={"aria-describedby":B.string,autoComplete:B.string,autoFocus:B.bool,classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["primary","secondary","error","info","success","warning"]),B.string]),components:B.shape({Input:B.elementType,Root:B.elementType}),componentsProps:B.shape({input:B.object,root:B.object}),defaultValue:B.any,disabled:B.bool,disableInjectingGlobalStyles:B.bool,endAdornment:B.node,error:B.bool,fullWidth:B.bool,id:B.string,inputComponent:La,inputProps:B.object,inputRef:ja,margin:B.oneOf(["dense","none"]),maxRows:B.oneOfType([B.number,B.string]),minRows:B.oneOfType([B.number,B.string]),multiline:B.bool,name:B.string,onBlur:B.func,onChange:B.func,onClick:B.func,onFocus:B.func,onInvalid:B.func,onKeyDown:B.func,onKeyUp:B.func,placeholder:B.string,readOnly:B.bool,renderSuffix:B.func,required:B.bool,rows:B.oneOfType([B.number,B.string]),size:B.oneOfType([B.oneOf(["medium","small"]),B.string]),slotProps:B.shape({input:B.object,root:B.object}),slots:B.shape({input:B.elementType,root:B.elementType}),startAdornment:B.node,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),type:B.string,value:B.any});const sK=iK;function aK(e){return Mo("MuiInput",e)}const lK=a({},JG,ta("MuiInput",["root","underline","input"]));function cK(e){return Mo("MuiOutlinedInput",e)}const uK=a({},JG,ta("MuiOutlinedInput",["root","notchedOutline","input"]));function pK(e){return Mo("MuiFilledInput",e)}const dK=a({},JG,ta("MuiFilledInput",["root","underline","input"])),fK=Cz(e.jsx("path",{d:"M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z"}),"Close"),hK=Cz(e.jsx("path",{d:"M7 10l5 5 5-5z"}),"ArrowDropDown");function mK(e){return Mo("MuiAutocomplete",e)}const gK=ta("MuiAutocomplete",["root","expanded","fullWidth","focused","focusVisible","tag","tagSizeSmall","tagSizeMedium","hasPopupIcon","hasClearIcon","inputRoot","input","inputFocused","endAdornment","clearIndicator","popupIndicator","popupIndicatorOpen","popper","popperDisablePortal","paper","listbox","loading","noOptions","option","groupLabel","groupUl"]);var vK,yK;const bK=["autoComplete","autoHighlight","autoSelect","blurOnSelect","ChipProps","className","clearIcon","clearOnBlur","clearOnEscape","clearText","closeText","componentsProps","defaultValue","disableClearable","disableCloseOnSelect","disabled","disabledItemsFocusable","disableListWrap","disablePortal","filterOptions","filterSelectedOptions","forcePopupIcon","freeSolo","fullWidth","getLimitTagsText","getOptionDisabled","getOptionKey","getOptionLabel","isOptionEqualToValue","groupBy","handleHomeEndKeys","id","includeInputInList","inputValue","limitTags","ListboxComponent","ListboxProps","loading","loadingText","multiple","noOptionsText","onChange","onClose","onHighlightChange","onInputChange","onOpen","open","openOnFocus","openText","options","PaperComponent","PopperComponent","popupIcon","readOnly","renderGroup","renderInput","renderOption","renderTags","selectOnFocus","size","slotProps","value"],wK=["ref"],xK=xU(),_K=Vi("div",{name:"MuiAutocomplete",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e,{fullWidth:n,hasClearIcon:o,hasPopupIcon:i,inputFocused:s,size:a}=r;return[{[`& .${gK.tag}`]:t.tag},{[`& .${gK.tag}`]:t[`tagSize${Zi(a)}`]},{[`& .${gK.inputRoot}`]:t.inputRoot},{[`& .${gK.input}`]:t.input},{[`& .${gK.input}`]:s&&t.inputFocused},t.root,n&&t.fullWidth,i&&t.hasPopupIcon,o&&t.hasClearIcon]}})({[`&.${gK.focused} .${gK.clearIndicator}`]:{visibility:"visible"},"@media (pointer: fine)":{[`&:hover .${gK.clearIndicator}`]:{visibility:"visible"}},[`& .${gK.tag}`]:{margin:3,maxWidth:"calc(100% - 6px)"},[`& .${gK.inputRoot}`]:{flexWrap:"wrap",[`.${gK.hasPopupIcon}&, .${gK.hasClearIcon}&`]:{paddingRight:30},[`.${gK.hasPopupIcon}.${gK.hasClearIcon}&`]:{paddingRight:56},[`& .${gK.input}`]:{width:0,minWidth:30}},[`& .${lK.root}`]:{paddingBottom:1,"& .MuiInput-input":{padding:"4px 4px 4px 0px"}},[`& .${lK.root}.${JG.sizeSmall}`]:{[`& .${lK.input}`]:{padding:"2px 4px 3px 0"}},[`& .${uK.root}`]:{padding:9,[`.${gK.hasPopupIcon}&, .${gK.hasClearIcon}&`]:{paddingRight:39},[`.${gK.hasPopupIcon}.${gK.hasClearIcon}&`]:{paddingRight:65},[`& .${gK.input}`]:{padding:"7.5px 4px 7.5px 5px"},[`& .${gK.endAdornment}`]:{right:9}},[`& .${uK.root}.${JG.sizeSmall}`]:{paddingTop:6,paddingBottom:6,paddingLeft:6,[`& .${gK.input}`]:{padding:"2.5px 4px 2.5px 8px"}},[`& .${dK.root}`]:{paddingTop:19,paddingLeft:8,[`.${gK.hasPopupIcon}&, .${gK.hasClearIcon}&`]:{paddingRight:39},[`.${gK.hasPopupIcon}.${gK.hasClearIcon}&`]:{paddingRight:65},[`& .${dK.input}`]:{padding:"7px 4px"},[`& .${gK.endAdornment}`]:{right:9}},[`& .${dK.root}.${JG.sizeSmall}`]:{paddingBottom:1,[`& .${dK.input}`]:{padding:"2.5px 4px"}},[`& .${JG.hiddenLabel}`]:{paddingTop:8},[`& .${dK.root}.${JG.hiddenLabel}`]:{paddingTop:0,paddingBottom:0,[`& .${gK.input}`]:{paddingTop:16,paddingBottom:17}},[`& .${dK.root}.${JG.hiddenLabel}.${JG.sizeSmall}`]:{[`& .${gK.input}`]:{paddingTop:8,paddingBottom:9}},[`& .${gK.input}`]:{flexGrow:1,textOverflow:"ellipsis",opacity:0},variants:[{props:{fullWidth:!0},style:{width:"100%"}},{props:{size:"small"},style:{[`& .${gK.tag}`]:{margin:2,maxWidth:"calc(100% - 4px)"}}},{props:{inputFocused:!0},style:{[`& .${gK.input}`]:{opacity:1}}}]}),SK=Vi("div",{name:"MuiAutocomplete",slot:"EndAdornment",overridesResolver:(e,t)=>t.endAdornment})({position:"absolute",right:0,top:"50%",transform:"translate(0, -50%)"}),kK=Vi(Ul,{name:"MuiAutocomplete",slot:"ClearIndicator",overridesResolver:(e,t)=>t.clearIndicator})({marginRight:-2,padding:4,visibility:"hidden"}),CK=Vi(Ul,{name:"MuiAutocomplete",slot:"PopupIndicator",overridesResolver:({ownerState:e},t)=>a({},t.popupIndicator,e.popupOpen&&t.popupIndicatorOpen)})({padding:2,marginRight:-2,variants:[{props:{popupOpen:!0},style:{transform:"rotate(180deg)"}}]}),OK=Vi(UG,{name:"MuiAutocomplete",slot:"Popper",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[{[`& .${gK.option}`]:t.option},t.popper,r.disablePortal&&t.popperDisablePortal]}})(({theme:e})=>({zIndex:(e.vars||e).zIndex.modal,variants:[{props:{disablePortal:!0},style:{position:"absolute"}}]})),EK=Vi(sa,{name:"MuiAutocomplete",slot:"Paper",overridesResolver:(e,t)=>t.paper})(({theme:e})=>a({},e.typography.body1,{overflow:"auto"})),TK=Vi("div",{name:"MuiAutocomplete",slot:"Loading",overridesResolver:(e,t)=>t.loading})(({theme:e})=>({color:(e.vars||e).palette.text.secondary,padding:"14px 16px"})),RK=Vi("div",{name:"MuiAutocomplete",slot:"NoOptions",overridesResolver:(e,t)=>t.noOptions})(({theme:e})=>({color:(e.vars||e).palette.text.secondary,padding:"14px 16px"})),IK=Vi("div",{name:"MuiAutocomplete",slot:"Listbox",overridesResolver:(e,t)=>t.listbox})(({theme:e})=>({listStyle:"none",margin:0,padding:"8px 0",maxHeight:"40vh",overflow:"auto",position:"relative",[`& .${gK.option}`]:{minHeight:48,display:"flex",overflow:"hidden",justifyContent:"flex-start",alignItems:"center",cursor:"pointer",paddingTop:6,boxSizing:"border-box",outline:"0",WebkitTapHighlightColor:"transparent",paddingBottom:6,paddingLeft:16,paddingRight:16,[e.breakpoints.up("sm")]:{minHeight:"auto"},[`&.${gK.focused}`]:{backgroundColor:(e.vars||e).palette.action.hover,"@media (hover: none)":{backgroundColor:"transparent"}},'&[aria-disabled="true"]':{opacity:(e.vars||e).palette.action.disabledOpacity,pointerEvents:"none"},[`&.${gK.focusVisible}`]:{backgroundColor:(e.vars||e).palette.action.focus},'&[aria-selected="true"]':{backgroundColor:e.vars?`rgba(${e.vars.palette.primary.mainChannel} / ${e.vars.palette.action.selectedOpacity})`:Fo.alpha(e.palette.primary.main,e.palette.action.selectedOpacity),[`&.${gK.focused}`]:{backgroundColor:e.vars?`rgba(${e.vars.palette.primary.mainChannel} / calc(${e.vars.palette.action.selectedOpacity} + ${e.vars.palette.action.hoverOpacity}))`:Fo.alpha(e.palette.primary.main,e.palette.action.selectedOpacity+e.palette.action.hoverOpacity),"@media (hover: none)":{backgroundColor:(e.vars||e).palette.action.selected}},[`&.${gK.focusVisible}`]:{backgroundColor:e.vars?`rgba(${e.vars.palette.primary.mainChannel} / calc(${e.vars.palette.action.selectedOpacity} + ${e.vars.palette.action.focusOpacity}))`:Fo.alpha(e.palette.primary.main,e.palette.action.selectedOpacity+e.palette.action.focusOpacity)}}}})),MK=Vi(KG,{name:"MuiAutocomplete",slot:"GroupLabel",overridesResolver:(e,t)=>t.groupLabel})(({theme:e})=>({backgroundColor:(e.vars||e).palette.background.paper,top:-8})),AK=Vi("ul",{name:"MuiAutocomplete",slot:"GroupUl",overridesResolver:(e,t)=>t.groupUl})({padding:0,[`& .${gK.option}`]:{paddingLeft:24}}),PK=o.forwardRef(function(r,n){var i,l,c,u;const p=xK({props:r,name:"MuiAutocomplete"}),{autoComplete:d=!1,autoHighlight:f=!1,autoSelect:h=!1,blurOnSelect:m=!1,ChipProps:g,className:v,clearIcon:y=vK||(vK=e.jsx(fK,{fontSize:"small"})),clearOnBlur:b=!p.freeSolo,clearOnEscape:w=!1,clearText:x="Clear",closeText:_="Close",componentsProps:S={},defaultValue:k=(p.multiple?[]:null),disableClearable:C=!1,disableCloseOnSelect:O=!1,disabled:E=!1,disabledItemsFocusable:T=!1,disableListWrap:R=!1,disablePortal:I=!1,filterSelectedOptions:M=!1,forcePopupIcon:A="auto",freeSolo:P=!1,fullWidth:N=!1,getLimitTagsText:j=e=>`+${e}`,getOptionLabel:L,groupBy:D,handleHomeEndKeys:F=!p.freeSolo,includeInputInList:$=!1,limitTags:B=-1,ListboxComponent:z="ul",ListboxProps:q,loading:W=!1,loadingText:H="Loading…",multiple:G=!1,noOptionsText:K="No options",openOnFocus:Y=!1,openText:Z="Open",PaperComponent:X=sa,PopperComponent:J=UG,popupIcon:Q=yK||(yK=e.jsx(hK,{})),readOnly:ee=!1,renderGroup:te,renderInput:re,renderOption:ne,renderTags:oe,selectOnFocus:ie=!p.freeSolo,size:se="medium",slotProps:ae={}}=p,le=s(p,bK),{getRootProps:ce,getInputProps:ue,getInputLabelProps:pe,getPopupIndicatorProps:de,getClearProps:fe,getTagProps:he,getListboxProps:me,getOptionProps:ge,value:ve,dirty:ye,expanded:be,id:we,popupOpen:xe,focused:_e,focusedTag:Se,anchorEl:ke,setAnchorEl:Ce,inputValue:Oe,groupedOptions:Ee}=function(e){const{unstable_isActiveElementInListbox:t=jG,unstable_classNamePrefix:r="Mui",autoComplete:n=!1,autoHighlight:i=!1,autoSelect:s=!1,blurOnSelect:l=!1,clearOnBlur:c=!e.freeSolo,clearOnEscape:u=!1,componentName:p="useAutocomplete",defaultValue:d=(e.multiple?[]:null),disableClearable:f=!1,disableCloseOnSelect:h=!1,disabled:m,disabledItemsFocusable:g=!1,disableListWrap:v=!1,filterOptions:y=NG,filterSelectedOptions:b=!1,freeSolo:w=!1,getOptionDisabled:x,getOptionKey:_,getOptionLabel:S=e=>{var t;return null!=(t=e.label)?t:e},groupBy:k,handleHomeEndKeys:C=!e.freeSolo,id:O,includeInputInList:E=!1,inputValue:T,isOptionEqualToValue:R=(e,t)=>e===t,multiple:I=!1,onChange:M,onClose:A,onHighlightChange:P,onInputChange:N,onOpen:j,open:L,openOnFocus:D=!1,options:F,readOnly:$=!1,selectOnFocus:B=!e.freeSolo,value:z}=e,V=Cf(O);let U=S;U=e=>{const t=S(e);if("string"!=typeof t){if(true){const r=void 0===t?"undefined":`${typeof t} (${t})`;console.error(`MUI: The \`getOptionLabel\` method of ${p} returned ${r} instead of a string for ${JSON.stringify(e)}.`)}return String(t)}return t};const q=o.useRef(!1),W=o.useRef(!0),H=o.useRef(null),G=o.useRef(null),[K,Y]=o.useState(null),[Z,X]=o.useState(-1),J=i?0:-1,Q=o.useRef(J),[ee,te]=Of({controlled:z,default:d,name:p}),[re,ne]=Of({controlled:T,default:"",name:p,state:"inputValue"}),[oe,ie]=o.useState(!1),se=o.useCallback((e,t)=>{if(!(I?ee.length<t.length:null!==t)&&!c)return;let r;if(I)r="";else if(null==t)r="";else{const e=U(t);r="string"==typeof e?e:""}re!==r&&(ne(r),N&&N(e,r,"reset"))},[U,re,I,N,ne,c,ee]),[ae,le]=Of({controlled:L,default:!1,name:p,state:"open"}),[ce,ue]=o.useState(!0),pe=!I&&null!=ee&&re===U(ee),de=ae&&!$,fe=de?y(F.filter(e=>!b||!(I?ee:[ee]).some(t=>null!==t&&R(e,t))),{inputValue:pe&&ce?"":re,getOptionLabel:U}):[],he=Tf({filteredOptions:fe,value:ee,inputValue:re});o.useEffect(()=>{const e=ee!==he.value;oe&&!e||w&&!e||se(null,ee)},[ee,se,oe,he.value,w]);const me=ae&&fe.length>0&&!$;if( true&&null!==ee&&!w&&F.length>0){const e=(I?ee:[ee]).filter(e=>!F.some(t=>R(t,e)));e.length>0&&console.warn([`MUI: The value provided to ${p} is invalid.`,`None of the options match with \`${e.length>1?JSON.stringify(e):JSON.stringify(e[0])}\`.`,"You can use the `isOptionEqualToValue` prop to customize the equality test."].join("\n"))}const ge=Ba(e=>{-1===e?H.current.focus():K.querySelector(`[data-tag-index="${e}"]`).focus()});o.useEffect(()=>{I&&Z>ee.length-1&&(X(-1),ge(-1))},[ee,I,Z,ge]);const ve=Ba(({event:e,index:t,reason:n="auto"})=>{if(Q.current=t,-1===t?H.current.removeAttribute("aria-activedescendant"):H.current.setAttribute("aria-activedescendant",`${V}-option-${t}`),P&&P(e,-1===t?null:fe[t],n),!G.current)return;const o=G.current.querySelector(`[role="option"].${r}-focused`);o&&(o.classList.remove(`${r}-focused`),o.classList.remove(`${r}-focusVisible`));let i=G.current;if("listbox"!==G.current.getAttribute("role")&&(i=G.current.parentElement.querySelector('[role="listbox"]')),!i)return;if(-1===t)return void(i.scrollTop=0);const s=G.current.querySelector(`[data-option-index="${t}"]`);if(s&&(s.classList.add(`${r}-focused`),"keyboard"===n&&s.classList.add(`${r}-focusVisible`),i.scrollHeight>i.clientHeight&&"mouse"!==n&&"touch"!==n)){const e=s,t=i.clientHeight+i.scrollTop,r=e.offsetTop+e.offsetHeight;r>t?i.scrollTop=r-i.clientHeight:e.offsetTop-e.offsetHeight*(k?1.3:0)<i.scrollTop&&(i.scrollTop=e.offsetTop-e.offsetHeight*(k?1.3:0))}}),ye=Ba(({event:e,diff:t,direction:r="next",reason:o="auto"})=>{if(!de)return;const i=function(e,t){if(!G.current||e<0||e>=fe.length)return-1;let r=e;for(;;){const n=G.current.querySelector(`[data-option-index="${r}"]`),o=!g&&(!n||n.disabled||"true"===n.getAttribute("aria-disabled"));if(n&&n.hasAttribute("tabindex")&&!o)return r;if(r="next"===t?(r+1)%fe.length:(r-1+fe.length)%fe.length,r===e)return-1}}((()=>{const e=fe.length-1;if("reset"===t)return J;if("start"===t)return 0;if("end"===t)return e;const r=Q.current+t;return r<0?-1===r&&E?-1:v&&-1!==Q.current||Math.abs(t)>1?0:e:r>e?r===e+1&&E?-1:v||Math.abs(t)>1?e:0:r})(),r);if(ve({index:i,reason:o,event:e}),n&&"reset"!==t)if(-1===i)H.current.value=re;else{const e=U(fe[i]);H.current.value=e,0===e.toLowerCase().indexOf(re.toLowerCase())&&re.length>0&&H.current.setSelectionRange(re.length,e.length)}}),be=o.useCallback(()=>{if(!de)return;const e=(()=>{if(-1!==Q.current&&he.filteredOptions&&he.filteredOptions.length!==fe.length&&he.inputValue===re&&(I?ee.length===he.value.length&&he.value.every((e,t)=>U(ee[t])===U(e)):(e=he.value,t=ee,(e?U(e):"")===(t?U(t):"")))){const e=he.filteredOptions[Q.current];if(e)return PG(fe,t=>U(t)===U(e))}var e,t;return-1})();if(-1!==e)return void(Q.current=e);const t=I?ee[0]:ee;if(0!==fe.length&&null!=t){if(G.current){if(null!=t){const e=fe[Q.current];if(I&&e&&-1!==PG(ee,t=>R(e,t)))return;const r=PG(fe,e=>R(e,t));return void(-1===r?ye({diff:"reset"}):ve({index:r}))}Q.current>=fe.length-1?ve({index:fe.length-1}):ve({index:Q.current})}}else ye({diff:"reset"})},[fe.length,!I&&ee,b,ye,ve,de,re,I]),we=Ba(e=>{Da(G,e),e&&be()}); true&&o.useEffect(()=>{H.current&&"INPUT"===H.current.nodeName||(H.current&&"TEXTAREA"===H.current.nodeName?console.warn([`A textarea element was provided to ${p} where input was expected.`,"This is not a supported scenario but it may work under certain conditions.","A textarea keyboard navigation may conflict with Autocomplete controls (for example enter and arrow keys).","Make sure to test keyboard navigation and add custom event handlers if necessary."].join("\n")):console.error([`MUI: Unable to find the input element. It was resolved to ${H.current} while an HTMLInputElement was expected.`,`Instead, ${p} expects an input element.`,"","useAutocomplete"===p?"Make sure you have bound getInputProps correctly and that the normal ref/effect resolutions order is guaranteed.":"Make sure you have customized the input component correctly."].join("\n")))},[p]),o.useEffect(()=>{be()},[be]);const xe=e=>{ae||(le(!0),ue(!0),j&&j(e))},_e=(e,t)=>{ae&&(le(!1),A&&A(e,t))},Se=(e,t,r,n)=>{if(I){if(ee.length===t.length&&ee.every((e,r)=>e===t[r]))return}else if(ee===t)return;M&&M(e,t,r,n),te(t)},ke=o.useRef(!1),Ce=(e,t,r="selectOption",n="options")=>{let o=r,i=t;if(I){if(i=Array.isArray(ee)?ee.slice():[],"production"!=="development"){const e=i.filter(e=>R(t,e));e.length>1&&console.error([`MUI: The \`isOptionEqualToValue\` method of ${p} does not handle the arguments correctly.`,`The component expects a single value to match a given option but found ${e.length} matches.`].join("\n"))}const e=PG(i,e=>R(t,e));-1===e?i.push(t):"freeSolo"!==n&&(i.splice(e,1),o="removeOption")}se(e,i),Se(e,i,o,{option:t}),h||e&&(e.ctrlKey||e.metaKey)||_e(e,o),(!0===l||"touch"===l&&ke.current||"mouse"===l&&!ke.current)&&H.current.blur()},Oe=(e,t)=>{if(!I)return;""===re&&_e(e,"toggleInput");let r=Z;-1===Z?""===re&&"previous"===t&&(r=ee.length-1):(r+="next"===t?1:-1,r<0&&(r=0),r===ee.length&&(r=-1)),r=function(e,t){if(-1===e)return-1;let r=e;for(;;){if("next"===t&&r===ee.length||"previous"===t&&-1===r)return-1;const e=K.querySelector(`[data-tag-index="${r}"]`);if(e&&e.hasAttribute("tabindex")&&!e.disabled&&"true"!==e.getAttribute("aria-disabled"))return r;r+="next"===t?1:-1}}(r,t),X(r),ge(r)},Ee=e=>{q.current=!0,ne(""),N&&N(e,"","clear"),Se(e,I?[]:null,"clear")},Te=e=>t=>{if(e.onKeyDown&&e.onKeyDown(t),!t.defaultMuiPrevented&&(-1!==Z&&-1===["ArrowLeft","ArrowRight"].indexOf(t.key)&&(X(-1),ge(-1)),229!==t.which))switch(t.key){case"Home":de&&C&&(t.preventDefault(),ye({diff:"start",direction:"next",reason:"keyboard",event:t}));break;case"End":de&&C&&(t.preventDefault(),ye({diff:"end",direction:"previous",reason:"keyboard",event:t}));break;case"PageUp":t.preventDefault(),ye({diff:-5,direction:"previous",reason:"keyboard",event:t}),xe(t);break;case"PageDown":t.preventDefault(),ye({diff:5,direction:"next",reason:"keyboard",event:t}),xe(t);break;case"ArrowDown":t.preventDefault(),ye({diff:1,direction:"next",reason:"keyboard",event:t}),xe(t);break;case"ArrowUp":t.preventDefault(),ye({diff:-1,direction:"previous",reason:"keyboard",event:t}),xe(t);break;case"ArrowLeft":Oe(t,"previous");break;case"ArrowRight":Oe(t,"next");break;case"Enter":if(-1!==Q.current&&de){const e=fe[Q.current],r=!!x&&x(e);if(t.preventDefault(),r)return;Ce(t,e,"selectOption"),n&&H.current.setSelectionRange(H.current.value.length,H.current.value.length)}else w&&""!==re&&!1===pe&&(I&&t.preventDefault(),Ce(t,re,"createOption","freeSolo"));break;case"Escape":de?(t.preventDefault(),t.stopPropagation(),_e(t,"escape")):u&&(""!==re||I&&ee.length>0)&&(t.preventDefault(),t.stopPropagation(),Ee(t));break;case"Backspace":if(I&&!$&&""===re&&ee.length>0){const e=-1===Z?ee.length-1:Z,r=ee.slice();r.splice(e,1),Se(t,r,"removeOption",{option:ee[e]})}break;case"Delete":if(I&&!$&&""===re&&ee.length>0&&-1!==Z){const e=Z,r=ee.slice();r.splice(e,1),Se(t,r,"removeOption",{option:ee[e]})}}},Re=e=>{ie(!0),D&&!q.current&&xe(e)},Ie=e=>{t(G)?H.current.focus():(ie(!1),W.current=!0,q.current=!1,s&&-1!==Q.current&&de?Ce(e,fe[Q.current],"blur"):s&&w&&""!==re?Ce(e,re,"blur","freeSolo"):c&&se(e,ee),_e(e,"blur"))},Me=e=>{const t=e.target.value;re!==t&&(ne(t),ue(!1),N&&N(e,t,"input")),""===t?f||I||Se(e,null,"clear"):xe(e)},Ae=e=>{const t=Number(e.currentTarget.getAttribute("data-option-index"));Q.current!==t&&ve({event:e,index:t,reason:"mouse"})},Pe=e=>{ve({event:e,index:Number(e.currentTarget.getAttribute("data-option-index")),reason:"touch"}),ke.current=!0},Ne=e=>{const t=Number(e.currentTarget.getAttribute("data-option-index"));Ce(e,fe[t],"selectOption"),ke.current=!1},je=e=>t=>{const r=ee.slice();r.splice(e,1),Se(t,r,"removeOption",{option:ee[e]})},Le=e=>{ae?_e(e,"toggleInput"):xe(e)},De=e=>{e.currentTarget.contains(e.target)&&e.target.getAttribute("id")!==V&&e.preventDefault()},Fe=e=>{e.currentTarget.contains(e.target)&&(H.current.focus(),B&&W.current&&H.current.selectionEnd-H.current.selectionStart===0&&H.current.select(),W.current=!1)},$e=e=>{m||""!==re&&ae||Le(e)};let Be=w&&re.length>0;Be=Be||(I?ee.length>0:null!==ee);let ze=fe;if(k){const e=new Map;let t=!1;ze=fe.reduce((r,n,o)=>{const i=k(n);return r.length>0&&r[r.length-1].group===i?r[r.length-1].options.push(n):( true&&(e.get(i)&&!t&&(console.warn(`MUI: The options provided combined with the \`groupBy\` method of ${p} returns duplicated headers.`,"You can solve the issue by sorting the options with the output of `groupBy`."),t=!0),e.set(i,!0)),r.push({key:o,index:o,group:i,options:[n]})),r},[])}return m&&oe&&Ie(),{getRootProps:(e={})=>a({"aria-owns":me?`${V}-listbox`:null},e,{onKeyDown:Te(e),onMouseDown:De,onClick:Fe}),getInputLabelProps:()=>({id:`${V}-label`,htmlFor:V}),getInputProps:()=>({id:V,value:re,onBlur:Ie,onFocus:Re,onChange:Me,onMouseDown:$e,"aria-activedescendant":de?"":null,"aria-autocomplete":n?"both":"list","aria-controls":me?`${V}-listbox`:void 0,"aria-expanded":me,autoComplete:"off",ref:H,autoCapitalize:"none",spellCheck:"false",role:"combobox",disabled:m}),getClearProps:()=>({tabIndex:-1,type:"button",onClick:Ee}),getPopupIndicatorProps:()=>({tabIndex:-1,type:"button",onClick:Le}),getTagProps:({index:e})=>a({key:e,"data-tag-index":e,tabIndex:-1},!$&&{onDelete:je(e)}),getListboxProps:()=>({role:"listbox",id:`${V}-listbox`,"aria-labelledby":`${V}-label`,ref:we,onMouseDown:e=>{e.preventDefault()}}),getOptionProps:({index:e,option:t})=>{var r;const n=(I?ee:[ee]).some(e=>null!=e&&R(t,e)),o=!!x&&x(t);return{key:null!=(r=null==_?void 0:_(t))?r:U(t),tabIndex:-1,role:"option",id:`${V}-option-${e}`,onMouseMove:Ae,onClick:Ne,onTouchStart:Pe,"data-option-index":e,"aria-disabled":o,"aria-selected":n}},id:V,inputValue:re,value:ee,dirty:Be,expanded:de&&K,popupOpen:de,focused:oe||-1!==Z,anchorEl:K,setAnchorEl:Y,focusedTag:Z,groupedOptions:ze}}(a({},p,{componentName:"Autocomplete"})),Te=!C&&!E&&ye&&!ee,Re=(!P||!0===A)&&!1!==A,{onMouseDown:Ie}=ue(),{ref:Me}=null!=q?q:{},Ae=me(),{ref:Pe}=Ae,Ne=s(Ae,wK),je=Fa(Pe,Me),Le=L||(e=>{var t;return null!=(t=e.label)?t:e}),De=a({},p,{disablePortal:I,expanded:be,focused:_e,fullWidth:N,getOptionLabel:Le,hasClearIcon:Te,hasPopupIcon:Re,inputFocused:-1===Se,popupOpen:xe,size:se}),Fe=(e=>{const{classes:t,disablePortal:r,expanded:n,focused:o,fullWidth:i,hasClearIcon:s,hasPopupIcon:a,inputFocused:l,popupOpen:c,size:u}=e;return U({root:["root",n&&"expanded",o&&"focused",i&&"fullWidth",s&&"hasClearIcon",a&&"hasPopupIcon"],inputRoot:["inputRoot"],input:["input",l&&"inputFocused"],tag:["tag",`tagSize${Zi(u)}`],endAdornment:["endAdornment"],clearIndicator:["clearIndicator"],popupIndicator:["popupIndicator",c&&"popupIndicatorOpen"],popper:["popper",r&&"popperDisablePortal"],paper:["paper"],listbox:["listbox"],loading:["loading"],noOptions:["noOptions"],option:["option"],groupLabel:["groupLabel"],groupUl:["groupUl"]},mK,t)})(De);let $e;if(G&&ve.length>0){const t=e=>a({className:Fe.tag,disabled:E},he(e));$e=oe?oe(ve,t,De):ve.map((r,n)=>e.jsx(Nz,a({label:Le(r),size:se},t({index:n}),g)))}if(B>-1&&Array.isArray($e)){const t=$e.length-B;!_e&&t>0&&($e=$e.splice(0,B),$e.push(e.jsx("span",{className:Fe.tag,children:j(t)},$e.length)))}const Be=te||(t=>e.jsxs("li",{children:[e.jsx(MK,{className:Fe.groupLabel,ownerState:De,component:"div",children:t.group}),e.jsx(AK,{className:Fe.groupUl,ownerState:De,children:t.children})]},t.key)),ze=ne||((e,r)=>t.createElement("li",a({},e,{key:e.key}),Le(r))),Ve=(e,t)=>{const r=ge({option:e,index:t});return ze(a({},r,{className:Fe.option}),e,{selected:r["aria-selected"],index:t,inputValue:Oe},De)},Ue=null!=(i=ae.clearIndicator)?i:S.clearIndicator,qe=null!=(l=ae.paper)?l:S.paper,We=null!=(c=ae.popper)?c:S.popper,He=null!=(u=ae.popupIndicator)?u:S.popupIndicator,Ge=t=>e.jsx(OK,a({as:J,disablePortal:I,style:{width:ke?ke.clientWidth:null},ownerState:De,role:"presentation",anchorEl:ke,open:xe},We,{className:V(Fe.popper,null==We?void 0:We.className),children:e.jsx(EK,a({ownerState:De,as:X},qe,{className:V(Fe.paper,null==qe?void 0:qe.className),children:t}))}));let Ke=null;return Ee.length>0?Ke=Ge(e.jsx(IK,a({as:z,className:Fe.listbox,ownerState:De},Ne,q,{ref:je,children:Ee.map((e,t)=>D?Be({key:e.key,group:e.group,children:e.options.map((t,r)=>Ve(t,e.index+r))}):Ve(e,t))}))):W&&0===Ee.length?Ke=Ge(e.jsx(TK,{className:Fe.loading,ownerState:De,children:H})):0!==Ee.length||P||W||(Ke=Ge(e.jsx(RK,{className:Fe.noOptions,ownerState:De,role:"presentation",onMouseDown:e=>{e.preventDefault()},children:K}))),e.jsxs(o.Fragment,{children:[e.jsx(_K,a({ref:n,className:V(Fe.root,v),ownerState:De},ce(le),{children:re({id:we,disabled:E,fullWidth:!0,size:"small"===se?"small":void 0,InputLabelProps:pe(),InputProps:a({ref:Ce,className:Fe.inputRoot,startAdornment:$e,onClick:e=>{e.target===e.currentTarget&&Ie(e)}},(Te||Re)&&{endAdornment:e.jsxs(SK,{className:Fe.endAdornment,ownerState:De,children:[Te?e.jsx(kK,a({},fe(),{"aria-label":x,title:x,ownerState:De},Ue,{className:V(Fe.clearIndicator,null==Ue?void 0:Ue.className),children:y})):null,Re?e.jsx(CK,a({},de(),{disabled:E,"aria-label":xe?_:Z,title:xe?_:Z,ownerState:De},He,{className:V(Fe.popupIndicator,null==He?void 0:He.className),children:Q})):null]})}),inputProps:a({className:Fe.input,disabled:E,readOnly:ee},ue())})})),ke?Ke:null]})}); true&&(PK.propTypes={autoComplete:B.bool,autoHighlight:B.bool,autoSelect:B.bool,blurOnSelect:B.oneOfType([B.oneOf(["mouse","touch"]),B.bool]),ChipProps:B.object,classes:B.object,className:B.string,clearIcon:B.node,clearOnBlur:B.bool,clearOnEscape:B.bool,clearText:B.string,closeText:B.string,componentsProps:B.shape({clearIndicator:B.object,paper:B.object,popper:B.object,popupIndicator:B.object}),defaultValue:rs(B.any,e=>e.multiple&&void 0!==e.defaultValue&&!Array.isArray(e.defaultValue)?new Error(["MUI: The Autocomplete expects the `defaultValue` prop to be an array when `multiple={true}` or undefined.",`However, ${e.defaultValue} was provided.`].join("\n")):null),disableClearable:B.bool,disableCloseOnSelect:B.bool,disabled:B.bool,disabledItemsFocusable:B.bool,disableListWrap:B.bool,disablePortal:B.bool,filterOptions:B.func,filterSelectedOptions:B.bool,forcePopupIcon:B.oneOfType([B.oneOf(["auto"]),B.bool]),freeSolo:B.bool,fullWidth:B.bool,getLimitTagsText:B.func,getOptionDisabled:B.func,getOptionKey:B.func,getOptionLabel:B.func,groupBy:B.func,handleHomeEndKeys:B.bool,id:B.string,includeInputInList:B.bool,inputValue:B.string,isOptionEqualToValue:B.func,limitTags:ts,ListboxComponent:B.elementType,ListboxProps:B.object,loading:B.bool,loadingText:B.node,multiple:B.bool,noOptionsText:B.node,onChange:B.func,onClose:B.func,onHighlightChange:B.func,onInputChange:B.func,onKeyDown:B.func,onOpen:B.func,open:B.bool,openOnFocus:B.bool,openText:B.string,options:B.array.isRequired,PaperComponent:B.elementType,PopperComponent:B.elementType,popupIcon:B.node,readOnly:B.bool,renderGroup:B.func,renderInput:B.func.isRequired,renderOption:B.func,renderTags:B.func,selectOnFocus:B.bool,size:B.oneOfType([B.oneOf(["small","medium"]),B.string]),slotProps:B.shape({clearIndicator:B.object,paper:B.object,popper:B.object,popupIndicator:B.object}),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),value:rs(B.any,e=>e.multiple&&void 0!==e.value&&!Array.isArray(e.value)?new Error(["MUI: The Autocomplete expects the `value` prop to be an array when `multiple={true}` or undefined.",`However, ${e.value} was provided.`].join("\n")):null)});const NK=PK,jK="MuiAutocomplete-listbox",LK={slotProps:{paper:{elevation:6}}};var DK=t.forwardRef((e,r)=>{const{renderInput:n,ListboxProps:o={},...i}=e,s={...LK,...i,slotProps:{...LK.slotProps,...i.slotProps,paper:{...LK.slotProps?.paper,...i.slotProps?.paper}}};return t.createElement(NK,{...s,ListboxProps:{...o,className:V([jK,`${jK}Size${a=i.size||"medium",a?a[0].toUpperCase()+a.slice(1):""}`,o.className])},renderInput:t=>n?.(function(e,t){const r=e;return t.size&&(r.size=t.size),r}(t,e)),ref:r});// removed by dead control flow
 var a; });const FK=["className","elementType","ownerState","externalForwardedProps","getSlotOwnerState","internalForwardedProps"],$K=["component","slots","slotProps"],BK=["component"];function zK(e,t){const{className:r,elementType:n,ownerState:o,externalForwardedProps:i,getSlotOwnerState:l,internalForwardedProps:c}=t,u=s(t,FK),{component:p,slots:d={[e]:void 0},slotProps:f={[e]:void 0}}=i,h=s(i,$K),m=d[e]||n,g=pf(f[e],o),v=If(a({className:r},u,{externalForwardedProps:"root"===e?h:void 0,externalSlotProps:g})),{props:{component:y},internalRef:b}=v,w=s(v.props,BK),x=Fa(b,null==g?void 0:g.ref,t.ref),_=l?l(w):{},S=a({},o,_),k="root"===e?y||p:y,C=af(m,a({},"root"===e&&!p&&!d[e]&&c,"root"!==e&&!d[e]&&c,w,k&&{as:k},{ref:x}),S);return Object.keys(_).forEach(e=>{delete C[e]}),[m,C]}function VK(e){return Mo("MuiAlert",e)}const UK=ta("MuiAlert",["root","action","icon","message","filled","colorSuccess","colorInfo","colorWarning","colorError","filledSuccess","filledInfo","filledWarning","filledError","outlined","outlinedSuccess","outlinedInfo","outlinedWarning","outlinedError","standard","standardSuccess","standardInfo","standardWarning","standardError"]),qK=Cz(e.jsx("path",{d:"M20,12A8,8 0 0,1 12,20A8,8 0 0,1 4,12A8,8 0 0,1 12,4C12.76,4 13.5,4.11 14.2, 4.31L15.77,2.74C14.61,2.26 13.34,2 12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0, 0 22,12M7.91,10.08L6.5,11.5L11,16L21,6L19.59,4.58L11,13.17L7.91,10.08Z"}),"SuccessOutlined"),WK=Cz(e.jsx("path",{d:"M12 5.99L19.53 19H4.47L12 5.99M12 2L1 21h22L12 2zm1 14h-2v2h2v-2zm0-6h-2v4h2v-4z"}),"ReportProblemOutlined"),HK=Cz(e.jsx("path",{d:"M11 15h2v2h-2zm0-8h2v6h-2zm.99-5C6.47 2 2 6.48 2 12s4.47 10 9.99 10C17.52 22 22 17.52 22 12S17.52 2 11.99 2zM12 20c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8z"}),"ErrorOutline"),GK=Cz(e.jsx("path",{d:"M11,9H13V7H11M12,20C7.59,20 4,16.41 4,12C4,7.59 7.59,4 12,4C16.41,4 20,7.59 20, 12C20,16.41 16.41,20 12,20M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10, 10 0 0,0 12,2M11,17H13V11H11V17Z"}),"InfoOutlined"),KK=["action","children","className","closeText","color","components","componentsProps","icon","iconMapping","onClose","role","severity","slotProps","slots","variant"],YK=xU(),ZK=Vi(sa,{name:"MuiAlert",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,t[r.variant],t[`${r.variant}${Zi(r.color||r.severity)}`]]}})(({theme:e})=>{const t="light"===e.palette.mode?Fo.darken:Fo.lighten,r="light"===e.palette.mode?Fo.lighten:Fo.darken;return a({},e.typography.body2,{backgroundColor:"transparent",display:"flex",padding:"6px 16px",variants:[...Object.entries(e.palette).filter(([,e])=>e.main&&e.light).map(([n])=>({props:{colorSeverity:n,variant:"standard"},style:{color:e.vars?e.vars.palette.Alert[`${n}Color`]:t(e.palette[n].light,.6),backgroundColor:e.vars?e.vars.palette.Alert[`${n}StandardBg`]:r(e.palette[n].light,.9),[`& .${UK.icon}`]:e.vars?{color:e.vars.palette.Alert[`${n}IconColor`]}:{color:e.palette[n].main}}})),...Object.entries(e.palette).filter(([,e])=>e.main&&e.light).map(([r])=>({props:{colorSeverity:r,variant:"outlined"},style:{color:e.vars?e.vars.palette.Alert[`${r}Color`]:t(e.palette[r].light,.6),border:`1px solid ${(e.vars||e).palette[r].light}`,[`& .${UK.icon}`]:e.vars?{color:e.vars.palette.Alert[`${r}IconColor`]}:{color:e.palette[r].main}}})),...Object.entries(e.palette).filter(([,e])=>e.main&&e.dark).map(([t])=>({props:{colorSeverity:t,variant:"filled"},style:a({fontWeight:e.typography.fontWeightMedium},e.vars?{color:e.vars.palette.Alert[`${t}FilledColor`],backgroundColor:e.vars.palette.Alert[`${t}FilledBg`]}:{backgroundColor:"dark"===e.palette.mode?e.palette[t].dark:e.palette[t].main,color:e.palette.getContrastText(e.palette[t].main)})}))]})}),XK=Vi("div",{name:"MuiAlert",slot:"Icon",overridesResolver:(e,t)=>t.icon})({marginRight:12,padding:"7px 0",display:"flex",fontSize:22,opacity:.9}),JK=Vi("div",{name:"MuiAlert",slot:"Message",overridesResolver:(e,t)=>t.message})({padding:"8px 0",minWidth:0,overflow:"auto"}),QK=Vi("div",{name:"MuiAlert",slot:"Action",overridesResolver:(e,t)=>t.action})({display:"flex",alignItems:"flex-start",padding:"4px 0 0 16px",marginLeft:"auto",marginRight:-8}),eY={success:e.jsx(qK,{fontSize:"inherit"}),warning:e.jsx(WK,{fontSize:"inherit"}),error:e.jsx(HK,{fontSize:"inherit"}),info:e.jsx(GK,{fontSize:"inherit"})},tY=o.forwardRef(function(t,r){const n=YK({props:t,name:"MuiAlert"}),{action:o,children:i,className:l,closeText:c="Close",color:u,components:p={},componentsProps:d={},icon:f,iconMapping:h=eY,onClose:m,role:g="alert",severity:v="success",slotProps:y={},slots:b={},variant:w="standard"}=n,x=s(n,KK),_=a({},n,{color:u,severity:v,variant:w,colorSeverity:u||v}),S=(e=>{const{variant:t,color:r,severity:n,classes:o}=e;return U({root:["root",`color${Zi(r||n)}`,`${t}${Zi(r||n)}`,`${t}`],icon:["icon"],message:["message"],action:["action"]},VK,o)})(_),k={slots:a({closeButton:p.CloseButton,closeIcon:p.CloseIcon},b),slotProps:a({},d,y)},[C,O]=zK("closeButton",{elementType:Ul,externalForwardedProps:k,ownerState:_}),[E,T]=zK("closeIcon",{elementType:fK,externalForwardedProps:k,ownerState:_});return e.jsxs(ZK,a({role:g,elevation:0,ownerState:_,className:V(S.root,l),ref:r},x,{children:[!1!==f?e.jsx(XK,{ownerState:_,className:S.icon,children:f||h[v]||eY[v]}):null,e.jsx(JK,{ownerState:_,className:S.message,children:i}),null!=o?e.jsx(QK,{ownerState:_,className:S.action,children:o}):null,null==o&&m?e.jsx(QK,{ownerState:_,className:S.action,children:e.jsx(C,a({size:"small","aria-label":c,title:c,color:"inherit",onClick:m},O,{children:e.jsx(E,a({fontSize:"small"},T))}))}):null]}))}); true&&(tY.propTypes={action:B.node,children:B.node,classes:B.object,className:B.string,closeText:B.string,color:B.oneOfType([B.oneOf(["error","info","success","warning"]),B.string]),components:B.shape({CloseButton:B.elementType,CloseIcon:B.elementType}),componentsProps:B.shape({closeButton:B.object,closeIcon:B.object}),icon:B.node,iconMapping:B.shape({error:B.node,info:B.node,success:B.node,warning:B.node}),onClose:B.func,role:B.string,severity:B.oneOfType([B.oneOf(["error","info","success","warning"]),B.string]),slotProps:B.shape({closeButton:B.oneOfType([B.func,B.object]),closeIcon:B.oneOfType([B.func,B.object])}),slots:B.shape({closeButton:B.elementType,closeIcon:B.elementType}),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),variant:B.oneOfType([B.oneOf(["filled","outlined","standard"]),B.string])});const rY=sc(tY)(({theme:e,severity:t,color:r,variant:n,ownerState:o})=>{const i="small"===o.size,s=function(e,t,r,n){const o=t||e;return o?"filled"===r?{"& .MuiButton-containedInherit:not(.Mui-disabled)":{color:n.palette[o].main,backgroundColor:"rgba(255, 255, 255, 1)","&:hover":{backgroundColor:"rgba(255, 255, 255, .96)"}},"& .MuiButton-outlinedInherit:not(.Mui-disabled):hover":{backgroundColor:n.palette[o].dark},"& a.MuiButtonBase-root.MuiButton-containedInherit:not(.Mui-disabled)":{[ql]:{color:n.palette[o].main}}}:{"&.MuiAlert-root":{color:n.palette.text.secondary},"& .MuiCloseButton-root":{color:n.palette.action.active},"& .MuiButton-containedInherit:not(.Mui-disabled)":{backgroundColor:n.palette[o].main,color:n.palette[o].contrastText,"&:hover":{backgroundColor:n.palette[o].dark,color:n.palette[o].contrastText}},"& .MuiButton-outlinedInherit:not(.Mui-disabled)":{borderColor:n.palette[o].main,color:n.palette[o].main,"&:hover":{backgroundColor:Rs(n.palette[o].main,.08),color:n.palette[o].main}},"& a.MuiButtonBase-root.MuiButton-containedInherit:not(.Mui-disabled)":{[ql]:{color:n.palette[o].contrastText}},"& a.MuiButtonBase-root.MuiButton-outlinedInherit:not(.Mui-disabled)":{[ql]:{color:n.palette[o].main}}}:{}}(t,r,n,e),a=function(e,t){return"small"!==e.size?{}:{"& .MuiButtonBase-root.MuiButton-root":{fontSize:t.typography.caption.fontSize,letterSpacing:t.typography.caption.letterSpacing,lineHeight:1},"& .MuiButtonBase-root.MuiButton-contained":{padding:"8px 9px"},"& .MuiButtonBase-root.MuiButton-outlined":{padding:"7px 9px"}}}(o,e),l=i?{...e.typography.caption,fontWeight:e.typography.subtitle2.fontWeight,lineHeight:e.typography.subtitle2.lineHeight}:e.typography.subtitle2,c=i?{...e.typography.caption,lineHeight:e.typography.body2.lineHeight}:{};return{borderRadius:o.square?void 0:e.shape.borderRadius*e.shape.__unstableBorderRadiusMultipliers[2],padding:i?e.spacing(1.5):e.spacing(1.5,2),"& .MuiAlert-message":{width:"100%",padding:0,minHeight:i?"28px":"31px",display:"flex",flexDirection:"row",flexWrap:"wrap",gap:i?e.spacing(1):e.spacing(1.5),...c},"& .MuiAlertTitle-root":{marginBottom:0,lineHeight:"inherit",marginRight:i?e.spacing(.25):e.spacing(.5),marginTop:0,...l},"& .MuiAlert-icon":{fontSize:i?"18px":"22px",padding:i?e.spacing(.25):0,paddingTop:i?"5px":e.spacing(.5),marginRight:i?e.spacing(.5):e.spacing(1.5)},"& .MuiAlert-action":{padding:i?e.spacing(.25,0,0):0,marginLeft:i?e.spacing(.5):e.spacing(1)},"&.MuiAlert-filledWarning":{color:e.palette.common.white},...a,...s}}),{slots:nY,classNames:oY}=tc("Alert",["actions","content"]),iY=sc("div",nY.content)(()=>({flexGrow:1,paddingTop:"6px"})),sY=sc("div",nY.content)(({theme:e})=>({alignItems:"center",display:"flex",flexWrap:"wrap",gap:e.spacing(.25),maxWidth:"800px"})),aY=({children:e,...r})=>t.createElement(iY,{...r},t.createElement(sY,null,e)),lY=sc("div")(({theme:e,ownerState:t})=>({display:"flex",alignItems:"flex-start",flexWrap:"wrap",gap:"small"===t.size?e.spacing(.5):e.spacing(1)})),cY={closeText:"Close",severity:"success",size:"medium"},uY=t.forwardRef((e,r)=>{const{onClose:n,action:o,secondaryAction:i,children:s,size:a,...l}={...cY,...e},c=Boolean(o||i);return t.createElement(rY,{iconMapping:{success:t.createElement(dY,null),error:t.createElement(hY,null),info:t.createElement(fY,null),warning:t.createElement(mY,null)},...l,ref:r,action:!!n&&t.createElement(UW,{color:"inherit",onClick:n,slotProps:{icon:{fontSize:"small"===a?"tiny":"small"}},title:l.closeText,"aria-label":l.closeText}),ownerState:{size:a,square:l.square}},t.createElement(aY,{className:oY.content},s),c&&t.createElement(lY,{className:oY.actions,ownerState:{size:a}},i,o))});uY.defaultProps=cY;var pY=uY;function dY(){return t.createElement(Cu,{viewBox:"0 0 24 24",fontSize:"inherit"},t.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M12 2.25C10.7196 2.25 9.45176 2.50219 8.26884 2.99217C7.08591 3.48216 6.01108 4.20034 5.10571 5.10571C4.20034 6.01108 3.48216 7.08591 2.99217 8.26884C2.50219 9.45176 2.25 10.7196 2.25 12C2.25 13.2804 2.50219 14.5482 2.99217 15.7312C3.48216 16.9141 4.20034 17.9889 5.10571 18.8943C6.01108 19.7997 7.08591 20.5178 8.26884 21.0078C9.45176 21.4978 10.7196 21.75 12 21.75C13.2804 21.75 14.5482 21.4978 15.7312 21.0078C16.9141 20.5178 17.9889 19.7997 18.8943 18.8943C19.7997 17.9889 20.5178 16.9141 21.0078 15.7312C21.4978 14.5482 21.75 13.2804 21.75 12C21.75 10.7196 21.4978 9.45176 21.0078 8.26884C20.5178 7.08591 19.7997 6.01108 18.8943 5.10571C17.9889 4.20034 16.9141 3.48216 15.7312 2.99217C14.5482 2.50219 13.2804 2.25 12 2.25ZM16.2415 10.0563C16.5344 9.76339 16.5344 9.28852 16.2415 8.99563C15.9486 8.70273 15.4737 8.70273 15.1809 8.99563L10.7631 13.4134L8.81939 11.4697C8.5265 11.1768 8.05163 11.1768 7.75873 11.4697C7.46584 11.7626 7.46584 12.2374 7.75873 12.5303L10.2328 15.0044C10.3734 15.145 10.5642 15.224 10.7631 15.224C10.962 15.224 11.1528 15.145 11.2934 15.0044L16.2415 10.0563Z"}))}function fY(){return t.createElement(Cu,{viewBox:"0 0 24 24",fontSize:"inherit"},t.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M11.75 2C17.1348 2 21.5 6.36522 21.5 11.75C21.5 17.1348 17.1348 21.5 11.75 21.5C6.36522 21.5 2 17.1348 2 11.75C2 6.36522 6.36522 2 11.75 2ZM10.75 10C10.3358 10 10 10.3358 10 10.75C10 11.1642 10.3358 11.5 10.75 11.5H11V15.75C11 16.1642 11.3358 16.5 11.75 16.5H12.75C13.1642 16.5 13.5 16.1642 13.5 15.75C13.5 15.3358 13.1642 15 12.75 15H12.5V10.75C12.5 10.3618 12.2051 10.0425 11.8271 10.0039L11.75 10H10.75ZM11.4502 6.75C10.8979 6.75 10.4502 7.19772 10.4502 7.75C10.4502 8.30228 10.8979 8.75 11.4502 8.75H11.46L11.5625 8.74512C12.0666 8.69378 12.46 8.26767 12.46 7.75C12.46 7.23233 12.0666 6.80622 11.5625 6.75488L11.46 6.75H11.4502Z"}))}function hY(){return t.createElement(Cu,{viewBox:"0 0 24 24",fontSize:"inherit"},t.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M15.0498 2C15.2873 2 15.5191 2.04048 15.7422 2.13965C15.962 2.23735 16.136 2.37531 16.2803 2.51953L20.9805 7.21973C21.1247 7.36397 21.2627 7.53802 21.3604 7.75781C21.4595 7.98094 21.5 8.21268 21.5 8.4502V15.0498C21.5 15.2873 21.4595 15.5191 21.3604 15.7422C21.2627 15.962 21.1247 16.136 20.9805 16.2803L16.2803 20.9805C16.136 21.1247 15.962 21.2627 15.7422 21.3604C15.5191 21.4595 15.2873 21.5 15.0498 21.5H8.4502C8.21268 21.5 7.98094 21.4595 7.75781 21.3604C7.53802 21.2627 7.36397 21.1247 7.21973 20.9805L2.51953 16.2803C2.37531 16.136 2.23735 15.962 2.13965 15.7422C2.04048 15.5191 2 15.2873 2 15.0498V8.4502C2 8.21268 2.04048 7.98094 2.13965 7.75781C2.23735 7.53802 2.37531 7.36397 2.51953 7.21973L7.21973 2.51953C7.36397 2.37531 7.53802 2.23735 7.75781 2.13965C7.98094 2.04048 8.21268 2 8.4502 2H15.0498ZM11.75 14.75C11.1977 14.75 10.75 15.1977 10.75 15.75C10.75 16.3023 11.1977 16.75 11.75 16.75H11.7598L11.8623 16.7451C12.3665 16.6939 12.7598 16.2678 12.7598 15.75C12.7598 15.2322 12.3665 14.8061 11.8623 14.7549L11.7598 14.75H11.75ZM11.75 7C11.3358 7 11 7.33579 11 7.75V12.75C11 13.1642 11.3358 13.5 11.75 13.5C12.1642 13.5 12.5 13.1642 12.5 12.75V7.75C12.5 7.33579 12.1642 7 11.75 7Z"}))}function mY(){return t.createElement(Cu,{viewBox:"0 0 24 24",fontSize:"inherit"},t.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M11.9302 3.00684C12.3573 3.03542 12.7729 3.16362 13.1431 3.38184C13.5618 3.6287 13.9074 3.98244 14.1451 4.40625L21.2456 16.6562L21.2915 16.751C21.4597 17.1668 21.524 17.6183 21.4781 18.0645C21.432 18.5106 21.2773 18.9397 21.0279 19.3125C20.7784 19.685 20.4411 19.9915 20.0464 20.2041C19.6517 20.4166 19.2105 20.529 18.7622 20.5322L18.7564 20.5332H4.75638C4.73812 20.5332 4.71964 20.5316 4.7017 20.5303C4.69631 20.5307 4.69052 20.5319 4.6851 20.5322L4.60795 20.5312L4.44388 20.5186C4.06393 20.476 3.69614 20.3543 3.36478 20.1611C2.98591 19.9403 2.66472 19.6317 2.42924 19.2617C2.19395 18.8919 2.051 18.4707 2.01127 18.0342C1.97166 17.5975 2.03678 17.1563 2.2017 16.75L2.2476 16.6562L9.34721 4.40625C9.58473 3.98261 9.93165 3.62868 10.3501 3.38184C10.7731 3.13252 11.2556 3.00006 11.7466 3L11.9302 3.00684ZM11.7574 15.7822C11.2051 15.7822 10.7574 16.2299 10.7574 16.7822C10.7574 17.3345 11.2051 17.7822 11.7574 17.7822H11.7671L11.8697 17.7773C12.3737 17.7259 12.7671 17.2998 12.7671 16.7822C12.7671 16.2647 12.3737 15.8386 11.8697 15.7871L11.7671 15.7822H11.7574ZM11.7564 8.0332C11.3424 8.03352 11.0064 8.36919 11.0064 8.7832V13.7832C11.0069 14.1968 11.3428 14.5329 11.7564 14.5332C12.1702 14.5332 12.5059 14.1969 12.5064 13.7832V8.7832C12.5064 8.36902 12.1706 8.03325 11.7564 8.0332Z"}))}const{slots:gY,classNames:vY}=tc("AlertAction",["root"]),yY=sc(wp,gY.root)({}),bY={color:"inherit",variant:"outlined"},wY=t.forwardRef((e,r)=>{const n=Yi({props:{...bY,...e},name:gY.root.name});return t.createElement(yY,{...n,size:"small",ref:r,className:V([[vY.root,n.className]]),ownerState:n})});wY.defaultProps=bY;var xY=wY;function _Y(e){return Mo("MuiSnackbarContent",e)}ta("MuiSnackbarContent",["root","message","action"]);const SY=["action","className","message","role"],kY=Vi(sa,{name:"MuiSnackbarContent",slot:"Root",overridesResolver:(e,t)=>t.root})(({theme:e})=>{const t="light"===e.palette.mode?.8:.98,r=Fo.emphasize(e.palette.background.default,t);return a({},e.typography.body2,{color:e.vars?e.vars.palette.SnackbarContent.color:e.palette.getContrastText(r),backgroundColor:e.vars?e.vars.palette.SnackbarContent.bg:r,display:"flex",alignItems:"center",flexWrap:"wrap",padding:"6px 16px",borderRadius:(e.vars||e).shape.borderRadius,flexGrow:1,[e.breakpoints.up("sm")]:{flexGrow:"initial",minWidth:288}})}),CY=Vi("div",{name:"MuiSnackbarContent",slot:"Message",overridesResolver:(e,t)=>t.message})({padding:"8px 0"}),OY=Vi("div",{name:"MuiSnackbarContent",slot:"Action",overridesResolver:(e,t)=>t.action})({display:"flex",alignItems:"center",marginLeft:"auto",paddingLeft:16,marginRight:-8}),EY=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiSnackbarContent"}),{action:o,className:i,message:l,role:c="alert"}=n,u=s(n,SY),p=n,d=(e=>{const{classes:t}=e;return U({root:["root"],action:["action"],message:["message"]},_Y,t)})(p);return e.jsxs(kY,a({role:c,square:!0,elevation:6,className:V(d.root,i),ownerState:p,ref:r},u,{children:[e.jsx(CY,{className:d.message,ownerState:p,children:l}),o?e.jsx(OY,{className:d.action,ownerState:p,children:o}):null]}))}); true&&(EY.propTypes={action:B.node,classes:B.object,className:B.string,message:B.node,role:B.string,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const TY=EY;function RY(e){return Mo("MuiSnackbar",e)}ta("MuiSnackbar",["root","anchorOriginTopCenter","anchorOriginBottomCenter","anchorOriginTopRight","anchorOriginBottomRight","anchorOriginTopLeft","anchorOriginBottomLeft"]);const IY=["onEnter","onExited"],MY=["action","anchorOrigin","autoHideDuration","children","className","ClickAwayListenerProps","ContentProps","disableWindowBlurListener","message","onBlur","onClose","onFocus","onMouseEnter","onMouseLeave","open","resumeHideDuration","TransitionComponent","transitionDuration","TransitionProps"],AY=Vi("div",{name:"MuiSnackbar",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,t[`anchorOrigin${Zi(r.anchorOrigin.vertical)}${Zi(r.anchorOrigin.horizontal)}`]]}})(({theme:e,ownerState:t})=>a({zIndex:(e.vars||e).zIndex.snackbar,position:"fixed",display:"flex",left:8,right:8,justifyContent:"center",alignItems:"center"},"top"===t.anchorOrigin.vertical?{top:8}:{bottom:8},"left"===t.anchorOrigin.horizontal&&{justifyContent:"flex-start"},"right"===t.anchorOrigin.horizontal&&{justifyContent:"flex-end"},{[e.breakpoints.up("sm")]:a({},"top"===t.anchorOrigin.vertical?{top:24}:{bottom:24},"center"===t.anchorOrigin.horizontal&&{left:"50%",right:"auto",transform:"translateX(-50%)"},"left"===t.anchorOrigin.horizontal&&{left:24,right:"auto"},"right"===t.anchorOrigin.horizontal&&{right:24,left:"auto"})})),PY=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiSnackbar"}),i=ea(),l={enter:i.transitions.duration.enteringScreen,exit:i.transitions.duration.leavingScreen},{action:c,anchorOrigin:{vertical:u,horizontal:p}={vertical:"bottom",horizontal:"left"},autoHideDuration:d=null,children:f,className:h,ClickAwayListenerProps:m,ContentProps:g,disableWindowBlurListener:v=!1,message:y,open:b,TransitionComponent:w=Qf,transitionDuration:x=l,TransitionProps:{onEnter:_,onExited:S}={}}=n,k=s(n.TransitionProps,IY),C=s(n,MY),O=a({},n,{anchorOrigin:{vertical:u,horizontal:p},autoHideDuration:d,disableWindowBlurListener:v,TransitionComponent:w,transitionDuration:x}),E=(e=>{const{classes:t,anchorOrigin:r}=e;return U({root:["root",`anchorOrigin${Zi(r.vertical)}${Zi(r.horizontal)}`]},RY,t)})(O),{getRootProps:T,onClickAway:R}=function(e={}){const{autoHideDuration:t=null,disableWindowBlurListener:r=!1,onClose:n,open:i,resumeHideDuration:s}=e,l=qa();o.useEffect(()=>{if(i)return document.addEventListener("keydown",e),()=>{document.removeEventListener("keydown",e)};function e(e){e.defaultPrevented||"Escape"!==e.key&&"Esc"!==e.key||null==n||n(e,"escapeKeyDown")}},[i,n]);const c=Ba((e,t)=>{null==n||n(e,t)}),u=Ba(e=>{n&&null!=e&&l.start(e,()=>{c(null,"timeout")})});o.useEffect(()=>(i&&u(t),l.clear),[i,t,u,l]);const p=l.clear,d=o.useCallback(()=>{null!=t&&u(null!=s?s:.5*t)},[t,s,u]),f=e=>t=>{const r=e.onFocus;null==r||r(t),p()},h=e=>t=>{const r=e.onMouseEnter;null==r||r(t),p()},m=e=>t=>{const r=e.onMouseLeave;null==r||r(t),d()};return o.useEffect(()=>{if(!r&&i)return window.addEventListener("focus",d),window.addEventListener("blur",p),()=>{window.removeEventListener("focus",d),window.removeEventListener("blur",p)}},[r,i,d,p]),{getRootProps:(t={})=>{const r=a({},uf(e),uf(t));return a({role:"presentation"},t,r,{onBlur:(n=r,e=>{const t=n.onBlur;null==t||t(e),d()}),onFocus:f(r),onMouseEnter:h(r),onMouseLeave:m(r)});// removed by dead control flow
 var n; },onClickAway:e=>{null==n||n(e,"clickaway")}}}(a({},O)),[I,M]=o.useState(!0),A=Af({elementType:AY,getSlotProps:T,externalForwardedProps:C,ownerState:O,additionalProps:{ref:r},className:[E.root,h]});return!b&&I?null:e.jsx(nH,a({onClickAway:R},m,{children:e.jsx(AY,a({},A,{children:e.jsx(w,a({appear:!0,in:b,timeout:x,direction:"top"===u?"down":"up",onEnter:(e,t)=>{M(!1),_&&_(e,t)},onExited:e=>{M(!0),S&&S(e)}},k,{children:f||e.jsx(TY,a({message:y,action:c},g))}))}))}))}); true&&(PY.propTypes={action:B.node,anchorOrigin:B.shape({horizontal:B.oneOf(["center","left","right"]).isRequired,vertical:B.oneOf(["bottom","top"]).isRequired}),autoHideDuration:B.number,children:B.element,classes:B.object,className:B.string,ClickAwayListenerProps:B.object,ContentProps:B.object,disableWindowBlurListener:B.bool,key:()=>null,message:B.node,onBlur:B.func,onClose:B.func,onFocus:B.func,onMouseEnter:B.func,onMouseLeave:B.func,open:B.bool,resumeHideDuration:B.number,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),TransitionComponent:B.elementType,transitionDuration:B.oneOfType([B.number,B.shape({appear:B.number,enter:B.number,exit:B.number})]),TransitionProps:B.object});const NY=PY;var jY=t.forwardRef((e,r)=>t.createElement(NY,{...e,ref:r}));const LY=["disableUnderline","components","componentsProps","fullWidth","inputComponent","multiline","slotProps","slots","type"],DY=Vi(rK,{shouldForwardProp:e=>zi(e)||"classes"===e,name:"MuiInput",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[...eK(e,t),!r.disableUnderline&&t.underline]}})(({theme:e,ownerState:t})=>{let r="light"===e.palette.mode?"rgba(0, 0, 0, 0.42)":"rgba(255, 255, 255, 0.7)";return e.vars&&(r=`rgba(${e.vars.palette.common.onBackgroundChannel} / ${e.vars.opacity.inputUnderline})`),a({position:"relative"},t.formControl&&{"label + &":{marginTop:16}},!t.disableUnderline&&{"&::after":{borderBottom:`2px solid ${(e.vars||e).palette[t.color].main}`,left:0,bottom:0,content:'""',position:"absolute",right:0,transform:"scaleX(0)",transition:e.transitions.create("transform",{duration:e.transitions.duration.shorter,easing:e.transitions.easing.easeOut}),pointerEvents:"none"},[`&.${lK.focused}:after`]:{transform:"scaleX(1) translateX(0)"},[`&.${lK.error}`]:{"&::before, &::after":{borderBottomColor:(e.vars||e).palette.error.main}},"&::before":{borderBottom:`1px solid ${r}`,left:0,bottom:0,content:'"\\00a0"',position:"absolute",right:0,transition:e.transitions.create("border-bottom-color",{duration:e.transitions.duration.shorter}),pointerEvents:"none"},[`&:hover:not(.${lK.disabled}, .${lK.error}):before`]:{borderBottom:`2px solid ${(e.vars||e).palette.text.primary}`,"@media (hover: none)":{borderBottom:`1px solid ${r}`}},[`&.${lK.disabled}:before`]:{borderBottomStyle:"dotted"}})}),FY=Vi(nK,{name:"MuiInput",slot:"Input",overridesResolver:tK})({}),$Y=o.forwardRef(function(t,r){var n,o,i,l;const c=Yi({props:t,name:"MuiInput"}),{disableUnderline:u,components:p={},componentsProps:d,fullWidth:f=!1,inputComponent:h="input",multiline:m=!1,slotProps:g,slots:v={},type:y="text"}=c,b=s(c,LY),w=(e=>{const{classes:t,disableUnderline:r}=e;return a({},t,U({root:["root",!r&&"underline"],input:["input"]},aK,t))})(c),x={root:{ownerState:{disableUnderline:u}}},_=(null!=g?g:d)?Eo(null!=g?g:d,x):x,S=null!=(n=null!=(o=v.root)?o:p.Root)?n:DY,k=null!=(i=null!=(l=v.input)?l:p.Input)?i:FY;return e.jsx(sK,a({slots:{root:S,input:k},slotProps:_,fullWidth:f,inputComponent:h,multiline:m,ref:r,type:y},b,{classes:w}))}); true&&($Y.propTypes={autoComplete:B.string,autoFocus:B.bool,classes:B.object,color:B.oneOfType([B.oneOf(["primary","secondary"]),B.string]),components:B.shape({Input:B.elementType,Root:B.elementType}),componentsProps:B.shape({input:B.object,root:B.object}),defaultValue:B.any,disabled:B.bool,disableUnderline:B.bool,endAdornment:B.node,error:B.bool,fullWidth:B.bool,id:B.string,inputComponent:B.elementType,inputProps:B.object,inputRef:ja,margin:B.oneOf(["dense","none"]),maxRows:B.oneOfType([B.number,B.string]),minRows:B.oneOfType([B.number,B.string]),multiline:B.bool,name:B.string,onChange:B.func,placeholder:B.string,readOnly:B.bool,required:B.bool,rows:B.oneOfType([B.number,B.string]),slotProps:B.shape({input:B.object,root:B.object}),slots:B.shape({input:B.elementType,root:B.elementType}),startAdornment:B.node,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),type:B.string,value:B.any}),$Y.muiName="Input";const BY=$Y,zY=["disableUnderline","components","componentsProps","fullWidth","hiddenLabel","inputComponent","multiline","slotProps","slots","type"],VY=Vi(rK,{shouldForwardProp:e=>zi(e)||"classes"===e,name:"MuiFilledInput",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[...eK(e,t),!r.disableUnderline&&t.underline]}})(({theme:e,ownerState:t})=>{var r;const n="light"===e.palette.mode,o=n?"rgba(0, 0, 0, 0.42)":"rgba(255, 255, 255, 0.7)",i=n?"rgba(0, 0, 0, 0.06)":"rgba(255, 255, 255, 0.09)",s=n?"rgba(0, 0, 0, 0.09)":"rgba(255, 255, 255, 0.13)",l=n?"rgba(0, 0, 0, 0.12)":"rgba(255, 255, 255, 0.12)";return a({position:"relative",backgroundColor:e.vars?e.vars.palette.FilledInput.bg:i,borderTopLeftRadius:(e.vars||e).shape.borderRadius,borderTopRightRadius:(e.vars||e).shape.borderRadius,transition:e.transitions.create("background-color",{duration:e.transitions.duration.shorter,easing:e.transitions.easing.easeOut}),"&:hover":{backgroundColor:e.vars?e.vars.palette.FilledInput.hoverBg:s,"@media (hover: none)":{backgroundColor:e.vars?e.vars.palette.FilledInput.bg:i}},[`&.${dK.focused}`]:{backgroundColor:e.vars?e.vars.palette.FilledInput.bg:i},[`&.${dK.disabled}`]:{backgroundColor:e.vars?e.vars.palette.FilledInput.disabledBg:l}},!t.disableUnderline&&{"&::after":{borderBottom:`2px solid ${null==(r=(e.vars||e).palette[t.color||"primary"])?void 0:r.main}`,left:0,bottom:0,content:'""',position:"absolute",right:0,transform:"scaleX(0)",transition:e.transitions.create("transform",{duration:e.transitions.duration.shorter,easing:e.transitions.easing.easeOut}),pointerEvents:"none"},[`&.${dK.focused}:after`]:{transform:"scaleX(1) translateX(0)"},[`&.${dK.error}`]:{"&::before, &::after":{borderBottomColor:(e.vars||e).palette.error.main}},"&::before":{borderBottom:`1px solid ${e.vars?`rgba(${e.vars.palette.common.onBackgroundChannel} / ${e.vars.opacity.inputUnderline})`:o}`,left:0,bottom:0,content:'"\\00a0"',position:"absolute",right:0,transition:e.transitions.create("border-bottom-color",{duration:e.transitions.duration.shorter}),pointerEvents:"none"},[`&:hover:not(.${dK.disabled}, .${dK.error}):before`]:{borderBottom:`1px solid ${(e.vars||e).palette.text.primary}`},[`&.${dK.disabled}:before`]:{borderBottomStyle:"dotted"}},t.startAdornment&&{paddingLeft:12},t.endAdornment&&{paddingRight:12},t.multiline&&a({padding:"25px 12px 8px"},"small"===t.size&&{paddingTop:21,paddingBottom:4},t.hiddenLabel&&{paddingTop:16,paddingBottom:17},t.hiddenLabel&&"small"===t.size&&{paddingTop:8,paddingBottom:9}))}),UY=Vi(nK,{name:"MuiFilledInput",slot:"Input",overridesResolver:tK})(({theme:e,ownerState:t})=>a({paddingTop:25,paddingRight:12,paddingBottom:8,paddingLeft:12},!e.vars&&{"&:-webkit-autofill":{WebkitBoxShadow:"light"===e.palette.mode?null:"0 0 0 100px #266798 inset",WebkitTextFillColor:"light"===e.palette.mode?null:"#fff",caretColor:"light"===e.palette.mode?null:"#fff",borderTopLeftRadius:"inherit",borderTopRightRadius:"inherit"}},e.vars&&{"&:-webkit-autofill":{borderTopLeftRadius:"inherit",borderTopRightRadius:"inherit"},[e.getColorSchemeSelector("dark")]:{"&:-webkit-autofill":{WebkitBoxShadow:"0 0 0 100px #266798 inset",WebkitTextFillColor:"#fff",caretColor:"#fff"}}},"small"===t.size&&{paddingTop:21,paddingBottom:4},t.hiddenLabel&&{paddingTop:16,paddingBottom:17},t.startAdornment&&{paddingLeft:0},t.endAdornment&&{paddingRight:0},t.hiddenLabel&&"small"===t.size&&{paddingTop:8,paddingBottom:9},t.multiline&&{paddingTop:0,paddingBottom:0,paddingLeft:0,paddingRight:0})),qY=o.forwardRef(function(t,r){var n,o,i,l;const c=Yi({props:t,name:"MuiFilledInput"}),{components:u={},componentsProps:p,fullWidth:d=!1,inputComponent:f="input",multiline:h=!1,slotProps:m,slots:g={},type:v="text"}=c,y=s(c,zY),b=a({},c,{fullWidth:d,inputComponent:f,multiline:h,type:v}),w=(e=>{const{classes:t,disableUnderline:r}=e;return a({},t,U({root:["root",!r&&"underline"],input:["input"]},pK,t))})(c),x={root:{ownerState:b},input:{ownerState:b}},_=(null!=m?m:p)?Eo(x,null!=m?m:p):x,S=null!=(n=null!=(o=g.root)?o:u.Root)?n:VY,k=null!=(i=null!=(l=g.input)?l:u.Input)?i:UY;return e.jsx(sK,a({slots:{root:S,input:k},componentsProps:_,fullWidth:d,inputComponent:f,multiline:h,ref:r,type:v},y,{classes:w}))}); true&&(qY.propTypes={autoComplete:B.string,autoFocus:B.bool,classes:B.object,color:B.oneOfType([B.oneOf(["primary","secondary"]),B.string]),components:B.shape({Input:B.elementType,Root:B.elementType}),componentsProps:B.shape({input:B.object,root:B.object}),defaultValue:B.any,disabled:B.bool,disableUnderline:B.bool,endAdornment:B.node,error:B.bool,fullWidth:B.bool,hiddenLabel:B.bool,id:B.string,inputComponent:B.elementType,inputProps:B.object,inputRef:ja,margin:B.oneOf(["dense","none"]),maxRows:B.oneOfType([B.number,B.string]),minRows:B.oneOfType([B.number,B.string]),multiline:B.bool,name:B.string,onChange:B.func,placeholder:B.string,readOnly:B.bool,required:B.bool,rows:B.oneOfType([B.number,B.string]),slotProps:B.shape({input:B.object,root:B.object}),slots:B.shape({input:B.elementType,root:B.elementType}),startAdornment:B.node,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),type:B.string,value:B.any}),qY.muiName="Input";const WY=qY;var HY;const GY=["children","classes","className","label","notched"],KY=Vi("fieldset",{shouldForwardProp:zi})({textAlign:"left",position:"absolute",bottom:0,right:0,top:-5,left:0,margin:0,padding:"0 8px",pointerEvents:"none",borderRadius:"inherit",borderStyle:"solid",borderWidth:1,overflow:"hidden",minWidth:"0%"}),YY=Vi("legend",{shouldForwardProp:zi})(({ownerState:e,theme:t})=>a({float:"unset",width:"auto",overflow:"hidden"},!e.withLabel&&{padding:0,lineHeight:"11px",transition:t.transitions.create("width",{duration:150,easing:t.transitions.easing.easeOut})},e.withLabel&&a({display:"block",padding:0,height:11,fontSize:"0.75em",visibility:"hidden",maxWidth:.01,transition:t.transitions.create("max-width",{duration:50,easing:t.transitions.easing.easeOut}),whiteSpace:"nowrap","& > span":{paddingLeft:5,paddingRight:5,display:"inline-block",opacity:0,visibility:"visible"}},e.notched&&{maxWidth:"100%",transition:t.transitions.create("max-width",{duration:100,easing:t.transitions.easing.easeOut,delay:50})})));function ZY(t){const{className:r,label:n,notched:o}=t,i=s(t,GY),l=null!=n&&""!==n,c=a({},t,{notched:o,withLabel:l});return e.jsx(KY,a({"aria-hidden":!0,className:r,ownerState:c},i,{children:e.jsx(YY,{ownerState:c,children:l?e.jsx("span",{children:n}):HY||(HY=e.jsx("span",{className:"notranslate",children:"​"}))})}))} true&&(ZY.propTypes={children:B.node,classes:B.object,className:B.string,label:B.node,notched:B.bool.isRequired,style:B.object});const XY=["components","fullWidth","inputComponent","label","multiline","notched","slots","type"],JY=Vi(rK,{shouldForwardProp:e=>zi(e)||"classes"===e,name:"MuiOutlinedInput",slot:"Root",overridesResolver:eK})(({theme:e,ownerState:t})=>{const r="light"===e.palette.mode?"rgba(0, 0, 0, 0.23)":"rgba(255, 255, 255, 0.23)";return a({position:"relative",borderRadius:(e.vars||e).shape.borderRadius,[`&:hover .${uK.notchedOutline}`]:{borderColor:(e.vars||e).palette.text.primary},"@media (hover: none)":{[`&:hover .${uK.notchedOutline}`]:{borderColor:e.vars?`rgba(${e.vars.palette.common.onBackgroundChannel} / 0.23)`:r}},[`&.${uK.focused} .${uK.notchedOutline}`]:{borderColor:(e.vars||e).palette[t.color].main,borderWidth:2},[`&.${uK.error} .${uK.notchedOutline}`]:{borderColor:(e.vars||e).palette.error.main},[`&.${uK.disabled} .${uK.notchedOutline}`]:{borderColor:(e.vars||e).palette.action.disabled}},t.startAdornment&&{paddingLeft:14},t.endAdornment&&{paddingRight:14},t.multiline&&a({padding:"16.5px 14px"},"small"===t.size&&{padding:"8.5px 14px"}))}),QY=Vi(ZY,{name:"MuiOutlinedInput",slot:"NotchedOutline",overridesResolver:(e,t)=>t.notchedOutline})(({theme:e})=>{const t="light"===e.palette.mode?"rgba(0, 0, 0, 0.23)":"rgba(255, 255, 255, 0.23)";return{borderColor:e.vars?`rgba(${e.vars.palette.common.onBackgroundChannel} / 0.23)`:t}}),eZ=Vi(nK,{name:"MuiOutlinedInput",slot:"Input",overridesResolver:tK})(({theme:e,ownerState:t})=>a({padding:"16.5px 14px"},!e.vars&&{"&:-webkit-autofill":{WebkitBoxShadow:"light"===e.palette.mode?null:"0 0 0 100px #266798 inset",WebkitTextFillColor:"light"===e.palette.mode?null:"#fff",caretColor:"light"===e.palette.mode?null:"#fff",borderRadius:"inherit"}},e.vars&&{"&:-webkit-autofill":{borderRadius:"inherit"},[e.getColorSchemeSelector("dark")]:{"&:-webkit-autofill":{WebkitBoxShadow:"0 0 0 100px #266798 inset",WebkitTextFillColor:"#fff",caretColor:"#fff"}}},"small"===t.size&&{padding:"8.5px 14px"},t.multiline&&{padding:0},t.startAdornment&&{paddingLeft:0},t.endAdornment&&{paddingRight:0})),tZ=o.forwardRef(function(t,r){var n,i,l,c,u;const p=Yi({props:t,name:"MuiOutlinedInput"}),{components:d={},fullWidth:f=!1,inputComponent:h="input",label:m,multiline:g=!1,notched:v,slots:y={},type:b="text"}=p,w=s(p,XY),x=(e=>{const{classes:t}=e;return a({},t,U({root:["root"],notchedOutline:["notchedOutline"],input:["input"]},cK,t))})(p),_=NW(),S=YG({props:p,muiFormControl:_,states:["color","disabled","error","focused","hiddenLabel","size","required"]}),k=a({},p,{color:S.color||"primary",disabled:S.disabled,error:S.error,focused:S.focused,formControl:_,fullWidth:f,hiddenLabel:S.hiddenLabel,multiline:g,size:S.size,type:b}),C=null!=(n=null!=(i=y.root)?i:d.Root)?n:JY,O=null!=(l=null!=(c=y.input)?c:d.Input)?l:eZ;return e.jsx(sK,a({slots:{root:C,input:O},renderSuffix:t=>e.jsx(QY,{ownerState:k,className:x.notchedOutline,label:null!=m&&""!==m&&S.required?u||(u=e.jsxs(o.Fragment,{children:[m," ","*"]})):m,notched:void 0!==v?v:Boolean(t.startAdornment||t.filled||t.focused)}),fullWidth:f,inputComponent:h,multiline:g,ref:r,type:b},w,{classes:a({},x,{notchedOutline:null})}))}); true&&(tZ.propTypes={autoComplete:B.string,autoFocus:B.bool,classes:B.object,color:B.oneOfType([B.oneOf(["primary","secondary"]),B.string]),components:B.shape({Input:B.elementType,Root:B.elementType}),defaultValue:B.any,disabled:B.bool,endAdornment:B.node,error:B.bool,fullWidth:B.bool,id:B.string,inputComponent:B.elementType,inputProps:B.object,inputRef:ja,label:B.node,margin:B.oneOf(["dense","none"]),maxRows:B.oneOfType([B.number,B.string]),minRows:B.oneOfType([B.number,B.string]),multiline:B.bool,name:B.string,notched:B.bool,onChange:B.func,placeholder:B.string,readOnly:B.bool,required:B.bool,rows:B.oneOfType([B.number,B.string]),slots:B.shape({input:B.elementType,root:B.elementType}),startAdornment:B.node,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),type:B.string,value:B.any}),tZ.muiName="Input";const rZ=tZ;function nZ(e){return Mo("MuiFormLabel",e)}const oZ=ta("MuiFormLabel",["root","colorSecondary","focused","disabled","error","filled","required","asterisk"]),iZ=["children","className","color","component","disabled","error","filled","focused","required"],sZ=Vi("label",{name:"MuiFormLabel",slot:"Root",overridesResolver:({ownerState:e},t)=>a({},t.root,"secondary"===e.color&&t.colorSecondary,e.filled&&t.filled)})(({theme:e,ownerState:t})=>a({color:(e.vars||e).palette.text.secondary},e.typography.body1,{lineHeight:"1.4375em",padding:0,position:"relative",[`&.${oZ.focused}`]:{color:(e.vars||e).palette[t.color].main},[`&.${oZ.disabled}`]:{color:(e.vars||e).palette.text.disabled},[`&.${oZ.error}`]:{color:(e.vars||e).palette.error.main}})),aZ=Vi("span",{name:"MuiFormLabel",slot:"Asterisk",overridesResolver:(e,t)=>t.asterisk})(({theme:e})=>({[`&.${oZ.error}`]:{color:(e.vars||e).palette.error.main}})),lZ=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiFormLabel"}),{children:o,className:i,component:l="label"}=n,c=s(n,iZ),u=YG({props:n,muiFormControl:NW(),states:["color","required","focused","disabled","error","filled"]}),p=a({},n,{color:u.color||"primary",component:l,disabled:u.disabled,error:u.error,filled:u.filled,focused:u.focused,required:u.required}),d=(e=>{const{classes:t,color:r,focused:n,disabled:o,error:i,filled:s,required:a}=e;return U({root:["root",`color${Zi(r)}`,o&&"disabled",i&&"error",s&&"filled",n&&"focused",a&&"required"],asterisk:["asterisk",i&&"error"]},nZ,t)})(p);return e.jsxs(sZ,a({as:l,ownerState:p,className:V(d.root,i),ref:r},c,{children:[o,u.required&&e.jsxs(aZ,{ownerState:p,"aria-hidden":!0,className:d.asterisk,children:[" ","*"]})]}))}); true&&(lZ.propTypes={children:B.node,classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["error","info","primary","secondary","success","warning"]),B.string]),component:B.elementType,disabled:B.bool,error:B.bool,filled:B.bool,focused:B.bool,required:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object])});const cZ=lZ;function uZ(e){return Mo("MuiInputLabel",e)}ta("MuiInputLabel",["root","focused","disabled","error","required","asterisk","formControl","sizeSmall","shrink","animated","standard","filled","outlined"]);const pZ=["disableAnimation","margin","shrink","variant","className"],dZ=Vi(cZ,{shouldForwardProp:e=>zi(e)||"classes"===e,name:"MuiInputLabel",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[{[`& .${oZ.asterisk}`]:t.asterisk},t.root,r.formControl&&t.formControl,"small"===r.size&&t.sizeSmall,r.shrink&&t.shrink,!r.disableAnimation&&t.animated,r.focused&&t.focused,t[r.variant]]}})(({theme:e,ownerState:t})=>a({display:"block",transformOrigin:"top left",whiteSpace:"nowrap",overflow:"hidden",textOverflow:"ellipsis",maxWidth:"100%"},t.formControl&&{position:"absolute",left:0,top:0,transform:"translate(0, 20px) scale(1)"},"small"===t.size&&{transform:"translate(0, 17px) scale(1)"},t.shrink&&{transform:"translate(0, -1.5px) scale(0.75)",transformOrigin:"top left",maxWidth:"133%"},!t.disableAnimation&&{transition:e.transitions.create(["color","transform","max-width"],{duration:e.transitions.duration.shorter,easing:e.transitions.easing.easeOut})},"filled"===t.variant&&a({zIndex:1,pointerEvents:"none",transform:"translate(12px, 16px) scale(1)",maxWidth:"calc(100% - 24px)"},"small"===t.size&&{transform:"translate(12px, 13px) scale(1)"},t.shrink&&a({userSelect:"none",pointerEvents:"auto",transform:"translate(12px, 7px) scale(0.75)",maxWidth:"calc(133% - 24px)"},"small"===t.size&&{transform:"translate(12px, 4px) scale(0.75)"})),"outlined"===t.variant&&a({zIndex:1,pointerEvents:"none",transform:"translate(14px, 16px) scale(1)",maxWidth:"calc(100% - 24px)"},"small"===t.size&&{transform:"translate(14px, 9px) scale(1)"},t.shrink&&{userSelect:"none",pointerEvents:"auto",maxWidth:"calc(133% - 32px)",transform:"translate(14px, -9px) scale(0.75)"}))),fZ=o.forwardRef(function(t,r){const n=Yi({name:"MuiInputLabel",props:t}),{disableAnimation:o=!1,shrink:i,className:l}=n,c=s(n,pZ),u=NW();let p=i;void 0===p&&u&&(p=u.filled||u.focused||u.adornedStart);const d=YG({props:n,muiFormControl:u,states:["size","variant","required","focused"]}),f=a({},n,{disableAnimation:o,formControl:u,shrink:p,size:d.size,variant:d.variant,required:d.required,focused:d.focused}),h=(e=>{const{classes:t,formControl:r,size:n,shrink:o,disableAnimation:i,variant:s,required:l}=e;return a({},t,U({root:["root",r&&"formControl",!i&&"animated",o&&"shrink",n&&"normal"!==n&&`size${Zi(n)}`,s],asterisk:[l&&"asterisk"]},uZ,t))})(f);return e.jsx(dZ,a({"data-shrink":p,ownerState:f,ref:r,className:V(h.root,l)},c,{classes:h}))}); true&&(fZ.propTypes={children:B.node,classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["error","info","primary","secondary","success","warning"]),B.string]),disableAnimation:B.bool,disabled:B.bool,error:B.bool,focused:B.bool,margin:B.oneOf(["dense"]),required:B.bool,shrink:B.bool,size:B.oneOfType([B.oneOf(["normal","small"]),B.string]),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),variant:B.oneOf(["filled","outlined","standard"])});const hZ=fZ;function mZ(e){return Mo("MuiFormHelperText",e)}const gZ=ta("MuiFormHelperText",["root","error","disabled","sizeSmall","sizeMedium","contained","focused","filled","required"]);var vZ;const yZ=["children","className","component","disabled","error","filled","focused","margin","required","variant"],bZ=Vi("p",{name:"MuiFormHelperText",slot:"Root",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.root,r.size&&t[`size${Zi(r.size)}`],r.contained&&t.contained,r.filled&&t.filled]}})(({theme:e,ownerState:t})=>a({color:(e.vars||e).palette.text.secondary},e.typography.caption,{textAlign:"left",marginTop:3,marginRight:0,marginBottom:0,marginLeft:0,[`&.${gZ.disabled}`]:{color:(e.vars||e).palette.text.disabled},[`&.${gZ.error}`]:{color:(e.vars||e).palette.error.main}},"small"===t.size&&{marginTop:4},t.contained&&{marginLeft:14,marginRight:14})),wZ=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiFormHelperText"}),{children:o,className:i,component:l="p"}=n,c=s(n,yZ),u=YG({props:n,muiFormControl:NW(),states:["variant","size","disabled","error","filled","focused","required"]}),p=a({},n,{component:l,contained:"filled"===u.variant||"outlined"===u.variant,variant:u.variant,size:u.size,disabled:u.disabled,error:u.error,filled:u.filled,focused:u.focused,required:u.required}),d=(e=>{const{classes:t,contained:r,size:n,disabled:o,error:i,filled:s,focused:a,required:l}=e;return U({root:["root",o&&"disabled",i&&"error",n&&`size${Zi(n)}`,r&&"contained",a&&"focused",s&&"filled",l&&"required"]},mZ,t)})(p);return e.jsx(bZ,a({as:l,ownerState:p,className:V(d.root,i),ref:r},c,{children:" "===o?vZ||(vZ=e.jsx("span",{className:"notranslate",children:"​"})):o}))}); true&&(wZ.propTypes={children:B.node,classes:B.object,className:B.string,component:B.elementType,disabled:B.bool,error:B.bool,filled:B.bool,focused:B.bool,margin:B.oneOf(["dense"]),required:B.bool,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),variant:B.oneOfType([B.oneOf(["filled","outlined","standard"]),B.string])});const xZ=wZ;function _Z(e){return Mo("MuiNativeSelect",e)}const SZ=ta("MuiNativeSelect",["root","select","multiple","filled","outlined","standard","disabled","icon","iconOpen","iconFilled","iconOutlined","iconStandard","nativeInput","error"]),kZ=["className","disabled","error","IconComponent","inputRef","variant"],CZ=({ownerState:e,theme:t})=>a({MozAppearance:"none",WebkitAppearance:"none",userSelect:"none",borderRadius:0,cursor:"pointer","&:focus":a({},t.vars?{backgroundColor:`rgba(${t.vars.palette.common.onBackgroundChannel} / 0.05)`}:{backgroundColor:"light"===t.palette.mode?"rgba(0, 0, 0, 0.05)":"rgba(255, 255, 255, 0.05)"},{borderRadius:0}),"&::-ms-expand":{display:"none"},[`&.${SZ.disabled}`]:{cursor:"default"},"&[multiple]":{height:"auto"},"&:not([multiple]) option, &:not([multiple]) optgroup":{backgroundColor:(t.vars||t).palette.background.paper},"&&&":{paddingRight:24,minWidth:16}},"filled"===e.variant&&{"&&&":{paddingRight:32}},"outlined"===e.variant&&{borderRadius:(t.vars||t).shape.borderRadius,"&:focus":{borderRadius:(t.vars||t).shape.borderRadius},"&&&":{paddingRight:32}}),OZ=Vi("select",{name:"MuiNativeSelect",slot:"Select",shouldForwardProp:zi,overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.select,t[r.variant],r.error&&t.error,{[`&.${SZ.multiple}`]:t.multiple}]}})(CZ),EZ=({ownerState:e,theme:t})=>a({position:"absolute",right:0,top:"calc(50% - .5em)",pointerEvents:"none",color:(t.vars||t).palette.action.active,[`&.${SZ.disabled}`]:{color:(t.vars||t).palette.action.disabled}},e.open&&{transform:"rotate(180deg)"},"filled"===e.variant&&{right:7},"outlined"===e.variant&&{right:7}),TZ=Vi("svg",{name:"MuiNativeSelect",slot:"Icon",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.icon,r.variant&&t[`icon${Zi(r.variant)}`],r.open&&t.iconOpen]}})(EZ),RZ=o.forwardRef(function(t,r){const{className:n,disabled:i,error:l,IconComponent:c,inputRef:u,variant:p="standard"}=t,d=s(t,kZ),f=a({},t,{disabled:i,variant:p,error:l}),h=(e=>{const{classes:t,variant:r,disabled:n,multiple:o,open:i,error:s}=e;return U({select:["select",r,n&&"disabled",o&&"multiple",s&&"error"],icon:["icon",`icon${Zi(r)}`,i&&"iconOpen",n&&"disabled"]},_Z,t)})(f);return e.jsxs(o.Fragment,{children:[e.jsx(OZ,a({ownerState:f,className:V(h.select,n),disabled:i,ref:u||r},d)),t.multiple?null:e.jsx(TZ,{as:c,ownerState:f,className:h.icon})]})}); true&&(RZ.propTypes={children:B.node,classes:B.object,className:B.string,disabled:B.bool,error:B.bool,IconComponent:B.elementType.isRequired,inputRef:ja,multiple:B.bool,name:B.string,onChange:B.func,value:B.any,variant:B.oneOf(["standard","outlined","filled"])});const IZ=RZ;function MZ(e){return Mo("MuiSelect",e)}const AZ=ta("MuiSelect",["root","select","multiple","filled","outlined","standard","disabled","focused","icon","iconOpen","iconFilled","iconOutlined","iconStandard","nativeInput","error"]);var PZ;const NZ=["aria-describedby","aria-label","autoFocus","autoWidth","children","className","defaultOpen","defaultValue","disabled","displayEmpty","error","IconComponent","inputRef","labelId","MenuProps","multiple","name","onBlur","onChange","onClose","onFocus","onOpen","open","readOnly","renderValue","SelectDisplayProps","tabIndex","type","value","variant"],jZ=Vi("div",{name:"MuiSelect",slot:"Select",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[{[`&.${AZ.select}`]:t.select},{[`&.${AZ.select}`]:t[r.variant]},{[`&.${AZ.error}`]:t.error},{[`&.${AZ.multiple}`]:t.multiple}]}})(CZ,{[`&.${AZ.select}`]:{height:"auto",minHeight:"1.4375em",textOverflow:"ellipsis",whiteSpace:"nowrap",overflow:"hidden"}}),LZ=Vi("svg",{name:"MuiSelect",slot:"Icon",overridesResolver:(e,t)=>{const{ownerState:r}=e;return[t.icon,r.variant&&t[`icon${Zi(r.variant)}`],r.open&&t.iconOpen]}})(EZ),DZ=Vi("input",{shouldForwardProp:e=>Bi(e)&&"classes"!==e,name:"MuiSelect",slot:"NativeInput",overridesResolver:(e,t)=>t.nativeInput})({bottom:0,left:0,position:"absolute",opacity:0,pointerEvents:"none",width:"100%",boxSizing:"border-box"});function FZ(e,t){return"object"==typeof t&&null!==t?e===t:String(e)===String(t)}function $Z(e){return null==e||"string"==typeof e&&!e.trim()}const BZ=o.forwardRef(function(t,r){var n;const{"aria-describedby":i,"aria-label":l,autoFocus:c,autoWidth:u,children:p,className:d,defaultOpen:f,defaultValue:h,disabled:m,displayEmpty:g,error:v=!1,IconComponent:y,inputRef:b,labelId:w,MenuProps:x={},multiple:_,name:S,onBlur:k,onChange:C,onClose:O,onFocus:E,onOpen:T,open:R,readOnly:I,renderValue:M,SelectDisplayProps:A={},tabIndex:P,value:N,variant:j="standard"}=t,L=s(t,NZ),[D,F]=Of({controlled:N,default:h,name:"Select"}),[$,B]=Of({controlled:R,default:f,name:"Select"}),z=o.useRef(null),q=o.useRef(null),[W,H]=o.useState(null),{current:G}=o.useRef(null!=R),[K,Y]=o.useState(),Z=Fa(r,b),X=o.useCallback(e=>{q.current=e,e&&H(e)},[]),J=null==W?void 0:W.parentNode;o.useImperativeHandle(Z,()=>({focus:()=>{q.current.focus()},node:z.current,value:D}),[D]),o.useEffect(()=>{f&&$&&W&&!G&&(Y(u?null:J.clientWidth),q.current.focus())},[W,u]),o.useEffect(()=>{c&&q.current.focus()},[c]),o.useEffect(()=>{if(!w)return;const e=xf(q.current).getElementById(w);if(e){const t=()=>{getSelection().isCollapsed&&q.current.focus()};return e.addEventListener("click",t),()=>{e.removeEventListener("click",t)}}},[w]);const Q=(e,t)=>{e?T&&T(t):O&&O(t),G||(Y(u?null:J.clientWidth),B(e))},ee=o.Children.toArray(p),te=e=>t=>{let r;if(t.currentTarget.hasAttribute("tabindex")){if(_){r=Array.isArray(D)?D.slice():[];const t=D.indexOf(e.props.value);-1===t?r.push(e.props.value):r.splice(t,1)}else r=e.props.value;if(e.props.onClick&&e.props.onClick(t),D!==r&&(F(r),C)){const n=t.nativeEvent||t,o=new n.constructor(n.type,n);Object.defineProperty(o,"target",{writable:!0,value:{value:r,name:S}}),C(o,e)}_||Q(!1,t)}},re=null!==W&&$;let ne,oe;delete L["aria-invalid"];const ie=[];let se=!1,ae=!1;(OW({value:D})||g)&&(M?ne=M(D):se=!0);const le=ee.map(e=>{if(!o.isValidElement(e))return null;let t;if( true&&of.isFragment(e)&&console.error(["MUI: The Select component doesn't accept a Fragment as a child.","Consider providing an array instead."].join("\n")),_){if(!Array.isArray(D))throw new Error( true?"MUI: The `value` prop must be an array when using the `Select` component with `multiple`.":0);t=D.some(t=>FZ(t,e.props.value)),t&&se&&ie.push(e.props.children)}else t=FZ(D,e.props.value),t&&se&&(oe=e.props.children);return t&&(ae=!0),o.cloneElement(e,{"aria-selected":t?"true":"false",onClick:te(e),onKeyUp:t=>{" "===t.key&&t.preventDefault(),e.props.onKeyUp&&e.props.onKeyUp(t)},role:"option",selected:t,value:void 0,"data-value":e.props.value})}); true&&o.useEffect(()=>{if(!ae&&!_&&""!==D){const e=ee.map(e=>e.props.value);console.warn([`MUI: You have provided an out-of-range value \`${D}\` for the select ${S?`(name="${S}") `:""}component.`,"Consider providing a value that matches one of the available options or ''.",`The available values are ${e.filter(e=>null!=e).map(e=>`\`${e}\``).join(", ")||'""'}.`].join("\n"))}},[ae,ee,_,S,D]),se&&(ne=_?0===ie.length?null:ie.reduce((e,t,r)=>(e.push(t),r<ie.length-1&&e.push(", "),e),[]):oe);let ce,ue=K;!u&&G&&W&&(ue=J.clientWidth),ce=void 0!==P?P:m?null:0;const pe=A.id||(S?`mui-component-select-${S}`:void 0),de=a({},t,{variant:j,value:D,open:re,error:v}),fe=(e=>{const{classes:t,variant:r,disabled:n,multiple:o,open:i,error:s}=e;return U({select:["select",r,n&&"disabled",o&&"multiple",s&&"error"],icon:["icon",`icon${Zi(r)}`,i&&"iconOpen",n&&"disabled"],nativeInput:["nativeInput"]},MZ,t)})(de),he=a({},x.PaperProps,null==(n=x.slotProps)?void 0:n.paper),me=Cf();return e.jsxs(o.Fragment,{children:[e.jsx(jZ,a({ref:X,tabIndex:ce,role:"combobox","aria-controls":me,"aria-disabled":m?"true":void 0,"aria-expanded":re?"true":"false","aria-haspopup":"listbox","aria-label":l,"aria-labelledby":[w,pe].filter(Boolean).join(" ")||void 0,"aria-describedby":i,onKeyDown:e=>{I||-1!==[" ","ArrowUp","ArrowDown","Enter"].indexOf(e.key)&&(e.preventDefault(),Q(!0,e))},onMouseDown:m||I?null:e=>{0===e.button&&(e.preventDefault(),q.current.focus(),Q(!0,e))},onBlur:e=>{!re&&k&&(Object.defineProperty(e,"target",{writable:!0,value:{value:D,name:S}}),k(e))},onFocus:E},A,{ownerState:de,className:V(A.className,fe.select,d),id:pe,children:$Z(ne)?PZ||(PZ=e.jsx("span",{className:"notranslate",children:"​"})):ne})),e.jsx(DZ,a({"aria-invalid":v,value:Array.isArray(D)?D.join(","):D,name:S,ref:z,"aria-hidden":!0,onChange:e=>{const t=ee.find(t=>t.props.value===e.target.value);void 0!==t&&(F(t.props.value),C&&C(e,t))},tabIndex:-1,disabled:m,className:fe.nativeInput,autoFocus:c,ownerState:de},L)),e.jsx(LZ,{as:y,className:fe.icon,ownerState:de}),e.jsx(Hh,a({id:`menu-${S||""}`,anchorEl:J,open:re,onClose:e=>{Q(!1,e)},anchorOrigin:{vertical:"bottom",horizontal:"center"},transformOrigin:{vertical:"top",horizontal:"center"}},x,{MenuListProps:a({"aria-labelledby":w,role:"listbox","aria-multiselectable":_?"true":void 0,disableListWrap:!0,id:me},x.MenuListProps),slotProps:a({},x.slotProps,{paper:a({},he,{style:a({minWidth:ue},null!=he?he.style:null)})}),children:le}))]})}); true&&(BZ.propTypes={"aria-describedby":B.string,"aria-label":B.string,autoFocus:B.bool,autoWidth:B.bool,children:B.node,classes:B.object,className:B.string,defaultOpen:B.bool,defaultValue:B.any,disabled:B.bool,displayEmpty:B.bool,error:B.bool,IconComponent:B.elementType.isRequired,inputRef:ja,labelId:B.string,MenuProps:B.object,multiple:B.bool,name:B.string,onBlur:B.func,onChange:B.func,onClose:B.func,onFocus:B.func,onOpen:B.func,open:B.bool,readOnly:B.bool,renderValue:B.func,SelectDisplayProps:B.object,tabIndex:B.oneOfType([B.number,B.string]),type:B.any,value:B.any,variant:B.oneOf(["standard","outlined","filled"])});const zZ=BZ,VZ=["autoWidth","children","classes","className","defaultOpen","displayEmpty","IconComponent","id","input","inputProps","label","labelId","MenuProps","multiple","native","onClose","onOpen","open","renderValue","SelectDisplayProps","variant"],UZ=["root"],qZ={name:"MuiSelect",overridesResolver:(e,t)=>t.root,shouldForwardProp:e=>zi(e)&&"variant"!==e,slot:"Root"},WZ=Vi(BY,qZ)(""),HZ=Vi(rZ,qZ)(""),GZ=Vi(WY,qZ)(""),KZ=o.forwardRef(function(t,r){const n=Yi({name:"MuiSelect",props:t}),{autoWidth:i=!1,children:l,classes:c={},className:u,defaultOpen:p=!1,displayEmpty:d=!1,IconComponent:f=hK,id:h,input:m,inputProps:g,label:v,labelId:y,MenuProps:b,multiple:w=!1,native:x=!1,onClose:_,onOpen:S,open:k,renderValue:C,SelectDisplayProps:O,variant:E="outlined"}=n,T=s(n,VZ),R=x?IZ:zZ,I=YG({props:n,muiFormControl:NW(),states:["variant","error"]}),M=I.variant||E,A=a({},n,{variant:M,classes:c}),P=(e=>{const{classes:t}=e;return t})(A),N=s(P,UZ),j=m||{standard:e.jsx(WZ,{ownerState:A}),outlined:e.jsx(HZ,{label:v,ownerState:A}),filled:e.jsx(GZ,{ownerState:A})}[M],L=Fa(r,j.ref);return e.jsx(o.Fragment,{children:o.cloneElement(j,a({inputComponent:R,inputProps:a({children:l,error:I.error,IconComponent:f,variant:M,type:void 0,multiple:w},x?{id:h}:{autoWidth:i,defaultOpen:p,displayEmpty:d,labelId:y,MenuProps:b,onClose:_,onOpen:S,open:k,renderValue:C,SelectDisplayProps:a({id:h},O)},g,{classes:g?Eo(N,g.classes):N},m?m.props.inputProps:{})},(w&&x||d)&&"outlined"===M?{notched:!0}:{},{ref:L,className:V(j.props.className,u,P.root)},!m&&{variant:M},T))})}); true&&(KZ.propTypes={autoWidth:B.bool,children:B.node,classes:B.object,className:B.string,defaultOpen:B.bool,defaultValue:B.any,displayEmpty:B.bool,IconComponent:B.elementType,id:B.string,input:B.element,inputProps:B.object,label:B.node,labelId:B.string,MenuProps:B.object,multiple:B.bool,native:B.bool,onChange:B.func,onClose:B.func,onOpen:B.func,open:B.bool,renderValue:B.func,SelectDisplayProps:B.object,sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),value:B.oneOfType([B.oneOf([""]),B.any]),variant:B.oneOf(["filled","outlined","standard"])}),KZ.muiName="Select";const YZ=KZ;function ZZ(e){return Mo("MuiTextField",e)}ta("MuiTextField",["root"]);const XZ=["autoComplete","autoFocus","children","className","color","defaultValue","disabled","error","FormHelperTextProps","fullWidth","helperText","id","InputLabelProps","inputProps","InputProps","inputRef","label","maxRows","minRows","multiline","name","onBlur","onChange","onFocus","placeholder","required","rows","select","SelectProps","type","value","variant"],JZ={standard:BY,filled:WY,outlined:rZ},QZ=Vi(PW,{name:"MuiTextField",slot:"Root",overridesResolver:(e,t)=>t.root})({}),eX=o.forwardRef(function(t,r){const n=Yi({props:t,name:"MuiTextField"}),{autoComplete:o,autoFocus:i=!1,children:l,className:c,color:u="primary",defaultValue:p,disabled:d=!1,error:f=!1,FormHelperTextProps:h,fullWidth:m=!1,helperText:g,id:v,InputLabelProps:y,inputProps:b,InputProps:w,inputRef:x,label:_,maxRows:S,minRows:k,multiline:C=!1,name:O,onBlur:E,onChange:T,onFocus:R,placeholder:I,required:M=!1,rows:A,select:P=!1,SelectProps:N,type:j,value:L,variant:D="outlined"}=n,F=s(n,XZ),$=a({},n,{autoFocus:i,color:u,disabled:d,error:f,fullWidth:m,multiline:C,required:M,select:P,variant:D}),B=(e=>{const{classes:t}=e;return U({root:["root"]},ZZ,t)})($); true&&P&&!l&&console.error("MUI: `children` must be passed when using the `TextField` component with `select`.");const z={};"outlined"===D&&(y&&void 0!==y.shrink&&(z.notched=y.shrink),z.label=_),P&&(N&&N.native||(z.id=void 0),z["aria-describedby"]=void 0);const q=Cf(v),W=g&&q?`${q}-helper-text`:void 0,H=_&&q?`${q}-label`:void 0,G=JZ[D],K=e.jsx(G,a({"aria-describedby":W,autoComplete:o,autoFocus:i,defaultValue:p,fullWidth:m,multiline:C,name:O,rows:A,maxRows:S,minRows:k,type:j,value:L,id:q,inputRef:x,onBlur:E,onChange:T,onFocus:R,placeholder:I,inputProps:b},z,w));return e.jsxs(QZ,a({className:V(B.root,c),disabled:d,error:f,fullWidth:m,ref:r,required:M,color:u,variant:D,ownerState:$},F,{children:[null!=_&&""!==_&&e.jsx(hZ,a({htmlFor:q,id:H},y,{children:_})),P?e.jsx(YZ,a({"aria-describedby":W,id:q,labelId:H,value:L,input:K},N,{children:l})):K,g&&e.jsx(xZ,a({id:W},h,{children:g}))]}))}); true&&(eX.propTypes={autoComplete:B.string,autoFocus:B.bool,children:B.node,classes:B.object,className:B.string,color:B.oneOfType([B.oneOf(["primary","secondary","error","info","success","warning"]),B.string]),defaultValue:B.any,disabled:B.bool,error:B.bool,FormHelperTextProps:B.object,fullWidth:B.bool,helperText:B.node,id:B.string,InputLabelProps:B.object,inputProps:B.object,InputProps:B.object,inputRef:ja,label:B.node,margin:B.oneOf(["dense","none","normal"]),maxRows:B.oneOfType([B.number,B.string]),minRows:B.oneOfType([B.number,B.string]),multiline:B.bool,name:B.string,onBlur:B.func,onChange:B.func,onFocus:B.func,placeholder:B.string,required:B.bool,rows:B.oneOfType([B.number,B.string]),select:B.bool,SelectProps:B.object,size:B.oneOfType([B.oneOf(["medium","small"]),B.string]),sx:B.oneOfType([B.arrayOf(B.oneOfType([B.func,B.object,B.bool])),B.func,B.object]),type:B.string,value:B.any,variant:B.oneOf(["filled","outlined","standard"])});const tX=eX,rX=t.forwardRef((e,r)=>t.createElement(Cu,{viewBox:"0 0 24 24",...e,ref:r},t.createElement("path",{fillRule:"evenodd",clipRule:"evenodd",d:"M5.46967 9.21967C5.76256 8.92678 6.23744 8.92678 6.53033 9.21967L12 14.6893L17.4697 9.21967C17.7626 8.92678 18.2374 8.92678 18.5303 9.21967C18.8232 9.51256 18.8232 9.98744 18.5303 10.2803L12.5303 16.2803C12.2374 16.5732 11.7626 16.5732 11.4697 16.2803L5.46967 10.2803C5.17678 9.98744 5.17678 9.51256 5.46967 9.21967Z"})));t.forwardRef((e,r)=>{const{MenuProps:n={},...o}=e;return t.createElement(YZ,{...o,MenuProps:{...n,MenuListProps:{dense:"tiny"===o.size,...n.MenuListProps||{}}},ref:r})}).defaultProps={IconComponent:rX};const nX=sc(t.forwardRef((e,r)=>{const n={...e};return n.select&&(n.SelectProps={IconComponent:rX,...n.SelectProps||{}},"tiny"===n.size&&(n.SelectProps.MenuProps={...n.SelectProps?.MenuProps||{},MenuListProps:{dense:!0,...n.SelectProps?.MenuProps?.MenuListProps||{}}})),"tiny"===n.size&&(n.InputLabelProps={size:"tiny",...n.InputLabelProps||{}}),t.createElement(tX,{...n,ref:r})}))`
	width: 100%;

	.wp-admin & .MuiInputBase-input,
	& .MuiInputBase-input:focus {
		background-color: inherit;
		border: unset;
		box-shadow: none;
		min-height: initial;
		color: inherit;
		outline: 0;
		padding: ${({$isWrapped:e,$noPadding:t,theme:r})=>t?"0":e?`${r.spacing(1)} ${r.spacing(.5)}`:`${r.spacing(2)} ${r.spacing(1.5)}`};
	}
`,oX=({isWrapped:t,noPadding:r,...n})=>e.jsx(nX,{...n,$isWrapped:t,$noPadding:r});var iX=function(e){return e.EN="en",e.DE="de",e.ES="es",e.IT="it",e.NL="nl",e.PT="pt-PT",e.PT_BR="pt-BR",e.FR="fr",e.HE="he-IL",e}({});const sX=({open:r,onClose:n,colorScheme:o="light"})=>{const{t:i}=Bd("send-feedback",{i18n:bm}),{SUPPORT_FORM_URL:s}=cz(),{control:a,handleSubmit:l,reset:c,formState:{isValid:u}}=function(e={}){const r=t.useRef(void 0),n=t.useRef(void 0),[o,i]=t.useState({isDirty:!1,isValidating:!1,isLoading:hq(e.defaultValues),isSubmitted:!1,isSubmitting:!1,isSubmitSuccessful:!1,isValid:!1,submitCount:0,dirtyFields:{},touchedFields:{},validatingFields:{},errors:e.errors||{},disabled:e.disabled||!1,isReady:!1,defaultValues:hq(e.defaultValues)?void 0:e.defaultValues});if(!r.current)if(e.formControl)r.current={...e.formControl,formState:o},e.defaultValues&&!hq(e.defaultValues)&&e.formControl.reset(e.defaultValues,e.resetOptions);else{const{formControl:t,...n}=Wq(e);r.current={...n,formState:o}}const s=r.current.control;return s._options=e,nq(()=>{const e=s._subscribe({formState:s._proxyFormState,callback:()=>i({...s._formState}),reRenderRoot:!0});return i(e=>({...e,isReady:!0})),s._formState.isReady=!0,e},[s]),t.useEffect(()=>s._disableForm(e.disabled),[s,e.disabled]),t.useEffect(()=>{e.mode&&(s._options.mode=e.mode),e.reValidateMode&&(s._options.reValidateMode=e.reValidateMode)},[s,e.mode,e.reValidateMode]),t.useEffect(()=>{e.errors&&(s._setErrors(e.errors),s._focusError())},[s,e.errors]),t.useEffect(()=>{e.shouldUnregister&&s._subjects.state.next({values:s._getWatch()})},[s,e.shouldUnregister]),t.useEffect(()=>{if(s._proxyFormState.isDirty){const e=s._getDirty();e!==o.isDirty&&s._subjects.state.next({isDirty:e})}},[s,o.isDirty]),t.useEffect(()=>{e.values&&!aq(e.values,n.current)?(s._reset(e.values,{keepFieldsRef:!0,...s._options.resetOptions}),n.current=e.values,i(e=>({...e}))):s._resetDefaultValues()},[s,e.values]),t.useEffect(()=>{s._state.mount||(s._setValid(),s._state.mount=!0),s._state.watch&&(s._state.watch=!1,s._subjects.state.next({...s._formState})),s._removeUnmounted()}),r.current.formState=rq(o,s),r.current}({defaultValues:{product:"",subject:"",title:"",description:""},mode:"onChange"}),{mutateAsync:p,isPending:d}=Py({mutationFn:e=>Ux.sendFeedback(e)}),{data:f}=Ay({queryKey:["countryCode"],queryFn:()=>Wx.getCountryCode(),staleTime:1/0,gcTime:1/0}),[h,m]=t.useState(null),g=t.useMemo(()=>[{label:i("dialog.products.general"),value:"GENERAL"},{label:i("dialog.products.editor"),value:"EDITOR"},{label:i("dialog.products.imageOptimization"),value:"IO"},{label:i("dialog.products.accessibility"),value:"ALLY"},{label:i("dialog.products.emailDeliverability"),value:"SM"},{label:i("dialog.products.siteManagement"),value:"MANAGE"},{label:i("dialog.products.cookieConsent"),value:"COOKIEZ"}],[i]),v=t.useMemo(()=>[{label:i("dialog.subjects.leaveFeedback"),value:i("dialog.subjects.leaveFeedback",{lng:iX.EN})},{label:i("dialog.subjects.reportBug"),value:i("dialog.subjects.reportBug",{lng:iX.EN})},{label:i("dialog.subjects.requestFeature"),value:i("dialog.subjects.requestFeature",{lng:iX.EN})},{label:i("dialog.subjects.shareThoughts"),value:i("dialog.subjects.shareThoughts",{lng:iX.EN})}],[i]),y=()=>{c(),n()};return e.jsxs(vu,{colorScheme:o,children:[e.jsxs(nW,{onClose:y,open:r,maxWidth:"sm",fullWidth:!0,"data-test":"send-feedback-dialog",children:[e.jsx(QW,{logo:!1,onClose:y,children:e.jsx(kW,{color:"text.primary",variant:"subtitle1",children:i("dialog.title")})}),e.jsxs(cV,{component:"form",onSubmit:l(e=>{p({...e,countryCode:f},{onSuccess:()=>{y(),m({type:"success",message:i("tooltipSuccess")})},onError:()=>{m({type:"error",message:i("tooltipError")})}})}),children:[e.jsx(pW,{sx:{px:3},dividers:!0,children:e.jsxs(ya,{gap:2,children:[e.jsx(lq,{name:"product",control:a,render:({field:{onChange:t,value:r}})=>e.jsx(DK,{multiple:!1,options:g,value:g.find(e=>e.value===r)||null,onChange:(e,r)=>t(r?.value||""),renderInput:t=>e.jsx(oX,{"data-test":"product-send-feedback-input",...t,isWrapped:!0,placeholder:i("dialog.fieldProductPlaceholder"),color:"secondary"})})}),e.jsx(lq,{name:"subject",control:a,render:({field:{onChange:t,value:r}})=>e.jsx(DK,{multiple:!1,options:v,value:v.find(e=>e.value===r)||null,onChange:(e,r)=>t(r?.value||""),renderInput:t=>e.jsx(oX,{"data-test":"subject-send-feedback-input",...t,isWrapped:!0,placeholder:i("dialog.fieldSubjectPlaceholder"),color:"secondary"})})}),e.jsx(lq,{name:"title",control:a,rules:{required:!0,maxLength:{value:90,message:i("dialog.titleLengthError")}},render:({field:t,fieldState:r})=>e.jsx(jW,{fullWidth:!0,children:e.jsx(oX,{...t,fullWidth:!0,placeholder:i("dialog.fieldTitlePlaceholder"),"data-test":"title-send-feedback-input",error:Boolean(r.error),helperText:r.error?.message,required:!0,sx:{"& .MuiInputBase-root":{minHeight:56}},color:"secondary"})})}),e.jsx(lq,{name:"description",control:a,rules:{required:!0,maxLength:{value:1024,message:i("dialog.descriptionLengthError")}},render:({field:t,fieldState:r})=>e.jsx(jW,{fullWidth:!0,children:e.jsx(oX,{...t,multiline:!0,rows:5,fullWidth:!0,noPadding:!0,placeholder:i("dialog.fieldDescriptionPlaceholder"),"data-test":"description-send-feedback-input",error:Boolean(r.error),helperText:r.error?.message,required:!0,color:"secondary"})})}),e.jsx(pY,{severity:"info",action:e.jsx(xY,{href:s,target:"_blank",color:"info",children:i("dialog.alert.button")}),children:i("dialog.alert.title")}),e.jsxs(ya,{direction:"row",gap:1,children:[e.jsx(Na,{sx:{ml:.5},variant:"body2",color:"text.primary",children:"• "}),e.jsx(Na,{variant:"body2",color:"text.primary",children:i("dialog.note")})]})]})}),e.jsxs(vW,{sx:{px:3,py:2,gap:1},children:[e.jsx(wp,{variant:"text",color:"secondary",onClick:y,"data-test":"cancel-send-feedback-modal",children:i("dialog.cancel")}),e.jsx(wp,{type:"submit",variant:"contained",loading:d,"data-test":"submit-feedback-button",disabled:!u||d,children:i("dialog.submit")})]})]})]}),e.jsx(jY,{open:Boolean(h),autoHideDuration:5e3,onClose:()=>m(null),anchorOrigin:{vertical:"bottom",horizontal:"right"},children:e.jsx(pY,{onClose:()=>m(null),severity:h?.type,variant:"filled",children:h?.message})})]})},aX="action_type",lX="app_context",cX=t=>e.jsx(Cu,{width:"25",height:"24",viewBox:"0 0 25 24",fill:"none",...t,children:e.jsx("path",{d:"M12.1207 0C5.42401 0 0 5.37 0 12C0 18.63 5.42401 24 12.1207 24C18.8174 24 24.2414 18.63 24.2414 12C24.2414 5.37 18.8174 0 12.1207 0ZM8.48448 18H6.06034V6H8.48448V18ZM18.181 18H10.9086V15.6H18.181V18ZM18.181 13.2H10.9086V10.8H18.181V13.2ZM18.181 8.4H10.9086V6H18.181V8.4Z",fill:"white"})});var uX,pX={exports:{}};function dX(){return uX||(uX=1,function(e,t){var r;function n(e,t){var r=[],n=0;function o(e){return r.push(e),t}function i(){return r[n++]}return{tokenize:function(t){return t.replace(e,o)},detokenize:function(e){return e.replace(new RegExp("("+t+")","g"),i)}}}r=new function(){var e="`TMP`",t="`COMMENT`",r="[^\\u0020-\\u007e]",o="(?:[0-9]*\\.[0-9]+|[0-9]+)",i="(?:em|ex|px|cm|mm|in|pt|pc|deg|rad|grad|ms|s|hz|khz|%)",s="direction\\s*:\\s*",a="['\"]?\\s*",l="(^|[^a-zA-Z])",c="\\/\\*\\!?\\s*@noflip\\s*\\*\\/",u="(?:(?:(?:\\\\[0-9a-f]{1,6})(?:\\r\\n|\\s)?)|\\\\[^\\r\\n\\f0-9a-f])",p="(?:[_a-z0-9-]|"+r+"|"+u+")",d=o+"(?:\\s*"+i+"|-?(?:[_a-z]|"+r+"|"+u+")"+p+"*)?",f="((?:-?"+d+")|(?:inherit|auto))",h="((?:-?"+d+")|(?:inherit|auto)|(?:calc\\((?:(?:(?:\\(|\\)|\\t| )|(?:-?"+o+"(?:\\s*"+i+")?)|(?:\\+|\\-|\\*|\\/)){3,})\\)))",m="(#?"+p+"+|(?:rgba?|hsla?)\\([ \\d.,%-]+\\))",g="(?:[!#$%&*-~]|"+r+"|"+u+")*?",v="(?![a-zA-Z])",y="(?!("+p+"|\\r?\\n|\\s|#|\\:|\\.|\\,|\\+|>|~|\\(|\\)|\\[|\\]|=|\\*=|~=|\\^=|'[^']*'|\"[^\"]*\"|"+t+")*?{)",b="(?!"+g+a+"\\))",w="(?="+g+a+"\\))",x="(\\s*(?:!important\\s*)?[;}])",_=/`TMP`/g,S=/`TMPLTR`/g,k=/`TMPRTL`/g,C=new RegExp("\\/\\*[^*]*\\*+([^\\/*][^*]*\\*+)*\\/","gi"),O=new RegExp("("+c+y+"[^;}]+;?)","gi"),E=new RegExp("("+c+"[^\\}]*?})","gi"),T=new RegExp("("+s+")ltr","gi"),R=new RegExp("("+s+")rtl","gi"),I=new RegExp(l+"(left)"+v+b+y,"gi"),M=new RegExp(l+"(right)"+v+b+y,"gi"),A=new RegExp(l+"(left)"+w,"gi"),P=new RegExp(l+"(right)"+w,"gi"),N=/(:dir\( *)ltr( *\))/g,j=/(:dir\( *)rtl( *\))/g,L=new RegExp(l+"(ltr)"+w,"gi"),D=new RegExp(l+"(rtl)"+w,"gi"),F=new RegExp(l+"([ns]?)e-resize","gi"),$=new RegExp(l+"([ns]?)w-resize","gi"),B=new RegExp("((?:margin|padding|border-width)\\s*:\\s*)"+h+"(\\s+)"+h+"(\\s+)"+h+"(\\s+)"+h+x,"gi"),z=new RegExp("((?:-color|border-style)\\s*:\\s*)"+m+"(\\s+)"+m+"(\\s+)"+m+"(\\s+)"+m+x,"gi"),V=new RegExp("(background(?:-position)?\\s*:\\s*(?:[^:;}\\s]+\\s+)*?)("+d+")","gi"),U=new RegExp("(background-position-x\\s*:\\s*)(-?"+o+"%)","gi"),q=new RegExp("(border-radius\\s*:\\s*)"+f+"(?:(?:\\s+"+f+")(?:\\s+"+f+")?(?:\\s+"+f+")?)?(?:(?:(?:\\s*\\/\\s*)"+f+")(?:\\s+"+f+")?(?:\\s+"+f+")?(?:\\s+"+f+")?)?"+x,"gi"),W=new RegExp("(box-shadow\\s*:\\s*(?:inset\\s*)?)"+f,"gi"),H=new RegExp("(text-shadow\\s*:\\s*)"+f+"(\\s*)"+m,"gi"),G=new RegExp("(text-shadow\\s*:\\s*)"+m+"(\\s*)"+f,"gi"),K=new RegExp("(text-shadow\\s*:\\s*)"+f,"gi"),Y=new RegExp("(transform\\s*:[^;}]*)(translateX\\s*\\(\\s*)"+f+"(\\s*\\))","gi"),Z=new RegExp("(transform\\s*:[^;}]*)(translate\\s*\\(\\s*)"+f+"((?:\\s*,\\s*"+f+"){0,2}\\s*\\))","gi");function X(e,t,r){var n,o;return"%"===r.slice(-1)&&(-1!==(n=r.indexOf("."))?(o=r.length-n-2,r=(r=100-parseFloat(r)).toFixed(o)+"%"):r=100-parseFloat(r)+"%"),t+r}function J(e){switch(e.length){case 4:e=[e[1],e[0],e[3],e[2]];break;case 3:e=[e[1],e[0],e[1],e[2]];break;case 2:e=[e[1],e[0]];break;case 1:e=[e[0]]}return e.join(" ")}function Q(e,t){var r=[].slice.call(arguments),n=r.slice(2,6).filter(function(e){return e}),o=r.slice(6,10).filter(function(e){return e}),i=r[10]||"";return t+(o.length?J(n)+" / "+J(o):J(n))+i}function ee(e){return 0===parseFloat(e)?e:"-"===e[0]?e.slice(1):"-"+e}function te(e,t,r){return t+ee(r)}function re(e,t,r,n,o){return t+r+ee(n)+o}function ne(e,t,r,n,o){return t+r+n+ee(o)}return{transform:function(r,o){var i=new n(O,"`NOFLIP_SINGLE`"),s=new n(E,"`NOFLIP_CLASS`"),a=new n(C,t);return r=a.tokenize(s.tokenize(i.tokenize(r.replace("`","%60")))),o.transformDirInUrl&&(r=r.replace(N,"$1`TMPLTR`$2").replace(j,"$1`TMPRTL`$2").replace(L,"$1"+e).replace(D,"$1ltr").replace(_,"rtl").replace(S,"ltr").replace(k,"rtl")),o.transformEdgeInUrl&&(r=r.replace(A,"$1"+e).replace(P,"$1left").replace(_,"right")),r=r.replace(T,"$1"+e).replace(R,"$1ltr").replace(_,"rtl").replace(I,"$1"+e).replace(M,"$1left").replace(_,"right").replace(F,"$1$2"+e).replace($,"$1$2e-resize").replace(_,"w-resize").replace(q,Q).replace(W,te).replace(H,ne).replace(G,ne).replace(K,te).replace(Y,re).replace(Z,re).replace(B,"$1$2$3$8$5$6$7$4$9").replace(z,"$1$2$3$8$5$6$7$4$9").replace(V,X).replace(U,X),i.detokenize(s.detokenize(a.detokenize(r)))}}},e.exports?t.transform=function(e,t,n){var o;return"object"==typeof t?o=t:(o={},"boolean"==typeof t&&(o.transformDirInUrl=t),"boolean"==typeof n&&(o.transformEdgeInUrl=n)),r.transform(e,o)}:"undefined"!=typeof window&&(window.cssjanus=r)}(pX,pX.exports)),pX.exports}const fX=l(dX());var hX="-ms-",mX="-moz-",gX="-webkit-",vX="comm",yX="rule",bX="decl",wX="@keyframes",xX=Math.abs,_X=String.fromCharCode,SX=Object.assign;function kX(e){return e.trim()}function CX(e,t){return(e=t.exec(e))?e[0]:e}function OX(e,t,r){return e.replace(t,r)}function EX(e,t){return e.indexOf(t)}function TX(e,t){return 0|e.charCodeAt(t)}function RX(e,t,r){return e.slice(t,r)}function IX(e){return e.length}function MX(e){return e.length}function AX(e,t){return t.push(e),e}var PX=1,NX=1,jX=0,LX=0,DX=0,FX="";function $X(e,t,r,n,o,i,s){return{value:e,root:t,parent:r,type:n,props:o,children:i,line:PX,column:NX,length:s,return:""}}function BX(e,t){return SX($X("",null,null,"",null,null,0),e,{length:-e.length},t)}function zX(){return DX=LX>0?TX(FX,--LX):0,NX--,10===DX&&(NX=1,PX--),DX}function VX(){return DX=LX<jX?TX(FX,LX++):0,NX++,10===DX&&(NX=1,PX++),DX}function UX(){return TX(FX,LX)}function qX(){return LX}function WX(e,t){return RX(FX,e,t)}function HX(e){switch(e){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function GX(e){return kX(WX(LX-1,ZX(91===e?e+2:40===e?e+1:e)))}function KX(e){for(;(DX=UX())&&DX<33;)VX();return HX(e)>2||HX(DX)>3?"":" "}function YX(e,t){for(;--t&&VX()&&!(DX<48||DX>102||DX>57&&DX<65||DX>70&&DX<97););return WX(e,qX()+(t<6&&32==UX()&&32==VX()))}function ZX(e){for(;VX();)switch(DX){case e:return LX;case 34:case 39:34!==e&&39!==e&&ZX(DX);break;case 40:41===e&&ZX(e);break;case 92:VX()}return LX}function XX(e,t){for(;VX()&&e+DX!==57&&(e+DX!==84||47!==UX()););return"/*"+WX(t,LX-1)+"*"+_X(47===e?e:VX())}function JX(e){for(;!HX(UX());)VX();return WX(e,LX)}function QX(e){return function(e){return FX="",e}(eJ("",null,null,null,[""],e=function(e){return PX=NX=1,jX=IX(FX=e),LX=0,[]}(e),0,[0],e))}function eJ(e,t,r,n,o,i,s,a,l){for(var c=0,u=0,p=s,d=0,f=0,h=0,m=1,g=1,v=1,y=0,b="",w=o,x=i,_=n,S=b;g;)switch(h=y,y=VX()){case 40:if(108!=h&&58==TX(S,p-1)){-1!=EX(S+=OX(GX(y),"&","&\f"),"&\f")&&(v=-1);break}case 34:case 39:case 91:S+=GX(y);break;case 9:case 10:case 13:case 32:S+=KX(h);break;case 92:S+=YX(qX()-1,7);continue;case 47:switch(UX()){case 42:case 47:AX(rJ(XX(VX(),qX()),t,r),l);break;default:S+="/"}break;case 123*m:a[c++]=IX(S)*v;case 125*m:case 59:case 0:switch(y){case 0:case 125:g=0;case 59+u:f>0&&IX(S)-p&&AX(f>32?nJ(S+";",n,r,p-1):nJ(OX(S," ","")+";",n,r,p-2),l);break;case 59:S+=";";default:if(AX(_=tJ(S,t,r,c,u,o,a,b,w=[],x=[],p),i),123===y)if(0===u)eJ(S,t,_,_,w,i,p,a,x);else switch(99===d&&110===TX(S,3)?100:d){case 100:case 109:case 115:eJ(e,_,_,n&&AX(tJ(e,_,_,0,0,o,a,b,o,w=[],p),x),o,x,p,a,n?w:x);break;default:eJ(S,_,_,_,[""],x,0,a,x)}}c=u=f=0,m=v=1,b=S="",p=s;break;case 58:p=1+IX(S),f=h;default:if(m<1)if(123==y)--m;else if(125==y&&0==m++&&125==zX())continue;switch(S+=_X(y),y*m){case 38:v=u>0?1:(S+="\f",-1);break;case 44:a[c++]=(IX(S)-1)*v,v=1;break;case 64:45===UX()&&(S+=GX(VX())),d=UX(),u=p=IX(b=S+=JX(qX())),y++;break;case 45:45===h&&2==IX(S)&&(m=0)}}return i}function tJ(e,t,r,n,o,i,s,a,l,c,u){for(var p=o-1,d=0===o?i:[""],f=MX(d),h=0,m=0,g=0;h<n;++h)for(var v=0,y=RX(e,p+1,p=xX(m=s[h])),b=e;v<f;++v)(b=kX(m>0?d[v]+" "+y:OX(y,/&\f/g,d[v])))&&(l[g++]=b);return $X(e,t,r,0===o?yX:a,l,c,u)}function rJ(e,t,r){return $X(e,t,r,vX,_X(DX),RX(e,2,-2),0)}function nJ(e,t,r,n){return $X(e,t,r,bX,RX(e,0,n),RX(e,n+1,-1),n)}function oJ(e,t,r){switch(function(e,t){return 45^TX(e,0)?(((t<<2^TX(e,0))<<2^TX(e,1))<<2^TX(e,2))<<2^TX(e,3):0}(e,t)){case 5103:return gX+"print-"+e+e;case 5737:case 4201:case 3177:case 3433:case 1641:case 4457:case 2921:case 5572:case 6356:case 5844:case 3191:case 6645:case 3005:case 6391:case 5879:case 5623:case 6135:case 4599:case 4855:case 4215:case 6389:case 5109:case 5365:case 5621:case 3829:return gX+e+e;case 4789:return mX+e+e;case 5349:case 4246:case 4810:case 6968:case 2756:return gX+e+mX+e+hX+e+e;case 5936:switch(TX(e,t+11)){case 114:return gX+e+hX+OX(e,/[svh]\w+-[tblr]{2}/,"tb")+e;case 108:return gX+e+hX+OX(e,/[svh]\w+-[tblr]{2}/,"tb-rl")+e;case 45:return gX+e+hX+OX(e,/[svh]\w+-[tblr]{2}/,"lr")+e}case 6828:case 4268:case 2903:return gX+e+hX+e+e;case 6165:return gX+e+hX+"flex-"+e+e;case 5187:return gX+e+OX(e,/(\w+).+(:[^]+)/,gX+"box-$1$2"+hX+"flex-$1$2")+e;case 5443:return gX+e+hX+"flex-item-"+OX(e,/flex-|-self/g,"")+(CX(e,/flex-|baseline/)?"":hX+"grid-row-"+OX(e,/flex-|-self/g,""))+e;case 4675:return gX+e+hX+"flex-line-pack"+OX(e,/align-content|flex-|-self/g,"")+e;case 5548:return gX+e+hX+OX(e,"shrink","negative")+e;case 5292:return gX+e+hX+OX(e,"basis","preferred-size")+e;case 6060:return gX+"box-"+OX(e,"-grow","")+gX+e+hX+OX(e,"grow","positive")+e;case 4554:return gX+OX(e,/([^-])(transform)/g,"$1"+gX+"$2")+e;case 6187:return OX(OX(OX(e,/(zoom-|grab)/,gX+"$1"),/(image-set)/,gX+"$1"),e,"")+e;case 5495:case 3959:return OX(e,/(image-set\([^]*)/,gX+"$1$`$1");case 4968:return OX(OX(e,/(.+:)(flex-)?(.*)/,gX+"box-pack:$3"+hX+"flex-pack:$3"),/s.+-b[^;]+/,"justify")+gX+e+e;case 4200:if(!CX(e,/flex-|baseline/))return hX+"grid-column-align"+RX(e,t)+e;break;case 2592:case 3360:return hX+OX(e,"template-","")+e;case 4384:case 3616:return r&&r.some(function(e,r){return t=r,CX(e.props,/grid-\w+-end/)})?~EX(e+(r=r[t].value),"span")?e:hX+OX(e,"-start","")+e+hX+"grid-row-span:"+(~EX(r,"span")?CX(r,/\d+/):+CX(r,/\d+/)-+CX(e,/\d+/))+";":hX+OX(e,"-start","")+e;case 4896:case 4128:return r&&r.some(function(e){return CX(e.props,/grid-\w+-start/)})?e:hX+OX(OX(e,"-end","-span"),"span ","")+e;case 4095:case 3583:case 4068:case 2532:return OX(e,/(.+)-inline(.+)/,gX+"$1$2")+e;case 8116:case 7059:case 5753:case 5535:case 5445:case 5701:case 4933:case 4677:case 5533:case 5789:case 5021:case 4765:if(IX(e)-1-t>6)switch(TX(e,t+1)){case 109:if(45!==TX(e,t+4))break;case 102:return OX(e,/(.+:)(.+)-([^]+)/,"$1"+gX+"$2-$3$1"+mX+(108==TX(e,t+3)?"$3":"$2-$3"))+e;case 115:return~EX(e,"stretch")?oJ(OX(e,"stretch","fill-available"),t,r)+e:e}break;case 5152:case 5920:return OX(e,/(.+?):(\d+)(\s*\/\s*(span)?\s*(\d+))?(.*)/,function(t,r,n,o,i,s,a){return hX+r+":"+n+a+(o?hX+r+"-span:"+(i?s:+s-+n)+a:"")+e});case 4949:if(121===TX(e,t+6))return OX(e,":",":"+gX)+e;break;case 6444:switch(TX(e,45===TX(e,14)?18:11)){case 120:return OX(e,/(.+:)([^;\s!]+)(;|(\s+)?!.+)?/,"$1"+gX+(45===TX(e,14)?"inline-":"")+"box$3$1"+gX+"$2$3$1"+hX+"$2box$3")+e;case 100:return OX(e,":",":"+hX)+e}break;case 5719:case 2647:case 2135:case 3927:case 2391:return OX(e,"scroll-","scroll-snap-")+e}return e}function iJ(e,t){for(var r="",n=MX(e),o=0;o<n;o++)r+=t(e[o],o,e,t)||"";return r}function sJ(e,t,r){switch(e.type){case"@import":case bX:case vX:return e.return=e.return||e.value;case yX:e.value=Array.isArray(e.props)?e.props.join(","):e.props,Array.isArray(e.children)&&e.children.forEach(function(e){e.type===vX&&(e.children=e.value)})}var n=iJ(Array.prototype.concat(e.children),sJ);return IX(n)?e.return=e.value+"{"+n+"}":""}function aJ(e,t,r,n){if(e.type===wX||"@supports"===e.type||e.type===yX&&(!e.parent||"@media"===e.parent.type||e.parent.type===yX)){var o=fX.transform(sJ(e));e.children=o?QX(o)[0].children:[],e.return=""}}Object.defineProperty(aJ,"name",{value:"stylisRTLPlugin"});const lJ=nt({key:Xl,stylisPlugins:[function(e,t,r,n){if(e.length>-1&&!e.return)switch(e.type){case bX:return void(e.return=oJ(e.value,e.length,r));case wX:return iJ([BX(e,{value:OX(e.value,"@","@"+gX)})],n);case yX:if(e.length)return function(e,t){return e.map(t).join("")}(e.props,function(t){switch(CX(t,/(::plac\w+|:read-\w+)/)){case":read-only":case":read-write":return iJ([BX(e,{props:[OX(t,/:(read-\w+)/,":-moz-$1")]})],n);case"::placeholder":return iJ([BX(e,{props:[OX(t,/:(plac\w+)/,":"+gX+"input-$1")]}),BX(e,{props:[OX(t,/:(plac\w+)/,":-moz-$1")]}),BX(e,{props:[OX(t,/:(plac\w+)/,hX+"input-$1")]})],n)}return""})}},aJ]}),cJ=nt({key:"eui"});var uJ=({rtl:e,children:r})=>t.createElement(xt,{value:e?lJ:cJ},r);exports.ElementorOneAssetsContext=lz,exports.ElementorOneAssetsProvider=({env:r,language:n="en",isRTL:o=!1,children:i})=>{const s=t.useMemo(()=>(e=>Ny[e])(r),[r]),a=t.useMemo(()=>({config:s,isRTL:o}),[s,o]);return t.useEffect(()=>{bm.changeLanguage(n)},[n]),t.useEffect(()=>{Gw.initialize(s)},[s]),t.useEffect(()=>{window.elementorOneSettingsData?.shareUsageData&&oz.initialize("150605b3b9f979922f2ac5a52e2dcfe9",r)},[r]),e.jsx(Ty,{client:az,children:e.jsx(lz.Provider,{value:a,children:i})})},exports.ElementorOneHeader=({appSettings:r,colorScheme:n="dark",title:o,multiDelpoymentSlot:i,isWithinWpAdmin:s=!0,containerSx:a={},onDisconnect:l})=>{const{t:c}=Bd("common",{i18n:bm}),u=(e=>{switch(e){case"image-optimizer":return"https://go.elementor.com/one-help-center-io/";case"ally":return"https://go.elementor.com/one-help-center-ally/";case"elementor-pro":case"elementor":return"https://go.elementor.com/one-help-center-editor/";case"site-mailer":return"https://go.elementor.com/one-help-center-sm/";case"angie":return"https://go.elementor.com/one-help-center-angie/";case"cookiez":return"https://go.elementor.com/cookiez-help-center/";default:return"https://go.elementor.com/one-help-center/"}})(r.slug),[p,d]=t.useState(!1),f=pz(),h=(()=>{const e=t.useContext(lz);if(!e)throw new Error("Wrap your component in <ElementorOneAssetsProvider> to access RTL orientation");return e.isRTL})(),m=t.useRef(!1),g=window.elementorOneSettingsData?.canUserManageOptions??!1,v=window.elementorOneSettingsData?.shareUsageData??!1,{data:y}=sz({enabled:g});t.useEffect(()=>{if(v&&!m.current){const{appType:e,productName:t}=(e=>{switch(e){case"elementor":case"elementor-pro":return{appType:"Editor"};case"elementor-home":default:return{appType:"Infra"};case"ally":return{appType:"Apps",productName:"app_access"};case"image-optimization":return{appType:"Apps",productName:"app_io"};case"site-mailer":return{appType:"Apps",productName:"app_mailer"};case"angie":return{appType:"Apps",productName:"app_ai"};case"cookiez":return{appType:"Apps",productName:"app_cookie"}}})(r.slug),n={appType:e};t&&(n.productName=t),oz.registerOnce(n),m.current=!0}},[r.slug,v]);const b=e=>{v&&oz.track("top_bar_clicked",{[aX]:e,[lX]:r.slug})};return e.jsx(uJ,{rtl:h,children:e.jsxs(vu,{colorScheme:n,children:[e.jsx(ma,{sx:{top:0,...a,position:"sticky",zIndex:1100},children:e.jsx(ka,{sx:{pl:"30px !important",backgroundColor:"background.paper"},variant:"dense",children:e.jsxs(ya,{direction:"row",justifyContent:"space-between",width:"100%",children:[e.jsxs(ya,{direction:"row",alignItems:"center",gap:1,flexWrap:"nowrap",children:[e.jsx(cX,{}),!f&&e.jsx(Na,{variant:"button",fontSize:"20px",fontWeight:400,whiteSpace:"nowrap",children:o||c("header.title")})]}),e.jsxs(ya,{direction:"row",alignItems:"center",gap:1,children:[y?.isConnected&&e.jsx(bu,{size:"small",onClick:()=>{b("feedback"),d(!0)},"data-test":"header-feedback-button",children:e.jsx(Ou,{fontSize:"small"})}),e.jsx(MU,{appSettings:r,onClick:()=>b("whats_new"),containerSx:{"& .MuiDrawer-paper":{width:320,padding:3,...s?{top:32,height:"calc(100vh - 32px)","@media (max-width: 784px)":{top:46,height:"calc(100vh - 46px)"}}:{}}}}),u&&e.jsx(bu,{size:"small",href:u,target:"_blank",onClick:()=>b("help"),"data-test":"header-help-button",children:e.jsx(Eu,{fontSize:"small"})}),i,g&&e.jsxs(e.Fragment,{children:[e.jsx(ju,{orientation:"vertical",flexItem:!0,sx:{my:1,mx:1}}),e.jsx(zz,{onDisconnect:l,onClick:()=>b("account"),onConnectClick:()=>b("connect")})]})]})]})})}),e.jsx(sX,{open:p,onClose:()=>d(!1)})]})})},exports.SendFeedbackDialog=sX,exports.WhatsNew=MU;
//# sourceMappingURL=index.cjs.js.map


/***/ }),

/***/ "../node_modules/@elementor/elementor-one-assets/locales lazy recursive ^\\.\\/.*\\/.*\\.json$":
/*!*********************************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/ lazy ^\.\/.*\/.*\.json$ namespace object ***!
  \*********************************************************************************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

var map = {
	"./de/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/de/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_de_assets-whatsnew_json"
	],
	"./de/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/de/common.json",
		"node_modules_elementor_elementor-one-assets_locales_de_common_json"
	],
	"./de/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/de/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_de_send-feedback_json"
	],
	"./en/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/en/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_en_assets-whatsnew_json"
	],
	"./en/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/en/common.json",
		"node_modules_elementor_elementor-one-assets_locales_en_common_json"
	],
	"./en/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/en/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_en_send-feedback_json"
	],
	"./es/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/es/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_es_assets-whatsnew_json"
	],
	"./es/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/es/common.json",
		"node_modules_elementor_elementor-one-assets_locales_es_common_json"
	],
	"./es/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/es/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_es_send-feedback_json"
	],
	"./fr/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/fr/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_fr_assets-whatsnew_json"
	],
	"./fr/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/fr/common.json",
		"node_modules_elementor_elementor-one-assets_locales_fr_common_json"
	],
	"./fr/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/fr/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_fr_send-feedback_json"
	],
	"./he-IL/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/he-IL/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_he-IL_assets-whatsnew_json"
	],
	"./he-IL/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/he-IL/common.json",
		"node_modules_elementor_elementor-one-assets_locales_he-IL_common_json"
	],
	"./he-IL/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/he-IL/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_he-IL_send-feedback_json"
	],
	"./id-ID/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/id-ID/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_id-ID_assets-whatsnew_json"
	],
	"./id-ID/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/id-ID/common.json",
		"node_modules_elementor_elementor-one-assets_locales_id-ID_common_json"
	],
	"./id-ID/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/id-ID/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_id-ID_send-feedback_json"
	],
	"./it/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/it/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_it_assets-whatsnew_json"
	],
	"./it/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/it/common.json",
		"node_modules_elementor_elementor-one-assets_locales_it_common_json"
	],
	"./it/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/it/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_it_send-feedback_json"
	],
	"./nl/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/nl/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_nl_assets-whatsnew_json"
	],
	"./nl/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/nl/common.json",
		"node_modules_elementor_elementor-one-assets_locales_nl_common_json"
	],
	"./nl/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/nl/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_nl_send-feedback_json"
	],
	"./pl-PL/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/pl-PL/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_pl-PL_assets-whatsnew_json"
	],
	"./pl-PL/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/pl-PL/common.json",
		"node_modules_elementor_elementor-one-assets_locales_pl-PL_common_json"
	],
	"./pl-PL/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/pl-PL/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_pl-PL_send-feedback_json"
	],
	"./pt-BR/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/pt-BR/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_pt-BR_assets-whatsnew_json"
	],
	"./pt-BR/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/pt-BR/common.json",
		"node_modules_elementor_elementor-one-assets_locales_pt-BR_common_json"
	],
	"./pt-BR/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/pt-BR/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_pt-BR_send-feedback_json"
	],
	"./pt-PT/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/pt-PT/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_pt-PT_assets-whatsnew_json"
	],
	"./pt-PT/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/pt-PT/common.json",
		"node_modules_elementor_elementor-one-assets_locales_pt-PT_common_json"
	],
	"./pt-PT/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/pt-PT/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_pt-PT_send-feedback_json"
	],
	"./tr-TR/assets-whatsnew.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/tr-TR/assets-whatsnew.json",
		"node_modules_elementor_elementor-one-assets_locales_tr-TR_assets-whatsnew_json"
	],
	"./tr-TR/common.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/tr-TR/common.json",
		"node_modules_elementor_elementor-one-assets_locales_tr-TR_common_json"
	],
	"./tr-TR/send-feedback.json": [
		"../node_modules/@elementor/elementor-one-assets/locales/tr-TR/send-feedback.json",
		"node_modules_elementor_elementor-one-assets_locales_tr-TR_send-feedback_json"
	]
};
function webpackAsyncContext(req) {
	if(!__webpack_require__.o(map, req)) {
		return Promise.resolve().then(() => {
			var e = new Error("Cannot find module '" + req + "'");
			e.code = 'MODULE_NOT_FOUND';
			throw e;
		});
	}

	var ids = map[req], id = ids[0];
	return __webpack_require__.e(ids[1]).then(() => {
		return __webpack_require__.t(id, 3 | 16);
	});
}
webpackAsyncContext.keys = () => (Object.keys(map));
webpackAsyncContext.id = "../node_modules/@elementor/elementor-one-assets/locales lazy recursive ^\\.\\/.*\\/.*\\.json$";
module.exports = webpackAsyncContext;

/***/ }),

/***/ "../node_modules/@wordpress/element/build-module/create-interpolate-element.js":
/*!*************************************************************************************!*\
  !*** ../node_modules/@wordpress/element/build-module/create-interpolate-element.js ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./react */ "react");
/* harmony import */ var _react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Internal dependencies
 */


/**
 * Object containing a React element.
 *
 * @typedef {import('react').ReactElement} Element
 */

let indoc, offset, output, stack;

/**
 * Matches tags in the localized string
 *
 * This is used for extracting the tag pattern groups for parsing the localized
 * string and along with the map converting it to a react element.
 *
 * There are four references extracted using this tokenizer:
 *
 * match: Full match of the tag (i.e. <strong>, </strong>, <br/>)
 * isClosing: The closing slash, if it exists.
 * name: The name portion of the tag (strong, br) (if )
 * isSelfClosed: The slash on a self closing tag, if it exists.
 *
 * @type {RegExp}
 */
const tokenizer = /<(\/)?(\w+)\s*(\/)?>/g;

/**
 * The stack frame tracking parse progress.
 *
 * @typedef Frame
 *
 * @property {Element}   element            A parent element which may still have
 * @property {number}    tokenStart         Offset at which parent element first
 *                                          appears.
 * @property {number}    tokenLength        Length of string marking start of parent
 *                                          element.
 * @property {number}    [prevOffset]       Running offset at which parsing should
 *                                          continue.
 * @property {number}    [leadingTextStart] Offset at which last closing element
 *                                          finished, used for finding text between
 *                                          elements.
 * @property {Element[]} children           Children.
 */

/**
 * Tracks recursive-descent parse state.
 *
 * This is a Stack frame holding parent elements until all children have been
 * parsed.
 *
 * @private
 * @param {Element} element            A parent element which may still have
 *                                     nested children not yet parsed.
 * @param {number}  tokenStart         Offset at which parent element first
 *                                     appears.
 * @param {number}  tokenLength        Length of string marking start of parent
 *                                     element.
 * @param {number}  [prevOffset]       Running offset at which parsing should
 *                                     continue.
 * @param {number}  [leadingTextStart] Offset at which last closing element
 *                                     finished, used for finding text between
 *                                     elements.
 *
 * @return {Frame} The stack frame tracking parse progress.
 */
function createFrame(element, tokenStart, tokenLength, prevOffset, leadingTextStart) {
  return {
    element,
    tokenStart,
    tokenLength,
    prevOffset,
    leadingTextStart,
    children: []
  };
}

/**
 * This function creates an interpolated element from a passed in string with
 * specific tags matching how the string should be converted to an element via
 * the conversion map value.
 *
 * @example
 * For example, for the given string:
 *
 * "This is a <span>string</span> with <a>a link</a> and a self-closing
 * <CustomComponentB/> tag"
 *
 * You would have something like this as the conversionMap value:
 *
 * ```js
 * {
 *     span: <span />,
 *     a: <a href={ 'https://github.com' } />,
 *     CustomComponentB: <CustomComponent />,
 * }
 * ```
 *
 * @param {string}                  interpolatedString The interpolation string to be parsed.
 * @param {Record<string, Element>} conversionMap      The map used to convert the string to
 *                                                     a react element.
 * @throws {TypeError}
 * @return {Element}  A wp element.
 */
const createInterpolateElement = (interpolatedString, conversionMap) => {
  indoc = interpolatedString;
  offset = 0;
  output = [];
  stack = [];
  tokenizer.lastIndex = 0;
  if (!isValidConversionMap(conversionMap)) {
    throw new TypeError('The conversionMap provided is not valid. It must be an object with values that are React Elements');
  }
  do {
    // twiddle our thumbs
  } while (proceed(conversionMap));
  return (0,_react__WEBPACK_IMPORTED_MODULE_0__.createElement)(_react__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, ...output);
};

/**
 * Validate conversion map.
 *
 * A map is considered valid if it's an object and every value in the object
 * is a React Element
 *
 * @private
 *
 * @param {Object} conversionMap The map being validated.
 *
 * @return {boolean}  True means the map is valid.
 */
const isValidConversionMap = conversionMap => {
  const isObject = typeof conversionMap === 'object';
  const values = isObject && Object.values(conversionMap);
  return isObject && values.length && values.every(element => (0,_react__WEBPACK_IMPORTED_MODULE_0__.isValidElement)(element));
};

/**
 * This is the iterator over the matches in the string.
 *
 * @private
 *
 * @param {Object} conversionMap The conversion map for the string.
 *
 * @return {boolean} true for continuing to iterate, false for finished.
 */
function proceed(conversionMap) {
  const next = nextToken();
  const [tokenType, name, startOffset, tokenLength] = next;
  const stackDepth = stack.length;
  const leadingTextStart = startOffset > offset ? offset : null;
  if (!conversionMap[name]) {
    addText();
    return false;
  }
  switch (tokenType) {
    case 'no-more-tokens':
      if (stackDepth !== 0) {
        const {
          leadingTextStart: stackLeadingText,
          tokenStart
        } = stack.pop();
        output.push(indoc.substr(stackLeadingText, tokenStart));
      }
      addText();
      return false;
    case 'self-closed':
      if (0 === stackDepth) {
        if (null !== leadingTextStart) {
          output.push(indoc.substr(leadingTextStart, startOffset - leadingTextStart));
        }
        output.push(conversionMap[name]);
        offset = startOffset + tokenLength;
        return true;
      }

      // Otherwise we found an inner element.
      addChild(createFrame(conversionMap[name], startOffset, tokenLength));
      offset = startOffset + tokenLength;
      return true;
    case 'opener':
      stack.push(createFrame(conversionMap[name], startOffset, tokenLength, startOffset + tokenLength, leadingTextStart));
      offset = startOffset + tokenLength;
      return true;
    case 'closer':
      // If we're not nesting then this is easy - close the block.
      if (1 === stackDepth) {
        closeOuterElement(startOffset);
        offset = startOffset + tokenLength;
        return true;
      }

      // Otherwise we're nested and we have to close out the current
      // block and add it as a innerBlock to the parent.
      const stackTop = stack.pop();
      const text = indoc.substr(stackTop.prevOffset, startOffset - stackTop.prevOffset);
      stackTop.children.push(text);
      stackTop.prevOffset = startOffset + tokenLength;
      const frame = createFrame(stackTop.element, stackTop.tokenStart, stackTop.tokenLength, startOffset + tokenLength);
      frame.children = stackTop.children;
      addChild(frame);
      offset = startOffset + tokenLength;
      return true;
    default:
      addText();
      return false;
  }
}

/**
 * Grabs the next token match in the string and returns it's details.
 *
 * @private
 *
 * @return {Array}  An array of details for the token matched.
 */
function nextToken() {
  const matches = tokenizer.exec(indoc);
  // We have no more tokens.
  if (null === matches) {
    return ['no-more-tokens'];
  }
  const startedAt = matches.index;
  const [match, isClosing, name, isSelfClosed] = matches;
  const length = match.length;
  if (isSelfClosed) {
    return ['self-closed', name, startedAt, length];
  }
  if (isClosing) {
    return ['closer', name, startedAt, length];
  }
  return ['opener', name, startedAt, length];
}

/**
 * Pushes text extracted from the indoc string to the output stack given the
 * current rawLength value and offset (if rawLength is provided ) or the
 * indoc.length and offset.
 *
 * @private
 */
function addText() {
  const length = indoc.length - offset;
  if (0 === length) {
    return;
  }
  output.push(indoc.substr(offset, length));
}

/**
 * Pushes a child element to the associated parent element's children for the
 * parent currently active in the stack.
 *
 * @private
 *
 * @param {Frame} frame The Frame containing the child element and it's
 *                      token information.
 */
function addChild(frame) {
  const {
    element,
    tokenStart,
    tokenLength,
    prevOffset,
    children
  } = frame;
  const parent = stack[stack.length - 1];
  const text = indoc.substr(parent.prevOffset, tokenStart - parent.prevOffset);
  if (text) {
    parent.children.push(text);
  }
  parent.children.push((0,_react__WEBPACK_IMPORTED_MODULE_0__.cloneElement)(element, null, ...children));
  parent.prevOffset = prevOffset ? prevOffset : tokenStart + tokenLength;
}

/**
 * This is called for closing tags. It creates the element currently active in
 * the stack.
 *
 * @private
 *
 * @param {number} endOffset Offset at which the closing tag for the element
 *                           begins in the string. If this is greater than the
 *                           prevOffset attached to the element, then this
 *                           helps capture any remaining nested text nodes in
 *                           the element.
 */
function closeOuterElement(endOffset) {
  const {
    element,
    leadingTextStart,
    prevOffset,
    tokenStart,
    children
  } = stack.pop();
  const text = endOffset ? indoc.substr(prevOffset, endOffset - prevOffset) : indoc.substr(prevOffset);
  if (text) {
    children.push(text);
  }
  if (null !== leadingTextStart) {
    output.push(indoc.substr(leadingTextStart, tokenStart - leadingTextStart));
  }
  output.push((0,_react__WEBPACK_IMPORTED_MODULE_0__.cloneElement)(element, null, ...children));
}
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (createInterpolateElement);
//# sourceMappingURL=create-interpolate-element.js.map

/***/ }),

/***/ "../node_modules/@wordpress/element/build-module/index.js":
/*!****************************************************************!*\
  !*** ../node_modules/@wordpress/element/build-module/index.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Children: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.Children),
/* harmony export */   Component: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.Component),
/* harmony export */   Fragment: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.Fragment),
/* harmony export */   Platform: () => (/* reexport safe */ _platform__WEBPACK_IMPORTED_MODULE_4__["default"]),
/* harmony export */   PureComponent: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.PureComponent),
/* harmony export */   RawHTML: () => (/* reexport safe */ _raw_html__WEBPACK_IMPORTED_MODULE_6__["default"]),
/* harmony export */   StrictMode: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.StrictMode),
/* harmony export */   Suspense: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.Suspense),
/* harmony export */   cloneElement: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.cloneElement),
/* harmony export */   concatChildren: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.concatChildren),
/* harmony export */   createContext: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.createContext),
/* harmony export */   createElement: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.createElement),
/* harmony export */   createInterpolateElement: () => (/* reexport safe */ _create_interpolate_element__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   createPortal: () => (/* reexport safe */ _react_platform__WEBPACK_IMPORTED_MODULE_2__.createPortal),
/* harmony export */   createRef: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.createRef),
/* harmony export */   createRoot: () => (/* reexport safe */ _react_platform__WEBPACK_IMPORTED_MODULE_2__.createRoot),
/* harmony export */   findDOMNode: () => (/* reexport safe */ _react_platform__WEBPACK_IMPORTED_MODULE_2__.findDOMNode),
/* harmony export */   flushSync: () => (/* reexport safe */ _react_platform__WEBPACK_IMPORTED_MODULE_2__.flushSync),
/* harmony export */   forwardRef: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.forwardRef),
/* harmony export */   hydrate: () => (/* reexport safe */ _react_platform__WEBPACK_IMPORTED_MODULE_2__.hydrate),
/* harmony export */   hydrateRoot: () => (/* reexport safe */ _react_platform__WEBPACK_IMPORTED_MODULE_2__.hydrateRoot),
/* harmony export */   isEmptyElement: () => (/* reexport safe */ _utils__WEBPACK_IMPORTED_MODULE_3__.isEmptyElement),
/* harmony export */   isValidElement: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.isValidElement),
/* harmony export */   lazy: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.lazy),
/* harmony export */   memo: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.memo),
/* harmony export */   render: () => (/* reexport safe */ _react_platform__WEBPACK_IMPORTED_MODULE_2__.render),
/* harmony export */   renderToString: () => (/* reexport safe */ _serialize__WEBPACK_IMPORTED_MODULE_5__["default"]),
/* harmony export */   startTransition: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.startTransition),
/* harmony export */   switchChildrenNodeName: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.switchChildrenNodeName),
/* harmony export */   unmountComponentAtNode: () => (/* reexport safe */ _react_platform__WEBPACK_IMPORTED_MODULE_2__.unmountComponentAtNode),
/* harmony export */   useCallback: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useCallback),
/* harmony export */   useContext: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useContext),
/* harmony export */   useDebugValue: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useDebugValue),
/* harmony export */   useDeferredValue: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useDeferredValue),
/* harmony export */   useEffect: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useEffect),
/* harmony export */   useId: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useId),
/* harmony export */   useImperativeHandle: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useImperativeHandle),
/* harmony export */   useInsertionEffect: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useInsertionEffect),
/* harmony export */   useLayoutEffect: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useLayoutEffect),
/* harmony export */   useMemo: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useMemo),
/* harmony export */   useReducer: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useReducer),
/* harmony export */   useRef: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useRef),
/* harmony export */   useState: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useState),
/* harmony export */   useSyncExternalStore: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useSyncExternalStore),
/* harmony export */   useTransition: () => (/* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.useTransition)
/* harmony export */ });
/* harmony import */ var _create_interpolate_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./create-interpolate-element */ "../node_modules/@wordpress/element/build-module/create-interpolate-element.js");
/* harmony import */ var _react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./react */ "../node_modules/@wordpress/element/build-module/react.js");
/* harmony import */ var _react_platform__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./react-platform */ "../node_modules/@wordpress/element/build-module/react-platform.js");
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./utils */ "../node_modules/@wordpress/element/build-module/utils.js");
/* harmony import */ var _platform__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./platform */ "../node_modules/@wordpress/element/build-module/platform.js");
/* harmony import */ var _serialize__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./serialize */ "../node_modules/@wordpress/element/build-module/serialize.js");
/* harmony import */ var _raw_html__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./raw-html */ "../node_modules/@wordpress/element/build-module/raw-html.js");







//# sourceMappingURL=index.js.map

/***/ }),

/***/ "../node_modules/@wordpress/element/build-module/platform.js":
/*!*******************************************************************!*\
  !*** ../node_modules/@wordpress/element/build-module/platform.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/**
 * Parts of this source were derived and modified from react-native-web,
 * released under the MIT license.
 *
 * Copyright (c) 2016-present, Nicolas Gallagher.
 * Copyright (c) 2015-present, Facebook, Inc.
 *
 */
const Platform = {
  OS: 'web',
  select: spec => 'web' in spec ? spec.web : spec.default,
  isWeb: true
};
/**
 * Component used to detect the current Platform being used.
 * Use Platform.OS === 'web' to detect if running on web enviroment.
 *
 * This is the same concept as the React Native implementation.
 *
 * @see https://reactnative.dev/docs/platform-specific-code#platform-module
 *
 * Here is an example of how to use the select method:
 * @example
 * ```js
 * import { Platform } from '@wordpress/element';
 *
 * const placeholderLabel = Platform.select( {
 *   native: __( 'Add media' ),
 *   web: __( 'Drag images, upload new ones or select files from your library.' ),
 * } );
 * ```
 */
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (Platform);
//# sourceMappingURL=platform.js.map

/***/ }),

/***/ "../node_modules/@wordpress/element/build-module/raw-html.js":
/*!*******************************************************************!*\
  !*** ../node_modules/@wordpress/element/build-module/raw-html.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ RawHTML)
/* harmony export */ });
/* harmony import */ var _react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./react */ "react");
/* harmony import */ var _react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * Internal dependencies
 */


/** @typedef {{children: string} & import('react').ComponentPropsWithoutRef<'div'>} RawHTMLProps */

/**
 * Component used as equivalent of Fragment with unescaped HTML, in cases where
 * it is desirable to render dangerous HTML without needing a wrapper element.
 * To preserve additional props, a `div` wrapper _will_ be created if any props
 * aside from `children` are passed.
 *
 * @param {RawHTMLProps} props Children should be a string of HTML or an array
 *                             of strings. Other props will be passed through
 *                             to the div wrapper.
 *
 * @return {JSX.Element} Dangerously-rendering component.
 */
function RawHTML({
  children,
  ...props
}) {
  let rawHtml = '';

  // Cast children as an array, and concatenate each element if it is a string.
  _react__WEBPACK_IMPORTED_MODULE_0__.Children.toArray(children).forEach(child => {
    if (typeof child === 'string' && child.trim() !== '') {
      rawHtml += child;
    }
  });

  // The `div` wrapper will be stripped by the `renderElement` serializer in
  // `./serialize.js` unless there are non-children props present.
  return (0,_react__WEBPACK_IMPORTED_MODULE_0__.createElement)('div', {
    dangerouslySetInnerHTML: {
      __html: rawHtml
    },
    ...props
  });
}
//# sourceMappingURL=raw-html.js.map

/***/ }),

/***/ "../node_modules/@wordpress/element/build-module/react-platform.js":
/*!*************************************************************************!*\
  !*** ../node_modules/@wordpress/element/build-module/react-platform.js ***!
  \*************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   createPortal: () => (/* reexport safe */ react_dom__WEBPACK_IMPORTED_MODULE_0__.createPortal),
/* harmony export */   createRoot: () => (/* reexport safe */ react_dom_client__WEBPACK_IMPORTED_MODULE_1__.createRoot),
/* harmony export */   findDOMNode: () => (/* reexport safe */ react_dom__WEBPACK_IMPORTED_MODULE_0__.findDOMNode),
/* harmony export */   flushSync: () => (/* reexport safe */ react_dom__WEBPACK_IMPORTED_MODULE_0__.flushSync),
/* harmony export */   hydrate: () => (/* reexport safe */ react_dom__WEBPACK_IMPORTED_MODULE_0__.hydrate),
/* harmony export */   hydrateRoot: () => (/* reexport safe */ react_dom_client__WEBPACK_IMPORTED_MODULE_1__.hydrateRoot),
/* harmony export */   render: () => (/* reexport safe */ react_dom__WEBPACK_IMPORTED_MODULE_0__.render),
/* harmony export */   unmountComponentAtNode: () => (/* reexport safe */ react_dom__WEBPACK_IMPORTED_MODULE_0__.unmountComponentAtNode)
/* harmony export */ });
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react-dom */ "react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_dom_client__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! react-dom/client */ "../node_modules/react-dom/client.js");
/**
 * External dependencies
 */



/**
 * Creates a portal into which a component can be rendered.
 *
 * @see https://github.com/facebook/react/issues/10309#issuecomment-318433235
 *
 * @param {import('react').ReactElement} child     Any renderable child, such as an element,
 *                                                 string, or fragment.
 * @param {HTMLElement}                  container DOM node into which element should be rendered.
 */


/**
 * Finds the dom node of a React component.
 *
 * @param {import('react').ComponentType} component Component's instance.
 */


/**
 * Forces React to flush any updates inside the provided callback synchronously.
 *
 * @param {Function} callback Callback to run synchronously.
 */


/**
 * Renders a given element into the target DOM node.
 *
 * @deprecated since WordPress 6.2.0. Use `createRoot` instead.
 * @see https://react.dev/reference/react-dom/render
 */


/**
 * Hydrates a given element into the target DOM node.
 *
 * @deprecated since WordPress 6.2.0. Use `hydrateRoot` instead.
 * @see https://react.dev/reference/react-dom/hydrate
 */


/**
 * Creates a new React root for the target DOM node.
 *
 * @since 6.2.0 Introduced in WordPress core.
 * @see https://react.dev/reference/react-dom/client/createRoot
 */


/**
 * Creates a new React root for the target DOM node and hydrates it with a pre-generated markup.
 *
 * @since 6.2.0 Introduced in WordPress core.
 * @see https://react.dev/reference/react-dom/client/hydrateRoot
 */


/**
 * Removes any mounted element from the target DOM node.
 *
 * @deprecated since WordPress 6.2.0. Use `root.unmount()` instead.
 * @see https://react.dev/reference/react-dom/unmountComponentAtNode
 */

//# sourceMappingURL=react-platform.js.map

/***/ }),

/***/ "../node_modules/@wordpress/element/build-module/react.js":
/*!****************************************************************!*\
  !*** ../node_modules/@wordpress/element/build-module/react.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   Children: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.Children),
/* harmony export */   Component: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.Component),
/* harmony export */   Fragment: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.Fragment),
/* harmony export */   PureComponent: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.PureComponent),
/* harmony export */   StrictMode: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.StrictMode),
/* harmony export */   Suspense: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.Suspense),
/* harmony export */   cloneElement: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.cloneElement),
/* harmony export */   concatChildren: () => (/* binding */ concatChildren),
/* harmony export */   createContext: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.createContext),
/* harmony export */   createElement: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.createElement),
/* harmony export */   createRef: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.createRef),
/* harmony export */   forwardRef: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.forwardRef),
/* harmony export */   isValidElement: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.isValidElement),
/* harmony export */   lazy: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.lazy),
/* harmony export */   memo: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.memo),
/* harmony export */   startTransition: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.startTransition),
/* harmony export */   switchChildrenNodeName: () => (/* binding */ switchChildrenNodeName),
/* harmony export */   useCallback: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useCallback),
/* harmony export */   useContext: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useContext),
/* harmony export */   useDebugValue: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useDebugValue),
/* harmony export */   useDeferredValue: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useDeferredValue),
/* harmony export */   useEffect: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useEffect),
/* harmony export */   useId: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useId),
/* harmony export */   useImperativeHandle: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useImperativeHandle),
/* harmony export */   useInsertionEffect: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useInsertionEffect),
/* harmony export */   useLayoutEffect: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useLayoutEffect),
/* harmony export */   useMemo: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useMemo),
/* harmony export */   useReducer: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useReducer),
/* harmony export */   useRef: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useRef),
/* harmony export */   useState: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useState),
/* harmony export */   useSyncExternalStore: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useSyncExternalStore),
/* harmony export */   useTransition: () => (/* reexport safe */ react__WEBPACK_IMPORTED_MODULE_0__.useTransition)
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/**
 * External dependencies
 */
// eslint-disable-next-line @typescript-eslint/no-restricted-imports


/**
 * Object containing a React element.
 *
 * @typedef {import('react').ReactElement} Element
 */

/**
 * Object containing a React component.
 *
 * @typedef {import('react').ComponentType} ComponentType
 */

/**
 * Object containing a React synthetic event.
 *
 * @typedef {import('react').SyntheticEvent} SyntheticEvent
 */

/**
 * Object containing a React synthetic event.
 *
 * @template T
 * @typedef {import('react').RefObject<T>} RefObject<T>
 */

/**
 * Object that provides utilities for dealing with React children.
 */


/**
 * Creates a copy of an element with extended props.
 *
 * @param {Element} element Element
 * @param {?Object} props   Props to apply to cloned element
 *
 * @return {Element} Cloned element.
 */


/**
 * A base class to create WordPress Components (Refs, state and lifecycle hooks)
 */


/**
 * Creates a context object containing two components: a provider and consumer.
 *
 * @param {Object} defaultValue A default data stored in the context.
 *
 * @return {Object} Context object.
 */


/**
 * Returns a new element of given type. Type can be either a string tag name or
 * another function which itself returns an element.
 *
 * @param {?(string|Function)} type     Tag name or element creator
 * @param {Object}             props    Element properties, either attribute
 *                                      set to apply to DOM node or values to
 *                                      pass through to element creator
 * @param {...Element}         children Descendant elements
 *
 * @return {Element} Element.
 */


/**
 * Returns an object tracking a reference to a rendered element via its
 * `current` property as either a DOMElement or Element, dependent upon the
 * type of element rendered with the ref attribute.
 *
 * @return {Object} Ref object.
 */


/**
 * Component enhancer used to enable passing a ref to its wrapped component.
 * Pass a function argument which receives `props` and `ref` as its arguments,
 * returning an element using the forwarded ref. The return value is a new
 * component which forwards its ref.
 *
 * @param {Function} forwarder Function passed `props` and `ref`, expected to
 *                             return an element.
 *
 * @return {Component} Enhanced component.
 */


/**
 * A component which renders its children without any wrapping element.
 */


/**
 * Checks if an object is a valid React Element.
 *
 * @param {Object} objectToCheck The object to be checked.
 *
 * @return {boolean} true if objectToTest is a valid React Element and false otherwise.
 */


/**
 * @see https://reactjs.org/docs/react-api.html#reactmemo
 */


/**
 * Component that activates additional checks and warnings for its descendants.
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#usecallback
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#usecontext
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#usedebugvalue
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#usedeferredvalue
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#useeffect
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#useid
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#useimperativehandle
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#useinsertioneffect
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#uselayouteffect
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#usememo
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#usereducer
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#useref
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#usestate
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#usesyncexternalstore
 */


/**
 * @see https://reactjs.org/docs/hooks-reference.html#usetransition
 */


/**
 * @see https://reactjs.org/docs/react-api.html#starttransition
 */


/**
 * @see https://reactjs.org/docs/react-api.html#reactlazy
 */


/**
 * @see https://reactjs.org/docs/react-api.html#reactsuspense
 */


/**
 * @see https://reactjs.org/docs/react-api.html#reactpurecomponent
 */


/**
 * Concatenate two or more React children objects.
 *
 * @param {...?Object} childrenArguments Array of children arguments (array of arrays/strings/objects) to concatenate.
 *
 * @return {Array} The concatenated value.
 */
function concatChildren(...childrenArguments) {
  return childrenArguments.reduce((accumulator, children, i) => {
    react__WEBPACK_IMPORTED_MODULE_0__.Children.forEach(children, (child, j) => {
      if (child && 'string' !== typeof child) {
        child = (0,react__WEBPACK_IMPORTED_MODULE_0__.cloneElement)(child, {
          key: [i, j].join()
        });
      }
      accumulator.push(child);
    });
    return accumulator;
  }, []);
}

/**
 * Switches the nodeName of all the elements in the children object.
 *
 * @param {?Object} children Children object.
 * @param {string}  nodeName Node name.
 *
 * @return {?Object} The updated children object.
 */
function switchChildrenNodeName(children, nodeName) {
  return children && react__WEBPACK_IMPORTED_MODULE_0__.Children.map(children, (elt, index) => {
    if (typeof elt?.valueOf() === 'string') {
      return (0,react__WEBPACK_IMPORTED_MODULE_0__.createElement)(nodeName, {
        key: index
      }, elt);
    }
    const {
      children: childrenProp,
      ...props
    } = elt.props;
    return (0,react__WEBPACK_IMPORTED_MODULE_0__.createElement)(nodeName, {
      key: index,
      ...props
    }, childrenProp);
  });
}
//# sourceMappingURL=react.js.map

/***/ }),

/***/ "../node_modules/@wordpress/element/build-module/serialize.js":
/*!********************************************************************!*\
  !*** ../node_modules/@wordpress/element/build-module/serialize.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__),
/* harmony export */   hasPrefix: () => (/* binding */ hasPrefix),
/* harmony export */   renderAttributes: () => (/* binding */ renderAttributes),
/* harmony export */   renderComponent: () => (/* binding */ renderComponent),
/* harmony export */   renderElement: () => (/* binding */ renderElement),
/* harmony export */   renderNativeComponent: () => (/* binding */ renderNativeComponent),
/* harmony export */   renderStyle: () => (/* binding */ renderStyle)
/* harmony export */ });
/* harmony import */ var is_plain_object__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! is-plain-object */ "../node_modules/is-plain-object/dist/is-plain-object.mjs");
/* harmony import */ var change_case__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! change-case */ "../node_modules/param-case/dist.es2015/index.js");
/* harmony import */ var _wordpress_escape_html__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @wordpress/escape-html */ "../node_modules/@wordpress/escape-html/build-module/index.js");
/* harmony import */ var _react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./react */ "react");
/* harmony import */ var _react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(_react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _raw_html__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./raw-html */ "../node_modules/@wordpress/element/build-module/raw-html.js");
/**
 * Parts of this source were derived and modified from fast-react-render,
 * released under the MIT license.
 *
 * https://github.com/alt-j/fast-react-render
 *
 * Copyright (c) 2016 Andrey Morozov
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/**
 * External dependencies
 */



/**
 * WordPress dependencies
 */


/**
 * Internal dependencies
 */



/** @typedef {import('react').ReactElement} ReactElement */

const {
  Provider,
  Consumer
} = (0,_react__WEBPACK_IMPORTED_MODULE_3__.createContext)(undefined);
const ForwardRef = (0,_react__WEBPACK_IMPORTED_MODULE_3__.forwardRef)(() => {
  return null;
});

/**
 * Valid attribute types.
 *
 * @type {Set<string>}
 */
const ATTRIBUTES_TYPES = new Set(['string', 'boolean', 'number']);

/**
 * Element tags which can be self-closing.
 *
 * @type {Set<string>}
 */
const SELF_CLOSING_TAGS = new Set(['area', 'base', 'br', 'col', 'command', 'embed', 'hr', 'img', 'input', 'keygen', 'link', 'meta', 'param', 'source', 'track', 'wbr']);

/**
 * Boolean attributes are attributes whose presence as being assigned is
 * meaningful, even if only empty.
 *
 * See: https://html.spec.whatwg.org/multipage/common-microsyntaxes.html#boolean-attributes
 * Extracted from: https://html.spec.whatwg.org/multipage/indices.html#attributes-3
 *
 * Object.keys( [ ...document.querySelectorAll( '#attributes-1 > tbody > tr' ) ]
 *     .filter( ( tr ) => tr.lastChild.textContent.indexOf( 'Boolean attribute' ) !== -1 )
 *     .reduce( ( result, tr ) => Object.assign( result, {
 *         [ tr.firstChild.textContent.trim() ]: true
 *     } ), {} ) ).sort();
 *
 * @type {Set<string>}
 */
const BOOLEAN_ATTRIBUTES = new Set(['allowfullscreen', 'allowpaymentrequest', 'allowusermedia', 'async', 'autofocus', 'autoplay', 'checked', 'controls', 'default', 'defer', 'disabled', 'download', 'formnovalidate', 'hidden', 'ismap', 'itemscope', 'loop', 'multiple', 'muted', 'nomodule', 'novalidate', 'open', 'playsinline', 'readonly', 'required', 'reversed', 'selected', 'typemustmatch']);

/**
 * Enumerated attributes are attributes which must be of a specific value form.
 * Like boolean attributes, these are meaningful if specified, even if not of a
 * valid enumerated value.
 *
 * See: https://html.spec.whatwg.org/multipage/common-microsyntaxes.html#enumerated-attribute
 * Extracted from: https://html.spec.whatwg.org/multipage/indices.html#attributes-3
 *
 * Object.keys( [ ...document.querySelectorAll( '#attributes-1 > tbody > tr' ) ]
 *     .filter( ( tr ) => /^("(.+?)";?\s*)+/.test( tr.lastChild.textContent.trim() ) )
 *     .reduce( ( result, tr ) => Object.assign( result, {
 *         [ tr.firstChild.textContent.trim() ]: true
 *     } ), {} ) ).sort();
 *
 * Some notable omissions:
 *
 *  - `alt`: https://blog.whatwg.org/omit-alt
 *
 * @type {Set<string>}
 */
const ENUMERATED_ATTRIBUTES = new Set(['autocapitalize', 'autocomplete', 'charset', 'contenteditable', 'crossorigin', 'decoding', 'dir', 'draggable', 'enctype', 'formenctype', 'formmethod', 'http-equiv', 'inputmode', 'kind', 'method', 'preload', 'scope', 'shape', 'spellcheck', 'translate', 'type', 'wrap']);

/**
 * Set of CSS style properties which support assignment of unitless numbers.
 * Used in rendering of style properties, where `px` unit is assumed unless
 * property is included in this set or value is zero.
 *
 * Generated via:
 *
 * Object.entries( document.createElement( 'div' ).style )
 *     .filter( ( [ key ] ) => (
 *         ! /^(webkit|ms|moz)/.test( key ) &&
 *         ( e.style[ key ] = 10 ) &&
 *         e.style[ key ] === '10'
 *     ) )
 *     .map( ( [ key ] ) => key )
 *     .sort();
 *
 * @type {Set<string>}
 */
const CSS_PROPERTIES_SUPPORTS_UNITLESS = new Set(['animation', 'animationIterationCount', 'baselineShift', 'borderImageOutset', 'borderImageSlice', 'borderImageWidth', 'columnCount', 'cx', 'cy', 'fillOpacity', 'flexGrow', 'flexShrink', 'floodOpacity', 'fontWeight', 'gridColumnEnd', 'gridColumnStart', 'gridRowEnd', 'gridRowStart', 'lineHeight', 'opacity', 'order', 'orphans', 'r', 'rx', 'ry', 'shapeImageThreshold', 'stopOpacity', 'strokeDasharray', 'strokeDashoffset', 'strokeMiterlimit', 'strokeOpacity', 'strokeWidth', 'tabSize', 'widows', 'x', 'y', 'zIndex', 'zoom']);

/**
 * Returns true if the specified string is prefixed by one of an array of
 * possible prefixes.
 *
 * @param {string}   string   String to check.
 * @param {string[]} prefixes Possible prefixes.
 *
 * @return {boolean} Whether string has prefix.
 */
function hasPrefix(string, prefixes) {
  return prefixes.some(prefix => string.indexOf(prefix) === 0);
}

/**
 * Returns true if the given prop name should be ignored in attributes
 * serialization, or false otherwise.
 *
 * @param {string} attribute Attribute to check.
 *
 * @return {boolean} Whether attribute should be ignored.
 */
function isInternalAttribute(attribute) {
  return 'key' === attribute || 'children' === attribute;
}

/**
 * Returns the normal form of the element's attribute value for HTML.
 *
 * @param {string} attribute Attribute name.
 * @param {*}      value     Non-normalized attribute value.
 *
 * @return {*} Normalized attribute value.
 */
function getNormalAttributeValue(attribute, value) {
  switch (attribute) {
    case 'style':
      return renderStyle(value);
  }
  return value;
}
/**
 * This is a map of all SVG attributes that have dashes. Map(lower case prop => dashed lower case attribute).
 * We need this to render e.g strokeWidth as stroke-width.
 *
 * List from: https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute.
 */
const SVG_ATTRIBUTE_WITH_DASHES_LIST = ['accentHeight', 'alignmentBaseline', 'arabicForm', 'baselineShift', 'capHeight', 'clipPath', 'clipRule', 'colorInterpolation', 'colorInterpolationFilters', 'colorProfile', 'colorRendering', 'dominantBaseline', 'enableBackground', 'fillOpacity', 'fillRule', 'floodColor', 'floodOpacity', 'fontFamily', 'fontSize', 'fontSizeAdjust', 'fontStretch', 'fontStyle', 'fontVariant', 'fontWeight', 'glyphName', 'glyphOrientationHorizontal', 'glyphOrientationVertical', 'horizAdvX', 'horizOriginX', 'imageRendering', 'letterSpacing', 'lightingColor', 'markerEnd', 'markerMid', 'markerStart', 'overlinePosition', 'overlineThickness', 'paintOrder', 'panose1', 'pointerEvents', 'renderingIntent', 'shapeRendering', 'stopColor', 'stopOpacity', 'strikethroughPosition', 'strikethroughThickness', 'strokeDasharray', 'strokeDashoffset', 'strokeLinecap', 'strokeLinejoin', 'strokeMiterlimit', 'strokeOpacity', 'strokeWidth', 'textAnchor', 'textDecoration', 'textRendering', 'underlinePosition', 'underlineThickness', 'unicodeBidi', 'unicodeRange', 'unitsPerEm', 'vAlphabetic', 'vHanging', 'vIdeographic', 'vMathematical', 'vectorEffect', 'vertAdvY', 'vertOriginX', 'vertOriginY', 'wordSpacing', 'writingMode', 'xmlnsXlink', 'xHeight'].reduce((map, attribute) => {
  // The keys are lower-cased for more robust lookup.
  map[attribute.toLowerCase()] = attribute;
  return map;
}, {});

/**
 * This is a map of all case-sensitive SVG attributes. Map(lowercase key => proper case attribute).
 * The keys are lower-cased for more robust lookup.
 * Note that this list only contains attributes that contain at least one capital letter.
 * Lowercase attributes don't need mapping, since we lowercase all attributes by default.
 */
const CASE_SENSITIVE_SVG_ATTRIBUTES = ['allowReorder', 'attributeName', 'attributeType', 'autoReverse', 'baseFrequency', 'baseProfile', 'calcMode', 'clipPathUnits', 'contentScriptType', 'contentStyleType', 'diffuseConstant', 'edgeMode', 'externalResourcesRequired', 'filterRes', 'filterUnits', 'glyphRef', 'gradientTransform', 'gradientUnits', 'kernelMatrix', 'kernelUnitLength', 'keyPoints', 'keySplines', 'keyTimes', 'lengthAdjust', 'limitingConeAngle', 'markerHeight', 'markerUnits', 'markerWidth', 'maskContentUnits', 'maskUnits', 'numOctaves', 'pathLength', 'patternContentUnits', 'patternTransform', 'patternUnits', 'pointsAtX', 'pointsAtY', 'pointsAtZ', 'preserveAlpha', 'preserveAspectRatio', 'primitiveUnits', 'refX', 'refY', 'repeatCount', 'repeatDur', 'requiredExtensions', 'requiredFeatures', 'specularConstant', 'specularExponent', 'spreadMethod', 'startOffset', 'stdDeviation', 'stitchTiles', 'suppressContentEditableWarning', 'suppressHydrationWarning', 'surfaceScale', 'systemLanguage', 'tableValues', 'targetX', 'targetY', 'textLength', 'viewBox', 'viewTarget', 'xChannelSelector', 'yChannelSelector'].reduce((map, attribute) => {
  // The keys are lower-cased for more robust lookup.
  map[attribute.toLowerCase()] = attribute;
  return map;
}, {});

/**
 * This is a map of all SVG attributes that have colons.
 * Keys are lower-cased and stripped of their colons for more robust lookup.
 */
const SVG_ATTRIBUTES_WITH_COLONS = ['xlink:actuate', 'xlink:arcrole', 'xlink:href', 'xlink:role', 'xlink:show', 'xlink:title', 'xlink:type', 'xml:base', 'xml:lang', 'xml:space', 'xmlns:xlink'].reduce((map, attribute) => {
  map[attribute.replace(':', '').toLowerCase()] = attribute;
  return map;
}, {});

/**
 * Returns the normal form of the element's attribute name for HTML.
 *
 * @param {string} attribute Non-normalized attribute name.
 *
 * @return {string} Normalized attribute name.
 */
function getNormalAttributeName(attribute) {
  switch (attribute) {
    case 'htmlFor':
      return 'for';
    case 'className':
      return 'class';
  }
  const attributeLowerCase = attribute.toLowerCase();
  if (CASE_SENSITIVE_SVG_ATTRIBUTES[attributeLowerCase]) {
    return CASE_SENSITIVE_SVG_ATTRIBUTES[attributeLowerCase];
  } else if (SVG_ATTRIBUTE_WITH_DASHES_LIST[attributeLowerCase]) {
    return (0,change_case__WEBPACK_IMPORTED_MODULE_1__.paramCase)(SVG_ATTRIBUTE_WITH_DASHES_LIST[attributeLowerCase]);
  } else if (SVG_ATTRIBUTES_WITH_COLONS[attributeLowerCase]) {
    return SVG_ATTRIBUTES_WITH_COLONS[attributeLowerCase];
  }
  return attributeLowerCase;
}

/**
 * Returns the normal form of the style property name for HTML.
 *
 * - Converts property names to kebab-case, e.g. 'backgroundColor' → 'background-color'
 * - Leaves custom attributes alone, e.g. '--myBackgroundColor' → '--myBackgroundColor'
 * - Converts vendor-prefixed property names to -kebab-case, e.g. 'MozTransform' → '-moz-transform'
 *
 * @param {string} property Property name.
 *
 * @return {string} Normalized property name.
 */
function getNormalStylePropertyName(property) {
  if (property.startsWith('--')) {
    return property;
  }
  if (hasPrefix(property, ['ms', 'O', 'Moz', 'Webkit'])) {
    return '-' + (0,change_case__WEBPACK_IMPORTED_MODULE_1__.paramCase)(property);
  }
  return (0,change_case__WEBPACK_IMPORTED_MODULE_1__.paramCase)(property);
}

/**
 * Returns the normal form of the style property value for HTML. Appends a
 * default pixel unit if numeric, not a unitless property, and not zero.
 *
 * @param {string} property Property name.
 * @param {*}      value    Non-normalized property value.
 *
 * @return {*} Normalized property value.
 */
function getNormalStylePropertyValue(property, value) {
  if (typeof value === 'number' && 0 !== value && !CSS_PROPERTIES_SUPPORTS_UNITLESS.has(property)) {
    return value + 'px';
  }
  return value;
}

/**
 * Serializes a React element to string.
 *
 * @param {import('react').ReactNode} element         Element to serialize.
 * @param {Object}                    [context]       Context object.
 * @param {Object}                    [legacyContext] Legacy context object.
 *
 * @return {string} Serialized element.
 */
function renderElement(element, context, legacyContext = {}) {
  if (null === element || undefined === element || false === element) {
    return '';
  }
  if (Array.isArray(element)) {
    return renderChildren(element, context, legacyContext);
  }
  switch (typeof element) {
    case 'string':
      return (0,_wordpress_escape_html__WEBPACK_IMPORTED_MODULE_2__.escapeHTML)(element);
    case 'number':
      return element.toString();
  }
  const {
    type,
    props
  } = /** @type {{type?: any, props?: any}} */
  element;
  switch (type) {
    case _react__WEBPACK_IMPORTED_MODULE_3__.StrictMode:
    case _react__WEBPACK_IMPORTED_MODULE_3__.Fragment:
      return renderChildren(props.children, context, legacyContext);
    case _raw_html__WEBPACK_IMPORTED_MODULE_4__["default"]:
      const {
        children,
        ...wrapperProps
      } = props;
      return renderNativeComponent(!Object.keys(wrapperProps).length ? null : 'div', {
        ...wrapperProps,
        dangerouslySetInnerHTML: {
          __html: children
        }
      }, context, legacyContext);
  }
  switch (typeof type) {
    case 'string':
      return renderNativeComponent(type, props, context, legacyContext);
    case 'function':
      if (type.prototype && typeof type.prototype.render === 'function') {
        return renderComponent(type, props, context, legacyContext);
      }
      return renderElement(type(props, legacyContext), context, legacyContext);
  }
  switch (type && type.$$typeof) {
    case Provider.$$typeof:
      return renderChildren(props.children, props.value, legacyContext);
    case Consumer.$$typeof:
      return renderElement(props.children(context || type._currentValue), context, legacyContext);
    case ForwardRef.$$typeof:
      return renderElement(type.render(props), context, legacyContext);
  }
  return '';
}

/**
 * Serializes a native component type to string.
 *
 * @param {?string} type            Native component type to serialize, or null if
 *                                  rendering as fragment of children content.
 * @param {Object}  props           Props object.
 * @param {Object}  [context]       Context object.
 * @param {Object}  [legacyContext] Legacy context object.
 *
 * @return {string} Serialized element.
 */
function renderNativeComponent(type, props, context, legacyContext = {}) {
  let content = '';
  if (type === 'textarea' && props.hasOwnProperty('value')) {
    // Textarea children can be assigned as value prop. If it is, render in
    // place of children. Ensure to omit so it is not assigned as attribute
    // as well.
    content = renderChildren(props.value, context, legacyContext);
    const {
      value,
      ...restProps
    } = props;
    props = restProps;
  } else if (props.dangerouslySetInnerHTML && typeof props.dangerouslySetInnerHTML.__html === 'string') {
    // Dangerous content is left unescaped.
    content = props.dangerouslySetInnerHTML.__html;
  } else if (typeof props.children !== 'undefined') {
    content = renderChildren(props.children, context, legacyContext);
  }
  if (!type) {
    return content;
  }
  const attributes = renderAttributes(props);
  if (SELF_CLOSING_TAGS.has(type)) {
    return '<' + type + attributes + '/>';
  }
  return '<' + type + attributes + '>' + content + '</' + type + '>';
}

/** @typedef {import('react').ComponentType} ComponentType */

/**
 * Serializes a non-native component type to string.
 *
 * @param {ComponentType} Component       Component type to serialize.
 * @param {Object}        props           Props object.
 * @param {Object}        [context]       Context object.
 * @param {Object}        [legacyContext] Legacy context object.
 *
 * @return {string} Serialized element
 */
function renderComponent(Component, props, context, legacyContext = {}) {
  const instance = new ( /** @type {import('react').ComponentClass} */
  Component)(props, legacyContext);
  if (typeof
  // Ignore reason: Current prettier reformats parens and mangles type assertion
  // prettier-ignore
  /** @type {{getChildContext?: () => unknown}} */
  instance.getChildContext === 'function') {
    Object.assign(legacyContext, /** @type {{getChildContext?: () => unknown}} */instance.getChildContext());
  }
  const html = renderElement(instance.render(), context, legacyContext);
  return html;
}

/**
 * Serializes an array of children to string.
 *
 * @param {import('react').ReactNodeArray} children        Children to serialize.
 * @param {Object}                         [context]       Context object.
 * @param {Object}                         [legacyContext] Legacy context object.
 *
 * @return {string} Serialized children.
 */
function renderChildren(children, context, legacyContext = {}) {
  let result = '';
  children = Array.isArray(children) ? children : [children];
  for (let i = 0; i < children.length; i++) {
    const child = children[i];
    result += renderElement(child, context, legacyContext);
  }
  return result;
}

/**
 * Renders a props object as a string of HTML attributes.
 *
 * @param {Object} props Props object.
 *
 * @return {string} Attributes string.
 */
function renderAttributes(props) {
  let result = '';
  for (const key in props) {
    const attribute = getNormalAttributeName(key);
    if (!(0,_wordpress_escape_html__WEBPACK_IMPORTED_MODULE_2__.isValidAttributeName)(attribute)) {
      continue;
    }
    let value = getNormalAttributeValue(key, props[key]);

    // If value is not of serializable type, skip.
    if (!ATTRIBUTES_TYPES.has(typeof value)) {
      continue;
    }

    // Don't render internal attribute names.
    if (isInternalAttribute(key)) {
      continue;
    }
    const isBooleanAttribute = BOOLEAN_ATTRIBUTES.has(attribute);

    // Boolean attribute should be omitted outright if its value is false.
    if (isBooleanAttribute && value === false) {
      continue;
    }
    const isMeaningfulAttribute = isBooleanAttribute || hasPrefix(key, ['data-', 'aria-']) || ENUMERATED_ATTRIBUTES.has(attribute);

    // Only write boolean value as attribute if meaningful.
    if (typeof value === 'boolean' && !isMeaningfulAttribute) {
      continue;
    }
    result += ' ' + attribute;

    // Boolean attributes should write attribute name, but without value.
    // Mere presence of attribute name is effective truthiness.
    if (isBooleanAttribute) {
      continue;
    }
    if (typeof value === 'string') {
      value = (0,_wordpress_escape_html__WEBPACK_IMPORTED_MODULE_2__.escapeAttribute)(value);
    }
    result += '="' + value + '"';
  }
  return result;
}

/**
 * Renders a style object as a string attribute value.
 *
 * @param {Object} style Style object.
 *
 * @return {string} Style attribute value.
 */
function renderStyle(style) {
  // Only generate from object, e.g. tolerate string value.
  if (!(0,is_plain_object__WEBPACK_IMPORTED_MODULE_0__.isPlainObject)(style)) {
    return style;
  }
  let result;
  for (const property in style) {
    const value = style[property];
    if (null === value || undefined === value) {
      continue;
    }
    if (result) {
      result += ';';
    } else {
      result = '';
    }
    const normalName = getNormalStylePropertyName(property);
    const normalValue = getNormalStylePropertyValue(property, value);
    result += normalName + ':' + normalValue;
  }
  return result;
}
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (renderElement);
//# sourceMappingURL=serialize.js.map

/***/ }),

/***/ "../node_modules/@wordpress/element/build-module/utils.js":
/*!****************************************************************!*\
  !*** ../node_modules/@wordpress/element/build-module/utils.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   isEmptyElement: () => (/* binding */ isEmptyElement)
/* harmony export */ });
/**
 * Checks if the provided WP element is empty.
 *
 * @param {*} element WP element to check.
 * @return {boolean} True when an element is considered empty.
 */
const isEmptyElement = element => {
  if (typeof element === 'number') {
    return false;
  }
  if (typeof element?.valueOf() === 'string' || Array.isArray(element)) {
    return !element.length;
  }
  return !element;
};
//# sourceMappingURL=utils.js.map

/***/ }),

/***/ "../node_modules/@wordpress/escape-html/build-module/escape-greater.js":
/*!*****************************************************************************!*\
  !*** ../node_modules/@wordpress/escape-html/build-module/escape-greater.js ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ __unstableEscapeGreaterThan)
/* harmony export */ });
/**
 * Returns a string with greater-than sign replaced.
 *
 * Note that if a resolution for Trac#45387 comes to fruition, it is no longer
 * necessary for `__unstableEscapeGreaterThan` to exist.
 *
 * See: https://core.trac.wordpress.org/ticket/45387
 *
 * @param {string} value Original string.
 *
 * @return {string} Escaped string.
 */
function __unstableEscapeGreaterThan(value) {
  return value.replace(/>/g, '&gt;');
}
//# sourceMappingURL=escape-greater.js.map

/***/ }),

/***/ "../node_modules/@wordpress/escape-html/build-module/index.js":
/*!********************************************************************!*\
  !*** ../node_modules/@wordpress/escape-html/build-module/index.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   escapeAmpersand: () => (/* binding */ escapeAmpersand),
/* harmony export */   escapeAttribute: () => (/* binding */ escapeAttribute),
/* harmony export */   escapeEditableHTML: () => (/* binding */ escapeEditableHTML),
/* harmony export */   escapeHTML: () => (/* binding */ escapeHTML),
/* harmony export */   escapeLessThan: () => (/* binding */ escapeLessThan),
/* harmony export */   escapeQuotationMark: () => (/* binding */ escapeQuotationMark),
/* harmony export */   isValidAttributeName: () => (/* binding */ isValidAttributeName)
/* harmony export */ });
/* harmony import */ var _escape_greater__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./escape-greater */ "../node_modules/@wordpress/escape-html/build-module/escape-greater.js");
/**
 * Internal dependencies
 */


/**
 * Regular expression matching invalid attribute names.
 *
 * "Attribute names must consist of one or more characters other than controls,
 * U+0020 SPACE, U+0022 ("), U+0027 ('), U+003E (>), U+002F (/), U+003D (=),
 * and noncharacters."
 *
 * @see https://html.spec.whatwg.org/multipage/syntax.html#attributes-2
 *
 * @type {RegExp}
 */
const REGEXP_INVALID_ATTRIBUTE_NAME = /[\u007F-\u009F "'>/="\uFDD0-\uFDEF]/;

/**
 * Returns a string with ampersands escaped. Note that this is an imperfect
 * implementation, where only ampersands which do not appear as a pattern of
 * named, decimal, or hexadecimal character references are escaped. Invalid
 * named references (i.e. ambiguous ampersand) are still permitted.
 *
 * @see https://w3c.github.io/html/syntax.html#character-references
 * @see https://w3c.github.io/html/syntax.html#ambiguous-ampersand
 * @see https://w3c.github.io/html/syntax.html#named-character-references
 *
 * @param {string} value Original string.
 *
 * @return {string} Escaped string.
 */
function escapeAmpersand(value) {
  return value.replace(/&(?!([a-z0-9]+|#[0-9]+|#x[a-f0-9]+);)/gi, '&amp;');
}

/**
 * Returns a string with quotation marks replaced.
 *
 * @param {string} value Original string.
 *
 * @return {string} Escaped string.
 */
function escapeQuotationMark(value) {
  return value.replace(/"/g, '&quot;');
}

/**
 * Returns a string with less-than sign replaced.
 *
 * @param {string} value Original string.
 *
 * @return {string} Escaped string.
 */
function escapeLessThan(value) {
  return value.replace(/</g, '&lt;');
}

/**
 * Returns an escaped attribute value.
 *
 * @see https://w3c.github.io/html/syntax.html#elements-attributes
 *
 * "[...] the text cannot contain an ambiguous ampersand [...] must not contain
 * any literal U+0022 QUOTATION MARK characters (")"
 *
 * Note we also escape the greater than symbol, as this is used by wptexturize to
 * split HTML strings. This is a WordPress specific fix
 *
 * Note that if a resolution for Trac#45387 comes to fruition, it is no longer
 * necessary for `__unstableEscapeGreaterThan` to be used.
 *
 * See: https://core.trac.wordpress.org/ticket/45387
 *
 * @param {string} value Attribute value.
 *
 * @return {string} Escaped attribute value.
 */
function escapeAttribute(value) {
  return (0,_escape_greater__WEBPACK_IMPORTED_MODULE_0__["default"])(escapeQuotationMark(escapeAmpersand(value)));
}

/**
 * Returns an escaped HTML element value.
 *
 * @see https://w3c.github.io/html/syntax.html#writing-html-documents-elements
 *
 * "the text must not contain the character U+003C LESS-THAN SIGN (<) or an
 * ambiguous ampersand."
 *
 * @param {string} value Element value.
 *
 * @return {string} Escaped HTML element value.
 */
function escapeHTML(value) {
  return escapeLessThan(escapeAmpersand(value));
}

/**
 * Returns an escaped Editable HTML element value. This is different from
 * `escapeHTML`, because for editable HTML, ALL ampersands must be escaped in
 * order to render the content correctly on the page.
 *
 * @param {string} value Element value.
 *
 * @return {string} Escaped HTML element value.
 */
function escapeEditableHTML(value) {
  return escapeLessThan(value.replace(/&/g, '&amp;'));
}

/**
 * Returns true if the given attribute name is valid, or false otherwise.
 *
 * @param {string} name Attribute name to test.
 *
 * @return {boolean} Whether attribute is valid.
 */
function isValidAttributeName(name) {
  return !REGEXP_INVALID_ATTRIBUTE_NAME.test(name);
}
//# sourceMappingURL=index.js.map

/***/ }),

/***/ "../node_modules/dot-case/dist.es2015/index.js":
/*!*****************************************************!*\
  !*** ../node_modules/dot-case/dist.es2015/index.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   dotCase: () => (/* binding */ dotCase)
/* harmony export */ });
/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! tslib */ "../node_modules/tslib/tslib.es6.mjs");
/* harmony import */ var no_case__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! no-case */ "../node_modules/no-case/dist.es2015/index.js");


function dotCase(input, options) {
    if (options === void 0) { options = {}; }
    return (0,no_case__WEBPACK_IMPORTED_MODULE_1__.noCase)(input, (0,tslib__WEBPACK_IMPORTED_MODULE_0__.__assign)({ delimiter: "." }, options));
}
//# sourceMappingURL=index.js.map

/***/ }),

/***/ "../node_modules/is-plain-object/dist/is-plain-object.mjs":
/*!****************************************************************!*\
  !*** ../node_modules/is-plain-object/dist/is-plain-object.mjs ***!
  \****************************************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   isPlainObject: () => (/* binding */ isPlainObject)
/* harmony export */ });
/*!
 * is-plain-object <https://github.com/jonschlinkert/is-plain-object>
 *
 * Copyright (c) 2014-2017, Jon Schlinkert.
 * Released under the MIT License.
 */

function isObject(o) {
  return Object.prototype.toString.call(o) === '[object Object]';
}

function isPlainObject(o) {
  var ctor,prot;

  if (isObject(o) === false) return false;

  // If has modified constructor
  ctor = o.constructor;
  if (ctor === undefined) return true;

  // If has modified prototype
  prot = ctor.prototype;
  if (isObject(prot) === false) return false;

  // If constructor does not have an Object-specific method
  if (prot.hasOwnProperty('isPrototypeOf') === false) {
    return false;
  }

  // Most likely a plain Object
  return true;
}




/***/ }),

/***/ "../node_modules/lower-case/dist.es2015/index.js":
/*!*******************************************************!*\
  !*** ../node_modules/lower-case/dist.es2015/index.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   localeLowerCase: () => (/* binding */ localeLowerCase),
/* harmony export */   lowerCase: () => (/* binding */ lowerCase)
/* harmony export */ });
/**
 * Source: ftp://ftp.unicode.org/Public/UCD/latest/ucd/SpecialCasing.txt
 */
var SUPPORTED_LOCALE = {
    tr: {
        regexp: /\u0130|\u0049|\u0049\u0307/g,
        map: {
            İ: "\u0069",
            I: "\u0131",
            İ: "\u0069",
        },
    },
    az: {
        regexp: /\u0130/g,
        map: {
            İ: "\u0069",
            I: "\u0131",
            İ: "\u0069",
        },
    },
    lt: {
        regexp: /\u0049|\u004A|\u012E|\u00CC|\u00CD|\u0128/g,
        map: {
            I: "\u0069\u0307",
            J: "\u006A\u0307",
            Į: "\u012F\u0307",
            Ì: "\u0069\u0307\u0300",
            Í: "\u0069\u0307\u0301",
            Ĩ: "\u0069\u0307\u0303",
        },
    },
};
/**
 * Localized lower case.
 */
function localeLowerCase(str, locale) {
    var lang = SUPPORTED_LOCALE[locale.toLowerCase()];
    if (lang)
        return lowerCase(str.replace(lang.regexp, function (m) { return lang.map[m]; }));
    return lowerCase(str);
}
/**
 * Lower case as a function.
 */
function lowerCase(str) {
    return str.toLowerCase();
}
//# sourceMappingURL=index.js.map

/***/ }),

/***/ "../node_modules/no-case/dist.es2015/index.js":
/*!****************************************************!*\
  !*** ../node_modules/no-case/dist.es2015/index.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   noCase: () => (/* binding */ noCase)
/* harmony export */ });
/* harmony import */ var lower_case__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! lower-case */ "../node_modules/lower-case/dist.es2015/index.js");

// Support camel case ("camelCase" -> "camel Case" and "CAMELCase" -> "CAMEL Case").
var DEFAULT_SPLIT_REGEXP = [/([a-z0-9])([A-Z])/g, /([A-Z])([A-Z][a-z])/g];
// Remove all non-word characters.
var DEFAULT_STRIP_REGEXP = /[^A-Z0-9]+/gi;
/**
 * Normalize the string into something other libraries can manipulate easier.
 */
function noCase(input, options) {
    if (options === void 0) { options = {}; }
    var _a = options.splitRegexp, splitRegexp = _a === void 0 ? DEFAULT_SPLIT_REGEXP : _a, _b = options.stripRegexp, stripRegexp = _b === void 0 ? DEFAULT_STRIP_REGEXP : _b, _c = options.transform, transform = _c === void 0 ? lower_case__WEBPACK_IMPORTED_MODULE_0__.lowerCase : _c, _d = options.delimiter, delimiter = _d === void 0 ? " " : _d;
    var result = replace(replace(input, splitRegexp, "$1\0$2"), stripRegexp, "\0");
    var start = 0;
    var end = result.length;
    // Trim the delimiter from around the output string.
    while (result.charAt(start) === "\0")
        start++;
    while (result.charAt(end - 1) === "\0")
        end--;
    // Transform each token independently.
    return result.slice(start, end).split("\0").map(transform).join(delimiter);
}
/**
 * Replace `re` in the input string with the replacement value.
 */
function replace(input, re, value) {
    if (re instanceof RegExp)
        return input.replace(re, value);
    return re.reduce(function (input, re) { return input.replace(re, value); }, input);
}
//# sourceMappingURL=index.js.map

/***/ }),

/***/ "../node_modules/param-case/dist.es2015/index.js":
/*!*******************************************************!*\
  !*** ../node_modules/param-case/dist.es2015/index.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   paramCase: () => (/* binding */ paramCase)
/* harmony export */ });
/* harmony import */ var tslib__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! tslib */ "../node_modules/tslib/tslib.es6.mjs");
/* harmony import */ var dot_case__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! dot-case */ "../node_modules/dot-case/dist.es2015/index.js");


function paramCase(input, options) {
    if (options === void 0) { options = {}; }
    return (0,dot_case__WEBPACK_IMPORTED_MODULE_1__.dotCase)(input, (0,tslib__WEBPACK_IMPORTED_MODULE_0__.__assign)({ delimiter: "-" }, options));
}
//# sourceMappingURL=index.js.map

/***/ }),

/***/ "../node_modules/react-dom/client.js":
/*!*******************************************!*\
  !*** ../node_modules/react-dom/client.js ***!
  \*******************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var m = __webpack_require__(/*! react-dom */ "react-dom");
if (false) // removed by dead control flow
{} else {
  var i = m.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;
  exports.createRoot = function(c, o) {
    i.usingClientEntryPoint = true;
    try {
      return m.createRoot(c, o);
    } finally {
      i.usingClientEntryPoint = false;
    }
  };
  exports.hydrateRoot = function(c, h, o) {
    i.usingClientEntryPoint = true;
    try {
      return m.hydrateRoot(c, h, o);
    } finally {
      i.usingClientEntryPoint = false;
    }
  };
}


/***/ }),

/***/ "../node_modules/react/cjs/react-jsx-runtime.development.js":
/*!******************************************************************!*\
  !*** ../node_modules/react/cjs/react-jsx-runtime.development.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";
/**
 * @license React
 * react-jsx-runtime.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */



if (true) {
  (function() {
'use strict';

var React = __webpack_require__(/*! react */ "react");

// ATTENTION
// When adding new symbols to this file,
// Please consider also adding to 'react-devtools-shared/src/backend/ReactSymbols'
// The Symbol used to tag the ReactElement-like types.
var REACT_ELEMENT_TYPE = Symbol.for('react.element');
var REACT_PORTAL_TYPE = Symbol.for('react.portal');
var REACT_FRAGMENT_TYPE = Symbol.for('react.fragment');
var REACT_STRICT_MODE_TYPE = Symbol.for('react.strict_mode');
var REACT_PROFILER_TYPE = Symbol.for('react.profiler');
var REACT_PROVIDER_TYPE = Symbol.for('react.provider');
var REACT_CONTEXT_TYPE = Symbol.for('react.context');
var REACT_FORWARD_REF_TYPE = Symbol.for('react.forward_ref');
var REACT_SUSPENSE_TYPE = Symbol.for('react.suspense');
var REACT_SUSPENSE_LIST_TYPE = Symbol.for('react.suspense_list');
var REACT_MEMO_TYPE = Symbol.for('react.memo');
var REACT_LAZY_TYPE = Symbol.for('react.lazy');
var REACT_OFFSCREEN_TYPE = Symbol.for('react.offscreen');
var MAYBE_ITERATOR_SYMBOL = Symbol.iterator;
var FAUX_ITERATOR_SYMBOL = '@@iterator';
function getIteratorFn(maybeIterable) {
  if (maybeIterable === null || typeof maybeIterable !== 'object') {
    return null;
  }

  var maybeIterator = MAYBE_ITERATOR_SYMBOL && maybeIterable[MAYBE_ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL];

  if (typeof maybeIterator === 'function') {
    return maybeIterator;
  }

  return null;
}

var ReactSharedInternals = React.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;

function error(format) {
  {
    {
      for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
        args[_key2 - 1] = arguments[_key2];
      }

      printWarning('error', format, args);
    }
  }
}

function printWarning(level, format, args) {
  // When changing this logic, you might want to also
  // update consoleWithStackDev.www.js as well.
  {
    var ReactDebugCurrentFrame = ReactSharedInternals.ReactDebugCurrentFrame;
    var stack = ReactDebugCurrentFrame.getStackAddendum();

    if (stack !== '') {
      format += '%s';
      args = args.concat([stack]);
    } // eslint-disable-next-line react-internal/safe-string-coercion


    var argsWithFormat = args.map(function (item) {
      return String(item);
    }); // Careful: RN currently depends on this prefix

    argsWithFormat.unshift('Warning: ' + format); // We intentionally don't use spread (or .apply) directly because it
    // breaks IE9: https://github.com/facebook/react/issues/13610
    // eslint-disable-next-line react-internal/no-production-logging

    Function.prototype.apply.call(console[level], console, argsWithFormat);
  }
}

// -----------------------------------------------------------------------------

var enableScopeAPI = false; // Experimental Create Event Handle API.
var enableCacheElement = false;
var enableTransitionTracing = false; // No known bugs, but needs performance testing

var enableLegacyHidden = false; // Enables unstable_avoidThisFallback feature in Fiber
// stuff. Intended to enable React core members to more easily debug scheduling
// issues in DEV builds.

var enableDebugTracing = false; // Track which Fiber(s) schedule render work.

var REACT_MODULE_REFERENCE;

{
  REACT_MODULE_REFERENCE = Symbol.for('react.module.reference');
}

function isValidElementType(type) {
  if (typeof type === 'string' || typeof type === 'function') {
    return true;
  } // Note: typeof might be other than 'symbol' or 'number' (e.g. if it's a polyfill).


  if (type === REACT_FRAGMENT_TYPE || type === REACT_PROFILER_TYPE || enableDebugTracing  || type === REACT_STRICT_MODE_TYPE || type === REACT_SUSPENSE_TYPE || type === REACT_SUSPENSE_LIST_TYPE || enableLegacyHidden  || type === REACT_OFFSCREEN_TYPE || enableScopeAPI  || enableCacheElement  || enableTransitionTracing ) {
    return true;
  }

  if (typeof type === 'object' && type !== null) {
    if (type.$$typeof === REACT_LAZY_TYPE || type.$$typeof === REACT_MEMO_TYPE || type.$$typeof === REACT_PROVIDER_TYPE || type.$$typeof === REACT_CONTEXT_TYPE || type.$$typeof === REACT_FORWARD_REF_TYPE || // This needs to include all possible module reference object
    // types supported by any Flight configuration anywhere since
    // we don't know which Flight build this will end up being used
    // with.
    type.$$typeof === REACT_MODULE_REFERENCE || type.getModuleId !== undefined) {
      return true;
    }
  }

  return false;
}

function getWrappedName(outerType, innerType, wrapperName) {
  var displayName = outerType.displayName;

  if (displayName) {
    return displayName;
  }

  var functionName = innerType.displayName || innerType.name || '';
  return functionName !== '' ? wrapperName + "(" + functionName + ")" : wrapperName;
} // Keep in sync with react-reconciler/getComponentNameFromFiber


function getContextName(type) {
  return type.displayName || 'Context';
} // Note that the reconciler package should generally prefer to use getComponentNameFromFiber() instead.


function getComponentNameFromType(type) {
  if (type == null) {
    // Host root, text node or just invalid type.
    return null;
  }

  {
    if (typeof type.tag === 'number') {
      error('Received an unexpected object in getComponentNameFromType(). ' + 'This is likely a bug in React. Please file an issue.');
    }
  }

  if (typeof type === 'function') {
    return type.displayName || type.name || null;
  }

  if (typeof type === 'string') {
    return type;
  }

  switch (type) {
    case REACT_FRAGMENT_TYPE:
      return 'Fragment';

    case REACT_PORTAL_TYPE:
      return 'Portal';

    case REACT_PROFILER_TYPE:
      return 'Profiler';

    case REACT_STRICT_MODE_TYPE:
      return 'StrictMode';

    case REACT_SUSPENSE_TYPE:
      return 'Suspense';

    case REACT_SUSPENSE_LIST_TYPE:
      return 'SuspenseList';

  }

  if (typeof type === 'object') {
    switch (type.$$typeof) {
      case REACT_CONTEXT_TYPE:
        var context = type;
        return getContextName(context) + '.Consumer';

      case REACT_PROVIDER_TYPE:
        var provider = type;
        return getContextName(provider._context) + '.Provider';

      case REACT_FORWARD_REF_TYPE:
        return getWrappedName(type, type.render, 'ForwardRef');

      case REACT_MEMO_TYPE:
        var outerName = type.displayName || null;

        if (outerName !== null) {
          return outerName;
        }

        return getComponentNameFromType(type.type) || 'Memo';

      case REACT_LAZY_TYPE:
        {
          var lazyComponent = type;
          var payload = lazyComponent._payload;
          var init = lazyComponent._init;

          try {
            return getComponentNameFromType(init(payload));
          } catch (x) {
            return null;
          }
        }

      // eslint-disable-next-line no-fallthrough
    }
  }

  return null;
}

var assign = Object.assign;

// Helpers to patch console.logs to avoid logging during side-effect free
// replaying on render function. This currently only patches the object
// lazily which won't cover if the log function was extracted eagerly.
// We could also eagerly patch the method.
var disabledDepth = 0;
var prevLog;
var prevInfo;
var prevWarn;
var prevError;
var prevGroup;
var prevGroupCollapsed;
var prevGroupEnd;

function disabledLog() {}

disabledLog.__reactDisabledLog = true;
function disableLogs() {
  {
    if (disabledDepth === 0) {
      /* eslint-disable react-internal/no-production-logging */
      prevLog = console.log;
      prevInfo = console.info;
      prevWarn = console.warn;
      prevError = console.error;
      prevGroup = console.group;
      prevGroupCollapsed = console.groupCollapsed;
      prevGroupEnd = console.groupEnd; // https://github.com/facebook/react/issues/19099

      var props = {
        configurable: true,
        enumerable: true,
        value: disabledLog,
        writable: true
      }; // $FlowFixMe Flow thinks console is immutable.

      Object.defineProperties(console, {
        info: props,
        log: props,
        warn: props,
        error: props,
        group: props,
        groupCollapsed: props,
        groupEnd: props
      });
      /* eslint-enable react-internal/no-production-logging */
    }

    disabledDepth++;
  }
}
function reenableLogs() {
  {
    disabledDepth--;

    if (disabledDepth === 0) {
      /* eslint-disable react-internal/no-production-logging */
      var props = {
        configurable: true,
        enumerable: true,
        writable: true
      }; // $FlowFixMe Flow thinks console is immutable.

      Object.defineProperties(console, {
        log: assign({}, props, {
          value: prevLog
        }),
        info: assign({}, props, {
          value: prevInfo
        }),
        warn: assign({}, props, {
          value: prevWarn
        }),
        error: assign({}, props, {
          value: prevError
        }),
        group: assign({}, props, {
          value: prevGroup
        }),
        groupCollapsed: assign({}, props, {
          value: prevGroupCollapsed
        }),
        groupEnd: assign({}, props, {
          value: prevGroupEnd
        })
      });
      /* eslint-enable react-internal/no-production-logging */
    }

    if (disabledDepth < 0) {
      error('disabledDepth fell below zero. ' + 'This is a bug in React. Please file an issue.');
    }
  }
}

var ReactCurrentDispatcher = ReactSharedInternals.ReactCurrentDispatcher;
var prefix;
function describeBuiltInComponentFrame(name, source, ownerFn) {
  {
    if (prefix === undefined) {
      // Extract the VM specific prefix used by each line.
      try {
        throw Error();
      } catch (x) {
        var match = x.stack.trim().match(/\n( *(at )?)/);
        prefix = match && match[1] || '';
      }
    } // We use the prefix to ensure our stacks line up with native stack frames.


    return '\n' + prefix + name;
  }
}
var reentry = false;
var componentFrameCache;

{
  var PossiblyWeakMap = typeof WeakMap === 'function' ? WeakMap : Map;
  componentFrameCache = new PossiblyWeakMap();
}

function describeNativeComponentFrame(fn, construct) {
  // If something asked for a stack inside a fake render, it should get ignored.
  if ( !fn || reentry) {
    return '';
  }

  {
    var frame = componentFrameCache.get(fn);

    if (frame !== undefined) {
      return frame;
    }
  }

  var control;
  reentry = true;
  var previousPrepareStackTrace = Error.prepareStackTrace; // $FlowFixMe It does accept undefined.

  Error.prepareStackTrace = undefined;
  var previousDispatcher;

  {
    previousDispatcher = ReactCurrentDispatcher.current; // Set the dispatcher in DEV because this might be call in the render function
    // for warnings.

    ReactCurrentDispatcher.current = null;
    disableLogs();
  }

  try {
    // This should throw.
    if (construct) {
      // Something should be setting the props in the constructor.
      var Fake = function () {
        throw Error();
      }; // $FlowFixMe


      Object.defineProperty(Fake.prototype, 'props', {
        set: function () {
          // We use a throwing setter instead of frozen or non-writable props
          // because that won't throw in a non-strict mode function.
          throw Error();
        }
      });

      if (typeof Reflect === 'object' && Reflect.construct) {
        // We construct a different control for this case to include any extra
        // frames added by the construct call.
        try {
          Reflect.construct(Fake, []);
        } catch (x) {
          control = x;
        }

        Reflect.construct(fn, [], Fake);
      } else {
        try {
          Fake.call();
        } catch (x) {
          control = x;
        }

        fn.call(Fake.prototype);
      }
    } else {
      try {
        throw Error();
      } catch (x) {
        control = x;
      }

      fn();
    }
  } catch (sample) {
    // This is inlined manually because closure doesn't do it for us.
    if (sample && control && typeof sample.stack === 'string') {
      // This extracts the first frame from the sample that isn't also in the control.
      // Skipping one frame that we assume is the frame that calls the two.
      var sampleLines = sample.stack.split('\n');
      var controlLines = control.stack.split('\n');
      var s = sampleLines.length - 1;
      var c = controlLines.length - 1;

      while (s >= 1 && c >= 0 && sampleLines[s] !== controlLines[c]) {
        // We expect at least one stack frame to be shared.
        // Typically this will be the root most one. However, stack frames may be
        // cut off due to maximum stack limits. In this case, one maybe cut off
        // earlier than the other. We assume that the sample is longer or the same
        // and there for cut off earlier. So we should find the root most frame in
        // the sample somewhere in the control.
        c--;
      }

      for (; s >= 1 && c >= 0; s--, c--) {
        // Next we find the first one that isn't the same which should be the
        // frame that called our sample function and the control.
        if (sampleLines[s] !== controlLines[c]) {
          // In V8, the first line is describing the message but other VMs don't.
          // If we're about to return the first line, and the control is also on the same
          // line, that's a pretty good indicator that our sample threw at same line as
          // the control. I.e. before we entered the sample frame. So we ignore this result.
          // This can happen if you passed a class to function component, or non-function.
          if (s !== 1 || c !== 1) {
            do {
              s--;
              c--; // We may still have similar intermediate frames from the construct call.
              // The next one that isn't the same should be our match though.

              if (c < 0 || sampleLines[s] !== controlLines[c]) {
                // V8 adds a "new" prefix for native classes. Let's remove it to make it prettier.
                var _frame = '\n' + sampleLines[s].replace(' at new ', ' at '); // If our component frame is labeled "<anonymous>"
                // but we have a user-provided "displayName"
                // splice it in to make the stack more readable.


                if (fn.displayName && _frame.includes('<anonymous>')) {
                  _frame = _frame.replace('<anonymous>', fn.displayName);
                }

                {
                  if (typeof fn === 'function') {
                    componentFrameCache.set(fn, _frame);
                  }
                } // Return the line we found.


                return _frame;
              }
            } while (s >= 1 && c >= 0);
          }

          break;
        }
      }
    }
  } finally {
    reentry = false;

    {
      ReactCurrentDispatcher.current = previousDispatcher;
      reenableLogs();
    }

    Error.prepareStackTrace = previousPrepareStackTrace;
  } // Fallback to just using the name if we couldn't make it throw.


  var name = fn ? fn.displayName || fn.name : '';
  var syntheticFrame = name ? describeBuiltInComponentFrame(name) : '';

  {
    if (typeof fn === 'function') {
      componentFrameCache.set(fn, syntheticFrame);
    }
  }

  return syntheticFrame;
}
function describeFunctionComponentFrame(fn, source, ownerFn) {
  {
    return describeNativeComponentFrame(fn, false);
  }
}

function shouldConstruct(Component) {
  var prototype = Component.prototype;
  return !!(prototype && prototype.isReactComponent);
}

function describeUnknownElementTypeFrameInDEV(type, source, ownerFn) {

  if (type == null) {
    return '';
  }

  if (typeof type === 'function') {
    {
      return describeNativeComponentFrame(type, shouldConstruct(type));
    }
  }

  if (typeof type === 'string') {
    return describeBuiltInComponentFrame(type);
  }

  switch (type) {
    case REACT_SUSPENSE_TYPE:
      return describeBuiltInComponentFrame('Suspense');

    case REACT_SUSPENSE_LIST_TYPE:
      return describeBuiltInComponentFrame('SuspenseList');
  }

  if (typeof type === 'object') {
    switch (type.$$typeof) {
      case REACT_FORWARD_REF_TYPE:
        return describeFunctionComponentFrame(type.render);

      case REACT_MEMO_TYPE:
        // Memo may contain any component type so we recursively resolve it.
        return describeUnknownElementTypeFrameInDEV(type.type, source, ownerFn);

      case REACT_LAZY_TYPE:
        {
          var lazyComponent = type;
          var payload = lazyComponent._payload;
          var init = lazyComponent._init;

          try {
            // Lazy may contain any component type so we recursively resolve it.
            return describeUnknownElementTypeFrameInDEV(init(payload), source, ownerFn);
          } catch (x) {}
        }
    }
  }

  return '';
}

var hasOwnProperty = Object.prototype.hasOwnProperty;

var loggedTypeFailures = {};
var ReactDebugCurrentFrame = ReactSharedInternals.ReactDebugCurrentFrame;

function setCurrentlyValidatingElement(element) {
  {
    if (element) {
      var owner = element._owner;
      var stack = describeUnknownElementTypeFrameInDEV(element.type, element._source, owner ? owner.type : null);
      ReactDebugCurrentFrame.setExtraStackFrame(stack);
    } else {
      ReactDebugCurrentFrame.setExtraStackFrame(null);
    }
  }
}

function checkPropTypes(typeSpecs, values, location, componentName, element) {
  {
    // $FlowFixMe This is okay but Flow doesn't know it.
    var has = Function.call.bind(hasOwnProperty);

    for (var typeSpecName in typeSpecs) {
      if (has(typeSpecs, typeSpecName)) {
        var error$1 = void 0; // Prop type validation may throw. In case they do, we don't want to
        // fail the render phase where it didn't fail before. So we log it.
        // After these have been cleaned up, we'll let them throw.

        try {
          // This is intentionally an invariant that gets caught. It's the same
          // behavior as without this statement except with a better message.
          if (typeof typeSpecs[typeSpecName] !== 'function') {
            // eslint-disable-next-line react-internal/prod-error-codes
            var err = Error((componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' + 'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.' + 'This often happens because of typos such as `PropTypes.function` instead of `PropTypes.func`.');
            err.name = 'Invariant Violation';
            throw err;
          }

          error$1 = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED');
        } catch (ex) {
          error$1 = ex;
        }

        if (error$1 && !(error$1 instanceof Error)) {
          setCurrentlyValidatingElement(element);

          error('%s: type specification of %s' + ' `%s` is invalid; the type checker ' + 'function must return `null` or an `Error` but returned a %s. ' + 'You may have forgotten to pass an argument to the type checker ' + 'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' + 'shape all require an argument).', componentName || 'React class', location, typeSpecName, typeof error$1);

          setCurrentlyValidatingElement(null);
        }

        if (error$1 instanceof Error && !(error$1.message in loggedTypeFailures)) {
          // Only monitor this failure once because there tends to be a lot of the
          // same error.
          loggedTypeFailures[error$1.message] = true;
          setCurrentlyValidatingElement(element);

          error('Failed %s type: %s', location, error$1.message);

          setCurrentlyValidatingElement(null);
        }
      }
    }
  }
}

var isArrayImpl = Array.isArray; // eslint-disable-next-line no-redeclare

function isArray(a) {
  return isArrayImpl(a);
}

/*
 * The `'' + value` pattern (used in in perf-sensitive code) throws for Symbol
 * and Temporal.* types. See https://github.com/facebook/react/pull/22064.
 *
 * The functions in this module will throw an easier-to-understand,
 * easier-to-debug exception with a clear errors message message explaining the
 * problem. (Instead of a confusing exception thrown inside the implementation
 * of the `value` object).
 */
// $FlowFixMe only called in DEV, so void return is not possible.
function typeName(value) {
  {
    // toStringTag is needed for namespaced types like Temporal.Instant
    var hasToStringTag = typeof Symbol === 'function' && Symbol.toStringTag;
    var type = hasToStringTag && value[Symbol.toStringTag] || value.constructor.name || 'Object';
    return type;
  }
} // $FlowFixMe only called in DEV, so void return is not possible.


function willCoercionThrow(value) {
  {
    try {
      testStringCoercion(value);
      return false;
    } catch (e) {
      return true;
    }
  }
}

function testStringCoercion(value) {
  // If you ended up here by following an exception call stack, here's what's
  // happened: you supplied an object or symbol value to React (as a prop, key,
  // DOM attribute, CSS property, string ref, etc.) and when React tried to
  // coerce it to a string using `'' + value`, an exception was thrown.
  //
  // The most common types that will cause this exception are `Symbol` instances
  // and Temporal objects like `Temporal.Instant`. But any object that has a
  // `valueOf` or `[Symbol.toPrimitive]` method that throws will also cause this
  // exception. (Library authors do this to prevent users from using built-in
  // numeric operators like `+` or comparison operators like `>=` because custom
  // methods are needed to perform accurate arithmetic or comparison.)
  //
  // To fix the problem, coerce this object or symbol value to a string before
  // passing it to React. The most reliable way is usually `String(value)`.
  //
  // To find which value is throwing, check the browser or debugger console.
  // Before this exception was thrown, there should be `console.error` output
  // that shows the type (Symbol, Temporal.PlainDate, etc.) that caused the
  // problem and how that type was used: key, atrribute, input value prop, etc.
  // In most cases, this console output also shows the component and its
  // ancestor components where the exception happened.
  //
  // eslint-disable-next-line react-internal/safe-string-coercion
  return '' + value;
}
function checkKeyStringCoercion(value) {
  {
    if (willCoercionThrow(value)) {
      error('The provided key is an unsupported type %s.' + ' This value must be coerced to a string before before using it here.', typeName(value));

      return testStringCoercion(value); // throw (to help callers find troubleshooting comments)
    }
  }
}

var ReactCurrentOwner = ReactSharedInternals.ReactCurrentOwner;
var RESERVED_PROPS = {
  key: true,
  ref: true,
  __self: true,
  __source: true
};
var specialPropKeyWarningShown;
var specialPropRefWarningShown;
var didWarnAboutStringRefs;

{
  didWarnAboutStringRefs = {};
}

function hasValidRef(config) {
  {
    if (hasOwnProperty.call(config, 'ref')) {
      var getter = Object.getOwnPropertyDescriptor(config, 'ref').get;

      if (getter && getter.isReactWarning) {
        return false;
      }
    }
  }

  return config.ref !== undefined;
}

function hasValidKey(config) {
  {
    if (hasOwnProperty.call(config, 'key')) {
      var getter = Object.getOwnPropertyDescriptor(config, 'key').get;

      if (getter && getter.isReactWarning) {
        return false;
      }
    }
  }

  return config.key !== undefined;
}

function warnIfStringRefCannotBeAutoConverted(config, self) {
  {
    if (typeof config.ref === 'string' && ReactCurrentOwner.current && self && ReactCurrentOwner.current.stateNode !== self) {
      var componentName = getComponentNameFromType(ReactCurrentOwner.current.type);

      if (!didWarnAboutStringRefs[componentName]) {
        error('Component "%s" contains the string ref "%s". ' + 'Support for string refs will be removed in a future major release. ' + 'This case cannot be automatically converted to an arrow function. ' + 'We ask you to manually fix this case by using useRef() or createRef() instead. ' + 'Learn more about using refs safely here: ' + 'https://reactjs.org/link/strict-mode-string-ref', getComponentNameFromType(ReactCurrentOwner.current.type), config.ref);

        didWarnAboutStringRefs[componentName] = true;
      }
    }
  }
}

function defineKeyPropWarningGetter(props, displayName) {
  {
    var warnAboutAccessingKey = function () {
      if (!specialPropKeyWarningShown) {
        specialPropKeyWarningShown = true;

        error('%s: `key` is not a prop. Trying to access it will result ' + 'in `undefined` being returned. If you need to access the same ' + 'value within the child component, you should pass it as a different ' + 'prop. (https://reactjs.org/link/special-props)', displayName);
      }
    };

    warnAboutAccessingKey.isReactWarning = true;
    Object.defineProperty(props, 'key', {
      get: warnAboutAccessingKey,
      configurable: true
    });
  }
}

function defineRefPropWarningGetter(props, displayName) {
  {
    var warnAboutAccessingRef = function () {
      if (!specialPropRefWarningShown) {
        specialPropRefWarningShown = true;

        error('%s: `ref` is not a prop. Trying to access it will result ' + 'in `undefined` being returned. If you need to access the same ' + 'value within the child component, you should pass it as a different ' + 'prop. (https://reactjs.org/link/special-props)', displayName);
      }
    };

    warnAboutAccessingRef.isReactWarning = true;
    Object.defineProperty(props, 'ref', {
      get: warnAboutAccessingRef,
      configurable: true
    });
  }
}
/**
 * Factory method to create a new React element. This no longer adheres to
 * the class pattern, so do not use new to call it. Also, instanceof check
 * will not work. Instead test $$typeof field against Symbol.for('react.element') to check
 * if something is a React Element.
 *
 * @param {*} type
 * @param {*} props
 * @param {*} key
 * @param {string|object} ref
 * @param {*} owner
 * @param {*} self A *temporary* helper to detect places where `this` is
 * different from the `owner` when React.createElement is called, so that we
 * can warn. We want to get rid of owner and replace string `ref`s with arrow
 * functions, and as long as `this` and owner are the same, there will be no
 * change in behavior.
 * @param {*} source An annotation object (added by a transpiler or otherwise)
 * indicating filename, line number, and/or other information.
 * @internal
 */


var ReactElement = function (type, key, ref, self, source, owner, props) {
  var element = {
    // This tag allows us to uniquely identify this as a React Element
    $$typeof: REACT_ELEMENT_TYPE,
    // Built-in properties that belong on the element
    type: type,
    key: key,
    ref: ref,
    props: props,
    // Record the component responsible for creating this element.
    _owner: owner
  };

  {
    // The validation flag is currently mutative. We put it on
    // an external backing store so that we can freeze the whole object.
    // This can be replaced with a WeakMap once they are implemented in
    // commonly used development environments.
    element._store = {}; // To make comparing ReactElements easier for testing purposes, we make
    // the validation flag non-enumerable (where possible, which should
    // include every environment we run tests in), so the test framework
    // ignores it.

    Object.defineProperty(element._store, 'validated', {
      configurable: false,
      enumerable: false,
      writable: true,
      value: false
    }); // self and source are DEV only properties.

    Object.defineProperty(element, '_self', {
      configurable: false,
      enumerable: false,
      writable: false,
      value: self
    }); // Two elements created in two different places should be considered
    // equal for testing purposes and therefore we hide it from enumeration.

    Object.defineProperty(element, '_source', {
      configurable: false,
      enumerable: false,
      writable: false,
      value: source
    });

    if (Object.freeze) {
      Object.freeze(element.props);
      Object.freeze(element);
    }
  }

  return element;
};
/**
 * https://github.com/reactjs/rfcs/pull/107
 * @param {*} type
 * @param {object} props
 * @param {string} key
 */

function jsxDEV(type, config, maybeKey, source, self) {
  {
    var propName; // Reserved names are extracted

    var props = {};
    var key = null;
    var ref = null; // Currently, key can be spread in as a prop. This causes a potential
    // issue if key is also explicitly declared (ie. <div {...props} key="Hi" />
    // or <div key="Hi" {...props} /> ). We want to deprecate key spread,
    // but as an intermediary step, we will use jsxDEV for everything except
    // <div {...props} key="Hi" />, because we aren't currently able to tell if
    // key is explicitly declared to be undefined or not.

    if (maybeKey !== undefined) {
      {
        checkKeyStringCoercion(maybeKey);
      }

      key = '' + maybeKey;
    }

    if (hasValidKey(config)) {
      {
        checkKeyStringCoercion(config.key);
      }

      key = '' + config.key;
    }

    if (hasValidRef(config)) {
      ref = config.ref;
      warnIfStringRefCannotBeAutoConverted(config, self);
    } // Remaining properties are added to a new props object


    for (propName in config) {
      if (hasOwnProperty.call(config, propName) && !RESERVED_PROPS.hasOwnProperty(propName)) {
        props[propName] = config[propName];
      }
    } // Resolve default props


    if (type && type.defaultProps) {
      var defaultProps = type.defaultProps;

      for (propName in defaultProps) {
        if (props[propName] === undefined) {
          props[propName] = defaultProps[propName];
        }
      }
    }

    if (key || ref) {
      var displayName = typeof type === 'function' ? type.displayName || type.name || 'Unknown' : type;

      if (key) {
        defineKeyPropWarningGetter(props, displayName);
      }

      if (ref) {
        defineRefPropWarningGetter(props, displayName);
      }
    }

    return ReactElement(type, key, ref, self, source, ReactCurrentOwner.current, props);
  }
}

var ReactCurrentOwner$1 = ReactSharedInternals.ReactCurrentOwner;
var ReactDebugCurrentFrame$1 = ReactSharedInternals.ReactDebugCurrentFrame;

function setCurrentlyValidatingElement$1(element) {
  {
    if (element) {
      var owner = element._owner;
      var stack = describeUnknownElementTypeFrameInDEV(element.type, element._source, owner ? owner.type : null);
      ReactDebugCurrentFrame$1.setExtraStackFrame(stack);
    } else {
      ReactDebugCurrentFrame$1.setExtraStackFrame(null);
    }
  }
}

var propTypesMisspellWarningShown;

{
  propTypesMisspellWarningShown = false;
}
/**
 * Verifies the object is a ReactElement.
 * See https://reactjs.org/docs/react-api.html#isvalidelement
 * @param {?object} object
 * @return {boolean} True if `object` is a ReactElement.
 * @final
 */


function isValidElement(object) {
  {
    return typeof object === 'object' && object !== null && object.$$typeof === REACT_ELEMENT_TYPE;
  }
}

function getDeclarationErrorAddendum() {
  {
    if (ReactCurrentOwner$1.current) {
      var name = getComponentNameFromType(ReactCurrentOwner$1.current.type);

      if (name) {
        return '\n\nCheck the render method of `' + name + '`.';
      }
    }

    return '';
  }
}

function getSourceInfoErrorAddendum(source) {
  {
    if (source !== undefined) {
      var fileName = source.fileName.replace(/^.*[\\\/]/, '');
      var lineNumber = source.lineNumber;
      return '\n\nCheck your code at ' + fileName + ':' + lineNumber + '.';
    }

    return '';
  }
}
/**
 * Warn if there's no key explicitly set on dynamic arrays of children or
 * object keys are not valid. This allows us to keep track of children between
 * updates.
 */


var ownerHasKeyUseWarning = {};

function getCurrentComponentErrorInfo(parentType) {
  {
    var info = getDeclarationErrorAddendum();

    if (!info) {
      var parentName = typeof parentType === 'string' ? parentType : parentType.displayName || parentType.name;

      if (parentName) {
        info = "\n\nCheck the top-level render call using <" + parentName + ">.";
      }
    }

    return info;
  }
}
/**
 * Warn if the element doesn't have an explicit key assigned to it.
 * This element is in an array. The array could grow and shrink or be
 * reordered. All children that haven't already been validated are required to
 * have a "key" property assigned to it. Error statuses are cached so a warning
 * will only be shown once.
 *
 * @internal
 * @param {ReactElement} element Element that requires a key.
 * @param {*} parentType element's parent's type.
 */


function validateExplicitKey(element, parentType) {
  {
    if (!element._store || element._store.validated || element.key != null) {
      return;
    }

    element._store.validated = true;
    var currentComponentErrorInfo = getCurrentComponentErrorInfo(parentType);

    if (ownerHasKeyUseWarning[currentComponentErrorInfo]) {
      return;
    }

    ownerHasKeyUseWarning[currentComponentErrorInfo] = true; // Usually the current owner is the offender, but if it accepts children as a
    // property, it may be the creator of the child that's responsible for
    // assigning it a key.

    var childOwner = '';

    if (element && element._owner && element._owner !== ReactCurrentOwner$1.current) {
      // Give the component that originally created this child.
      childOwner = " It was passed a child from " + getComponentNameFromType(element._owner.type) + ".";
    }

    setCurrentlyValidatingElement$1(element);

    error('Each child in a list should have a unique "key" prop.' + '%s%s See https://reactjs.org/link/warning-keys for more information.', currentComponentErrorInfo, childOwner);

    setCurrentlyValidatingElement$1(null);
  }
}
/**
 * Ensure that every element either is passed in a static location, in an
 * array with an explicit keys property defined, or in an object literal
 * with valid key property.
 *
 * @internal
 * @param {ReactNode} node Statically passed child of any type.
 * @param {*} parentType node's parent's type.
 */


function validateChildKeys(node, parentType) {
  {
    if (typeof node !== 'object') {
      return;
    }

    if (isArray(node)) {
      for (var i = 0; i < node.length; i++) {
        var child = node[i];

        if (isValidElement(child)) {
          validateExplicitKey(child, parentType);
        }
      }
    } else if (isValidElement(node)) {
      // This element was passed in a valid location.
      if (node._store) {
        node._store.validated = true;
      }
    } else if (node) {
      var iteratorFn = getIteratorFn(node);

      if (typeof iteratorFn === 'function') {
        // Entry iterators used to provide implicit keys,
        // but now we print a separate warning for them later.
        if (iteratorFn !== node.entries) {
          var iterator = iteratorFn.call(node);
          var step;

          while (!(step = iterator.next()).done) {
            if (isValidElement(step.value)) {
              validateExplicitKey(step.value, parentType);
            }
          }
        }
      }
    }
  }
}
/**
 * Given an element, validate that its props follow the propTypes definition,
 * provided by the type.
 *
 * @param {ReactElement} element
 */


function validatePropTypes(element) {
  {
    var type = element.type;

    if (type === null || type === undefined || typeof type === 'string') {
      return;
    }

    var propTypes;

    if (typeof type === 'function') {
      propTypes = type.propTypes;
    } else if (typeof type === 'object' && (type.$$typeof === REACT_FORWARD_REF_TYPE || // Note: Memo only checks outer props here.
    // Inner props are checked in the reconciler.
    type.$$typeof === REACT_MEMO_TYPE)) {
      propTypes = type.propTypes;
    } else {
      return;
    }

    if (propTypes) {
      // Intentionally inside to avoid triggering lazy initializers:
      var name = getComponentNameFromType(type);
      checkPropTypes(propTypes, element.props, 'prop', name, element);
    } else if (type.PropTypes !== undefined && !propTypesMisspellWarningShown) {
      propTypesMisspellWarningShown = true; // Intentionally inside to avoid triggering lazy initializers:

      var _name = getComponentNameFromType(type);

      error('Component %s declared `PropTypes` instead of `propTypes`. Did you misspell the property assignment?', _name || 'Unknown');
    }

    if (typeof type.getDefaultProps === 'function' && !type.getDefaultProps.isReactClassApproved) {
      error('getDefaultProps is only used on classic React.createClass ' + 'definitions. Use a static property named `defaultProps` instead.');
    }
  }
}
/**
 * Given a fragment, validate that it can only be provided with fragment props
 * @param {ReactElement} fragment
 */


function validateFragmentProps(fragment) {
  {
    var keys = Object.keys(fragment.props);

    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];

      if (key !== 'children' && key !== 'key') {
        setCurrentlyValidatingElement$1(fragment);

        error('Invalid prop `%s` supplied to `React.Fragment`. ' + 'React.Fragment can only have `key` and `children` props.', key);

        setCurrentlyValidatingElement$1(null);
        break;
      }
    }

    if (fragment.ref !== null) {
      setCurrentlyValidatingElement$1(fragment);

      error('Invalid attribute `ref` supplied to `React.Fragment`.');

      setCurrentlyValidatingElement$1(null);
    }
  }
}

var didWarnAboutKeySpread = {};
function jsxWithValidation(type, props, key, isStaticChildren, source, self) {
  {
    var validType = isValidElementType(type); // We warn in this case but don't throw. We expect the element creation to
    // succeed and there will likely be errors in render.

    if (!validType) {
      var info = '';

      if (type === undefined || typeof type === 'object' && type !== null && Object.keys(type).length === 0) {
        info += ' You likely forgot to export your component from the file ' + "it's defined in, or you might have mixed up default and named imports.";
      }

      var sourceInfo = getSourceInfoErrorAddendum(source);

      if (sourceInfo) {
        info += sourceInfo;
      } else {
        info += getDeclarationErrorAddendum();
      }

      var typeString;

      if (type === null) {
        typeString = 'null';
      } else if (isArray(type)) {
        typeString = 'array';
      } else if (type !== undefined && type.$$typeof === REACT_ELEMENT_TYPE) {
        typeString = "<" + (getComponentNameFromType(type.type) || 'Unknown') + " />";
        info = ' Did you accidentally export a JSX literal instead of a component?';
      } else {
        typeString = typeof type;
      }

      error('React.jsx: type is invalid -- expected a string (for ' + 'built-in components) or a class/function (for composite ' + 'components) but got: %s.%s', typeString, info);
    }

    var element = jsxDEV(type, props, key, source, self); // The result can be nullish if a mock or a custom function is used.
    // TODO: Drop this when these are no longer allowed as the type argument.

    if (element == null) {
      return element;
    } // Skip key warning if the type isn't valid since our key validation logic
    // doesn't expect a non-string/function type and can throw confusing errors.
    // We don't want exception behavior to differ between dev and prod.
    // (Rendering will throw with a helpful message and as soon as the type is
    // fixed, the key warnings will appear.)


    if (validType) {
      var children = props.children;

      if (children !== undefined) {
        if (isStaticChildren) {
          if (isArray(children)) {
            for (var i = 0; i < children.length; i++) {
              validateChildKeys(children[i], type);
            }

            if (Object.freeze) {
              Object.freeze(children);
            }
          } else {
            error('React.jsx: Static children should always be an array. ' + 'You are likely explicitly calling React.jsxs or React.jsxDEV. ' + 'Use the Babel transform instead.');
          }
        } else {
          validateChildKeys(children, type);
        }
      }
    }

    {
      if (hasOwnProperty.call(props, 'key')) {
        var componentName = getComponentNameFromType(type);
        var keys = Object.keys(props).filter(function (k) {
          return k !== 'key';
        });
        var beforeExample = keys.length > 0 ? '{key: someKey, ' + keys.join(': ..., ') + ': ...}' : '{key: someKey}';

        if (!didWarnAboutKeySpread[componentName + beforeExample]) {
          var afterExample = keys.length > 0 ? '{' + keys.join(': ..., ') + ': ...}' : '{}';

          error('A props object containing a "key" prop is being spread into JSX:\n' + '  let props = %s;\n' + '  <%s {...props} />\n' + 'React keys must be passed directly to JSX without using spread:\n' + '  let props = %s;\n' + '  <%s key={someKey} {...props} />', beforeExample, componentName, afterExample, componentName);

          didWarnAboutKeySpread[componentName + beforeExample] = true;
        }
      }
    }

    if (type === REACT_FRAGMENT_TYPE) {
      validateFragmentProps(element);
    } else {
      validatePropTypes(element);
    }

    return element;
  }
} // These two functions exist to still get child warnings in dev
// even with the prod transform. This means that jsxDEV is purely
// opt-in behavior for better messages but that we won't stop
// giving you warnings if you use production apis.

function jsxWithValidationStatic(type, props, key) {
  {
    return jsxWithValidation(type, props, key, true);
  }
}
function jsxWithValidationDynamic(type, props, key) {
  {
    return jsxWithValidation(type, props, key, false);
  }
}

var jsx =  jsxWithValidationDynamic ; // we may want to special case jsxs internally to take advantage of static children.
// for now we can ship identical prod functions

var jsxs =  jsxWithValidationStatic ;

exports.Fragment = REACT_FRAGMENT_TYPE;
exports.jsx = jsx;
exports.jsxs = jsxs;
  })();
}


/***/ }),

/***/ "../node_modules/react/jsx-runtime.js":
/*!********************************************!*\
  !*** ../node_modules/react/jsx-runtime.js ***!
  \********************************************/
/***/ ((module, __unused_webpack_exports, __webpack_require__) => {

"use strict";


if (false) // removed by dead control flow
{} else {
  module.exports = __webpack_require__(/*! ./cjs/react-jsx-runtime.development.js */ "../node_modules/react/cjs/react-jsx-runtime.development.js");
}


/***/ }),

/***/ "../node_modules/tslib/tslib.es6.mjs":
/*!*******************************************!*\
  !*** ../node_modules/tslib/tslib.es6.mjs ***!
  \*******************************************/
/***/ ((__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   __addDisposableResource: () => (/* binding */ __addDisposableResource),
/* harmony export */   __assign: () => (/* binding */ __assign),
/* harmony export */   __asyncDelegator: () => (/* binding */ __asyncDelegator),
/* harmony export */   __asyncGenerator: () => (/* binding */ __asyncGenerator),
/* harmony export */   __asyncValues: () => (/* binding */ __asyncValues),
/* harmony export */   __await: () => (/* binding */ __await),
/* harmony export */   __awaiter: () => (/* binding */ __awaiter),
/* harmony export */   __classPrivateFieldGet: () => (/* binding */ __classPrivateFieldGet),
/* harmony export */   __classPrivateFieldIn: () => (/* binding */ __classPrivateFieldIn),
/* harmony export */   __classPrivateFieldSet: () => (/* binding */ __classPrivateFieldSet),
/* harmony export */   __createBinding: () => (/* binding */ __createBinding),
/* harmony export */   __decorate: () => (/* binding */ __decorate),
/* harmony export */   __disposeResources: () => (/* binding */ __disposeResources),
/* harmony export */   __esDecorate: () => (/* binding */ __esDecorate),
/* harmony export */   __exportStar: () => (/* binding */ __exportStar),
/* harmony export */   __extends: () => (/* binding */ __extends),
/* harmony export */   __generator: () => (/* binding */ __generator),
/* harmony export */   __importDefault: () => (/* binding */ __importDefault),
/* harmony export */   __importStar: () => (/* binding */ __importStar),
/* harmony export */   __makeTemplateObject: () => (/* binding */ __makeTemplateObject),
/* harmony export */   __metadata: () => (/* binding */ __metadata),
/* harmony export */   __param: () => (/* binding */ __param),
/* harmony export */   __propKey: () => (/* binding */ __propKey),
/* harmony export */   __read: () => (/* binding */ __read),
/* harmony export */   __rest: () => (/* binding */ __rest),
/* harmony export */   __rewriteRelativeImportExtension: () => (/* binding */ __rewriteRelativeImportExtension),
/* harmony export */   __runInitializers: () => (/* binding */ __runInitializers),
/* harmony export */   __setFunctionName: () => (/* binding */ __setFunctionName),
/* harmony export */   __spread: () => (/* binding */ __spread),
/* harmony export */   __spreadArray: () => (/* binding */ __spreadArray),
/* harmony export */   __spreadArrays: () => (/* binding */ __spreadArrays),
/* harmony export */   __values: () => (/* binding */ __values),
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise, SuppressedError, Symbol, Iterator */

var extendStatics = function(d, b) {
  extendStatics = Object.setPrototypeOf ||
      ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
      function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
  return extendStatics(d, b);
};

function __extends(d, b) {
  if (typeof b !== "function" && b !== null)
      throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
  extendStatics(d, b);
  function __() { this.constructor = d; }
  d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
  __assign = Object.assign || function __assign(t) {
      for (var s, i = 1, n = arguments.length; i < n; i++) {
          s = arguments[i];
          for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
      }
      return t;
  }
  return __assign.apply(this, arguments);
}

function __rest(s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
      t[p] = s[p];
  if (s != null && typeof Object.getOwnPropertySymbols === "function")
      for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
          if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
              t[p[i]] = s[p[i]];
      }
  return t;
}

function __decorate(decorators, target, key, desc) {
  var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
  else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
  return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function __param(paramIndex, decorator) {
  return function (target, key) { decorator(target, key, paramIndex); }
}

function __esDecorate(ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
  function accept(f) { if (f !== void 0 && typeof f !== "function") throw new TypeError("Function expected"); return f; }
  var kind = contextIn.kind, key = kind === "getter" ? "get" : kind === "setter" ? "set" : "value";
  var target = !descriptorIn && ctor ? contextIn["static"] ? ctor : ctor.prototype : null;
  var descriptor = descriptorIn || (target ? Object.getOwnPropertyDescriptor(target, contextIn.name) : {});
  var _, done = false;
  for (var i = decorators.length - 1; i >= 0; i--) {
      var context = {};
      for (var p in contextIn) context[p] = p === "access" ? {} : contextIn[p];
      for (var p in contextIn.access) context.access[p] = contextIn.access[p];
      context.addInitializer = function (f) { if (done) throw new TypeError("Cannot add initializers after decoration has completed"); extraInitializers.push(accept(f || null)); };
      var result = (0, decorators[i])(kind === "accessor" ? { get: descriptor.get, set: descriptor.set } : descriptor[key], context);
      if (kind === "accessor") {
          if (result === void 0) continue;
          if (result === null || typeof result !== "object") throw new TypeError("Object expected");
          if (_ = accept(result.get)) descriptor.get = _;
          if (_ = accept(result.set)) descriptor.set = _;
          if (_ = accept(result.init)) initializers.unshift(_);
      }
      else if (_ = accept(result)) {
          if (kind === "field") initializers.unshift(_);
          else descriptor[key] = _;
      }
  }
  if (target) Object.defineProperty(target, contextIn.name, descriptor);
  done = true;
};

function __runInitializers(thisArg, initializers, value) {
  var useValue = arguments.length > 2;
  for (var i = 0; i < initializers.length; i++) {
      value = useValue ? initializers[i].call(thisArg, value) : initializers[i].call(thisArg);
  }
  return useValue ? value : void 0;
};

function __propKey(x) {
  return typeof x === "symbol" ? x : "".concat(x);
};

function __setFunctionName(f, name, prefix) {
  if (typeof name === "symbol") name = name.description ? "[".concat(name.description, "]") : "";
  return Object.defineProperty(f, "name", { configurable: true, value: prefix ? "".concat(prefix, " ", name) : name });
};

function __metadata(metadataKey, metadataValue) {
  if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
}

function __awaiter(thisArg, _arguments, P, generator) {
  function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
  return new (P || (P = Promise))(function (resolve, reject) {
      function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
      function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
      function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
      step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
}

function __generator(thisArg, body) {
  var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g = Object.create((typeof Iterator === "function" ? Iterator : Object).prototype);
  return g.next = verb(0), g["throw"] = verb(1), g["return"] = verb(2), typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
  function verb(n) { return function (v) { return step([n, v]); }; }
  function step(op) {
      if (f) throw new TypeError("Generator is already executing.");
      while (g && (g = 0, op[0] && (_ = 0)), _) try {
          if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
          if (y = 0, t) op = [op[0] & 2, t.value];
          switch (op[0]) {
              case 0: case 1: t = op; break;
              case 4: _.label++; return { value: op[1], done: false };
              case 5: _.label++; y = op[1]; op = [0]; continue;
              case 7: op = _.ops.pop(); _.trys.pop(); continue;
              default:
                  if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                  if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                  if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                  if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                  if (t[2]) _.ops.pop();
                  _.trys.pop(); continue;
          }
          op = body.call(thisArg, _);
      } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
      if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
  }
}

var __createBinding = Object.create ? (function(o, m, k, k2) {
  if (k2 === undefined) k2 = k;
  var desc = Object.getOwnPropertyDescriptor(m, k);
  if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
  }
  Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
  if (k2 === undefined) k2 = k;
  o[k2] = m[k];
});

function __exportStar(m, o) {
  for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p)) __createBinding(o, m, p);
}

function __values(o) {
  var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
  if (m) return m.call(o);
  if (o && typeof o.length === "number") return {
      next: function () {
          if (o && i >= o.length) o = void 0;
          return { value: o && o[i++], done: !o };
      }
  };
  throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
}

function __read(o, n) {
  var m = typeof Symbol === "function" && o[Symbol.iterator];
  if (!m) return o;
  var i = m.call(o), r, ar = [], e;
  try {
      while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
  }
  catch (error) { e = { error: error }; }
  finally {
      try {
          if (r && !r.done && (m = i["return"])) m.call(i);
      }
      finally { if (e) throw e.error; }
  }
  return ar;
}

/** @deprecated */
function __spread() {
  for (var ar = [], i = 0; i < arguments.length; i++)
      ar = ar.concat(__read(arguments[i]));
  return ar;
}

/** @deprecated */
function __spreadArrays() {
  for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
  for (var r = Array(s), k = 0, i = 0; i < il; i++)
      for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
          r[k] = a[j];
  return r;
}

function __spreadArray(to, from, pack) {
  if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
      if (ar || !(i in from)) {
          if (!ar) ar = Array.prototype.slice.call(from, 0, i);
          ar[i] = from[i];
      }
  }
  return to.concat(ar || Array.prototype.slice.call(from));
}

function __await(v) {
  return this instanceof __await ? (this.v = v, this) : new __await(v);
}

function __asyncGenerator(thisArg, _arguments, generator) {
  if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
  var g = generator.apply(thisArg, _arguments || []), i, q = [];
  return i = Object.create((typeof AsyncIterator === "function" ? AsyncIterator : Object).prototype), verb("next"), verb("throw"), verb("return", awaitReturn), i[Symbol.asyncIterator] = function () { return this; }, i;
  function awaitReturn(f) { return function (v) { return Promise.resolve(v).then(f, reject); }; }
  function verb(n, f) { if (g[n]) { i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; if (f) i[n] = f(i[n]); } }
  function resume(n, v) { try { step(g[n](v)); } catch (e) { settle(q[0][3], e); } }
  function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
  function fulfill(value) { resume("next", value); }
  function reject(value) { resume("throw", value); }
  function settle(f, v) { if (f(v), q.shift(), q.length) resume(q[0][0], q[0][1]); }
}

function __asyncDelegator(o) {
  var i, p;
  return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
  function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: false } : f ? f(v) : v; } : f; }
}

function __asyncValues(o) {
  if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
  var m = o[Symbol.asyncIterator], i;
  return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
  function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
  function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
}

function __makeTemplateObject(cooked, raw) {
  if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
  return cooked;
};

var __setModuleDefault = Object.create ? (function(o, v) {
  Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
  o["default"] = v;
};

var ownKeys = function(o) {
  ownKeys = Object.getOwnPropertyNames || function (o) {
    var ar = [];
    for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
    return ar;
  };
  return ownKeys(o);
};

function __importStar(mod) {
  if (mod && mod.__esModule) return mod;
  var result = {};
  if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
  __setModuleDefault(result, mod);
  return result;
}

function __importDefault(mod) {
  return (mod && mod.__esModule) ? mod : { default: mod };
}

function __classPrivateFieldGet(receiver, state, kind, f) {
  if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
  if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
  return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
}

function __classPrivateFieldSet(receiver, state, value, kind, f) {
  if (kind === "m") throw new TypeError("Private method is not writable");
  if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
  if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
  return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
}

function __classPrivateFieldIn(state, receiver) {
  if (receiver === null || (typeof receiver !== "object" && typeof receiver !== "function")) throw new TypeError("Cannot use 'in' operator on non-object");
  return typeof state === "function" ? receiver === state : state.has(receiver);
}

function __addDisposableResource(env, value, async) {
  if (value !== null && value !== void 0) {
    if (typeof value !== "object" && typeof value !== "function") throw new TypeError("Object expected.");
    var dispose, inner;
    if (async) {
      if (!Symbol.asyncDispose) throw new TypeError("Symbol.asyncDispose is not defined.");
      dispose = value[Symbol.asyncDispose];
    }
    if (dispose === void 0) {
      if (!Symbol.dispose) throw new TypeError("Symbol.dispose is not defined.");
      dispose = value[Symbol.dispose];
      if (async) inner = dispose;
    }
    if (typeof dispose !== "function") throw new TypeError("Object not disposable.");
    if (inner) dispose = function() { try { inner.call(this); } catch (e) { return Promise.reject(e); } };
    env.stack.push({ value: value, dispose: dispose, async: async });
  }
  else if (async) {
    env.stack.push({ async: true });
  }
  return value;
}

var _SuppressedError = typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
  var e = new Error(message);
  return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

function __disposeResources(env) {
  function fail(e) {
    env.error = env.hasError ? new _SuppressedError(e, env.error, "An error was suppressed during disposal.") : e;
    env.hasError = true;
  }
  var r, s = 0;
  function next() {
    while (r = env.stack.pop()) {
      try {
        if (!r.async && s === 1) return s = 0, env.stack.push(r), Promise.resolve().then(next);
        if (r.dispose) {
          var result = r.dispose.call(r.value);
          if (r.async) return s |= 2, Promise.resolve(result).then(next, function(e) { fail(e); return next(); });
        }
        else s |= 1;
      }
      catch (e) {
        fail(e);
      }
    }
    if (s === 1) return env.hasError ? Promise.reject(env.error) : Promise.resolve();
    if (env.hasError) throw env.error;
  }
  return next();
}

function __rewriteRelativeImportExtension(path, preserveJsx) {
  if (typeof path === "string" && /^\.\.?\//.test(path)) {
      return path.replace(/\.(tsx)$|((?:\.d)?)((?:\.[^./]+?)?)\.([cm]?)ts$/i, function (m, tsx, d, ext, cm) {
          return tsx ? preserveJsx ? ".jsx" : ".js" : d && (!ext || !cm) ? m : (d + ext + "." + cm.toLowerCase() + "js");
      });
  }
  return path;
}

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ({
  __extends,
  __assign,
  __rest,
  __decorate,
  __param,
  __esDecorate,
  __runInitializers,
  __propKey,
  __setFunctionName,
  __metadata,
  __awaiter,
  __generator,
  __createBinding,
  __exportStar,
  __values,
  __read,
  __spread,
  __spreadArrays,
  __spreadArray,
  __await,
  __asyncGenerator,
  __asyncDelegator,
  __asyncValues,
  __makeTemplateObject,
  __importStar,
  __importDefault,
  __classPrivateFieldGet,
  __classPrivateFieldSet,
  __classPrivateFieldIn,
  __addDisposableResource,
  __disposeResources,
  __rewriteRelativeImportExtension,
});


/***/ }),

/***/ "react":
/*!************************!*\
  !*** external "React" ***!
  \************************/
/***/ ((module) => {

"use strict";
module.exports = React;

/***/ }),

/***/ "react-dom":
/*!***************************!*\
  !*** external "ReactDOM" ***!
  \***************************/
/***/ ((module) => {

"use strict";
module.exports = ReactDOM;

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId](module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = __webpack_modules__;
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	(() => {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = (module) => {
/******/ 			var getter = module && module.__esModule ?
/******/ 				() => (module['default']) :
/******/ 				() => (module);
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/create fake namespace object */
/******/ 	(() => {
/******/ 		var getProto = Object.getPrototypeOf ? (obj) => (Object.getPrototypeOf(obj)) : (obj) => (obj.__proto__);
/******/ 		var leafPrototypes;
/******/ 		// create a fake namespace object
/******/ 		// mode & 1: value is a module id, require it
/******/ 		// mode & 2: merge all properties of value into the ns
/******/ 		// mode & 4: return value when already ns object
/******/ 		// mode & 16: return value when it's Promise-like
/******/ 		// mode & 8|1: behave like require
/******/ 		__webpack_require__.t = function(value, mode) {
/******/ 			if(mode & 1) value = this(value);
/******/ 			if(mode & 8) return value;
/******/ 			if(typeof value === 'object' && value) {
/******/ 				if((mode & 4) && value.__esModule) return value;
/******/ 				if((mode & 16) && typeof value.then === 'function') return value;
/******/ 			}
/******/ 			var ns = Object.create(null);
/******/ 			__webpack_require__.r(ns);
/******/ 			var def = {};
/******/ 			leafPrototypes = leafPrototypes || [null, getProto({}), getProto([]), getProto(getProto)];
/******/ 			for(var current = mode & 2 && value; (typeof current == 'object' || typeof current == 'function') && !~leafPrototypes.indexOf(current); current = getProto(current)) {
/******/ 				Object.getOwnPropertyNames(current).forEach((key) => (def[key] = () => (value[key])));
/******/ 			}
/******/ 			def['default'] = () => (value);
/******/ 			__webpack_require__.d(ns, def);
/******/ 			return ns;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/ensure chunk */
/******/ 	(() => {
/******/ 		__webpack_require__.f = {};
/******/ 		// This file contains only the entry chunk.
/******/ 		// The chunk loading function for additional chunks
/******/ 		__webpack_require__.e = (chunkId) => {
/******/ 			return Promise.all(Object.keys(__webpack_require__.f).reduce((promises, key) => {
/******/ 				__webpack_require__.f[key](chunkId, promises);
/******/ 				return promises;
/******/ 			}, []));
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/get javascript chunk filename */
/******/ 	(() => {
/******/ 		// This function allow to reference async chunks
/******/ 		__webpack_require__.u = (chunkId) => {
/******/ 			// return url for filenames not based on template
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_de_assets-whatsnew_json") return "220e9c3d1caa01726b1a.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_de_common_json") return "59845ab5a628d2b79f57.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_de_send-feedback_json") return "32f7c5e8db4c8976b254.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_en_assets-whatsnew_json") return "7698e0d50a8ad7ecc822.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_en_common_json") return "40d841f4b4ce7b1928f5.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_en_send-feedback_json") return "4c96eab5a48ee097dcb2.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_es_assets-whatsnew_json") return "df4ff09f2b412abf0cd3.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_es_common_json") return "de7511b88f9ec0968921.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_es_send-feedback_json") return "979a9c03fe10da23400d.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_fr_assets-whatsnew_json") return "a0f667abb781daab8e48.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_fr_common_json") return "e9a764dcd37c06162942.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_fr_send-feedback_json") return "fdda4547e887fbda71b3.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_he-IL_assets-whatsnew_json") return "29c342e9c10e3f13f498.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_he-IL_common_json") return "b4d39e5186d768f79598.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_he-IL_send-feedback_json") return "df2f2a2ae20e0181ec2d.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_id-ID_assets-whatsnew_json") return "0982f37bec0944fbcb10.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_id-ID_common_json") return "8e8b47ad5b4e4d038c80.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_id-ID_send-feedback_json") return "d4c67aa71d8173f6201f.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_it_assets-whatsnew_json") return "8c20eb5e96967d3016b2.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_it_common_json") return "012778ff5828d0d1739f.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_it_send-feedback_json") return "2140afa714e988f1069e.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_nl_assets-whatsnew_json") return "9ffe53753902b9aca176.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_nl_common_json") return "831aea236b1ddda24f0c.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_nl_send-feedback_json") return "9e7e356552c03a622b0f.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_pl-PL_assets-whatsnew_json") return "cf6ec600fcf4e08ba6d3.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_pl-PL_common_json") return "7dae73b622bebe8a5d94.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_pl-PL_send-feedback_json") return "6844b6c0a66040e3ca12.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_pt-BR_assets-whatsnew_json") return "06dbd869189450c5db6c.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_pt-BR_common_json") return "5b575dffd21b0cec15a5.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_pt-BR_send-feedback_json") return "8e80438d29fc79b648e5.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_pt-PT_assets-whatsnew_json") return "af05aac2eb23e7438265.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_pt-PT_common_json") return "a9c3d5b02d26399aebfb.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_pt-PT_send-feedback_json") return "0352e30f394e8e1dd4dc.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_tr-TR_assets-whatsnew_json") return "8ecfd8495b7ec419862a.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_tr-TR_common_json") return "ef35c83e4628f0a5c328.bundle.js";
/******/ 			if (chunkId === "node_modules_elementor_elementor-one-assets_locales_tr-TR_send-feedback_json") return "6117d083decd13b6ed73.bundle.js";
/******/ 			// return url for filenames based on template
/******/ 			return undefined;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/global */
/******/ 	(() => {
/******/ 		__webpack_require__.g = (function() {
/******/ 			if (typeof globalThis === 'object') return globalThis;
/******/ 			try {
/******/ 				return this || new Function('return this')();
/******/ 			} catch (e) {
/******/ 				if (typeof window === 'object') return window;
/******/ 			}
/******/ 		})();
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/load script */
/******/ 	(() => {
/******/ 		var inProgress = {};
/******/ 		var dataWebpackPrefix = "elementor:";
/******/ 		// loadScript function to load a script via script tag
/******/ 		__webpack_require__.l = (url, done, key, chunkId) => {
/******/ 			if(inProgress[url]) { inProgress[url].push(done); return; }
/******/ 			var script, needAttach;
/******/ 			if(key !== undefined) {
/******/ 				var scripts = document.getElementsByTagName("script");
/******/ 				for(var i = 0; i < scripts.length; i++) {
/******/ 					var s = scripts[i];
/******/ 					if(s.getAttribute("src") == url || s.getAttribute("data-webpack") == dataWebpackPrefix + key) { script = s; break; }
/******/ 				}
/******/ 			}
/******/ 			if(!script) {
/******/ 				needAttach = true;
/******/ 				script = document.createElement('script');
/******/ 		
/******/ 				script.charset = 'utf-8';
/******/ 				if (__webpack_require__.nc) {
/******/ 					script.setAttribute("nonce", __webpack_require__.nc);
/******/ 				}
/******/ 				script.setAttribute("data-webpack", dataWebpackPrefix + key);
/******/ 		
/******/ 				script.src = url;
/******/ 			}
/******/ 			inProgress[url] = [done];
/******/ 			var onScriptComplete = (prev, event) => {
/******/ 				// avoid mem leaks in IE.
/******/ 				script.onerror = script.onload = null;
/******/ 				clearTimeout(timeout);
/******/ 				var doneFns = inProgress[url];
/******/ 				delete inProgress[url];
/******/ 				script.parentNode && script.parentNode.removeChild(script);
/******/ 				doneFns && doneFns.forEach((fn) => (fn(event)));
/******/ 				if(prev) return prev(event);
/******/ 			}
/******/ 			var timeout = setTimeout(onScriptComplete.bind(null, undefined, { type: 'timeout', target: script }), 120000);
/******/ 			script.onerror = onScriptComplete.bind(null, script.onerror);
/******/ 			script.onload = onScriptComplete.bind(null, script.onload);
/******/ 			needAttach && document.head.appendChild(script);
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	(() => {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = (exports) => {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/publicPath */
/******/ 	(() => {
/******/ 		var scriptUrl;
/******/ 		if (__webpack_require__.g.importScripts) scriptUrl = __webpack_require__.g.location + "";
/******/ 		var document = __webpack_require__.g.document;
/******/ 		if (!scriptUrl && document) {
/******/ 			if (document.currentScript && document.currentScript.tagName.toUpperCase() === 'SCRIPT')
/******/ 				scriptUrl = document.currentScript.src;
/******/ 			if (!scriptUrl) {
/******/ 				var scripts = document.getElementsByTagName("script");
/******/ 				if(scripts.length) {
/******/ 					var i = scripts.length - 1;
/******/ 					while (i > -1 && (!scriptUrl || !/^http(s?):/.test(scriptUrl))) scriptUrl = scripts[i--].src;
/******/ 				}
/******/ 			}
/******/ 		}
/******/ 		// When supporting browsers where an automatic publicPath is not supported you must specify an output.publicPath manually via configuration
/******/ 		// or pass an empty string ("") and set the __webpack_public_path__ variable from your code to use your own logic.
/******/ 		if (!scriptUrl) throw new Error("Automatic publicPath is not supported in this browser");
/******/ 		scriptUrl = scriptUrl.replace(/^blob:/, "").replace(/#.*$/, "").replace(/\?.*$/, "").replace(/\/[^\/]+$/, "/");
/******/ 		__webpack_require__.p = scriptUrl;
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/jsonp chunk loading */
/******/ 	(() => {
/******/ 		// no baseURI
/******/ 		
/******/ 		// object to store loaded and loading chunks
/******/ 		// undefined = chunk not loaded, null = chunk preloaded/prefetched
/******/ 		// [resolve, reject, Promise] = chunk loading, 0 = chunk loaded
/******/ 		var installedChunks = {
/******/ 			"editor-one-top-bar": 0
/******/ 		};
/******/ 		
/******/ 		__webpack_require__.f.j = (chunkId, promises) => {
/******/ 				// JSONP chunk loading for javascript
/******/ 				var installedChunkData = __webpack_require__.o(installedChunks, chunkId) ? installedChunks[chunkId] : undefined;
/******/ 				if(installedChunkData !== 0) { // 0 means "already installed".
/******/ 		
/******/ 					// a Promise means "currently loading".
/******/ 					if(installedChunkData) {
/******/ 						promises.push(installedChunkData[2]);
/******/ 					} else {
/******/ 						if(true) { // all chunks have JS
/******/ 							// setup Promise in chunk cache
/******/ 							var promise = new Promise((resolve, reject) => (installedChunkData = installedChunks[chunkId] = [resolve, reject]));
/******/ 							promises.push(installedChunkData[2] = promise);
/******/ 		
/******/ 							// start chunk loading
/******/ 							var url = __webpack_require__.p + __webpack_require__.u(chunkId);
/******/ 							// create error before stack unwound to get useful stacktrace later
/******/ 							var error = new Error();
/******/ 							var loadingEnded = (event) => {
/******/ 								if(__webpack_require__.o(installedChunks, chunkId)) {
/******/ 									installedChunkData = installedChunks[chunkId];
/******/ 									if(installedChunkData !== 0) installedChunks[chunkId] = undefined;
/******/ 									if(installedChunkData) {
/******/ 										var errorType = event && (event.type === 'load' ? 'missing' : event.type);
/******/ 										var realSrc = event && event.target && event.target.src;
/******/ 										error.message = 'Loading chunk ' + chunkId + ' failed.\n(' + errorType + ': ' + realSrc + ')';
/******/ 										error.name = 'ChunkLoadError';
/******/ 										error.type = errorType;
/******/ 										error.request = realSrc;
/******/ 										installedChunkData[1](error);
/******/ 									}
/******/ 								}
/******/ 							};
/******/ 							__webpack_require__.l(url, loadingEnded, "chunk-" + chunkId, chunkId);
/******/ 						}
/******/ 					}
/******/ 				}
/******/ 		};
/******/ 		
/******/ 		// no prefetching
/******/ 		
/******/ 		// no preloaded
/******/ 		
/******/ 		// no HMR
/******/ 		
/******/ 		// no HMR manifest
/******/ 		
/******/ 		// no on chunks loaded
/******/ 		
/******/ 		// install a JSONP callback for chunk loading
/******/ 		var webpackJsonpCallback = (parentChunkLoadingFunction, data) => {
/******/ 			var [chunkIds, moreModules, runtime] = data;
/******/ 			// add "moreModules" to the modules object,
/******/ 			// then flag all "chunkIds" as loaded and fire callback
/******/ 			var moduleId, chunkId, i = 0;
/******/ 			if(chunkIds.some((id) => (installedChunks[id] !== 0))) {
/******/ 				for(moduleId in moreModules) {
/******/ 					if(__webpack_require__.o(moreModules, moduleId)) {
/******/ 						__webpack_require__.m[moduleId] = moreModules[moduleId];
/******/ 					}
/******/ 				}
/******/ 				if(runtime) var result = runtime(__webpack_require__);
/******/ 			}
/******/ 			if(parentChunkLoadingFunction) parentChunkLoadingFunction(data);
/******/ 			for(;i < chunkIds.length; i++) {
/******/ 				chunkId = chunkIds[i];
/******/ 				if(__webpack_require__.o(installedChunks, chunkId) && installedChunks[chunkId]) {
/******/ 					installedChunks[chunkId][0]();
/******/ 				}
/******/ 				installedChunks[chunkId] = 0;
/******/ 			}
/******/ 		
/******/ 		}
/******/ 		
/******/ 		var chunkLoadingGlobal = self["webpackChunkelementor"] = self["webpackChunkelementor"] || [];
/******/ 		chunkLoadingGlobal.forEach(webpackJsonpCallback.bind(null, 0));
/******/ 		chunkLoadingGlobal.push = webpackJsonpCallback.bind(null, chunkLoadingGlobal.push.bind(chunkLoadingGlobal));
/******/ 	})();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};
// This entry needs to be wrapped in an IIFE because it needs to be in strict mode.
(() => {
"use strict";
/*!******************************************************!*\
  !*** ../modules/editor-one/assets/js/top-bar/app.js ***!
  \******************************************************/


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "../node_modules/@babel/runtime/helpers/interopRequireDefault.js");
var _react = _interopRequireDefault(__webpack_require__(/*! react */ "react"));
var _react2 = _interopRequireDefault(__webpack_require__(/*! elementor-utils/react */ "../assets/dev/js/utils/react.js"));
var _elementorOneAssets = __webpack_require__(/*! @elementor/elementor-one-assets */ "../node_modules/@elementor/elementor-one-assets/index.cjs.js");
var _useAdminMenuOffset = __webpack_require__(/*! ../sidebar-navigation/components/hooks/use-admin-menu-offset */ "../modules/editor-one/assets/js/sidebar-navigation/components/hooks/use-admin-menu-offset.js");
var _isRtl = _interopRequireDefault(__webpack_require__(/*! ../shared/is-rtl */ "../modules/editor-one/assets/js/shared/is-rtl.js"));
var App = function App() {
  var _window = window,
    _window$elementorOneT = _window.elementorOneTopBarConfig,
    version = _window$elementorOneT.version,
    title = _window$elementorOneT.title,
    environment = _window$elementorOneT.environment;
  var isRtlLanguage = (0, _isRtl.default)();
  (0, _useAdminMenuOffset.useAdminMenuOffset)();
  return /*#__PURE__*/_react.default.createElement(_elementorOneAssets.ElementorOneAssetsProvider, {
    env: environment,
    isRTL: isRtlLanguage
  }, /*#__PURE__*/_react.default.createElement(_elementorOneAssets.ElementorOneHeader, {
    appSettings: {
      slug: 'elementor',
      version: version
    },
    isWithinWpAdmin: true,
    title: title
  }));
};
var rootElement = document.getElementById('editor-one-top-bar');
if (rootElement) {
  _react2.default.render(/*#__PURE__*/_react.default.createElement(App, null), rootElement);
}
})();

/******/ })()
;
//# sourceMappingURL=editor-one-top-bar.js.map